(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   2520881,      43937]
NotebookOptionsPosition[   2520383,      43916]
NotebookOutlinePosition[   2520723,      43931]
CellTagsIndexPosition[   2520680,      43928]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "CassegrainTelescope", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inch", "=", "25.4"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CassegrainTelescope", "[", 
    RowBox[{
    "fnumber_", ",", "bigdiameter_", ",", "smalldiameter_", ",", 
     "eyepieceposition_", ",", "options___"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "bigmirrorthickness", ",", "smallmirrorthickness", ",", "focallength1", 
       ",", "focallength2", ",", "gamma", ",", "position", ",", 
       "holediameter"}], "}"}], ",", 
     RowBox[{
      RowBox[{"bigmirrorthickness", "=", 
       RowBox[{"bigdiameter", "/", "10"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"smallmirrorthickness", "=", 
       RowBox[{"smalldiameter", "/", "10"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"focallength1", "=", 
       RowBox[{"fnumber", " ", "bigdiameter"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"position", "=", 
       RowBox[{"N", "[", 
        RowBox[{"smalldiameter", " ", 
         RowBox[{"focallength1", "/", "bigdiameter"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"gamma", "=", 
       RowBox[{"N", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "focallength1", "-", "position", "+", "eyepieceposition", "+", 
           "bigmirrorthickness"}], ")"}], "/", "position"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"focallength2", "=", 
       RowBox[{"-", 
        RowBox[{"N", "[", 
         RowBox[{"position", " ", 
          RowBox[{"gamma", "/", 
           RowBox[{"(", 
            RowBox[{"gamma", "-", "1"}], ")"}]}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"holediameter", "=", 
       RowBox[{"N", "[", 
        RowBox[{".75", " ", "smalldiameter"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Resonate", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"ParabolicMirror", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"mf1", ",", " ", "focallength1"}], "}"}], ",", " ", 
               "bigdiameter", ",", "bigmirrorthickness", ",", "options", ",", 
               
               RowBox[{"Hole", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{"HoleDiameter", ",", " ", "holediameter"}], 
                 "}"}]}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"Mx1", ",", " ", 
               RowBox[{"-", "focallength1"}]}], "}"}], ",", "180"}], "]"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"ParabolicMirror", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"mf2", ",", " ", "focallength2"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"md2", ",", " ", "smalldiameter"}], "}"}], ",", 
               "smallmirrorthickness", ",", "options"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"Mx2", ",", " ", 
               RowBox[{"-", "position"}]}], "}"}]}], "]"}]}], "}"}], "]"}], 
        ",", "\[IndentingNewLine]", "     ", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"CylinderGraphic", "[", 
           RowBox[{"bigdiameter", ",", 
            RowBox[{"-", 
             RowBox[{"N", "[", 
              RowBox[{
               RowBox[{".1", " ", "bigdiameter"}], "+", 
               RowBox[{".1", " ", "smalldiameter"}], "+", "focallength1", "-",
                "position"}], "]"}]}], ",", "options"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "position"}], "+", 
             RowBox[{".05", " ", "bigdiameter"}]}], ",", "0", ",", "0"}], 
           "}"}]}], "]"}], ",", 
        RowBox[{"Boundary", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"N", "[", 
              RowBox[{"1.25", 
               RowBox[{"(", 
                RowBox[{"focallength1", "+", "eyepieceposition"}], ")"}]}], 
              "]"}]}], ",", 
            RowBox[{
             RowBox[{"-", "bigdiameter"}], "/", "2"}], ",", 
            RowBox[{
             RowBox[{"-", "bigdiameter"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1.5", "eyepieceposition"}], ",", 
            RowBox[{"bigdiameter", "/", "2"}], ",", 
            RowBox[{"bigdiameter", "/", "2"}]}], "}"}]}], "]"}]}], "}"}]}]}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.417565769883215*^9, 3.4175657901009703`*^9}, {
  3.417565832135276*^9, 3.417565923254533*^9}, {3.4175659652725554`*^9, 
  3.417566014542016*^9}, {3.41756705107544*^9, 3.417567114372313*^9}, {
  3.4175681445714417`*^9, 3.4175681705678263`*^9}, {3.4175682443791943`*^9, 
  3.417568253679315*^9}, {3.417568384595335*^9, 3.417568407719339*^9}, {
  3.417568602174498*^9, 3.4175686051442327`*^9}, {3.41760525202143*^9, 
  3.4176052585352163`*^9}, {3.510626676400804*^9, 3.510626713203479*^9}, {
  3.510626751689386*^9, 3.5106267543857183`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DrawSystem", "[", "\n", 
   RowBox[{
    RowBox[{"Move", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"CircleOfRays", "[", 
           RowBox[{
            RowBox[{"15", " ", "inch"}], ",", " ", 
            RowBox[{"NumberOfRays", "->", "6"}]}], "]"}], ",", 
          RowBox[{"15", " ", "inch"}], ",", "180"}], "]"}], ",", "\n", "\t", 
        RowBox[{"CassegrainTelescope", "[", 
         RowBox[{"2.5", ",", 
          RowBox[{"20", " ", "inch"}], ",", 
          RowBox[{"4", " ", "inch"}], ",", 
          RowBox[{"10", " ", "inch"}], ",", " ", 
          RowBox[{"OpenSide", "->", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               StyleBox["-",
                FontFamily->"Symbol",
                FontWeight->"Plain"], ".25"}], " ", "Pi"}], ",", 
             RowBox[{"1.3", " ", "Pi"}]}], "}"}]}], ",", " ", 
          RowBox[{"GraphicDesign", "->", "Solid"}]}], "]"}]}], "}"}], ",", 
      "\n", "\t", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "90"}], "}"}]}], "]"}], ",", 
    RowBox[{"Boxed", "->", "False"}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1269.71425, -38.099999999999994`, 
      90.}, {-1267.6152222222222`, -110.06666666666666`, 
      90.}, {-1267.6152222222222`, -106.31623594688342`, 
      118.4873495642841}, {-1269.71425, -36.80177398161349, 
      99.86100561840604}, {-1269.71425, -38.099999999999994`, 90.}}], 
     Polygon3DBox[{{-1269.71425, -36.80177398161349, 
      99.86100561840604}, {-1267.6152222222222`, -106.31623594688342`, 
      118.4873495642841}, {-1267.6152222222224`, -95.32052944320719, 
      145.03333333333333`}, {-1269.71425, -32.9955678841871, 
      109.05}, {-1269.71425, -36.80177398161349, 99.86100561840604}}], 
     Polygon3DBox[{{-1269.71425, -32.9955678841871, 
      109.05}, {-1267.6152222222224`, -95.32052944320719, 
      145.03333333333333`}, {-1267.6152222222222`, -77.82888638259932, 
      167.8288863825993}, {-1269.71425, -26.940768363207454`, 
      116.94076836320745`}, {-1269.71425, -32.9955678841871, 109.05}}], 
     Polygon3DBox[{{-1269.71425, -26.940768363207454`, 
      116.94076836320745`}, {-1267.6152222222222`, -77.82888638259932, 
      167.8288863825993}, {-1267.6152222222224`, -55.03333333333333, 
      185.3205294432072}, {-1269.71425, -19.049999999999997`, 
      122.9955678841871}, {-1269.71425, -26.940768363207454`, 
      116.94076836320745`}}], 
     Polygon3DBox[{{-1269.71425, -19.049999999999997`, 
      122.9955678841871}, {-1267.6152222222224`, -55.03333333333333, 
      185.3205294432072}, {-1267.6152222222222`, -28.48734956428411, 
      196.3162359468834}, {-1269.71425, -9.861005618406038, 
      126.8017739816135}, {-1269.71425, -19.049999999999997`, 
      122.9955678841871}}], 
     Polygon3DBox[{{-1269.71425, -9.861005618406038, 
      126.8017739816135}, {-1267.6152222222222`, -28.48734956428411, 
      196.3162359468834}, {-1267.6152222222222`, 0., 
      200.06666666666666`}, {-1269.71425, 0., 
      128.1}, {-1269.71425, -9.861005618406038, 126.8017739816135}}], 
     Polygon3DBox[{{-1269.71425, 0., 128.1}, {-1267.6152222222222`, 0., 
      200.06666666666666`}, {-1267.6152222222222`, 28.48734956428411, 
      196.3162359468834}, {-1269.71425, 9.861005618406038, 
      126.8017739816135}, {-1269.71425, 0., 128.1}}], 
     Polygon3DBox[{{-1269.71425, 9.861005618406038, 
      126.8017739816135}, {-1267.6152222222222`, 28.48734956428411, 
      196.3162359468834}, {-1267.6152222222224`, 55.03333333333333, 
      185.3205294432072}, {-1269.71425, 19.049999999999997`, 
      122.9955678841871}, {-1269.71425, 9.861005618406038, 
      126.8017739816135}}], 
     Polygon3DBox[{{-1269.71425, 19.049999999999997`, 
      122.9955678841871}, {-1267.6152222222224`, 55.03333333333333, 
      185.3205294432072}, {-1267.6152222222222`, 77.82888638259932, 
      167.8288863825993}, {-1269.71425, 26.940768363207454`, 
      116.94076836320745`}, {-1269.71425, 19.049999999999997`, 
      122.9955678841871}}], 
     Polygon3DBox[{{-1269.71425, 26.940768363207454`, 
      116.94076836320745`}, {-1267.6152222222222`, 77.82888638259932, 
      167.8288863825993}, {-1267.6152222222224`, 95.32052944320719, 
      145.03333333333333`}, {-1269.71425, 32.9955678841871, 
      109.05}, {-1269.71425, 26.940768363207454`, 116.94076836320745`}}], 
     Polygon3DBox[{{-1269.71425, 32.9955678841871, 
      109.05}, {-1267.6152222222224`, 95.32052944320719, 
      145.03333333333333`}, {-1267.6152222222222`, 106.31623594688342`, 
      118.4873495642841}, {-1269.71425, 36.80177398161349, 
      99.86100561840604}, {-1269.71425, 32.9955678841871, 109.05}}], 
     Polygon3DBox[{{-1269.71425, 36.80177398161349, 
      99.86100561840604}, {-1267.6152222222222`, 106.31623594688342`, 
      118.4873495642841}, {-1267.6152222222222`, 110.06666666666666`, 
      90.}, {-1269.71425, 38.099999999999994`, 90.}, {-1269.71425, 
      36.80177398161349, 99.86100561840604}}], 
     Polygon3DBox[{{-1269.71425, 38.099999999999994`, 
      90.}, {-1267.6152222222222`, 110.06666666666666`, 
      90.}, {-1267.6152222222222`, 106.31623594688342`, 
      61.51265043571589}, {-1269.71425, 36.80177398161349, 
      80.13899438159396}, {-1269.71425, 38.099999999999994`, 90.}}], 
     Polygon3DBox[{{-1269.71425, 36.80177398161349, 
      80.13899438159396}, {-1267.6152222222222`, 106.31623594688342`, 
      61.51265043571589}, {-1267.6152222222224`, 95.32052944320719, 
      34.96666666666667}, {-1269.71425, 32.9955678841871, 
      70.95}, {-1269.71425, 36.80177398161349, 80.13899438159396}}], 
     Polygon3DBox[{{-1269.71425, 32.9955678841871, 
      70.95}, {-1267.6152222222224`, 95.32052944320719, 
      34.96666666666667}, {-1267.6152222222222`, 77.82888638259932, 
      12.171113617400678`}, {-1269.71425, 26.940768363207454`, 
      63.059231636792546`}, {-1269.71425, 32.9955678841871, 70.95}}], 
     Polygon3DBox[{{-1269.71425, 26.940768363207454`, 
      63.059231636792546`}, {-1267.6152222222222`, 77.82888638259932, 
      12.171113617400678`}, {-1267.6152222222224`, 
      55.03333333333333, -5.320529443207192}, {-1269.71425, 
      19.049999999999997`, 57.0044321158129}, {-1269.71425, 
      26.940768363207454`, 63.059231636792546`}}], 
     Polygon3DBox[{{-1269.71425, 19.049999999999997`, 
      57.0044321158129}, {-1267.6152222222224`, 
      55.03333333333333, -5.320529443207192}, {-1267.6152222222222`, 
      28.48734956428411, -16.316235946883424`}, {-1269.71425, 
      9.861005618406038, 53.19822601838651}, {-1269.71425, 
      19.049999999999997`, 57.0044321158129}}], 
     Polygon3DBox[{{-1269.71425, 9.861005618406038, 
      53.19822601838651}, {-1267.6152222222222`, 
      28.48734956428411, -16.316235946883424`}, {-1267.6152222222222`, 
      0., -20.066666666666663`}, {-1269.71425, 0., 
      51.900000000000006`}, {-1269.71425, 9.861005618406038, 
      53.19822601838651}}], 
     Polygon3DBox[{{-1269.71425, 0., 
      51.900000000000006`}, {-1267.6152222222222`, 
      0., -20.066666666666663`}, {-1267.6152222222222`, -28.48734956428411, \
-16.316235946883424`}, {-1269.71425, -9.861005618406038, 
      53.19822601838651}, {-1269.71425, 0., 51.900000000000006`}}], 
     Polygon3DBox[{{-1269.71425, -9.861005618406038, 
      53.19822601838651}, {-1267.6152222222222`, -28.48734956428411, \
-16.316235946883424`}, {-1267.6152222222224`, -55.03333333333333, \
-5.320529443207192}, {-1269.71425, -19.049999999999997`, 
      57.0044321158129}, {-1269.71425, -9.861005618406038, 
      53.19822601838651}}], 
     Polygon3DBox[{{-1269.71425, -19.049999999999997`, 
      57.0044321158129}, {-1267.6152222222224`, -55.03333333333333, \
-5.320529443207192}, {-1267.6152222222222`, -77.82888638259932, 
      12.171113617400678`}, {-1269.71425, -26.940768363207454`, 
      63.059231636792546`}, {-1269.71425, -19.049999999999997`, 
      57.0044321158129}}], 
     Polygon3DBox[{{-1269.71425, -26.940768363207454`, 
      63.059231636792546`}, {-1267.6152222222222`, -77.82888638259932, 
      12.171113617400678`}, {-1267.6152222222224`, -95.32052944320719, 
      34.96666666666667}, {-1269.71425, -32.9955678841871, 
      70.95}, {-1269.71425, -26.940768363207454`, 63.059231636792546`}}], 
     Polygon3DBox[{{-1269.71425, -32.9955678841871, 
      70.95}, {-1267.6152222222224`, -95.32052944320719, 
      34.96666666666667}, {-1267.6152222222222`, -106.31623594688342`, 
      61.51265043571589}, {-1269.71425, -36.80177398161349, 
      80.13899438159396}, {-1269.71425, -32.9955678841871, 70.95}}], 
     Polygon3DBox[{{-1269.71425, -36.80177398161349, 
      80.13899438159396}, {-1267.6152222222222`, -106.31623594688342`, 
      61.51265043571589}, {-1267.6152222222222`, -110.06666666666666`, 
      90.}, {-1269.71425, -38.099999999999994`, 
      90.}, {-1269.71425, -36.80177398161349, 80.13899438159396}}], 
     Polygon3DBox[{{-1267.6152222222222`, -110.06666666666666`, 
      90.}, {-1263.477138888889, -182.03333333333333`, 
      90.}, {-1263.477138888889, -175.83069791215337`, 
      137.1136935101622}, {-1267.6152222222222`, -106.31623594688342`, 
      118.4873495642841}, {-1267.6152222222222`, -110.06666666666666`, 90.}}],
      Polygon3DBox[{{-1267.6152222222222`, -106.31623594688342`, 
      118.4873495642841}, {-1263.477138888889, -175.83069791215337`, 
      137.1136935101622}, {-1263.4771388888887`, -157.6454910022273, 
      181.01666666666665`}, {-1267.6152222222224`, -95.32052944320719, 
      145.03333333333333`}, {-1267.6152222222222`, -106.31623594688342`, 
      118.4873495642841}}], 
     Polygon3DBox[{{-1267.6152222222224`, -95.32052944320719, 
      145.03333333333333`}, {-1263.4771388888887`, -157.6454910022273, 
      181.01666666666665`}, {-1263.477138888889, -128.71700440199118`, 
      218.71700440199118`}, {-1267.6152222222222`, -77.82888638259932, 
      167.8288863825993}, {-1267.6152222222224`, -95.32052944320719, 
      145.03333333333333`}}], 
     Polygon3DBox[{{-1267.6152222222222`, -77.82888638259932, 
      167.8288863825993}, {-1263.477138888889, -128.71700440199118`, 
      218.71700440199118`}, {-1263.4771388888887`, -91.01666666666667, 
      247.6454910022273}, {-1267.6152222222224`, -55.03333333333333, 
      185.3205294432072}, {-1267.6152222222222`, -77.82888638259932, 
      167.8288863825993}}], 
     Polygon3DBox[{{-1267.6152222222224`, -55.03333333333333, 
      185.3205294432072}, {-1263.4771388888887`, -91.01666666666667, 
      247.6454910022273}, {-1263.477138888889, -47.113693510162186`, 
      265.83069791215337`}, {-1267.6152222222222`, -28.48734956428411, 
      196.3162359468834}, {-1267.6152222222224`, -55.03333333333333, 
      185.3205294432072}}], 
     Polygon3DBox[{{-1267.6152222222222`, -28.48734956428411, 
      196.3162359468834}, {-1263.477138888889, -47.113693510162186`, 
      265.83069791215337`}, {-1263.477138888889, 0., 
      272.0333333333333}, {-1267.6152222222222`, 0., 
      200.06666666666666`}, {-1267.6152222222222`, -28.48734956428411, 
      196.3162359468834}}], 
     Polygon3DBox[{{-1267.6152222222222`, 0., 
      200.06666666666666`}, {-1263.477138888889, 0., 
      272.0333333333333}, {-1263.477138888889, 47.113693510162186`, 
      265.83069791215337`}, {-1267.6152222222222`, 28.48734956428411, 
      196.3162359468834}, {-1267.6152222222222`, 0., 200.06666666666666`}}], 
     Polygon3DBox[{{-1267.6152222222222`, 28.48734956428411, 
      196.3162359468834}, {-1263.477138888889, 47.113693510162186`, 
      265.83069791215337`}, {-1263.4771388888887`, 91.01666666666667, 
      247.6454910022273}, {-1267.6152222222224`, 55.03333333333333, 
      185.3205294432072}, {-1267.6152222222222`, 28.48734956428411, 
      196.3162359468834}}], 
     Polygon3DBox[{{-1267.6152222222224`, 55.03333333333333, 
      185.3205294432072}, {-1263.4771388888887`, 91.01666666666667, 
      247.6454910022273}, {-1263.477138888889, 128.71700440199118`, 
      218.71700440199118`}, {-1267.6152222222222`, 77.82888638259932, 
      167.8288863825993}, {-1267.6152222222224`, 55.03333333333333, 
      185.3205294432072}}], 
     Polygon3DBox[{{-1267.6152222222222`, 77.82888638259932, 
      167.8288863825993}, {-1263.477138888889, 128.71700440199118`, 
      218.71700440199118`}, {-1263.4771388888887`, 157.6454910022273, 
      181.01666666666665`}, {-1267.6152222222224`, 95.32052944320719, 
      145.03333333333333`}, {-1267.6152222222222`, 77.82888638259932, 
      167.8288863825993}}], 
     Polygon3DBox[{{-1267.6152222222224`, 95.32052944320719, 
      145.03333333333333`}, {-1263.4771388888887`, 157.6454910022273, 
      181.01666666666665`}, {-1263.477138888889, 175.83069791215337`, 
      137.1136935101622}, {-1267.6152222222222`, 106.31623594688342`, 
      118.4873495642841}, {-1267.6152222222224`, 95.32052944320719, 
      145.03333333333333`}}], 
     Polygon3DBox[{{-1267.6152222222222`, 106.31623594688342`, 
      118.4873495642841}, {-1263.477138888889, 175.83069791215337`, 
      137.1136935101622}, {-1263.477138888889, 182.03333333333333`, 
      90.}, {-1267.6152222222222`, 110.06666666666666`, 
      90.}, {-1267.6152222222222`, 106.31623594688342`, 118.4873495642841}}], 
     Polygon3DBox[{{-1267.6152222222222`, 110.06666666666666`, 
      90.}, {-1263.477138888889, 182.03333333333333`, 
      90.}, {-1263.477138888889, 175.83069791215337`, 
      42.886306489837814`}, {-1267.6152222222222`, 106.31623594688342`, 
      61.51265043571589}, {-1267.6152222222222`, 110.06666666666666`, 90.}}], 
     Polygon3DBox[{{-1267.6152222222222`, 106.31623594688342`, 
      61.51265043571589}, {-1263.477138888889, 175.83069791215337`, 
      42.886306489837814`}, {-1263.4771388888887`, 
      157.6454910022273, -1.0166666666666657`}, {-1267.6152222222224`, 
      95.32052944320719, 34.96666666666667}, {-1267.6152222222222`, 
      106.31623594688342`, 61.51265043571589}}], 
     Polygon3DBox[{{-1267.6152222222224`, 95.32052944320719, 
      34.96666666666667}, {-1263.4771388888887`, 
      157.6454910022273, -1.0166666666666657`}, {-1263.477138888889, 
      128.71700440199118`, -38.717004401991176`}, {-1267.6152222222222`, 
      77.82888638259932, 12.171113617400678`}, {-1267.6152222222224`, 
      95.32052944320719, 34.96666666666667}}], 
     Polygon3DBox[{{-1267.6152222222222`, 77.82888638259932, 
      12.171113617400678`}, {-1263.477138888889, 
      128.71700440199118`, -38.717004401991176`}, {-1263.4771388888887`, 
      91.01666666666667, -67.64549100222729}, {-1267.6152222222224`, 
      55.03333333333333, -5.320529443207192}, {-1267.6152222222222`, 
      77.82888638259932, 12.171113617400678`}}], 
     Polygon3DBox[{{-1267.6152222222224`, 
      55.03333333333333, -5.320529443207192}, {-1263.4771388888887`, 
      91.01666666666667, -67.64549100222729}, {-1263.477138888889, 
      47.113693510162186`, -85.83069791215337}, {-1267.6152222222222`, 
      28.48734956428411, -16.316235946883424`}, {-1267.6152222222224`, 
      55.03333333333333, -5.320529443207192}}], 
     Polygon3DBox[{{-1267.6152222222222`, 
      28.48734956428411, -16.316235946883424`}, {-1263.477138888889, 
      47.113693510162186`, -85.83069791215337}, {-1263.477138888889, 
      0., -92.03333333333333}, {-1267.6152222222222`, 
      0., -20.066666666666663`}, {-1267.6152222222222`, 
      28.48734956428411, -16.316235946883424`}}], 
     Polygon3DBox[{{-1267.6152222222222`, 
      0., -20.066666666666663`}, {-1263.477138888889, 
      0., -92.03333333333333}, {-1263.477138888889, -47.113693510162186`, \
-85.83069791215337}, {-1267.6152222222222`, -28.48734956428411, \
-16.316235946883424`}, {-1267.6152222222222`, 0., -20.066666666666663`}}], 
     Polygon3DBox[{{-1267.6152222222222`, -28.48734956428411, \
-16.316235946883424`}, {-1263.477138888889, -47.113693510162186`, \
-85.83069791215337}, {-1263.4771388888887`, -91.01666666666667, \
-67.64549100222729}, {-1267.6152222222224`, -55.03333333333333, \
-5.320529443207192}, {-1267.6152222222222`, -28.48734956428411, \
-16.316235946883424`}}], 
     Polygon3DBox[{{-1267.6152222222224`, -55.03333333333333, \
-5.320529443207192}, {-1263.4771388888887`, -91.01666666666667, \
-67.64549100222729}, {-1263.477138888889, -128.71700440199118`, \
-38.717004401991176`}, {-1267.6152222222222`, -77.82888638259932, 
      12.171113617400678`}, {-1267.6152222222224`, -55.03333333333333, \
-5.320529443207192}}], 
     Polygon3DBox[{{-1267.6152222222222`, -77.82888638259932, 
      12.171113617400678`}, {-1263.477138888889, -128.71700440199118`, \
-38.717004401991176`}, {-1263.4771388888887`, -157.6454910022273, \
-1.0166666666666657`}, {-1267.6152222222224`, -95.32052944320719, 
      34.96666666666667}, {-1267.6152222222222`, -77.82888638259932, 
      12.171113617400678`}}], 
     Polygon3DBox[{{-1267.6152222222224`, -95.32052944320719, 
      34.96666666666667}, {-1263.4771388888887`, -157.6454910022273, \
-1.0166666666666657`}, {-1263.477138888889, -175.83069791215337`, 
      42.886306489837814`}, {-1267.6152222222222`, -106.31623594688342`, 
      61.51265043571589}, {-1267.6152222222224`, -95.32052944320719, 
      34.96666666666667}}], 
     Polygon3DBox[{{-1267.6152222222222`, -106.31623594688342`, 
      61.51265043571589}, {-1263.477138888889, -175.83069791215337`, 
      42.886306489837814`}, {-1263.477138888889, -182.03333333333333`, 
      90.}, {-1267.6152222222222`, -110.06666666666666`, 
      90.}, {-1267.6152222222222`, -106.31623594688342`, 61.51265043571589}}],
      Polygon3DBox[{{-1263.477138888889, -182.03333333333333`, 
      90.}, {-1257.3, -254., 
      90.}, {-1257.3000000000002`, -245.34515987742333`, 
      155.74003745604026`}, {-1263.477138888889, -175.83069791215337`, 
      137.1136935101622}, {-1263.477138888889, -182.03333333333333`, 90.}}], 
     Polygon3DBox[{{-1263.477138888889, -175.83069791215337`, 
      137.1136935101622}, {-1257.3000000000002`, -245.34515987742333`, 
      155.74003745604026`}, {-1257.3, -219.97045256124738`, 
      217.}, {-1263.4771388888887`, -157.6454910022273, 
      181.01666666666665`}, {-1263.477138888889, -175.83069791215337`, 
      137.1136935101622}}], 
     Polygon3DBox[{{-1263.4771388888887`, -157.6454910022273, 
      181.01666666666665`}, {-1257.3, -219.97045256124738`, 
      217.}, {-1257.3000000000002`, -179.60512242138304`, 
      269.60512242138304`}, {-1263.477138888889, -128.71700440199118`, 
      218.71700440199118`}, {-1263.4771388888887`, -157.6454910022273, 
      181.01666666666665`}}], 
     Polygon3DBox[{{-1263.477138888889, -128.71700440199118`, 
      218.71700440199118`}, {-1257.3000000000002`, -179.60512242138304`, 
      269.60512242138304`}, {-1257.3, -127., 
      309.9704525612474}, {-1263.4771388888887`, -91.01666666666667, 
      247.6454910022273}, {-1263.477138888889, -128.71700440199118`, 
      218.71700440199118`}}], 
     Polygon3DBox[{{-1263.4771388888887`, -91.01666666666667, 
      247.6454910022273}, {-1257.3, -127., 
      309.9704525612474}, {-1257.3000000000002`, -65.74003745604026, 
      335.3451598774233}, {-1263.477138888889, -47.113693510162186`, 
      265.83069791215337`}, {-1263.4771388888887`, -91.01666666666667, 
      247.6454910022273}}], 
     Polygon3DBox[{{-1263.477138888889, -47.113693510162186`, 
      265.83069791215337`}, {-1257.3000000000002`, -65.74003745604026, 
      335.3451598774233}, {-1257.3, 0., 344.}, {-1263.477138888889, 0., 
      272.0333333333333}, {-1263.477138888889, -47.113693510162186`, 
      265.83069791215337`}}], 
     Polygon3DBox[{{-1263.477138888889, 0., 272.0333333333333}, {-1257.3, 0., 
      344.}, {-1257.3000000000002`, 65.74003745604026, 
      335.3451598774233}, {-1263.477138888889, 47.113693510162186`, 
      265.83069791215337`}, {-1263.477138888889, 0., 272.0333333333333}}], 
     Polygon3DBox[{{-1263.477138888889, 47.113693510162186`, 
      265.83069791215337`}, {-1257.3000000000002`, 65.74003745604026, 
      335.3451598774233}, {-1257.3, 127., 
      309.9704525612474}, {-1263.4771388888887`, 91.01666666666667, 
      247.6454910022273}, {-1263.477138888889, 47.113693510162186`, 
      265.83069791215337`}}], 
     Polygon3DBox[{{-1263.4771388888887`, 91.01666666666667, 
      247.6454910022273}, {-1257.3, 127., 
      309.9704525612474}, {-1257.3000000000002`, 179.60512242138304`, 
      269.60512242138304`}, {-1263.477138888889, 128.71700440199118`, 
      218.71700440199118`}, {-1263.4771388888887`, 91.01666666666667, 
      247.6454910022273}}], 
     Polygon3DBox[{{-1263.477138888889, 128.71700440199118`, 
      218.71700440199118`}, {-1257.3000000000002`, 179.60512242138304`, 
      269.60512242138304`}, {-1257.3, 219.97045256124738`, 
      217.}, {-1263.4771388888887`, 157.6454910022273, 
      181.01666666666665`}, {-1263.477138888889, 128.71700440199118`, 
      218.71700440199118`}}], 
     Polygon3DBox[{{-1263.4771388888887`, 157.6454910022273, 
      181.01666666666665`}, {-1257.3, 219.97045256124738`, 
      217.}, {-1257.3000000000002`, 245.34515987742333`, 
      155.74003745604026`}, {-1263.477138888889, 175.83069791215337`, 
      137.1136935101622}, {-1263.4771388888887`, 157.6454910022273, 
      181.01666666666665`}}], 
     Polygon3DBox[{{-1263.477138888889, 175.83069791215337`, 
      137.1136935101622}, {-1257.3000000000002`, 245.34515987742333`, 
      155.74003745604026`}, {-1257.3, 254., 90.}, {-1263.477138888889, 
      182.03333333333333`, 90.}, {-1263.477138888889, 175.83069791215337`, 
      137.1136935101622}}], 
     Polygon3DBox[{{-1263.477138888889, 182.03333333333333`, 90.}, {-1257.3, 
      254., 90.}, {-1257.3000000000002`, 245.34515987742333`, 
      24.259962543959745`}, {-1263.477138888889, 175.83069791215337`, 
      42.886306489837814`}, {-1263.477138888889, 182.03333333333333`, 90.}}], 
     Polygon3DBox[{{-1263.477138888889, 175.83069791215337`, 
      42.886306489837814`}, {-1257.3000000000002`, 245.34515987742333`, 
      24.259962543959745`}, {-1257.3, 
      219.97045256124738`, -37.}, {-1263.4771388888887`, 
      157.6454910022273, -1.0166666666666657`}, {-1263.477138888889, 
      175.83069791215337`, 42.886306489837814`}}], 
     Polygon3DBox[{{-1263.4771388888887`, 
      157.6454910022273, -1.0166666666666657`}, {-1257.3, 
      219.97045256124738`, -37.}, {-1257.3000000000002`, 
      179.60512242138304`, -89.60512242138304}, {-1263.477138888889, 
      128.71700440199118`, -38.717004401991176`}, {-1263.4771388888887`, 
      157.6454910022273, -1.0166666666666657`}}], 
     Polygon3DBox[{{-1263.477138888889, 
      128.71700440199118`, -38.717004401991176`}, {-1257.3000000000002`, 
      179.60512242138304`, -89.60512242138304}, {-1257.3, 
      127., -129.97045256124738`}, {-1263.4771388888887`, 
      91.01666666666667, -67.64549100222729}, {-1263.477138888889, 
      128.71700440199118`, -38.717004401991176`}}], 
     Polygon3DBox[{{-1263.4771388888887`, 
      91.01666666666667, -67.64549100222729}, {-1257.3, 
      127., -129.97045256124738`}, {-1257.3000000000002`, 
      65.74003745604026, -155.34515987742333`}, {-1263.477138888889, 
      47.113693510162186`, -85.83069791215337}, {-1263.4771388888887`, 
      91.01666666666667, -67.64549100222729}}], 
     Polygon3DBox[{{-1263.477138888889, 
      47.113693510162186`, -85.83069791215337}, {-1257.3000000000002`, 
      65.74003745604026, -155.34515987742333`}, {-1257.3, 
      0., -164.}, {-1263.477138888889, 
      0., -92.03333333333333}, {-1263.477138888889, 
      47.113693510162186`, -85.83069791215337}}], 
     Polygon3DBox[{{-1263.477138888889, 0., -92.03333333333333}, {-1257.3, 
      0., -164.}, {-1257.3000000000002`, -65.74003745604026, \
-155.34515987742333`}, {-1263.477138888889, -47.113693510162186`, \
-85.83069791215337}, {-1263.477138888889, 0., -92.03333333333333}}], 
     Polygon3DBox[{{-1263.477138888889, -47.113693510162186`, \
-85.83069791215337}, {-1257.3000000000002`, -65.74003745604026, \
-155.34515987742333`}, {-1257.3, -127., -129.97045256124738`}, \
{-1263.4771388888887`, -91.01666666666667, -67.64549100222729}, \
{-1263.477138888889, -47.113693510162186`, -85.83069791215337}}], 
     Polygon3DBox[{{-1263.4771388888887`, -91.01666666666667, \
-67.64549100222729}, {-1257.3, -127., -129.97045256124738`}, \
{-1257.3000000000002`, -179.60512242138304`, -89.60512242138304}, \
{-1263.477138888889, -128.71700440199118`, -38.717004401991176`}, \
{-1263.4771388888887`, -91.01666666666667, -67.64549100222729}}], 
     Polygon3DBox[{{-1263.477138888889, -128.71700440199118`, \
-38.717004401991176`}, {-1257.3000000000002`, -179.60512242138304`, \
-89.60512242138304}, {-1257.3, -219.97045256124738`, -37.}, \
{-1263.4771388888887`, -157.6454910022273, -1.0166666666666657`}, \
{-1263.477138888889, -128.71700440199118`, -38.717004401991176`}}], 
     Polygon3DBox[{{-1263.4771388888887`, -157.6454910022273, \
-1.0166666666666657`}, {-1257.3, -219.97045256124738`, -37.}, \
{-1257.3000000000002`, -245.34515987742333`, 
      24.259962543959745`}, {-1263.477138888889, -175.83069791215337`, 
      42.886306489837814`}, {-1263.4771388888887`, -157.6454910022273, \
-1.0166666666666657`}}], 
     Polygon3DBox[{{-1263.477138888889, -175.83069791215337`, 
      42.886306489837814`}, {-1257.3000000000002`, -245.34515987742333`, 
      24.259962543959745`}, {-1257.3, -254., 
      90.}, {-1263.477138888889, -182.03333333333333`, 
      90.}, {-1263.477138888889, -175.83069791215337`, 42.886306489837814`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIF4jE5Vy+9rkA2dAgMf5AAMINIQ5wMTVXyxqX5Dm
dKBKz3+71PcIuDjXke1H8uodDhiDgHM0XDxVjNPo2gerAzNdm3pMbWLh4mfB
5hsfYHkUnbR9fxxc/Epx5a6rO5QPCJdcdA7YHA8X174+92E289M9YPOZExDm
QNQ7iKCpPwUx34ENzfwUiHsc0N3DCXG/gwma+9Ug/nWoRvMvNHwccISPQ/vF
DR5POULg4txQ88+B9O0JhItnQt1zoeT3synt/nDxi1D3/7D2sJ7Y4AMXvw/1
723x2Ir4mV5w8f2Hci4ptv63Abv/sydc/Bg0PG+iqT8CDf8vaOZDw+fAGTT3
cEDj9wya+1Wh6aEFzb+w9PMfBOrDHADzvzD2
       "]], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIDYGgaWTDzCAwIF8CN0Q5mACFZ+uu6uHe3XeAacP
7MnrypMdYOqF5rR/4q3PhqhXyIarD7XdpBlbnHZgldzNKetuFsDVM4HNjz/A
cc75Z1t8MVx9+wP+YzH5AQdOi8Uea/1aAlfvb7zu2c0mwb0Q95TC1TdC1Duc
QVP/5z8Q7I934EIzPwTiHgd09whA3O/AjOb+aRD/Orig+RcaPg5MaOEzA6pe
oO7A8x4nC7h6Yaj5P0Duqnc6AFMfAXXPoqqU4F1pYQdg6jkg4ePAD9JnnwBX
PwHq36kge7KT4eq/+bDecnPRsoWETwpcfTU0PGegqf8MCZ8DomjmQ8PnwBo0
9/BD41cAbD7C/VOh6WFPLap/YekHHA/1YQ4A2Cz0Pw==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-1320.8, -38.099999999999994`, 
        90.}, {-1320.8, -110.06666666666666`, 
        90.}, {-1320.8, -106.31623594688342`, 
        118.4873495642841}, {-1320.8, -36.80177398161349, 
        99.86100561840604}, {-1320.8, -38.099999999999994`, 90.}}], 
       Polygon3DBox[{{-1320.8, -36.80177398161349, 
        99.86100561840604}, {-1320.8, -106.31623594688342`, 
        118.4873495642841}, {-1320.8, -95.32052944320719, 
        145.03333333333333`}, {-1320.8, -32.9955678841871, 
        109.05}, {-1320.8, -36.80177398161349, 99.86100561840604}}], 
       Polygon3DBox[{{-1320.8, -32.9955678841871, 
        109.05}, {-1320.8, -95.32052944320719, 
        145.03333333333333`}, {-1320.8, -77.82888638259932, 
        167.8288863825993}, {-1320.8, -26.940768363207454`, 
        116.94076836320745`}, {-1320.8, -32.9955678841871, 109.05}}], 
       Polygon3DBox[{{-1320.8, -26.940768363207454`, 
        116.94076836320745`}, {-1320.8, -77.82888638259932, 
        167.8288863825993}, {-1320.8, -55.03333333333333, 
        185.3205294432072}, {-1320.8, -19.049999999999997`, 
        122.9955678841871}, {-1320.8, -26.940768363207454`, 
        116.94076836320745`}}], 
       Polygon3DBox[{{-1320.8, -19.049999999999997`, 
        122.9955678841871}, {-1320.8, -55.03333333333333, 
        185.3205294432072}, {-1320.8, -28.48734956428411, 
        196.3162359468834}, {-1320.8, -9.861005618406038, 
        126.8017739816135}, {-1320.8, -19.049999999999997`, 
        122.9955678841871}}], 
       Polygon3DBox[{{-1320.8, -9.861005618406038, 
        126.8017739816135}, {-1320.8, -28.48734956428411, 
        196.3162359468834}, {-1320.8, 0., 200.06666666666666`}, {-1320.8, 0., 
        128.1}, {-1320.8, -9.861005618406038, 126.8017739816135}}], 
       Polygon3DBox[{{-1320.8, 0., 128.1}, {-1320.8, 0., 
        200.06666666666666`}, {-1320.8, 28.48734956428411, 
        196.3162359468834}, {-1320.8, 9.861005618406038, 
        126.8017739816135}, {-1320.8, 0., 128.1}}], 
       Polygon3DBox[{{-1320.8, 9.861005618406038, 
        126.8017739816135}, {-1320.8, 28.48734956428411, 
        196.3162359468834}, {-1320.8, 55.03333333333333, 
        185.3205294432072}, {-1320.8, 19.049999999999997`, 
        122.9955678841871}, {-1320.8, 9.861005618406038, 126.8017739816135}}],
        Polygon3DBox[{{-1320.8, 19.049999999999997`, 
        122.9955678841871}, {-1320.8, 55.03333333333333, 
        185.3205294432072}, {-1320.8, 77.82888638259932, 
        167.8288863825993}, {-1320.8, 26.940768363207454`, 
        116.94076836320745`}, {-1320.8, 19.049999999999997`, 
        122.9955678841871}}], 
       Polygon3DBox[{{-1320.8, 26.940768363207454`, 
        116.94076836320745`}, {-1320.8, 77.82888638259932, 
        167.8288863825993}, {-1320.8, 95.32052944320719, 
        145.03333333333333`}, {-1320.8, 32.9955678841871, 109.05}, {-1320.8, 
        26.940768363207454`, 116.94076836320745`}}], 
       Polygon3DBox[{{-1320.8, 32.9955678841871, 109.05}, {-1320.8, 
        95.32052944320719, 145.03333333333333`}, {-1320.8, 
        106.31623594688342`, 118.4873495642841}, {-1320.8, 36.80177398161349, 
        99.86100561840604}, {-1320.8, 32.9955678841871, 109.05}}], 
       Polygon3DBox[{{-1320.8, 36.80177398161349, 
        99.86100561840604}, {-1320.8, 106.31623594688342`, 
        118.4873495642841}, {-1320.8, 110.06666666666666`, 90.}, {-1320.8, 
        38.099999999999994`, 90.}, {-1320.8, 36.80177398161349, 
        99.86100561840604}}], 
       Polygon3DBox[{{-1320.8, 38.099999999999994`, 90.}, {-1320.8, 
        110.06666666666666`, 90.}, {-1320.8, 106.31623594688342`, 
        61.51265043571589}, {-1320.8, 36.80177398161349, 
        80.13899438159396}, {-1320.8, 38.099999999999994`, 90.}}], 
       Polygon3DBox[{{-1320.8, 36.80177398161349, 
        80.13899438159396}, {-1320.8, 106.31623594688342`, 
        61.51265043571589}, {-1320.8, 95.32052944320719, 
        34.96666666666667}, {-1320.8, 32.9955678841871, 70.95}, {-1320.8, 
        36.80177398161349, 80.13899438159396}}], 
       Polygon3DBox[{{-1320.8, 32.9955678841871, 70.95}, {-1320.8, 
        95.32052944320719, 34.96666666666667}, {-1320.8, 77.82888638259932, 
        12.171113617400678`}, {-1320.8, 26.940768363207454`, 
        63.059231636792546`}, {-1320.8, 32.9955678841871, 70.95}}], 
       Polygon3DBox[{{-1320.8, 26.940768363207454`, 
        63.059231636792546`}, {-1320.8, 77.82888638259932, 
        12.171113617400678`}, {-1320.8, 
        55.03333333333333, -5.320529443207192}, {-1320.8, 19.049999999999997`,
         57.0044321158129}, {-1320.8, 26.940768363207454`, 
        63.059231636792546`}}], 
       Polygon3DBox[{{-1320.8, 19.049999999999997`, 
        57.0044321158129}, {-1320.8, 
        55.03333333333333, -5.320529443207192}, {-1320.8, 
        28.48734956428411, -16.316235946883424`}, {-1320.8, 9.861005618406038,
         53.19822601838651}, {-1320.8, 19.049999999999997`, 
        57.0044321158129}}], 
       Polygon3DBox[{{-1320.8, 9.861005618406038, 
        53.19822601838651}, {-1320.8, 
        28.48734956428411, -16.316235946883424`}, {-1320.8, 
        0., -20.066666666666663`}, {-1320.8, 0., 
        51.900000000000006`}, {-1320.8, 9.861005618406038, 
        53.19822601838651}}], 
       Polygon3DBox[{{-1320.8, 0., 51.900000000000006`}, {-1320.8, 
        0., -20.066666666666663`}, {-1320.8, -28.48734956428411, \
-16.316235946883424`}, {-1320.8, -9.861005618406038, 
        53.19822601838651}, {-1320.8, 0., 51.900000000000006`}}], 
       Polygon3DBox[{{-1320.8, -9.861005618406038, 
        53.19822601838651}, {-1320.8, -28.48734956428411, \
-16.316235946883424`}, {-1320.8, -55.03333333333333, -5.320529443207192}, \
{-1320.8, -19.049999999999997`, 
        57.0044321158129}, {-1320.8, -9.861005618406038, 53.19822601838651}}],
        Polygon3DBox[{{-1320.8, -19.049999999999997`, 
        57.0044321158129}, {-1320.8, -55.03333333333333, -5.320529443207192}, \
{-1320.8, -77.82888638259932, 
        12.171113617400678`}, {-1320.8, -26.940768363207454`, 
        63.059231636792546`}, {-1320.8, -19.049999999999997`, 
        57.0044321158129}}], 
       Polygon3DBox[{{-1320.8, -26.940768363207454`, 
        63.059231636792546`}, {-1320.8, -77.82888638259932, 
        12.171113617400678`}, {-1320.8, -95.32052944320719, 
        34.96666666666667}, {-1320.8, -32.9955678841871, 
        70.95}, {-1320.8, -26.940768363207454`, 63.059231636792546`}}], 
       Polygon3DBox[{{-1320.8, -32.9955678841871, 
        70.95}, {-1320.8, -95.32052944320719, 
        34.96666666666667}, {-1320.8, -106.31623594688342`, 
        61.51265043571589}, {-1320.8, -36.80177398161349, 
        80.13899438159396}, {-1320.8, -32.9955678841871, 70.95}}], 
       Polygon3DBox[{{-1320.8, -36.80177398161349, 
        80.13899438159396}, {-1320.8, -106.31623594688342`, 
        61.51265043571589}, {-1320.8, -110.06666666666666`, 
        90.}, {-1320.8, -38.099999999999994`, 
        90.}, {-1320.8, -36.80177398161349, 80.13899438159396}}], 
       Polygon3DBox[{{-1320.8, -110.06666666666666`, 
        90.}, {-1320.8, -182.03333333333333`, 
        90.}, {-1320.8, -175.83069791215337`, 
        137.1136935101622}, {-1320.8, -106.31623594688342`, 
        118.4873495642841}, {-1320.8, -110.06666666666666`, 90.}}], 
       Polygon3DBox[{{-1320.8, -106.31623594688342`, 
        118.4873495642841}, {-1320.8, -175.83069791215337`, 
        137.1136935101622}, {-1320.8, -157.6454910022273, 
        181.01666666666665`}, {-1320.8, -95.32052944320719, 
        145.03333333333333`}, {-1320.8, -106.31623594688342`, 
        118.4873495642841}}], 
       Polygon3DBox[{{-1320.8, -95.32052944320719, 
        145.03333333333333`}, {-1320.8, -157.6454910022273, 
        181.01666666666665`}, {-1320.8, -128.71700440199118`, 
        218.71700440199118`}, {-1320.8, -77.82888638259932, 
        167.8288863825993}, {-1320.8, -95.32052944320719, 
        145.03333333333333`}}], 
       Polygon3DBox[{{-1320.8, -77.82888638259932, 
        167.8288863825993}, {-1320.8, -128.71700440199118`, 
        218.71700440199118`}, {-1320.8, -91.01666666666667, 
        247.6454910022273}, {-1320.8, -55.03333333333333, 
        185.3205294432072}, {-1320.8, -77.82888638259932, 
        167.8288863825993}}], 
       Polygon3DBox[{{-1320.8, -55.03333333333333, 
        185.3205294432072}, {-1320.8, -91.01666666666667, 
        247.6454910022273}, {-1320.8, -47.113693510162186`, 
        265.83069791215337`}, {-1320.8, -28.48734956428411, 
        196.3162359468834}, {-1320.8, -55.03333333333333, 
        185.3205294432072}}], 
       Polygon3DBox[{{-1320.8, -28.48734956428411, 
        196.3162359468834}, {-1320.8, -47.113693510162186`, 
        265.83069791215337`}, {-1320.8, 0., 272.0333333333333}, {-1320.8, 0., 
        200.06666666666666`}, {-1320.8, -28.48734956428411, 
        196.3162359468834}}], 
       Polygon3DBox[{{-1320.8, 0., 200.06666666666666`}, {-1320.8, 0., 
        272.0333333333333}, {-1320.8, 47.113693510162186`, 
        265.83069791215337`}, {-1320.8, 28.48734956428411, 
        196.3162359468834}, {-1320.8, 0., 200.06666666666666`}}], 
       Polygon3DBox[{{-1320.8, 28.48734956428411, 
        196.3162359468834}, {-1320.8, 47.113693510162186`, 
        265.83069791215337`}, {-1320.8, 91.01666666666667, 
        247.6454910022273}, {-1320.8, 55.03333333333333, 
        185.3205294432072}, {-1320.8, 28.48734956428411, 196.3162359468834}}],
        Polygon3DBox[{{-1320.8, 55.03333333333333, 
        185.3205294432072}, {-1320.8, 91.01666666666667, 
        247.6454910022273}, {-1320.8, 128.71700440199118`, 
        218.71700440199118`}, {-1320.8, 77.82888638259932, 
        167.8288863825993}, {-1320.8, 55.03333333333333, 185.3205294432072}}],
        Polygon3DBox[{{-1320.8, 77.82888638259932, 
        167.8288863825993}, {-1320.8, 128.71700440199118`, 
        218.71700440199118`}, {-1320.8, 157.6454910022273, 
        181.01666666666665`}, {-1320.8, 95.32052944320719, 
        145.03333333333333`}, {-1320.8, 77.82888638259932, 
        167.8288863825993}}], 
       Polygon3DBox[{{-1320.8, 95.32052944320719, 
        145.03333333333333`}, {-1320.8, 157.6454910022273, 
        181.01666666666665`}, {-1320.8, 175.83069791215337`, 
        137.1136935101622}, {-1320.8, 106.31623594688342`, 
        118.4873495642841}, {-1320.8, 95.32052944320719, 
        145.03333333333333`}}], 
       Polygon3DBox[{{-1320.8, 106.31623594688342`, 
        118.4873495642841}, {-1320.8, 175.83069791215337`, 
        137.1136935101622}, {-1320.8, 182.03333333333333`, 90.}, {-1320.8, 
        110.06666666666666`, 90.}, {-1320.8, 106.31623594688342`, 
        118.4873495642841}}], 
       Polygon3DBox[{{-1320.8, 110.06666666666666`, 90.}, {-1320.8, 
        182.03333333333333`, 90.}, {-1320.8, 175.83069791215337`, 
        42.886306489837814`}, {-1320.8, 106.31623594688342`, 
        61.51265043571589}, {-1320.8, 110.06666666666666`, 90.}}], 
       Polygon3DBox[{{-1320.8, 106.31623594688342`, 
        61.51265043571589}, {-1320.8, 175.83069791215337`, 
        42.886306489837814`}, {-1320.8, 
        157.6454910022273, -1.0166666666666657`}, {-1320.8, 95.32052944320719,
         34.96666666666667}, {-1320.8, 106.31623594688342`, 
        61.51265043571589}}], 
       Polygon3DBox[{{-1320.8, 95.32052944320719, 
        34.96666666666667}, {-1320.8, 
        157.6454910022273, -1.0166666666666657`}, {-1320.8, 
        128.71700440199118`, -38.717004401991176`}, {-1320.8, 
        77.82888638259932, 12.171113617400678`}, {-1320.8, 95.32052944320719, 
        34.96666666666667}}], 
       Polygon3DBox[{{-1320.8, 77.82888638259932, 
        12.171113617400678`}, {-1320.8, 
        128.71700440199118`, -38.717004401991176`}, {-1320.8, 
        91.01666666666667, -67.64549100222729}, {-1320.8, 
        55.03333333333333, -5.320529443207192}, {-1320.8, 77.82888638259932, 
        12.171113617400678`}}], 
       Polygon3DBox[{{-1320.8, 
        55.03333333333333, -5.320529443207192}, {-1320.8, 
        91.01666666666667, -67.64549100222729}, {-1320.8, 
        47.113693510162186`, -85.83069791215337}, {-1320.8, 
        28.48734956428411, -16.316235946883424`}, {-1320.8, 
        55.03333333333333, -5.320529443207192}}], 
       Polygon3DBox[{{-1320.8, 
        28.48734956428411, -16.316235946883424`}, {-1320.8, 
        47.113693510162186`, -85.83069791215337}, {-1320.8, 
        0., -92.03333333333333}, {-1320.8, 
        0., -20.066666666666663`}, {-1320.8, 
        28.48734956428411, -16.316235946883424`}}], 
       Polygon3DBox[{{-1320.8, 0., -20.066666666666663`}, {-1320.8, 
        0., -92.03333333333333}, {-1320.8, -47.113693510162186`, \
-85.83069791215337}, {-1320.8, -28.48734956428411, -16.316235946883424`}, \
{-1320.8, 0., -20.066666666666663`}}], 
       Polygon3DBox[{{-1320.8, -28.48734956428411, -16.316235946883424`}, \
{-1320.8, -47.113693510162186`, -85.83069791215337}, {-1320.8, \
-91.01666666666667, -67.64549100222729}, {-1320.8, -55.03333333333333, \
-5.320529443207192}, {-1320.8, -28.48734956428411, -16.316235946883424`}}], 
       Polygon3DBox[{{-1320.8, -55.03333333333333, -5.320529443207192}, \
{-1320.8, -91.01666666666667, -67.64549100222729}, {-1320.8, \
-128.71700440199118`, -38.717004401991176`}, {-1320.8, -77.82888638259932, 
        12.171113617400678`}, {-1320.8, -55.03333333333333, \
-5.320529443207192}}], 
       Polygon3DBox[{{-1320.8, -77.82888638259932, 
        12.171113617400678`}, {-1320.8, -128.71700440199118`, \
-38.717004401991176`}, {-1320.8, -157.6454910022273, -1.0166666666666657`}, \
{-1320.8, -95.32052944320719, 
        34.96666666666667}, {-1320.8, -77.82888638259932, 
        12.171113617400678`}}], 
       Polygon3DBox[{{-1320.8, -95.32052944320719, 
        34.96666666666667}, {-1320.8, -157.6454910022273, \
-1.0166666666666657`}, {-1320.8, -175.83069791215337`, 
        42.886306489837814`}, {-1320.8, -106.31623594688342`, 
        61.51265043571589}, {-1320.8, -95.32052944320719, 
        34.96666666666667}}], 
       Polygon3DBox[{{-1320.8, -106.31623594688342`, 
        61.51265043571589}, {-1320.8, -175.83069791215337`, 
        42.886306489837814`}, {-1320.8, -182.03333333333333`, 
        90.}, {-1320.8, -110.06666666666666`, 
        90.}, {-1320.8, -106.31623594688342`, 61.51265043571589}}], 
       Polygon3DBox[{{-1320.8, -182.03333333333333`, 90.}, {-1320.8, -254., 
        90.}, {-1320.8, -245.34515987742333`, 
        155.74003745604026`}, {-1320.8, -175.83069791215337`, 
        137.1136935101622}, {-1320.8, -182.03333333333333`, 90.}}], 
       Polygon3DBox[{{-1320.8, -175.83069791215337`, 
        137.1136935101622}, {-1320.8, -245.34515987742333`, 
        155.74003745604026`}, {-1320.8, -219.97045256124738`, 
        217.}, {-1320.8, -157.6454910022273, 
        181.01666666666665`}, {-1320.8, -175.83069791215337`, 
        137.1136935101622}}], 
       Polygon3DBox[{{-1320.8, -157.6454910022273, 
        181.01666666666665`}, {-1320.8, -219.97045256124738`, 
        217.}, {-1320.8, -179.60512242138304`, 
        269.60512242138304`}, {-1320.8, -128.71700440199118`, 
        218.71700440199118`}, {-1320.8, -157.6454910022273, 
        181.01666666666665`}}], 
       Polygon3DBox[{{-1320.8, -128.71700440199118`, 
        218.71700440199118`}, {-1320.8, -179.60512242138304`, 
        269.60512242138304`}, {-1320.8, -127., 
        309.9704525612474}, {-1320.8, -91.01666666666667, 
        247.6454910022273}, {-1320.8, -128.71700440199118`, 
        218.71700440199118`}}], 
       Polygon3DBox[{{-1320.8, -91.01666666666667, 
        247.6454910022273}, {-1320.8, -127., 
        309.9704525612474}, {-1320.8, -65.74003745604026, 
        335.3451598774233}, {-1320.8, -47.113693510162186`, 
        265.83069791215337`}, {-1320.8, -91.01666666666667, 
        247.6454910022273}}], 
       Polygon3DBox[{{-1320.8, -47.113693510162186`, 
        265.83069791215337`}, {-1320.8, -65.74003745604026, 
        335.3451598774233}, {-1320.8, 0., 344.}, {-1320.8, 0., 
        272.0333333333333}, {-1320.8, -47.113693510162186`, 
        265.83069791215337`}}], 
       Polygon3DBox[{{-1320.8, 0., 272.0333333333333}, {-1320.8, 0., 
        344.}, {-1320.8, 65.74003745604026, 335.3451598774233}, {-1320.8, 
        47.113693510162186`, 265.83069791215337`}, {-1320.8, 0., 
        272.0333333333333}}], 
       Polygon3DBox[{{-1320.8, 47.113693510162186`, 
        265.83069791215337`}, {-1320.8, 65.74003745604026, 
        335.3451598774233}, {-1320.8, 127., 309.9704525612474}, {-1320.8, 
        91.01666666666667, 247.6454910022273}, {-1320.8, 47.113693510162186`, 
        265.83069791215337`}}], 
       Polygon3DBox[{{-1320.8, 91.01666666666667, 
        247.6454910022273}, {-1320.8, 127., 309.9704525612474}, {-1320.8, 
        179.60512242138304`, 269.60512242138304`}, {-1320.8, 
        128.71700440199118`, 218.71700440199118`}, {-1320.8, 
        91.01666666666667, 247.6454910022273}}], 
       Polygon3DBox[{{-1320.8, 128.71700440199118`, 
        218.71700440199118`}, {-1320.8, 179.60512242138304`, 
        269.60512242138304`}, {-1320.8, 219.97045256124738`, 217.}, {-1320.8, 
        157.6454910022273, 181.01666666666665`}, {-1320.8, 
        128.71700440199118`, 218.71700440199118`}}], 
       Polygon3DBox[{{-1320.8, 157.6454910022273, 
        181.01666666666665`}, {-1320.8, 219.97045256124738`, 217.}, {-1320.8, 
        245.34515987742333`, 155.74003745604026`}, {-1320.8, 
        175.83069791215337`, 137.1136935101622}, {-1320.8, 157.6454910022273, 
        181.01666666666665`}}], 
       Polygon3DBox[{{-1320.8, 175.83069791215337`, 
        137.1136935101622}, {-1320.8, 245.34515987742333`, 
        155.74003745604026`}, {-1320.8, 254., 90.}, {-1320.8, 
        182.03333333333333`, 90.}, {-1320.8, 175.83069791215337`, 
        137.1136935101622}}], 
       Polygon3DBox[{{-1320.8, 182.03333333333333`, 90.}, {-1320.8, 254., 
        90.}, {-1320.8, 245.34515987742333`, 24.259962543959745`}, {-1320.8, 
        175.83069791215337`, 42.886306489837814`}, {-1320.8, 
        182.03333333333333`, 90.}}], 
       Polygon3DBox[{{-1320.8, 175.83069791215337`, 
        42.886306489837814`}, {-1320.8, 245.34515987742333`, 
        24.259962543959745`}, {-1320.8, 219.97045256124738`, -37.}, {-1320.8, 
        157.6454910022273, -1.0166666666666657`}, {-1320.8, 
        175.83069791215337`, 42.886306489837814`}}], 
       Polygon3DBox[{{-1320.8, 
        157.6454910022273, -1.0166666666666657`}, {-1320.8, 
        219.97045256124738`, -37.}, {-1320.8, 
        179.60512242138304`, -89.60512242138304}, {-1320.8, 
        128.71700440199118`, -38.717004401991176`}, {-1320.8, 
        157.6454910022273, -1.0166666666666657`}}], 
       Polygon3DBox[{{-1320.8, 
        128.71700440199118`, -38.717004401991176`}, {-1320.8, 
        179.60512242138304`, -89.60512242138304}, {-1320.8, 
        127., -129.97045256124738`}, {-1320.8, 
        91.01666666666667, -67.64549100222729}, {-1320.8, 
        128.71700440199118`, -38.717004401991176`}}], 
       Polygon3DBox[{{-1320.8, 
        91.01666666666667, -67.64549100222729}, {-1320.8, 
        127., -129.97045256124738`}, {-1320.8, 
        65.74003745604026, -155.34515987742333`}, {-1320.8, 
        47.113693510162186`, -85.83069791215337}, {-1320.8, 
        91.01666666666667, -67.64549100222729}}], 
       Polygon3DBox[{{-1320.8, 
        47.113693510162186`, -85.83069791215337}, {-1320.8, 
        65.74003745604026, -155.34515987742333`}, {-1320.8, 
        0., -164.}, {-1320.8, 0., -92.03333333333333}, {-1320.8, 
        47.113693510162186`, -85.83069791215337}}], 
       Polygon3DBox[{{-1320.8, 0., -92.03333333333333}, {-1320.8, 
        0., -164.}, {-1320.8, -65.74003745604026, -155.34515987742333`}, \
{-1320.8, -47.113693510162186`, -85.83069791215337}, {-1320.8, 
        0., -92.03333333333333}}], 
       Polygon3DBox[{{-1320.8, -47.113693510162186`, -85.83069791215337}, \
{-1320.8, -65.74003745604026, -155.34515987742333`}, {-1320.8, -127., \
-129.97045256124738`}, {-1320.8, -91.01666666666667, -67.64549100222729}, \
{-1320.8, -47.113693510162186`, -85.83069791215337}}], 
       Polygon3DBox[{{-1320.8, -91.01666666666667, -67.64549100222729}, \
{-1320.8, -127., -129.97045256124738`}, {-1320.8, -179.60512242138304`, \
-89.60512242138304}, {-1320.8, -128.71700440199118`, -38.717004401991176`}, \
{-1320.8, -91.01666666666667, -67.64549100222729}}], 
       Polygon3DBox[{{-1320.8, -128.71700440199118`, -38.717004401991176`}, \
{-1320.8, -179.60512242138304`, -89.60512242138304}, {-1320.8, \
-219.97045256124738`, -37.}, {-1320.8, -157.6454910022273, \
-1.0166666666666657`}, {-1320.8, -128.71700440199118`, \
-38.717004401991176`}}], 
       Polygon3DBox[{{-1320.8, -157.6454910022273, -1.0166666666666657`}, \
{-1320.8, -219.97045256124738`, -37.}, {-1320.8, -245.34515987742333`, 
        24.259962543959745`}, {-1320.8, -175.83069791215337`, 
        42.886306489837814`}, {-1320.8, -157.6454910022273, \
-1.0166666666666657`}}], 
       Polygon3DBox[{{-1320.8, -175.83069791215337`, 
        42.886306489837814`}, {-1320.8, -245.34515987742333`, 
        24.259962543959745`}, {-1320.8, -254., 
        90.}, {-1320.8, -182.03333333333333`, 
        90.}, {-1320.8, -175.83069791215337`, 42.886306489837814`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIDYGgcVTDpwBAR7nAwwg0BDmABNXf7GofUGa04Eq
Pf/tUt8j4OJcR7Yfyat3OADmO0fDxVPFOI2ufbA6MNO1qcfUJhYufhZsvvEB
lkfRSdv3x8HFrxRX7rq6Q/mAcMlF54DN8XBx7etzH2YzP90D5jMnIMyBqHcQ
QVN/CmK+Axua+SkQ9zigu4cT4n4HEzT3q0H861CN5l9o+DjgCB+H9osbPJ5y
hMDFuaHmnwPp2xMIF8+EuudCye9nU9r94eIXoe7/Ye1hPbHBBy5+H+rf2+Kx
FfEzveDi+w/lXFJs/W8Ddv9nT7j4MWh43kRTfwQa/l/QzIeGz4EzaO7hgMbv
GTT3q0LTQwuaf2Hp5z8I1Ic5AABJSQmC
         "]], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIDYGgcVTDjCAwIF8CN0Q5gATn667q4d7dd4Bpw/s
yevKk+HiQnPaP/HWZ0PUK2TDxUNtN2nGFqcdWCV3c8q6mwVwcSaw+fEHOM45
/2yLL4aLtz/gPxaTH3DgtFjssdavJXBxf+N1z242Ce6FuKcULt4IUe9wBk39
n/9AsD/egQvN/BCIexzQ3SMAcb8DM5r7p0H86+CC5l9o+DgwoYXPDKh6gboD
z3ucLODiwlDzf4DcVe90ACYeAXXPoqqU4F1pYXBxDkj4OPCD9NknwMUnQP07
FWRPdjJc/JsP6y03Fy1bSPikwMWroeE5A039Z0j4HBBFMx8aPgfWoLmHHxq/
AmDzEe6fCk0Pe2pR/QtLP+B4qA9zAACrePQa
         "]], {
         {GrayLevel[0.5], EdgeForm[None], 
          Polygon3DBox[{{-1257.3, -254., 90.}, {-1320.8, -254., 
           90.}, {-1320.8, -245.34515987742336`, 
           155.74003745604028`}, {-1257.3000000000002`, -245.34515987742336`, 
           155.74003745604028`}, {-1257.3, -254., 90.}}], 
          Polygon3DBox[{{-1257.3000000000002`, -245.34515987742336`, 
           155.74003745604028`}, {-1320.8, -245.34515987742336`, 
           155.74003745604028`}, {-1320.8, -219.97045256124744`, 
           217.}, {-1257.3, -219.97045256124744`, 
           217.}, {-1257.3000000000002`, -245.34515987742336`, 
           155.74003745604028`}}], 
          Polygon3DBox[{{-1257.3, -219.97045256124744`, 
           217.}, {-1320.8, -219.97045256124744`, 
           217.}, {-1320.8, -179.60512242138307`, 
           269.60512242138304`}, {-1257.3000000000002`, -179.60512242138307`, 
           269.60512242138304`}, {-1257.3, -219.97045256124744`, 217.}}], 
          Polygon3DBox[{{-1257.3000000000002`, -179.60512242138307`, 
           269.60512242138304`}, {-1320.8, -179.60512242138307`, 
           269.60512242138304`}, {-1320.8, -127.00000000000003`, 
           309.9704525612474}, {-1257.3, -127.00000000000003`, 
           309.9704525612474}, {-1257.3000000000002`, -179.60512242138307`, 
           269.60512242138304`}}], 
          Polygon3DBox[{{-1257.3, -127.00000000000003`, 
           309.9704525612474}, {-1320.8, -127.00000000000003`, 
           309.9704525612474}, {-1320.8, -65.74003745604033, 
           335.3451598774233}, {-1257.3000000000002`, -65.74003745604033, 
           335.3451598774233}, {-1257.3, -127.00000000000003`, 
           309.9704525612474}}], 
          Polygon3DBox[{{-1257.3000000000002`, -65.74003745604033, 
           335.3451598774233}, {-1320.8, -65.74003745604033, 
           335.3451598774233}, {-1320.8, -7.195234400012934*^-14, 
           344.}, {-1257.3, -7.195234400012934*^-14, 
           344.}, {-1257.3000000000002`, -65.74003745604033, 
           335.3451598774233}}], 
          Polygon3DBox[{{-1257.3, -1.5553014349171386`*^-14, 
           344.}, {-1320.8, -1.5553014349171386`*^-14, 344.}, {-1320.8, 
           65.74003745604024, 335.3451598774234}, {-1257.3000000000002`, 
           65.74003745604024, 
           335.3451598774234}, {-1257.3, -1.5553014349171386`*^-14, 344.}}], 
          Polygon3DBox[{{-1257.3000000000002`, 65.74003745604024, 
           335.3451598774234}, {-1320.8, 65.74003745604024, 
           335.3451598774234}, {-1320.8, 126.99999999999994`, 
           309.9704525612475}, {-1257.3, 126.99999999999994`, 
           309.9704525612475}, {-1257.3000000000002`, 65.74003745604024, 
           335.3451598774234}}], 
          Polygon3DBox[{{-1257.3, 126.99999999999994`, 
           309.9704525612475}, {-1320.8, 126.99999999999994`, 
           309.9704525612475}, {-1320.8, 179.60512242138304`, 
           269.60512242138304`}, {-1257.3000000000002`, 179.60512242138304`, 
           269.60512242138304`}, {-1257.3, 126.99999999999994`, 
           309.9704525612475}}], 
          Polygon3DBox[{{-1257.3000000000002`, 179.60512242138304`, 
           269.60512242138304`}, {-1320.8, 179.60512242138304`, 
           269.60512242138304`}, {-1320.8, 219.97045256124744`, 
           217.}, {-1257.3, 219.97045256124744`, 217.}, {-1257.3000000000002`,
            179.60512242138304`, 269.60512242138304`}}], 
          Polygon3DBox[{{-1257.3, 219.97045256124738`, 
           217.00000000000009`}, {-1320.8, 219.97045256124738`, 
           217.00000000000009`}, {-1320.8, 245.34515987742333`, 
           155.74003745604034`}, {-1257.3000000000002`, 245.34515987742333`, 
           155.74003745604034`}, {-1257.3, 219.97045256124738`, 
           217.00000000000009`}}], 
          Polygon3DBox[{{-1257.3000000000002`, 245.34515987742333`, 
           155.74003745604034`}, {-1320.8, 245.34515987742333`, 
           155.74003745604034`}, {-1320.8, 254., 90.00000000000003}, {-1257.3,
            254., 90.00000000000003}, {-1257.3000000000002`, 
           245.34515987742333`, 155.74003745604034`}}], 
          Polygon3DBox[{{-1257.3, 254., 90.00000000000003}, {-1320.8, 254., 
           90.00000000000003}, {-1320.8, 245.34515987742336`, 
           24.259962543959716`}, {-1257.3000000000002`, 245.34515987742336`, 
           24.259962543959716`}, {-1257.3, 254., 90.00000000000003}}], 
          Polygon3DBox[{{-1257.3000000000002`, 245.34515987742338`, 
           24.25996254395983}, {-1320.8, 245.34515987742338`, 
           24.25996254395983}, {-1320.8, 
           219.97045256124747`, -36.99999999999994}, {-1257.3, 
           219.97045256124747`, -36.99999999999994}, {-1257.3000000000002`, 
           245.34515987742338`, 24.25996254395983}}], 
          Polygon3DBox[{{-1257.3, 
           219.97045256124747`, -36.99999999999994}, {-1320.8, 
           219.97045256124747`, -36.99999999999994}, {-1320.8, 
           179.6051224213831, -89.60512242138304}, {-1257.3000000000002`, 
           179.6051224213831, -89.60512242138304}, {-1257.3, 
           219.97045256124747`, -36.99999999999994}}], 
          Polygon3DBox[{{-1257.3000000000002`, 
           179.60512242138316`, -89.60512242138296}, {-1320.8, 
           179.60512242138316`, -89.60512242138296}, {-1320.8, 
           127.00000000000011`, -129.97045256124736`}, {-1257.3, 
           127.00000000000011`, -129.97045256124736`}, {-1257.3000000000002`, 
           179.60512242138316`, -89.60512242138296}}], 
          Polygon3DBox[{{-1257.3, 
           127.00000000000011`, -129.97045256124736`}, {-1320.8, 
           127.00000000000011`, -129.97045256124736`}, {-1320.8, 
           65.74003745604045, -155.3451598774233}, {-1257.3000000000002`, 
           65.74003745604045, -155.3451598774233}, {-1257.3, 
           127.00000000000011`, -129.97045256124736`}}], 
          Polygon3DBox[{{-1257.3000000000002`, 
           65.74003745604045, -155.3451598774233}, {-1320.8, 
           65.74003745604045, -155.3451598774233}, {-1320.8, 
           2.7225636165134593`*^-13, -164.}, {-1257.3, 
           2.7225636165134593`*^-13, -164.}, {-1257.3000000000002`, 
           65.74003745604045, -155.3451598774233}}], 
          Polygon3DBox[{{-1257.3, 4.6659043047514155`*^-14, -164.}, {-1320.8, 
           4.6659043047514155`*^-14, -164.}, {-1320.8, -65.74003745604016, \
-155.34515987742338`}, {-1257.3000000000002`, -65.74003745604016, \
-155.34515987742338`}, {-1257.3, 4.6659043047514155`*^-14, -164.}}], 
          Polygon3DBox[{{-1257.3000000000002`, -65.74003745604016, \
-155.34515987742338`}, {-1320.8, -65.74003745604016, -155.34515987742338`}, \
{-1320.8, -126.99999999999982`, -129.97045256124753`}, {-1257.3, \
-126.99999999999982`, -129.97045256124753`}, {-1257.3000000000002`, \
-65.74003745604016, -155.34515987742338`}}], 
          Polygon3DBox[{{-1257.3, -126.99999999999982`, \
-129.97045256124753`}, {-1320.8, -126.99999999999982`, -129.97045256124753`}, \
{-1320.8, -179.60512242138284`, -89.60512242138327}, {-1257.3000000000002`, \
-179.60512242138284`, -89.60512242138327}, {-1257.3, -126.99999999999982`, \
-129.97045256124753`}}], 
          Polygon3DBox[{{-1257.3000000000002`, -179.60512242138304`, \
-89.6051224213831}, {-1320.8, -179.60512242138304`, -89.6051224213831}, \
{-1320.8, -219.97045256124736`, -37.000000000000114`}, {-1257.3, \
-219.97045256124736`, -37.000000000000114`}, {-1257.3000000000002`, \
-179.60512242138304`, -89.6051224213831}}], 
          Polygon3DBox[{{-1257.3, -219.97045256124736`, \
-37.000000000000114`}, {-1320.8, -219.97045256124736`, -37.000000000000114`}, \
{-1320.8, -245.3451598774233, 
           24.25996254395953}, {-1257.3000000000002`, -245.3451598774233, 
           24.25996254395953}, {-1257.3, -219.97045256124736`, \
-37.000000000000114`}}], 
          Polygon3DBox[{{-1257.3000000000002`, -245.3451598774233, 
           24.25996254395953}, {-1320.8, -245.3451598774233, 
           24.25996254395953}, {-1320.8, -254., 
           89.99999999999972}, {-1257.3, -254., 
           89.99999999999972}, {-1257.3000000000002`, -245.3451598774233, 
           24.25996254395953}}]}, 
         {GrayLevel[0.5], EdgeForm[None], 
          Polygon3DBox[{{-1269.71425, -38.099999999999994`, 
           90.}, {-1320.8, -38.099999999999994`, 
           90.}, {-1320.8, -36.8017739816135, 
           99.86100561840604}, {-1269.71425, -36.8017739816135, 
           99.86100561840604}, {-1269.71425, -38.099999999999994`, 90.}}], 
          Polygon3DBox[{{-1269.71425, -36.8017739816135, 
           99.86100561840604}, {-1320.8, -36.8017739816135, 
           99.86100561840604}, {-1320.8, -32.99556788418711, 
           109.05}, {-1269.71425, -32.99556788418711, 
           109.05}, {-1269.71425, -36.8017739816135, 99.86100561840604}}], 
          Polygon3DBox[{{-1269.71425, -32.99556788418711, 
           109.05}, {-1320.8, -32.99556788418711, 
           109.05}, {-1320.8, -26.940768363207457`, 
           116.94076836320745`}, {-1269.71425, -26.940768363207457`, 
           116.94076836320745`}, {-1269.71425, -32.99556788418711, 109.05}}], 
          Polygon3DBox[{{-1269.71425, -26.940768363207457`, 
           116.94076836320745`}, {-1320.8, -26.940768363207457`, 
           116.94076836320745`}, {-1320.8, -19.05, 
           122.9955678841871}, {-1269.71425, -19.05, 
           122.9955678841871}, {-1269.71425, -26.940768363207457`, 
           116.94076836320745`}}], 
          Polygon3DBox[{{-1269.71425, -19.05, 
           122.9955678841871}, {-1320.8, -19.05, 
           122.9955678841871}, {-1320.8, -9.861005618406047, 
           126.8017739816135}, {-1269.71425, -9.861005618406047, 
           126.8017739816135}, {-1269.71425, -19.05, 122.9955678841871}}], 
          Polygon3DBox[{{-1269.71425, -9.861005618406047, 
           126.8017739816135}, {-1320.8, -9.861005618406047, 
           126.8017739816135}, {-1320.8, -1.07928516000194*^-14, 
           128.1}, {-1269.71425, -1.07928516000194*^-14, 
           128.1}, {-1269.71425, -9.861005618406047, 126.8017739816135}}], 
          Polygon3DBox[{{-1269.71425, -2.3329521523757076`*^-15, 
           128.1}, {-1320.8, -2.3329521523757076`*^-15, 128.1}, {-1320.8, 
           9.861005618406034, 126.80177398161351`}, {-1269.71425, 
           9.861005618406034, 
           126.80177398161351`}, {-1269.71425, -2.3329521523757076`*^-15, 
           128.1}}], 
          Polygon3DBox[{{-1269.71425, 9.861005618406034, 
           126.80177398161351`}, {-1320.8, 9.861005618406034, 
           126.80177398161351`}, {-1320.8, 19.04999999999999, 
           122.99556788418712`}, {-1269.71425, 19.04999999999999, 
           122.99556788418712`}, {-1269.71425, 9.861005618406034, 
           126.80177398161351`}}], 
          Polygon3DBox[{{-1269.71425, 19.04999999999999, 
           122.99556788418712`}, {-1320.8, 19.04999999999999, 
           122.99556788418712`}, {-1320.8, 26.940768363207454`, 
           116.94076836320745`}, {-1269.71425, 26.940768363207454`, 
           116.94076836320745`}, {-1269.71425, 19.04999999999999, 
           122.99556788418712`}}], 
          Polygon3DBox[{{-1269.71425, 26.940768363207454`, 
           116.94076836320745`}, {-1320.8, 26.940768363207454`, 
           116.94076836320745`}, {-1320.8, 32.99556788418711, 
           109.05}, {-1269.71425, 32.99556788418711, 109.05}, {-1269.71425, 
           26.940768363207454`, 116.94076836320745`}}], 
          Polygon3DBox[{{-1269.71425, 32.9955678841871, 
           109.05000000000001`}, {-1320.8, 32.9955678841871, 
           109.05000000000001`}, {-1320.8, 36.80177398161349, 
           99.86100561840605}, {-1269.71425, 36.80177398161349, 
           99.86100561840605}, {-1269.71425, 32.9955678841871, 
           109.05000000000001`}}], 
          Polygon3DBox[{{-1269.71425, 36.80177398161349, 
           99.86100561840605}, {-1320.8, 36.80177398161349, 
           99.86100561840605}, {-1320.8, 38.099999999999994`, 
           90.}, {-1269.71425, 38.099999999999994`, 90.}, {-1269.71425, 
           36.80177398161349, 99.86100561840605}}], 
          Polygon3DBox[{{-1269.71425, 38.099999999999994`, 90.}, {-1320.8, 
           38.099999999999994`, 90.}, {-1320.8, 36.8017739816135, 
           80.13899438159396}, {-1269.71425, 36.8017739816135, 
           80.13899438159396}, {-1269.71425, 38.099999999999994`, 90.}}], 
          Polygon3DBox[{{-1269.71425, 36.8017739816135, 
           80.13899438159397}, {-1320.8, 36.8017739816135, 
           80.13899438159397}, {-1320.8, 32.99556788418712, 
           70.95000000000002}, {-1269.71425, 32.99556788418712, 
           70.95000000000002}, {-1269.71425, 36.8017739816135, 
           80.13899438159397}}], 
          Polygon3DBox[{{-1269.71425, 32.99556788418712, 
           70.95000000000002}, {-1320.8, 32.99556788418712, 
           70.95000000000002}, {-1320.8, 26.940768363207464`, 
           63.059231636792546`}, {-1269.71425, 26.940768363207464`, 
           63.059231636792546`}, {-1269.71425, 32.99556788418712, 
           70.95000000000002}}], 
          Polygon3DBox[{{-1269.71425, 26.94076836320747, 
           63.05923163679256}, {-1320.8, 26.94076836320747, 
           63.05923163679256}, {-1320.8, 19.050000000000015`, 
           57.004432115812904`}, {-1269.71425, 19.050000000000015`, 
           57.004432115812904`}, {-1269.71425, 26.94076836320747, 
           63.05923163679256}}], 
          Polygon3DBox[{{-1269.71425, 19.050000000000015`, 
           57.004432115812904`}, {-1320.8, 19.050000000000015`, 
           57.004432115812904`}, {-1320.8, 9.861005618406066, 
           53.198226018386514`}, {-1269.71425, 9.861005618406066, 
           53.198226018386514`}, {-1269.71425, 19.050000000000015`, 
           57.004432115812904`}}], 
          Polygon3DBox[{{-1269.71425, 9.861005618406066, 
           53.198226018386514`}, {-1320.8, 9.861005618406066, 
           53.198226018386514`}, {-1320.8, 4.083845424770189*^-14, 
           51.900000000000006`}, {-1269.71425, 4.083845424770189*^-14, 
           51.900000000000006`}, {-1269.71425, 9.861005618406066, 
           53.198226018386514`}}], 
          Polygon3DBox[{{-1269.71425, 6.998856457127122*^-15, 
           51.900000000000006`}, {-1320.8, 6.998856457127122*^-15, 
           51.900000000000006`}, {-1320.8, -9.861005618406022, 
           53.1982260183865}, {-1269.71425, -9.861005618406022, 
           53.1982260183865}, {-1269.71425, 6.998856457127122*^-15, 
           51.900000000000006`}}], 
          Polygon3DBox[{{-1269.71425, -9.861005618406022, 
           53.1982260183865}, {-1320.8, -9.861005618406022, 
           53.1982260183865}, {-1320.8, -19.04999999999997, 
           57.004432115812875`}, {-1269.71425, -19.04999999999997, 
           57.004432115812875`}, {-1269.71425, -9.861005618406022, 
           53.1982260183865}}], 
          Polygon3DBox[{{-1269.71425, -19.04999999999997, 
           57.004432115812875`}, {-1320.8, -19.04999999999997, 
           57.004432115812875`}, {-1320.8, -26.940768363207425`, 
           63.05923163679251}, {-1269.71425, -26.940768363207425`, 
           63.05923163679251}, {-1269.71425, -19.04999999999997, 
           57.004432115812875`}}], 
          Polygon3DBox[{{-1269.71425, -26.940768363207454`, 
           63.05923163679253}, {-1320.8, -26.940768363207454`, 
           63.05923163679253}, {-1320.8, -32.995567884187096`, 
           70.94999999999999}, {-1269.71425, -32.995567884187096`, 
           70.94999999999999}, {-1269.71425, -26.940768363207454`, 
           63.05923163679253}}], 
          Polygon3DBox[{{-1269.71425, -32.995567884187096`, 
           70.94999999999999}, {-1320.8, -32.995567884187096`, 
           70.94999999999999}, {-1320.8, -36.801773981613486`, 
           80.13899438159393}, {-1269.71425, -36.801773981613486`, 
           80.13899438159393}, {-1269.71425, -32.995567884187096`, 
           70.94999999999999}}], 
          Polygon3DBox[{{-1269.71425, -36.801773981613486`, 
           80.13899438159393}, {-1320.8, -36.801773981613486`, 
           80.13899438159393}, {-1320.8, -38.099999999999994`, 
           89.99999999999996}, {-1269.71425, -38.099999999999994`, 
           89.99999999999996}, {-1269.71425, -36.801773981613486`, 
           80.13899438159393}}]}}, 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{-254., 0., 90.}, {-253.77205128205128`, 
          16.93333333333333, 90.}, {-253.77205128205128`, 16.356343991828222`,
           94.38266916373601}, {-254., 0., 90.}, {-254., 0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, 16.93333333333333, 
          90.}, {-253.08820512820512`, 33.86666666666666, 
          90.}, {-253.08820512820512`, 32.712687983656444`, 
          98.76533832747204}, {-253.77205128205128`, 16.356343991828222`, 
          94.38266916373601}, {-253.77205128205128`, 16.93333333333333, 
          90.}}], Polygon3DBox[{{-253.08820512820512`, 33.86666666666666, 
          90.}, {-251.94846153846154`, 50.8, 90.}, {-251.94846153846154`, 
          49.06903197548467, 103.14800749120805`}, {-253.08820512820512`, 
          32.712687983656444`, 98.76533832747204}, {-253.08820512820512`, 
          33.86666666666666, 90.}}], 
         Polygon3DBox[{{-254., 0., 90.}, {-253.77205128205128`, 
          16.356343991828222`, 94.38266916373601}, {-253.77205128205128`, 
          14.664696837416495`, 98.46666666666667}, {-254., 0., 90.}, {-254., 
          0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, 16.356343991828222`, 
          94.38266916373601}, {-253.08820512820512`, 32.712687983656444`, 
          98.76533832747204}, {-253.08820512820512`, 29.32939367483299, 
          106.93333333333334`}, {-253.77205128205128`, 14.664696837416495`, 
          98.46666666666667}, {-253.77205128205128`, 16.356343991828222`, 
          94.38266916373601}}], 
         Polygon3DBox[{{-253.08820512820512`, 32.712687983656444`, 
          98.76533832747204}, {-251.94846153846154`, 49.06903197548467, 
          103.14800749120805`}, {-251.94846153846154`, 43.994090512249485`, 
          115.39999999999999`}, {-253.08820512820512`, 29.32939367483299, 
          106.93333333333334`}, {-253.08820512820512`, 32.712687983656444`, 
          98.76533832747204}}], 
         Polygon3DBox[{{-254., 0., 90.}, {-253.77205128205128`, 
          14.664696837416495`, 98.46666666666667}, {-253.77205128205128`, 
          11.973674828092204`, 101.9736748280922}, {-254., 0., 90.}, {-254., 
          0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, 14.664696837416495`, 
          98.46666666666667}, {-253.08820512820512`, 29.32939367483299, 
          106.93333333333334`}, {-253.08820512820512`, 23.947349656184407`, 
          113.9473496561844}, {-253.77205128205128`, 11.973674828092204`, 
          101.9736748280922}, {-253.77205128205128`, 14.664696837416495`, 
          98.46666666666667}}], 
         Polygon3DBox[{{-253.08820512820512`, 29.32939367483299, 
          106.93333333333334`}, {-251.94846153846154`, 43.994090512249485`, 
          115.39999999999999`}, {-251.94846153846152`, 35.921024484276614`, 
          125.92102448427661`}, {-253.08820512820512`, 23.947349656184407`, 
          113.9473496561844}, {-253.08820512820512`, 29.32939367483299, 
          106.93333333333334`}}], 
         Polygon3DBox[{{-254., 0., 90.}, {-253.77205128205128`, 
          11.973674828092204`, 101.9736748280922}, {-253.77205128205128`, 
          8.466666666666669, 104.6646968374165}, {-254., 0., 90.}, {-254., 0.,
           90.}}], 
         Polygon3DBox[{{-253.77205128205128`, 11.973674828092204`, 
          101.9736748280922}, {-253.08820512820512`, 23.947349656184407`, 
          113.9473496561844}, {-253.08820512820512`, 16.933333333333337`, 
          119.32939367483299`}, {-253.77205128205128`, 8.466666666666669, 
          104.6646968374165}, {-253.77205128205128`, 11.973674828092204`, 
          101.9736748280922}}], 
         Polygon3DBox[{{-253.08820512820512`, 23.947349656184407`, 
          113.9473496561844}, {-251.94846153846152`, 35.921024484276614`, 
          125.92102448427661`}, {-251.94846153846154`, 25.400000000000006`, 
          133.99409051224947`}, {-253.08820512820512`, 16.933333333333337`, 
          119.32939367483299`}, {-253.08820512820512`, 23.947349656184407`, 
          113.9473496561844}}], 
         Polygon3DBox[{{-254., 0., 90.}, {-253.77205128205128`, 
          8.466666666666669, 104.6646968374165}, {-253.77205128205128`, 
          4.382669163736021, 106.35634399182823`}, {-254., 0., 90.}, {-254., 
          0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, 8.466666666666669, 
          104.6646968374165}, {-253.08820512820512`, 16.933333333333337`, 
          119.32939367483299`}, {-253.08820512820512`, 8.765338327472042, 
          122.71268798365644`}, {-253.77205128205128`, 4.382669163736021, 
          106.35634399182823`}, {-253.77205128205128`, 8.466666666666669, 
          104.6646968374165}}], 
         Polygon3DBox[{{-253.08820512820512`, 16.933333333333337`, 
          119.32939367483299`}, {-251.94846153846154`, 25.400000000000006`, 
          133.99409051224947`}, {-251.94846153846154`, 13.148007491208064`, 
          139.06903197548468`}, {-253.08820512820512`, 8.765338327472042, 
          122.71268798365644`}, {-253.08820512820512`, 16.933333333333337`, 
          119.32939367483299`}}], 
         Polygon3DBox[{{-254., 0., 90.}, {-253.77205128205128`, 
          4.382669163736021, 106.35634399182823`}, {-253.77205128205128`, 
          4.7968229333419556`*^-15, 106.93333333333334`}, {-254., 0., 
          90.}, {-254., 0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, 4.382669163736021, 
          106.35634399182823`}, {-253.08820512820512`, 8.765338327472042, 
          122.71268798365644`}, {-253.08820512820512`, 9.593645866683911*^-15,
           123.86666666666666`}, {-253.77205128205128`, 
          4.7968229333419556`*^-15, 
          106.93333333333334`}, {-253.77205128205128`, 4.382669163736021, 
          106.35634399182823`}}], 
         Polygon3DBox[{{-253.08820512820512`, 8.765338327472042, 
          122.71268798365644`}, {-251.94846153846154`, 13.148007491208064`, 
          139.06903197548468`}, {-251.94846153846154`, 
          1.4390468800025868`*^-14, 140.8}, {-253.08820512820512`, 
          9.593645866683911*^-15, 123.86666666666666`}, {-253.08820512820512`,
           8.765338327472042, 122.71268798365644`}}], 
         Polygon3DBox[{{-254., 0., 90.}, {-253.77205128205128`, 
          1.0368676232780922`*^-15, 
          106.93333333333334`}, {-253.77205128205128`, -4.382669163736015, 
          106.35634399182823`}, {-254., 0., 90.}, {-254., 0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, 1.0368676232780922`*^-15, 
          106.93333333333334`}, {-253.08820512820512`, 
          2.0737352465561844`*^-15, 
          123.86666666666666`}, {-253.08820512820512`, -8.76533832747203, 
          122.71268798365645`}, {-253.77205128205128`, -4.382669163736015, 
          106.35634399182823`}, {-253.77205128205128`, 
          1.0368676232780922`*^-15, 106.93333333333334`}}], 
         Polygon3DBox[{{-253.08820512820512`, 2.0737352465561844`*^-15, 
          123.86666666666666`}, {-251.94846153846154`, 3.110602869834277*^-15,
           140.8}, {-251.94846153846154`, -13.148007491208046`, 
          139.06903197548468`}, {-253.08820512820512`, -8.76533832747203, 
          122.71268798365645`}, {-253.08820512820512`, 
          2.0737352465561844`*^-15, 123.86666666666666`}}], 
         Polygon3DBox[{{-254., 0., 
          90.}, {-253.77205128205128`, -4.382669163736015, 
          106.35634399182823`}, {-253.77205128205128`, -8.466666666666661, 
          104.6646968374165}, {-254., 0., 90.}, {-254., 0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, -4.382669163736015, 
          106.35634399182823`}, {-253.08820512820512`, -8.76533832747203, 
          122.71268798365645`}, {-253.08820512820512`, -16.933333333333323`, 
          119.329393674833}, {-253.77205128205128`, -8.466666666666661, 
          104.6646968374165}, {-253.77205128205128`, -4.382669163736015, 
          106.35634399182823`}}], 
         Polygon3DBox[{{-253.08820512820512`, -8.76533832747203, 
          122.71268798365645`}, {-251.94846153846154`, -13.148007491208046`, 
          139.06903197548468`}, {-251.94846153846154`, -25.399999999999988`, 
          133.9940905122495}, {-253.08820512820512`, -16.933333333333323`, 
          119.329393674833}, {-253.08820512820512`, -8.76533832747203, 
          122.71268798365645`}}], 
         Polygon3DBox[{{-254., 0., 
          90.}, {-253.77205128205128`, -8.466666666666661, 
          104.6646968374165}, {-253.77205128205128`, -11.973674828092202`, 
          101.9736748280922}, {-254., 0., 90.}, {-254., 0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, -8.466666666666661, 
          104.6646968374165}, {-253.08820512820512`, -16.933333333333323`, 
          119.329393674833}, {-253.08820512820512`, -23.947349656184404`, 
          113.9473496561844}, {-253.77205128205128`, -11.973674828092202`, 
          101.9736748280922}, {-253.77205128205128`, -8.466666666666661, 
          104.6646968374165}}], 
         Polygon3DBox[{{-253.08820512820512`, -16.933333333333323`, 
          119.329393674833}, {-251.94846153846154`, -25.399999999999988`, 
          133.9940905122495}, {-251.94846153846152`, -35.92102448427661, 
          125.92102448427661`}, {-253.08820512820512`, -23.947349656184404`, 
          113.9473496561844}, {-253.08820512820512`, -16.933333333333323`, 
          119.329393674833}}], 
         Polygon3DBox[{{-254., 0., 
          90.}, {-253.77205128205128`, -11.973674828092202`, 
          101.9736748280922}, {-253.77205128205128`, -14.664696837416495`, 
          98.46666666666667}, {-254., 0., 90.}, {-254., 0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, -11.973674828092202`, 
          101.9736748280922}, {-253.08820512820512`, -23.947349656184404`, 
          113.9473496561844}, {-253.08820512820512`, -29.32939367483299, 
          106.93333333333334`}, {-253.77205128205128`, -14.664696837416495`, 
          98.46666666666667}, {-253.77205128205128`, -11.973674828092202`, 
          101.9736748280922}}], 
         Polygon3DBox[{{-253.08820512820512`, -23.947349656184404`, 
          113.9473496561844}, {-251.94846153846152`, -35.92102448427661, 
          125.92102448427661`}, {-251.94846153846154`, -43.994090512249485`, 
          115.39999999999999`}, {-253.08820512820512`, -29.32939367483299, 
          106.93333333333334`}, {-253.08820512820512`, -23.947349656184404`, 
          113.9473496561844}}], 
         Polygon3DBox[{{-254., 0., 
          90.}, {-253.77205128205128`, -14.66469683741649, 
          98.46666666666667}, {-253.77205128205128`, -16.35634399182822, 
          94.38266916373603}, {-254., 0., 90.}, {-254., 0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, -14.66469683741649, 
          98.46666666666667}, {-253.08820512820512`, -29.32939367483298, 
          106.93333333333334`}, {-253.08820512820512`, -32.71268798365644, 
          98.76533832747205}, {-253.77205128205128`, -16.35634399182822, 
          94.38266916373603}, {-253.77205128205128`, -14.66469683741649, 
          98.46666666666667}}], 
         Polygon3DBox[{{-253.08820512820512`, -29.32939367483298, 
          106.93333333333334`}, {-251.94846153846154`, -43.99409051224947, 
          115.40000000000002`}, {-251.94846153846154`, -49.06903197548466, 
          103.14800749120806`}, {-253.08820512820512`, -32.71268798365644, 
          98.76533832747205}, {-253.08820512820512`, -29.32939367483298, 
          106.93333333333334`}}], 
         Polygon3DBox[{{-254., 0., 
          90.}, {-253.77205128205128`, -16.35634399182822, 
          94.38266916373603}, {-253.77205128205128`, -16.93333333333333, 
          90.}, {-254., 0., 90.}, {-254., 0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, -16.35634399182822, 
          94.38266916373603}, {-253.08820512820512`, -32.71268798365644, 
          98.76533832747205}, {-253.08820512820512`, -33.86666666666666, 
          90.}, {-253.77205128205128`, -16.93333333333333, 
          90.}, {-253.77205128205128`, -16.35634399182822, 
          94.38266916373603}}], 
         Polygon3DBox[{{-253.08820512820512`, -32.71268798365644, 
          98.76533832747205}, {-251.94846153846154`, -49.06903197548466, 
          103.14800749120806`}, {-251.94846153846154`, -50.8, 
          90.}, {-253.08820512820512`, -33.86666666666666, 
          90.}, {-253.08820512820512`, -32.71268798365644, 
          98.76533832747205}}], 
         Polygon3DBox[{{-254., 0., 
          90.}, {-253.77205128205128`, -16.93333333333333, 
          90.}, {-253.77205128205128`, -16.356343991828222`, 
          85.61733083626399}, {-254., 0., 90.}, {-254., 0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, -16.93333333333333, 
          90.}, {-253.08820512820512`, -33.86666666666666, 
          90.}, {-253.08820512820512`, -32.712687983656444`, 
          81.23466167252796}, {-253.77205128205128`, -16.356343991828222`, 
          85.61733083626399}, {-253.77205128205128`, -16.93333333333333, 
          90.}}], Polygon3DBox[{{-253.08820512820512`, -33.86666666666666, 
          90.}, {-251.94846153846154`, -50.8, 
          90.}, {-251.94846153846154`, -49.06903197548467, 
          76.85199250879194}, {-253.08820512820512`, -32.712687983656444`, 
          81.23466167252796}, {-253.08820512820512`, -33.86666666666666, 
          90.}}], Polygon3DBox[{{-254., 0., 
          90.}, {-253.77205128205128`, -16.356343991828222`, 
          85.61733083626399}, {-253.77205128205128`, -14.664696837416496`, 
          81.53333333333333}, {-254., 0., 90.}, {-254., 0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, -16.356343991828222`, 
          85.61733083626399}, {-253.08820512820512`, -32.712687983656444`, 
          81.23466167252798}, {-253.08820512820512`, -29.329393674832993`, 
          73.06666666666668}, {-253.77205128205128`, -14.664696837416496`, 
          81.53333333333333}, {-253.77205128205128`, -16.356343991828222`, 
          85.61733083626399}}], 
         Polygon3DBox[{{-253.08820512820512`, -32.712687983656444`, 
          81.23466167252798}, {-251.94846153846154`, -49.06903197548467, 
          76.85199250879197}, {-251.94846153846154`, -43.99409051224949, 
          64.60000000000001}, {-253.08820512820512`, -29.329393674832993`, 
          73.06666666666668}, {-253.08820512820512`, -32.712687983656444`, 
          81.23466167252798}}], 
         Polygon3DBox[{{-254., 0., 
          90.}, {-253.77205128205128`, -14.664696837416496`, 
          81.53333333333333}, {-253.77205128205128`, -11.973674828092207`, 
          78.0263251719078}, {-254., 0., 90.}, {-254., 0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, -14.664696837416496`, 
          81.53333333333333}, {-253.08820512820512`, -29.329393674832993`, 
          73.06666666666668}, {-253.08820512820512`, -23.947349656184414`, 
          66.0526503438156}, {-253.77205128205128`, -11.973674828092207`, 
          78.0263251719078}, {-253.77205128205128`, -14.664696837416496`, 
          81.53333333333333}}], 
         Polygon3DBox[{{-253.08820512820512`, -29.329393674832993`, 
          73.06666666666668}, {-251.94846153846154`, -43.99409051224949, 
          64.60000000000001}, {-251.94846153846152`, -35.92102448427662, 
          54.07897551572339}, {-253.08820512820512`, -23.947349656184414`, 
          66.0526503438156}, {-253.08820512820512`, -29.329393674832993`, 
          73.06666666666668}}], 
         Polygon3DBox[{{-254., 0., 
          90.}, {-253.77205128205128`, -11.973674828092209`, 
          78.0263251719078}, {-253.77205128205128`, -8.466666666666672, 
          75.33530316258351}, {-254., 0., 90.}, {-254., 0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, -11.973674828092209`, 
          78.0263251719078}, {-253.08820512820512`, -23.947349656184418`, 
          66.0526503438156}, {-253.08820512820512`, -16.933333333333344`, 
          60.67060632516703}, {-253.77205128205128`, -8.466666666666672, 
          75.33530316258351}, {-253.77205128205128`, -11.973674828092209`, 
          78.0263251719078}}], 
         Polygon3DBox[{{-253.08820512820512`, -23.947349656184418`, 
          66.0526503438156}, {-251.94846153846152`, -35.92102448427663, 
          54.07897551572341}, {-251.94846153846154`, -25.40000000000002, 
          46.005909487750536`}, {-253.08820512820512`, -16.933333333333344`, 
          60.67060632516703}, {-253.08820512820512`, -23.947349656184418`, 
          66.0526503438156}}], 
         Polygon3DBox[{{-254., 0., 
          90.}, {-253.77205128205128`, -8.466666666666672, 
          75.33530316258351}, {-253.77205128205128`, -4.382669163736029, 
          73.64365600817177}, {-254., 0., 90.}, {-254., 0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, -8.466666666666672, 
          75.33530316258351}, {-253.08820512820512`, -16.933333333333344`, 
          60.67060632516703}, {-253.08820512820512`, -8.765338327472058, 
          57.28731201634356}, {-253.77205128205128`, -4.382669163736029, 
          73.64365600817177}, {-253.77205128205128`, -8.466666666666672, 
          75.33530316258351}}], 
         Polygon3DBox[{{-253.08820512820512`, -16.933333333333344`, 
          60.67060632516703}, {-251.94846153846154`, -25.40000000000002, 
          46.005909487750536`}, {-251.94846153846154`, -13.148007491208089`, 
          40.930968024515344`}, {-253.08820512820512`, -8.765338327472058, 
          57.28731201634356}, {-253.08820512820512`, -16.933333333333344`, 
          60.67060632516703}}], 
         Polygon3DBox[{{-254., 0., 
          90.}, {-253.77205128205128`, -4.382669163736029, 
          73.64365600817177}, {-253.77205128205128`, \
-1.8150424110089726`*^-14, 73.06666666666666}, {-254., 0., 90.}, {-254., 0., 
          90.}}], Polygon3DBox[{{-253.77205128205128`, -4.382669163736029, 
          73.64365600817177}, {-253.08820512820512`, -8.765338327472058, 
          57.28731201634356}, {-253.08820512820512`, -3.630084822017945*^-14, 
          56.13333333333334}, {-253.77205128205128`, \
-1.8150424110089726`*^-14, 
          73.06666666666666}, {-253.77205128205128`, -4.382669163736029, 
          73.64365600817177}}], 
         Polygon3DBox[{{-253.08820512820512`, -8.765338327472058, 
          57.28731201634356}, {-251.94846153846154`, -13.148007491208089`, 
          40.930968024515344`}, {-251.94846153846154`, \
-5.4451272330269185`*^-14, 
          39.2}, {-253.08820512820512`, -3.630084822017945*^-14, 
          56.13333333333334}, {-253.08820512820512`, -8.765338327472058, 
          57.28731201634356}}], 
         Polygon3DBox[{{-254., 0., 
          90.}, {-253.77205128205128`, -3.110602869834277*^-15, 
          73.06666666666666}, {-253.77205128205128`, 4.38266916373601, 
          73.64365600817177}, {-254., 0., 90.}, {-254., 0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, -3.110602869834277*^-15, 
          73.06666666666666}, {-253.08820512820512`, -6.221205739668554*^-15, 
          56.13333333333334}, {-253.08820512820512`, 8.76533832747202, 
          57.287312016343556`}, {-253.77205128205128`, 4.38266916373601, 
          73.64365600817177}, {-253.77205128205128`, -3.110602869834277*^-15, 
          73.06666666666666}}], 
         Polygon3DBox[{{-253.08820512820512`, -6.221205739668554*^-15, 
          56.13333333333334}, {-251.94846153846154`, -9.33180860950283*^-15, 
          39.2}, {-251.94846153846154`, 13.14800749120803, 
          40.93096802451533}, {-253.08820512820512`, 8.76533832747202, 
          57.287312016343556`}, {-253.08820512820512`, \
-6.221205739668554*^-15, 56.13333333333334}}], 
         Polygon3DBox[{{-254., 0., 90.}, {-253.77205128205128`, 
          4.38266916373601, 73.64365600817177}, {-253.77205128205128`, 
          8.466666666666654, 75.3353031625835}, {-254., 0., 90.}, {-254., 0., 
          90.}}], Polygon3DBox[{{-253.77205128205128`, 4.38266916373601, 
          73.64365600817177}, {-253.08820512820512`, 8.76533832747202, 
          57.287312016343556`}, {-253.08820512820512`, 16.93333333333331, 
          60.670606325167}, {-253.77205128205128`, 8.466666666666654, 
          75.3353031625835}, {-253.77205128205128`, 4.38266916373601, 
          73.64365600817177}}], 
         Polygon3DBox[{{-253.08820512820512`, 8.76533832747202, 
          57.287312016343556`}, {-251.94846153846154`, 13.14800749120803, 
          40.93096802451533}, {-251.94846153846154`, 25.399999999999963`, 
          46.0059094877505}, {-253.08820512820512`, 16.93333333333331, 
          60.670606325167}, {-253.08820512820512`, 8.76533832747202, 
          57.287312016343556`}}], 
         Polygon3DBox[{{-254., 0., 90.}, {-253.77205128205128`, 
          8.466666666666654, 75.3353031625835}, {-253.77205128205128`, 
          11.97367482809219, 78.02632517190779}, {-254., 0., 90.}, {-254., 0.,
           90.}}], 
         Polygon3DBox[{{-253.77205128205128`, 8.466666666666654, 
          75.3353031625835}, {-253.08820512820512`, 16.93333333333331, 
          60.670606325167}, {-253.08820512820512`, 23.94734965618438, 
          66.05265034381557}, {-253.77205128205128`, 11.97367482809219, 
          78.02632517190779}, {-253.77205128205128`, 8.466666666666654, 
          75.3353031625835}}], 
         Polygon3DBox[{{-253.08820512820512`, 16.93333333333331, 
          60.670606325167}, {-251.94846153846154`, 25.399999999999963`, 
          46.0059094877505}, {-251.94846153846152`, 35.92102448427657, 
          54.07897551572334}, {-253.08820512820512`, 23.94734965618438, 
          66.05265034381557}, {-253.08820512820512`, 16.93333333333331, 
          60.670606325167}}], 
         Polygon3DBox[{{-254., 0., 90.}, {-253.77205128205128`, 
          11.973674828092202`, 78.02632517190779}, {-253.77205128205128`, 
          14.664696837416487`, 81.53333333333333}, {-254., 0., 90.}, {-254., 
          0., 90.}}], 
         Polygon3DBox[{{-253.77205128205128`, 11.973674828092202`, 
          78.02632517190779}, {-253.08820512820512`, 23.947349656184404`, 
          66.05265034381559}, {-253.08820512820512`, 29.329393674832975`, 
          73.06666666666666}, {-253.77205128205128`, 14.664696837416487`, 
          81.53333333333333}, {-253.77205128205128`, 11.973674828092202`, 
          78.02632517190779}}], 
         Polygon3DBox[{{-253.08820512820512`, 23.947349656184404`, 
          66.05265034381559}, {-251.94846153846152`, 35.92102448427661, 
          54.07897551572338}, {-251.94846153846154`, 43.994090512249464`, 
          64.59999999999998}, {-253.08820512820512`, 29.329393674832975`, 
          73.06666666666666}, {-253.08820512820512`, 23.947349656184404`, 
          66.05265034381559}}], 
         Polygon3DBox[{{-254., 0., 90.}, {-253.77205128205128`, 
          14.664696837416487`, 81.53333333333333}, {-253.77205128205128`, 
          16.35634399182822, 85.61733083626397}, {-254., 0., 90.}, {-254., 0.,
           90.}}], 
         Polygon3DBox[{{-253.77205128205128`, 14.664696837416487`, 
          81.53333333333333}, {-253.08820512820512`, 29.329393674832975`, 
          73.06666666666666}, {-253.08820512820512`, 32.71268798365644, 
          81.23466167252793}, {-253.77205128205128`, 16.35634399182822, 
          85.61733083626397}, {-253.77205128205128`, 14.664696837416487`, 
          81.53333333333333}}], 
         Polygon3DBox[{{-253.08820512820512`, 29.329393674832975`, 
          73.06666666666666}, {-251.94846153846154`, 43.994090512249464`, 
          64.59999999999998}, {-251.94846153846154`, 49.069031975484656`, 
          76.85199250879191}, {-253.08820512820512`, 32.71268798365644, 
          81.23466167252793}, {-253.08820512820512`, 29.329393674832975`, 
          73.06666666666666}}], 
         Polygon3DBox[{{-254., 0., 90.}, {-253.77205128205128`, 
          16.35634399182822, 85.61733083626397}, {-253.77205128205128`, 
          16.93333333333333, 89.99999999999999}, {-254., 0., 90.}, {-254., 0.,
           90.}}], 
         Polygon3DBox[{{-253.77205128205128`, 16.35634399182822, 
          85.61733083626397}, {-253.08820512820512`, 32.71268798365644, 
          81.23466167252793}, {-253.08820512820512`, 33.86666666666666, 
          89.99999999999996}, {-253.77205128205128`, 16.93333333333333, 
          89.99999999999999}, {-253.77205128205128`, 16.35634399182822, 
          85.61733083626397}}], 
         Polygon3DBox[{{-253.08820512820512`, 32.71268798365644, 
          81.23466167252793}, {-251.94846153846154`, 49.069031975484656`, 
          76.85199250879191}, {-251.94846153846154`, 50.8, 
          89.99999999999994}, {-253.08820512820512`, 33.86666666666666, 
          89.99999999999996}, {-253.08820512820512`, 32.71268798365644, 
          81.23466167252793}}], 
         {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIJ6pxnwmsi7/QBoYeDowgEBDmANM/H6XHte1Dg8H
38mZXypORsLF+TbMj7b77+owEwRuxjjMgIq7pEQrPvnq6KC0aa3Ap6p4uPoM
sPmWDsxvnk87vz8BLl44y2fxcW8thx2LuptMkxLh4k/kaq/3s7yxmQW2ACGe
DlF/AF19MsT8AyxQ82HucYa45wC6e3gg7j8wG+p+mPg9iH8P+KH5Fxo+B3CE
z4EtOdO4282C4eL8UPPTQdrUAuDucYO6Z//sJfekubzh6nOg7v/qn7DkIIM7
XLwe6l/l0otfNctd4OLa1+c+zGZm3QsJH2e4eBw0PBXR1MdAw/8D1Hy08HHY
jeYebmj8pkLdDxO/C00PG9D8C0s//0GgPswBAOv6DoE=
           "]], 
          {GrayLevel[0.5], EdgeForm[None], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, 16.93333333333333, 
            90.}, {-243.84, 16.356343991828222`, 94.38266916373601}, {-243.84,
             0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, 16.93333333333333, 90.}, {-243.84, 
            33.86666666666666, 90.}, {-243.84, 32.712687983656444`, 
            98.76533832747204}, {-243.84, 16.356343991828222`, 
            94.38266916373601}, {-243.84, 16.93333333333333, 90.}}], 
           Polygon3DBox[{{-243.84, 33.86666666666666, 90.}, {-243.84, 50.8, 
            90.}, {-243.84, 49.06903197548467, 103.14800749120805`}, {-243.84,
             32.712687983656444`, 98.76533832747204}, {-243.84, 
            33.86666666666666, 90.}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, 16.356343991828222`, 
            94.38266916373601}, {-243.84, 14.664696837416495`, 
            98.46666666666667}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, 16.356343991828222`, 
            94.38266916373601}, {-243.84, 32.712687983656444`, 
            98.76533832747204}, {-243.84, 29.32939367483299, 
            106.93333333333334`}, {-243.84, 14.664696837416495`, 
            98.46666666666667}, {-243.84, 16.356343991828222`, 
            94.38266916373601}}], 
           Polygon3DBox[{{-243.84, 32.712687983656444`, 
            98.76533832747204}, {-243.84, 49.06903197548467, 
            103.14800749120805`}, {-243.84, 43.994090512249485`, 
            115.39999999999999`}, {-243.84, 29.32939367483299, 
            106.93333333333334`}, {-243.84, 32.712687983656444`, 
            98.76533832747204}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, 14.664696837416495`, 
            98.46666666666667}, {-243.84, 11.973674828092204`, 
            101.9736748280922}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, 14.664696837416495`, 
            98.46666666666667}, {-243.84, 29.32939367483299, 
            106.93333333333334`}, {-243.84, 23.947349656184407`, 
            113.9473496561844}, {-243.84, 11.973674828092204`, 
            101.9736748280922}, {-243.84, 14.664696837416495`, 
            98.46666666666667}}], 
           Polygon3DBox[{{-243.84, 29.32939367483299, 
            106.93333333333334`}, {-243.84, 43.994090512249485`, 
            115.39999999999999`}, {-243.84, 35.921024484276614`, 
            125.92102448427661`}, {-243.84, 23.947349656184407`, 
            113.9473496561844}, {-243.84, 29.32939367483299, 
            106.93333333333334`}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, 11.973674828092204`, 
            101.9736748280922}, {-243.84, 8.466666666666669, 
            104.6646968374165}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, 11.973674828092204`, 
            101.9736748280922}, {-243.84, 23.947349656184407`, 
            113.9473496561844}, {-243.84, 16.933333333333337`, 
            119.32939367483299`}, {-243.84, 8.466666666666669, 
            104.6646968374165}, {-243.84, 11.973674828092204`, 
            101.9736748280922}}], 
           Polygon3DBox[{{-243.84, 23.947349656184407`, 
            113.9473496561844}, {-243.84, 35.921024484276614`, 
            125.92102448427661`}, {-243.84, 25.400000000000006`, 
            133.99409051224947`}, {-243.84, 16.933333333333337`, 
            119.32939367483299`}, {-243.84, 23.947349656184407`, 
            113.9473496561844}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, 8.466666666666669, 
            104.6646968374165}, {-243.84, 4.382669163736021, 
            106.35634399182823`}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, 8.466666666666669, 
            104.6646968374165}, {-243.84, 16.933333333333337`, 
            119.32939367483299`}, {-243.84, 8.765338327472042, 
            122.71268798365644`}, {-243.84, 4.382669163736021, 
            106.35634399182823`}, {-243.84, 8.466666666666669, 
            104.6646968374165}}], 
           Polygon3DBox[{{-243.84, 16.933333333333337`, 
            119.32939367483299`}, {-243.84, 25.400000000000006`, 
            133.99409051224947`}, {-243.84, 13.148007491208064`, 
            139.06903197548468`}, {-243.84, 8.765338327472042, 
            122.71268798365644`}, {-243.84, 16.933333333333337`, 
            119.32939367483299`}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, 4.382669163736021, 
            106.35634399182823`}, {-243.84, 4.7968229333419556`*^-15, 
            106.93333333333334`}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, 4.382669163736021, 
            106.35634399182823`}, {-243.84, 8.765338327472042, 
            122.71268798365644`}, {-243.84, 9.593645866683911*^-15, 
            123.86666666666666`}, {-243.84, 4.7968229333419556`*^-15, 
            106.93333333333334`}, {-243.84, 4.382669163736021, 
            106.35634399182823`}}], 
           Polygon3DBox[{{-243.84, 8.765338327472042, 
            122.71268798365644`}, {-243.84, 13.148007491208064`, 
            139.06903197548468`}, {-243.84, 1.4390468800025868`*^-14, 
            140.8}, {-243.84, 9.593645866683911*^-15, 
            123.86666666666666`}, {-243.84, 8.765338327472042, 
            122.71268798365644`}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, 
            1.0368676232780922`*^-15, 
            106.93333333333334`}, {-243.84, -4.382669163736015, 
            106.35634399182823`}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, 1.0368676232780922`*^-15, 
            106.93333333333334`}, {-243.84, 2.0737352465561844`*^-15, 
            123.86666666666666`}, {-243.84, -8.76533832747203, 
            122.71268798365645`}, {-243.84, -4.382669163736015, 
            106.35634399182823`}, {-243.84, 1.0368676232780922`*^-15, 
            106.93333333333334`}}], 
           Polygon3DBox[{{-243.84, 2.0737352465561844`*^-15, 
            123.86666666666666`}, {-243.84, 3.110602869834277*^-15, 
            140.8}, {-243.84, -13.148007491208046`, 
            139.06903197548468`}, {-243.84, -8.76533832747203, 
            122.71268798365645`}, {-243.84, 2.0737352465561844`*^-15, 
            123.86666666666666`}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, -4.382669163736015, 
            106.35634399182823`}, {-243.84, -8.466666666666661, 
            104.6646968374165}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, -4.382669163736015, 
            106.35634399182823`}, {-243.84, -8.76533832747203, 
            122.71268798365645`}, {-243.84, -16.933333333333323`, 
            119.329393674833}, {-243.84, -8.466666666666661, 
            104.6646968374165}, {-243.84, -4.382669163736015, 
            106.35634399182823`}}], 
           Polygon3DBox[{{-243.84, -8.76533832747203, 
            122.71268798365645`}, {-243.84, -13.148007491208046`, 
            139.06903197548468`}, {-243.84, -25.399999999999988`, 
            133.9940905122495}, {-243.84, -16.933333333333323`, 
            119.329393674833}, {-243.84, -8.76533832747203, 
            122.71268798365645`}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, -8.466666666666661, 
            104.6646968374165}, {-243.84, -11.973674828092202`, 
            101.9736748280922}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, -8.466666666666661, 
            104.6646968374165}, {-243.84, -16.933333333333323`, 
            119.329393674833}, {-243.84, -23.947349656184404`, 
            113.9473496561844}, {-243.84, -11.973674828092202`, 
            101.9736748280922}, {-243.84, -8.466666666666661, 
            104.6646968374165}}], 
           Polygon3DBox[{{-243.84, -16.933333333333323`, 
            119.329393674833}, {-243.84, -25.399999999999988`, 
            133.9940905122495}, {-243.84, -35.92102448427661, 
            125.92102448427661`}, {-243.84, -23.947349656184404`, 
            113.9473496561844}, {-243.84, -16.933333333333323`, 
            119.329393674833}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, -11.973674828092202`, 
            101.9736748280922}, {-243.84, -14.664696837416495`, 
            98.46666666666667}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, -11.973674828092202`, 
            101.9736748280922}, {-243.84, -23.947349656184404`, 
            113.9473496561844}, {-243.84, -29.32939367483299, 
            106.93333333333334`}, {-243.84, -14.664696837416495`, 
            98.46666666666667}, {-243.84, -11.973674828092202`, 
            101.9736748280922}}], 
           Polygon3DBox[{{-243.84, -23.947349656184404`, 
            113.9473496561844}, {-243.84, -35.92102448427661, 
            125.92102448427661`}, {-243.84, -43.994090512249485`, 
            115.39999999999999`}, {-243.84, -29.32939367483299, 
            106.93333333333334`}, {-243.84, -23.947349656184404`, 
            113.9473496561844}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, -14.66469683741649, 
            98.46666666666667}, {-243.84, -16.35634399182822, 
            94.38266916373603}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, -14.66469683741649, 
            98.46666666666667}, {-243.84, -29.32939367483298, 
            106.93333333333334`}, {-243.84, -32.71268798365644, 
            98.76533832747205}, {-243.84, -16.35634399182822, 
            94.38266916373603}, {-243.84, -14.66469683741649, 
            98.46666666666667}}], 
           Polygon3DBox[{{-243.84, -29.32939367483298, 
            106.93333333333334`}, {-243.84, -43.99409051224947, 
            115.40000000000002`}, {-243.84, -49.06903197548466, 
            103.14800749120806`}, {-243.84, -32.71268798365644, 
            98.76533832747205}, {-243.84, -29.32939367483298, 
            106.93333333333334`}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, -16.35634399182822, 
            94.38266916373603}, {-243.84, -16.93333333333333, 90.}, {-243.84, 
            0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, -16.35634399182822, 
            94.38266916373603}, {-243.84, -32.71268798365644, 
            98.76533832747205}, {-243.84, -33.86666666666666, 
            90.}, {-243.84, -16.93333333333333, 
            90.}, {-243.84, -16.35634399182822, 94.38266916373603}}], 
           Polygon3DBox[{{-243.84, -32.71268798365644, 
            98.76533832747205}, {-243.84, -49.06903197548466, 
            103.14800749120806`}, {-243.84, -50.8, 
            90.}, {-243.84, -33.86666666666666, 
            90.}, {-243.84, -32.71268798365644, 98.76533832747205}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, -16.93333333333333, 
            90.}, {-243.84, -16.356343991828222`, 
            85.61733083626399}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, -16.93333333333333, 
            90.}, {-243.84, -33.86666666666666, 
            90.}, {-243.84, -32.712687983656444`, 
            81.23466167252796}, {-243.84, -16.356343991828222`, 
            85.61733083626399}, {-243.84, -16.93333333333333, 90.}}], 
           Polygon3DBox[{{-243.84, -33.86666666666666, 90.}, {-243.84, -50.8, 
            90.}, {-243.84, -49.06903197548467, 
            76.85199250879194}, {-243.84, -32.712687983656444`, 
            81.23466167252796}, {-243.84, -33.86666666666666, 90.}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, -16.356343991828222`, 
            85.61733083626399}, {-243.84, -14.664696837416496`, 
            81.53333333333333}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, -16.356343991828222`, 
            85.61733083626399}, {-243.84, -32.712687983656444`, 
            81.23466167252798}, {-243.84, -29.329393674832993`, 
            73.06666666666668}, {-243.84, -14.664696837416496`, 
            81.53333333333333}, {-243.84, -16.356343991828222`, 
            85.61733083626399}}], 
           Polygon3DBox[{{-243.84, -32.712687983656444`, 
            81.23466167252798}, {-243.84, -49.06903197548467, 
            76.85199250879197}, {-243.84, -43.99409051224949, 
            64.60000000000001}, {-243.84, -29.329393674832993`, 
            73.06666666666668}, {-243.84, -32.712687983656444`, 
            81.23466167252798}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, -14.664696837416496`, 
            81.53333333333333}, {-243.84, -11.973674828092207`, 
            78.0263251719078}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, -14.664696837416496`, 
            81.53333333333333}, {-243.84, -29.329393674832993`, 
            73.06666666666668}, {-243.84, -23.947349656184414`, 
            66.0526503438156}, {-243.84, -11.973674828092207`, 
            78.0263251719078}, {-243.84, -14.664696837416496`, 
            81.53333333333333}}], 
           Polygon3DBox[{{-243.84, -29.329393674832993`, 
            73.06666666666668}, {-243.84, -43.99409051224949, 
            64.60000000000001}, {-243.84, -35.92102448427662, 
            54.07897551572339}, {-243.84, -23.947349656184414`, 
            66.0526503438156}, {-243.84, -29.329393674832993`, 
            73.06666666666668}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, -11.973674828092209`, 
            78.0263251719078}, {-243.84, -8.466666666666672, 
            75.33530316258351}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, -11.973674828092209`, 
            78.0263251719078}, {-243.84, -23.947349656184418`, 
            66.0526503438156}, {-243.84, -16.933333333333344`, 
            60.67060632516703}, {-243.84, -8.466666666666672, 
            75.33530316258351}, {-243.84, -11.973674828092209`, 
            78.0263251719078}}], 
           Polygon3DBox[{{-243.84, -23.947349656184418`, 
            66.0526503438156}, {-243.84, -35.92102448427663, 
            54.07897551572341}, {-243.84, -25.40000000000002, 
            46.005909487750536`}, {-243.84, -16.933333333333344`, 
            60.67060632516703}, {-243.84, -23.947349656184418`, 
            66.0526503438156}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, -8.466666666666672, 
            75.33530316258351}, {-243.84, -4.382669163736029, 
            73.64365600817177}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, -8.466666666666672, 
            75.33530316258351}, {-243.84, -16.933333333333344`, 
            60.67060632516703}, {-243.84, -8.765338327472058, 
            57.28731201634356}, {-243.84, -4.382669163736029, 
            73.64365600817177}, {-243.84, -8.466666666666672, 
            75.33530316258351}}], 
           Polygon3DBox[{{-243.84, -16.933333333333344`, 
            60.67060632516703}, {-243.84, -25.40000000000002, 
            46.005909487750536`}, {-243.84, -13.148007491208089`, 
            40.930968024515344`}, {-243.84, -8.765338327472058, 
            57.28731201634356}, {-243.84, -16.933333333333344`, 
            60.67060632516703}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, -4.382669163736029, 
            73.64365600817177}, {-243.84, -1.8150424110089726`*^-14, 
            73.06666666666666}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, -4.382669163736029, 
            73.64365600817177}, {-243.84, -8.765338327472058, 
            57.28731201634356}, {-243.84, -3.630084822017945*^-14, 
            56.13333333333334}, {-243.84, -1.8150424110089726`*^-14, 
            73.06666666666666}, {-243.84, -4.382669163736029, 
            73.64365600817177}}], 
           Polygon3DBox[{{-243.84, -8.765338327472058, 
            57.28731201634356}, {-243.84, -13.148007491208089`, 
            40.930968024515344`}, {-243.84, -5.4451272330269185`*^-14, 
            39.2}, {-243.84, -3.630084822017945*^-14, 
            56.13333333333334}, {-243.84, -8.765338327472058, 
            57.28731201634356}}], 
           Polygon3DBox[{{-243.84, 0., 
            90.}, {-243.84, -3.110602869834277*^-15, 
            73.06666666666666}, {-243.84, 4.38266916373601, 
            73.64365600817177}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, -3.110602869834277*^-15, 
            73.06666666666666}, {-243.84, -6.221205739668554*^-15, 
            56.13333333333334}, {-243.84, 8.76533832747202, 
            57.287312016343556`}, {-243.84, 4.38266916373601, 
            73.64365600817177}, {-243.84, -3.110602869834277*^-15, 
            73.06666666666666}}], 
           Polygon3DBox[{{-243.84, -6.221205739668554*^-15, 
            56.13333333333334}, {-243.84, -9.33180860950283*^-15, 
            39.2}, {-243.84, 13.14800749120803, 40.93096802451533}, {-243.84, 
            8.76533832747202, 
            57.287312016343556`}, {-243.84, -6.221205739668554*^-15, 
            56.13333333333334}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, 4.38266916373601, 
            73.64365600817177}, {-243.84, 8.466666666666654, 
            75.3353031625835}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, 4.38266916373601, 
            73.64365600817177}, {-243.84, 8.76533832747202, 
            57.287312016343556`}, {-243.84, 16.93333333333331, 
            60.670606325167}, {-243.84, 8.466666666666654, 
            75.3353031625835}, {-243.84, 4.38266916373601, 
            73.64365600817177}}], 
           Polygon3DBox[{{-243.84, 8.76533832747202, 
            57.287312016343556`}, {-243.84, 13.14800749120803, 
            40.93096802451533}, {-243.84, 25.399999999999963`, 
            46.0059094877505}, {-243.84, 16.93333333333331, 
            60.670606325167}, {-243.84, 8.76533832747202, 
            57.287312016343556`}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, 8.466666666666654, 
            75.3353031625835}, {-243.84, 11.97367482809219, 
            78.02632517190779}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, 8.466666666666654, 
            75.3353031625835}, {-243.84, 16.93333333333331, 
            60.670606325167}, {-243.84, 23.94734965618438, 
            66.05265034381557}, {-243.84, 11.97367482809219, 
            78.02632517190779}, {-243.84, 8.466666666666654, 
            75.3353031625835}}], 
           Polygon3DBox[{{-243.84, 16.93333333333331, 
            60.670606325167}, {-243.84, 25.399999999999963`, 
            46.0059094877505}, {-243.84, 35.92102448427657, 
            54.07897551572334}, {-243.84, 23.94734965618438, 
            66.05265034381557}, {-243.84, 16.93333333333331, 
            60.670606325167}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, 11.973674828092202`, 
            78.02632517190779}, {-243.84, 14.664696837416487`, 
            81.53333333333333}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, 11.973674828092202`, 
            78.02632517190779}, {-243.84, 23.947349656184404`, 
            66.05265034381559}, {-243.84, 29.329393674832975`, 
            73.06666666666666}, {-243.84, 14.664696837416487`, 
            81.53333333333333}, {-243.84, 11.973674828092202`, 
            78.02632517190779}}], 
           Polygon3DBox[{{-243.84, 23.947349656184404`, 
            66.05265034381559}, {-243.84, 35.92102448427661, 
            54.07897551572338}, {-243.84, 43.994090512249464`, 
            64.59999999999998}, {-243.84, 29.329393674832975`, 
            73.06666666666666}, {-243.84, 23.947349656184404`, 
            66.05265034381559}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, 14.664696837416487`, 
            81.53333333333333}, {-243.84, 16.35634399182822, 
            85.61733083626397}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, 14.664696837416487`, 
            81.53333333333333}, {-243.84, 29.329393674832975`, 
            73.06666666666666}, {-243.84, 32.71268798365644, 
            81.23466167252793}, {-243.84, 16.35634399182822, 
            85.61733083626397}, {-243.84, 14.664696837416487`, 
            81.53333333333333}}], 
           Polygon3DBox[{{-243.84, 29.329393674832975`, 
            73.06666666666666}, {-243.84, 43.994090512249464`, 
            64.59999999999998}, {-243.84, 49.069031975484656`, 
            76.85199250879191}, {-243.84, 32.71268798365644, 
            81.23466167252793}, {-243.84, 29.329393674832975`, 
            73.06666666666666}}], 
           Polygon3DBox[{{-243.84, 0., 90.}, {-243.84, 16.35634399182822, 
            85.61733083626397}, {-243.84, 16.93333333333333, 
            89.99999999999999}, {-243.84, 0., 90.}, {-243.84, 0., 90.}}], 
           Polygon3DBox[{{-243.84, 16.35634399182822, 
            85.61733083626397}, {-243.84, 32.71268798365644, 
            81.23466167252793}, {-243.84, 33.86666666666666, 
            89.99999999999996}, {-243.84, 16.93333333333333, 
            89.99999999999999}, {-243.84, 16.35634399182822, 
            85.61733083626397}}], 
           Polygon3DBox[{{-243.84, 32.71268798365644, 
            81.23466167252793}, {-243.84, 49.069031975484656`, 
            76.85199250879191}, {-243.84, 50.8, 89.99999999999994}, {-243.84, 
            33.86666666666666, 89.99999999999996}, {-243.84, 
            32.71268798365644, 81.23466167252793}}], 
           {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIK4WWef+sCrvQBoYeDowgEBDmANM/H6XHte1Dg8H
38mZXypORsLF+TbMj7b77+owEwRuxsDFXVKiFZ98dXRQ2rRW4FNVPFw8A2y+
pQPzm+fTzu9PgIsXzvJZfNxby2HHou4m06REuPgTudrr/SxvbGaBLUCIp0PU
H0BXnwwx/wALmvnOEPccQHcPD8T9B2ajuf8exL8H/ND8Cw2fAzjC58CWnGnc
7WbBcHF+qPnpIG1qAXBxN6h79s9eck+ayxsungN1/1f/hCUHGdzh4vVQ/yqX
XvyqWe4CF9e+PvdhNjPrXkj4OMPF46DhqYimPgYa/h/QzIeGj8NuNPdwQ+M3
Fc39d6HpYQOaf2Hp5z8I1Ic5AAAtMBpW
             "]], 
            {GrayLevel[0.5], EdgeForm[None], 
             Polygon3DBox[{{-251.94846153846154`, 50.8, 90.}, {-243.84, 50.8, 
              90.}, {-243.84, 49.06903197548467, 
              103.14800749120805`}, {-251.94846153846154`, 49.06903197548467, 
              103.14800749120805`}, {-251.94846153846154`, 50.8, 90.}}], 
             Polygon3DBox[{{-251.94846153846154`, 49.06903197548467, 
              103.14800749120805`}, {-243.84, 49.06903197548467, 
              103.14800749120805`}, {-243.84, 43.994090512249485`, 
              115.39999999999999`}, {-251.94846153846154`, 
              43.994090512249485`, 
              115.39999999999999`}, {-251.94846153846154`, 49.06903197548467, 
              103.14800749120805`}}], 
             Polygon3DBox[{{-251.94846153846154`, 43.994090512249485`, 
              115.39999999999999`}, {-243.84, 43.994090512249485`, 
              115.39999999999999`}, {-243.84, 35.921024484276614`, 
              125.92102448427661`}, {-251.94846153846152`, 
              35.921024484276614`, 
              125.92102448427661`}, {-251.94846153846154`, 
              43.994090512249485`, 115.39999999999999`}}], 
             Polygon3DBox[{{-251.94846153846152`, 35.921024484276614`, 
              125.92102448427661`}, {-243.84, 35.921024484276614`, 
              125.92102448427661`}, {-243.84, 25.400000000000006`, 
              133.99409051224947`}, {-251.94846153846154`, 
              25.400000000000006`, 
              133.99409051224947`}, {-251.94846153846152`, 
              35.921024484276614`, 125.92102448427661`}}], 
             Polygon3DBox[{{-251.94846153846154`, 25.400000000000006`, 
              133.99409051224947`}, {-243.84, 25.400000000000006`, 
              133.99409051224947`}, {-243.84, 13.148007491208064`, 
              139.06903197548468`}, {-251.94846153846154`, 
              13.148007491208064`, 
              139.06903197548468`}, {-251.94846153846154`, 
              25.400000000000006`, 133.99409051224947`}}], 
             Polygon3DBox[{{-251.94846153846154`, 13.148007491208064`, 
              139.06903197548468`}, {-243.84, 13.148007491208064`, 
              139.06903197548468`}, {-243.84, 1.4390468800025868`*^-14, 
              140.8}, {-251.94846153846154`, 1.4390468800025868`*^-14, 
              140.8}, {-251.94846153846154`, 13.148007491208064`, 
              139.06903197548468`}}], 
             Polygon3DBox[{{-251.94846153846154`, 3.110602869834277*^-15, 
              140.8}, {-243.84, 3.110602869834277*^-15, 
              140.8}, {-243.84, -13.148007491208046`, 
              139.06903197548468`}, {-251.94846153846154`, \
-13.148007491208046`, 139.06903197548468`}, {-251.94846153846154`, 
              3.110602869834277*^-15, 140.8}}], 
             Polygon3DBox[{{-251.94846153846154`, -13.148007491208046`, 
              139.06903197548468`}, {-243.84, -13.148007491208046`, 
              139.06903197548468`}, {-243.84, -25.399999999999988`, 
              133.9940905122495}, {-251.94846153846154`, -25.399999999999988`,
               133.9940905122495}, {-251.94846153846154`, \
-13.148007491208046`, 139.06903197548468`}}], 
             Polygon3DBox[{{-251.94846153846154`, -25.399999999999988`, 
              133.9940905122495}, {-243.84, -25.399999999999988`, 
              133.9940905122495}, {-243.84, -35.92102448427661, 
              125.92102448427661`}, {-251.94846153846152`, -35.92102448427661,
               125.92102448427661`}, {-251.94846153846154`, \
-25.399999999999988`, 133.9940905122495}}], 
             Polygon3DBox[{{-251.94846153846152`, -35.92102448427661, 
              125.92102448427661`}, {-243.84, -35.92102448427661, 
              125.92102448427661`}, {-243.84, -43.994090512249485`, 
              115.39999999999999`}, {-251.94846153846154`, \
-43.994090512249485`, 
              115.39999999999999`}, {-251.94846153846152`, -35.92102448427661,
               125.92102448427661`}}], 
             Polygon3DBox[{{-251.94846153846154`, -43.99409051224947, 
              115.40000000000002`}, {-243.84, -43.99409051224947, 
              115.40000000000002`}, {-243.84, -49.06903197548466, 
              103.14800749120806`}, {-251.94846153846154`, -49.06903197548466,
               103.14800749120806`}, {-251.94846153846154`, \
-43.99409051224947, 115.40000000000002`}}], 
             Polygon3DBox[{{-251.94846153846154`, -49.06903197548466, 
              103.14800749120806`}, {-243.84, -49.06903197548466, 
              103.14800749120806`}, {-243.84, -50.8, 
              90.}, {-251.94846153846154`, -50.8, 
              90.}, {-251.94846153846154`, -49.06903197548466, 
              103.14800749120806`}}], 
             Polygon3DBox[{{-251.94846153846154`, -50.8, 
              90.}, {-243.84, -50.8, 90.}, {-243.84, -49.06903197548467, 
              76.85199250879194}, {-251.94846153846154`, -49.06903197548467, 
              76.85199250879194}, {-251.94846153846154`, -50.8, 90.}}], 
             Polygon3DBox[{{-251.94846153846154`, -49.06903197548467, 
              76.85199250879197}, {-243.84, -49.06903197548467, 
              76.85199250879197}, {-243.84, -43.99409051224949, 
              64.60000000000001}, {-251.94846153846154`, -43.99409051224949, 
              64.60000000000001}, {-251.94846153846154`, -49.06903197548467, 
              76.85199250879197}}], 
             Polygon3DBox[{{-251.94846153846154`, -43.99409051224949, 
              64.60000000000001}, {-243.84, -43.99409051224949, 
              64.60000000000001}, {-243.84, -35.92102448427662, 
              54.07897551572339}, {-251.94846153846152`, -35.92102448427662, 
              54.07897551572339}, {-251.94846153846154`, -43.99409051224949, 
              64.60000000000001}}], 
             Polygon3DBox[{{-251.94846153846152`, -35.92102448427663, 
              54.07897551572341}, {-243.84, -35.92102448427663, 
              54.07897551572341}, {-243.84, -25.40000000000002, 
              46.005909487750536`}, {-251.94846153846154`, -25.40000000000002,
               46.005909487750536`}, {-251.94846153846152`, \
-35.92102448427663, 54.07897551572341}}], 
             Polygon3DBox[{{-251.94846153846154`, -25.40000000000002, 
              46.005909487750536`}, {-243.84, -25.40000000000002, 
              46.005909487750536`}, {-243.84, -13.148007491208089`, 
              40.930968024515344`}, {-251.94846153846154`, \
-13.148007491208089`, 
              40.930968024515344`}, {-251.94846153846154`, -25.40000000000002,
               46.005909487750536`}}], 
             Polygon3DBox[{{-251.94846153846154`, -13.148007491208089`, 
              40.930968024515344`}, {-243.84, -13.148007491208089`, 
              40.930968024515344`}, {-243.84, -5.4451272330269185`*^-14, 
              39.2}, {-251.94846153846154`, -5.4451272330269185`*^-14, 
              39.2}, {-251.94846153846154`, -13.148007491208089`, 
              40.930968024515344`}}], 
             Polygon3DBox[{{-251.94846153846154`, -9.33180860950283*^-15, 
              39.2}, {-243.84, -9.33180860950283*^-15, 39.2}, {-243.84, 
              13.14800749120803, 40.93096802451533}, {-251.94846153846154`, 
              13.14800749120803, 
              40.93096802451533}, {-251.94846153846154`, \
-9.33180860950283*^-15, 39.2}}], 
             Polygon3DBox[{{-251.94846153846154`, 13.14800749120803, 
              40.93096802451533}, {-243.84, 13.14800749120803, 
              40.93096802451533}, {-243.84, 25.399999999999963`, 
              46.0059094877505}, {-251.94846153846154`, 25.399999999999963`, 
              46.0059094877505}, {-251.94846153846154`, 13.14800749120803, 
              40.93096802451533}}], 
             Polygon3DBox[{{-251.94846153846154`, 25.399999999999963`, 
              46.0059094877505}, {-243.84, 25.399999999999963`, 
              46.0059094877505}, {-243.84, 35.92102448427657, 
              54.07897551572334}, {-251.94846153846152`, 35.92102448427657, 
              54.07897551572334}, {-251.94846153846154`, 25.399999999999963`, 
              46.0059094877505}}], 
             Polygon3DBox[{{-251.94846153846152`, 35.92102448427661, 
              54.07897551572338}, {-243.84, 35.92102448427661, 
              54.07897551572338}, {-243.84, 43.994090512249464`, 
              64.59999999999998}, {-251.94846153846154`, 43.994090512249464`, 
              64.59999999999998}, {-251.94846153846152`, 35.92102448427661, 
              54.07897551572338}}], 
             Polygon3DBox[{{-251.94846153846154`, 43.994090512249464`, 
              64.59999999999998}, {-243.84, 43.994090512249464`, 
              64.59999999999998}, {-243.84, 49.069031975484656`, 
              76.85199250879191}, {-251.94846153846154`, 49.069031975484656`, 
              76.85199250879191}, {-251.94846153846154`, 43.994090512249464`, 
              64.59999999999998}}], 
             Polygon3DBox[{{-251.94846153846154`, 49.069031975484656`, 
              76.85199250879191}, {-243.84, 49.069031975484656`, 
              76.85199250879191}, {-243.84, 50.8, 
              89.99999999999994}, {-251.94846153846154`, 50.8, 
              89.99999999999994}, {-251.94846153846154`, 49.069031975484656`, 
              76.85199250879191}}]}}}}}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{381., 254., -164.}, {381., -254., -164.}, {381., -254., 
       344.}, {381., 254., 344.}, {381., 254., -164.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{381., -254., -164.}, {-1905., -254., -164.}, {-1905., -254.,
        344.}, {381., -254., 344.}, {381., -254., -164.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-1905., -254., -164.}, {-1905., 254., -164.}, {-1905., 254.,
        344.}, {-1905., -254., 344.}, {-1905., -254., -164.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-1905., 254., -164.}, {381., 254., -164.}, {381., 254., 
       344.}, {-1905., 254., 344.}, {-1905., 254., -164.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{381., -254., -164.}, {381., 254., -164.}, {-1905., 
       254., -164.}, {-1905., -254., -164.}, {381., -254., -164.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{381., 254., 344.}, {381., -254., 344.}, {-1905., -254., 
       344.}, {-1905., 254., 344.}, {381., 254., 344.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1302.8676, -240.75437774378105`, 
      9.047362012070394}, {-1124.2717333333335`, -240.75437774378105`, 
      9.047362012070394}, {-1124.2717333333335`, -136.88512437026523`, \
-123.95902113754636`}, {-1302.8676, -136.88512437026523`, \
-123.95902113754636`}, {-1302.8676, -240.75437774378105`, 
      9.047362012070394}}], 
     Polygon3DBox[{{-1302.8676, -136.88512437026523`, -123.95902113754636`}, \
{-1124.2717333333335`, -136.88512437026523`, -123.95902113754636`}, \
{-1124.2717333333335`, 
      27.409800211274426`, -162.51673776678254`}, {-1302.8676, 
      27.409800211274426`, -162.51673776678254`}, {-1302.8676, \
-136.88512437026523`, -123.95902113754636`}}], 
     Polygon3DBox[{{-1302.8676, 
      27.40980021127437, -162.51673776678254`}, {-1124.2717333333335`, 
      27.40980021127437, -162.51673776678254`}, {-1124.2717333333335`, 
      179.60512242138302`, -89.6051224213831}, {-1302.8676, 
      179.60512242138302`, -89.6051224213831}, {-1302.8676, 
      27.40980021127437, -162.51673776678254`}}], 
     Polygon3DBox[{{-1302.8676, 
      179.605122421383, -89.60512242138313}, {-1124.2717333333335`, 
      179.605122421383, -89.60512242138313}, {-1124.2717333333335`, 
      252.5167377667825, 62.59019978872544}, {-1302.8676, 252.5167377667825, 
      62.59019978872544}, {-1302.8676, 
      179.605122421383, -89.60512242138313}}], 
     Polygon3DBox[{{-1302.8676, 252.5167377667825, 
      62.59019978872547}, {-1124.2717333333335`, 252.5167377667825, 
      62.59019978872547}, {-1124.2717333333335`, 213.95902113754642`, 
      226.88512437026517`}, {-1302.8676, 213.95902113754642`, 
      226.88512437026517`}, {-1302.8676, 252.5167377667825, 
      62.59019978872547}}], 
     Polygon3DBox[{{-1302.8676, 213.95902113754642`, 
      226.88512437026517`}, {-1124.2717333333335`, 213.95902113754642`, 
      226.88512437026517`}, {-1124.2717333333335`, 80.9526379879297, 
      330.754377743781}, {-1302.8676, 80.9526379879297, 
      330.754377743781}, {-1302.8676, 213.95902113754642`, 
      226.88512437026517`}}], 
     Polygon3DBox[{{-1124.2717333333335`, -240.75437774378105`, 
      9.047362012070394}, {-945.6758666666667, -240.75437774378105`, 
      9.047362012070394}, {-945.6758666666667, -136.88512437026523`, \
-123.95902113754636`}, {-1124.2717333333335`, -136.88512437026523`, \
-123.95902113754636`}, {-1124.2717333333335`, -240.75437774378105`, 
      9.047362012070394}}], 
     Polygon3DBox[{{-1124.2717333333335`, -136.88512437026523`, \
-123.95902113754636`}, {-945.6758666666667, -136.88512437026523`, \
-123.95902113754636`}, {-945.6758666666667, 
      27.409800211274426`, -162.51673776678254`}, {-1124.2717333333335`, 
      27.409800211274426`, -162.51673776678254`}, {-1124.2717333333335`, \
-136.88512437026523`, -123.95902113754636`}}], 
     Polygon3DBox[{{-1124.2717333333335`, 
      27.40980021127437, -162.51673776678254`}, {-945.6758666666667, 
      27.40980021127437, -162.51673776678254`}, {-945.6758666666667, 
      179.60512242138302`, -89.6051224213831}, {-1124.2717333333335`, 
      179.60512242138302`, -89.6051224213831}, {-1124.2717333333335`, 
      27.40980021127437, -162.51673776678254`}}], 
     Polygon3DBox[{{-1124.2717333333335`, 
      179.605122421383, -89.60512242138313}, {-945.6758666666667, 
      179.605122421383, -89.60512242138313}, {-945.6758666666667, 
      252.5167377667825, 62.59019978872544}, {-1124.2717333333335`, 
      252.5167377667825, 62.59019978872544}, {-1124.2717333333335`, 
      179.605122421383, -89.60512242138313}}], 
     Polygon3DBox[{{-1124.2717333333335`, 252.5167377667825, 
      62.59019978872547}, {-945.6758666666667, 252.5167377667825, 
      62.59019978872547}, {-945.6758666666667, 213.95902113754642`, 
      226.88512437026517`}, {-1124.2717333333335`, 213.95902113754642`, 
      226.88512437026517`}, {-1124.2717333333335`, 252.5167377667825, 
      62.59019978872547}}], 
     Polygon3DBox[{{-1124.2717333333335`, 213.95902113754642`, 
      226.88512437026517`}, {-945.6758666666667, 213.95902113754642`, 
      226.88512437026517`}, {-945.6758666666667, 80.9526379879297, 
      330.754377743781}, {-1124.2717333333335`, 80.9526379879297, 
      330.754377743781}, {-1124.2717333333335`, 213.95902113754642`, 
      226.88512437026517`}}], 
     Polygon3DBox[{{-945.6758666666667, -240.75437774378105`, 
      9.047362012070394}, {-767.08, -240.75437774378105`, 
      9.047362012070394}, {-767.08, -136.88512437026523`, \
-123.95902113754636`}, {-945.6758666666667, -136.88512437026523`, \
-123.95902113754636`}, {-945.6758666666667, -240.75437774378105`, 
      9.047362012070394}}], 
     Polygon3DBox[{{-945.6758666666667, -136.88512437026523`, \
-123.95902113754636`}, {-767.08, -136.88512437026523`, -123.95902113754636`}, \
{-767.08, 27.409800211274426`, -162.51673776678254`}, {-945.6758666666667, 
      27.409800211274426`, -162.51673776678254`}, {-945.6758666666667, \
-136.88512437026523`, -123.95902113754636`}}], 
     Polygon3DBox[{{-945.6758666666667, 
      27.40980021127437, -162.51673776678254`}, {-767.08, 
      27.40980021127437, -162.51673776678254`}, {-767.08, 
      179.60512242138302`, -89.6051224213831}, {-945.6758666666667, 
      179.60512242138302`, -89.6051224213831}, {-945.6758666666667, 
      27.40980021127437, -162.51673776678254`}}], 
     Polygon3DBox[{{-945.6758666666667, 
      179.605122421383, -89.60512242138313}, {-767.08, 
      179.605122421383, -89.60512242138313}, {-767.08, 252.5167377667825, 
      62.59019978872544}, {-945.6758666666667, 252.5167377667825, 
      62.59019978872544}, {-945.6758666666667, 
      179.605122421383, -89.60512242138313}}], 
     Polygon3DBox[{{-945.6758666666667, 252.5167377667825, 
      62.59019978872547}, {-767.08, 252.5167377667825, 
      62.59019978872547}, {-767.08, 213.95902113754642`, 
      226.88512437026517`}, {-945.6758666666667, 213.95902113754642`, 
      226.88512437026517`}, {-945.6758666666667, 252.5167377667825, 
      62.59019978872547}}], 
     Polygon3DBox[{{-945.6758666666667, 213.95902113754642`, 
      226.88512437026517`}, {-767.08, 213.95902113754642`, 
      226.88512437026517`}, {-767.08, 80.9526379879297, 
      330.754377743781}, {-945.6758666666667, 80.9526379879297, 
      330.754377743781}, {-945.6758666666667, 213.95902113754642`, 
      226.88512437026517`}}], 
     Polygon3DBox[{{-767.08, -240.75437774378105`, 
      9.047362012070394}, {-588.4841333333334, -240.75437774378105`, 
      9.047362012070394}, {-588.4841333333334, -136.88512437026523`, \
-123.95902113754636`}, {-767.08, -136.88512437026523`, -123.95902113754636`}, \
{-767.08, -240.75437774378105`, 9.047362012070394}}], 
     Polygon3DBox[{{-767.08, -136.88512437026523`, -123.95902113754636`}, \
{-588.4841333333334, -136.88512437026523`, -123.95902113754636`}, \
{-588.4841333333334, 27.409800211274426`, -162.51673776678254`}, {-767.08, 
      27.409800211274426`, -162.51673776678254`}, {-767.08, \
-136.88512437026523`, -123.95902113754636`}}], 
     Polygon3DBox[{{-767.08, 
      27.40980021127437, -162.51673776678254`}, {-588.4841333333334, 
      27.40980021127437, -162.51673776678254`}, {-588.4841333333334, 
      179.60512242138302`, -89.6051224213831}, {-767.08, 
      179.60512242138302`, -89.6051224213831}, {-767.08, 
      27.40980021127437, -162.51673776678254`}}], 
     Polygon3DBox[{{-767.08, 
      179.605122421383, -89.60512242138313}, {-588.4841333333334, 
      179.605122421383, -89.60512242138313}, {-588.4841333333334, 
      252.5167377667825, 62.59019978872544}, {-767.08, 252.5167377667825, 
      62.59019978872544}, {-767.08, 179.605122421383, -89.60512242138313}}], 
     Polygon3DBox[{{-767.08, 252.5167377667825, 
      62.59019978872547}, {-588.4841333333334, 252.5167377667825, 
      62.59019978872547}, {-588.4841333333334, 213.95902113754642`, 
      226.88512437026517`}, {-767.08, 213.95902113754642`, 
      226.88512437026517`}, {-767.08, 252.5167377667825, 62.59019978872547}}],
      Polygon3DBox[{{-767.08, 213.95902113754642`, 
      226.88512437026517`}, {-588.4841333333334, 213.95902113754642`, 
      226.88512437026517`}, {-588.4841333333334, 80.9526379879297, 
      330.754377743781}, {-767.08, 80.9526379879297, 
      330.754377743781}, {-767.08, 213.95902113754642`, 
      226.88512437026517`}}], 
     Polygon3DBox[{{-588.4841333333334, -240.75437774378105`, 
      9.047362012070394}, {-409.8882666666667, -240.75437774378105`, 
      9.047362012070394}, {-409.8882666666667, -136.88512437026523`, \
-123.95902113754636`}, {-588.4841333333334, -136.88512437026523`, \
-123.95902113754636`}, {-588.4841333333334, -240.75437774378105`, 
      9.047362012070394}}], 
     Polygon3DBox[{{-588.4841333333334, -136.88512437026523`, \
-123.95902113754636`}, {-409.8882666666667, -136.88512437026523`, \
-123.95902113754636`}, {-409.8882666666667, 
      27.409800211274426`, -162.51673776678254`}, {-588.4841333333334, 
      27.409800211274426`, -162.51673776678254`}, {-588.4841333333334, \
-136.88512437026523`, -123.95902113754636`}}], 
     Polygon3DBox[{{-588.4841333333334, 
      27.40980021127437, -162.51673776678254`}, {-409.8882666666667, 
      27.40980021127437, -162.51673776678254`}, {-409.8882666666667, 
      179.60512242138302`, -89.6051224213831}, {-588.4841333333334, 
      179.60512242138302`, -89.6051224213831}, {-588.4841333333334, 
      27.40980021127437, -162.51673776678254`}}], 
     Polygon3DBox[{{-588.4841333333334, 
      179.605122421383, -89.60512242138313}, {-409.8882666666667, 
      179.605122421383, -89.60512242138313}, {-409.8882666666667, 
      252.5167377667825, 62.59019978872544}, {-588.4841333333334, 
      252.5167377667825, 62.59019978872544}, {-588.4841333333334, 
      179.605122421383, -89.60512242138313}}], 
     Polygon3DBox[{{-588.4841333333334, 252.5167377667825, 
      62.59019978872547}, {-409.8882666666667, 252.5167377667825, 
      62.59019978872547}, {-409.8882666666667, 213.95902113754642`, 
      226.88512437026517`}, {-588.4841333333334, 213.95902113754642`, 
      226.88512437026517`}, {-588.4841333333334, 252.5167377667825, 
      62.59019978872547}}], 
     Polygon3DBox[{{-588.4841333333334, 213.95902113754642`, 
      226.88512437026517`}, {-409.8882666666667, 213.95902113754642`, 
      226.88512437026517`}, {-409.8882666666667, 80.9526379879297, 
      330.754377743781}, {-588.4841333333334, 80.9526379879297, 
      330.754377743781}, {-588.4841333333334, 213.95902113754642`, 
      226.88512437026517`}}], 
     Polygon3DBox[{{-409.8882666666667, -240.75437774378105`, 
      9.047362012070394}, {-231.29240000000004`, -240.75437774378105`, 
      9.047362012070394}, {-231.29240000000004`, -136.88512437026523`, \
-123.95902113754636`}, {-409.8882666666667, -136.88512437026523`, \
-123.95902113754636`}, {-409.8882666666667, -240.75437774378105`, 
      9.047362012070394}}], 
     Polygon3DBox[{{-409.8882666666667, -136.88512437026523`, \
-123.95902113754636`}, {-231.29240000000004`, -136.88512437026523`, \
-123.95902113754636`}, {-231.29240000000004`, 
      27.409800211274426`, -162.51673776678254`}, {-409.8882666666667, 
      27.409800211274426`, -162.51673776678254`}, {-409.8882666666667, \
-136.88512437026523`, -123.95902113754636`}}], 
     Polygon3DBox[{{-409.8882666666667, 
      27.40980021127437, -162.51673776678254`}, {-231.29240000000004`, 
      27.40980021127437, -162.51673776678254`}, {-231.29240000000004`, 
      179.60512242138302`, -89.6051224213831}, {-409.8882666666667, 
      179.60512242138302`, -89.6051224213831}, {-409.8882666666667, 
      27.40980021127437, -162.51673776678254`}}], 
     Polygon3DBox[{{-409.8882666666667, 
      179.605122421383, -89.60512242138313}, {-231.29240000000004`, 
      179.605122421383, -89.60512242138313}, {-231.29240000000004`, 
      252.5167377667825, 62.59019978872544}, {-409.8882666666667, 
      252.5167377667825, 62.59019978872544}, {-409.8882666666667, 
      179.605122421383, -89.60512242138313}}], 
     Polygon3DBox[{{-409.8882666666667, 252.5167377667825, 
      62.59019978872547}, {-231.29240000000004`, 252.5167377667825, 
      62.59019978872547}, {-231.29240000000004`, 213.95902113754642`, 
      226.88512437026517`}, {-409.8882666666667, 213.95902113754642`, 
      226.88512437026517`}, {-409.8882666666667, 252.5167377667825, 
      62.59019978872547}}], 
     Polygon3DBox[{{-409.8882666666667, 213.95902113754642`, 
      226.88512437026517`}, {-231.29240000000004`, 213.95902113754642`, 
      226.88512437026517`}, {-231.29240000000004`, 80.9526379879297, 
      330.754377743781}, {-409.8882666666667, 80.9526379879297, 
      330.754377743781}, {-409.8882666666667, 213.95902113754642`, 
      226.88512437026517`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIOa6vrjANm3KgdrOgxGJ84MdtJ71/RbfWeLgAgIz
JmKI/006qT9tSi+GeKEt0KQf7RjiT8W96zbGNGGIb3oClGisxBA3MQaCyTkk
i9dcjnm4bUGWg960g5WXu3Lg4t/KzoVWTs53mCPwV2jSTn+4eKjtJs3Y4jSH
FVUpwbvSwg7AxNfcY711u8fK4TtIX3AKXNwIZK5X4oEvy3Yeyj0YBxcPPSP7
Xd8o74DAls+WX1nUHXCJw/yLLg4LH3RxWHiii8PCH10cFl/o4rD4JVVcB+rf
P1D/wsRPQ8PnGzR84OaghSdM/Ds0/NdAwx8mXgmNL2NofOFKhwDGi0Eg
       "]], {}}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGAQAmImIAaxweBCuQOETj8AphvCHM6eOXMmZ/fkA+jiMPWM
YDr8AO/Wp6Ve9/Ph6tHFYer//geC8+EOfGjq0cXR3OPAhN09DujuYYPY6yCW
dfr1lH1BB2Dq0cVh6r9B7D0gh6Yelzh6OLRscZD7Nyv/wJ9aqUV8Qs4Y4YYe
Dnc2Q9TPAKs3PsB1abnqv4NxOMPhAlR9D0S9A7p69HBAc48DunvQwwGmnqEO
Yv6U6A1bmGt8HHCFwxmoe1qg7v8AVY8rHMD0kbkHdJrd/MMMleDuwRUOMPUL
ekHqhRyaRBzFrrSH4AwHmHqVPrD6Aw1Q9bjCAc09GPGIHg4w9SnNEPOTXu17
qV0R4YArHGDqKyDucZj0GqIeANAJalM=
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGAQAmJmID575syZnN2TDzCAwIV0CN0Q5gATZwSLhx/g3fq0
1Ot+Plz8738gOB/uwIcmDjXHAd0cNog5DmJZp19P2Rd0ACb+DWLOATmoeMsW
B7l/s/IP/KmVWsQn5Ax3z53NEPEZYHHjA1yXlqv+OxjncAEq3gMRd4CJo5kD
dw9MnKEOon5K9IYtzDU+Dmeg5rRAzf8AFQfrOzL3gE6zm3+YoRLcHJj4gl6Q
uJBDk4ij2JX2ELi4Sh9Y/EADmjjUnAPo5qQ0Q9Qnvdr3UrsiAi5eATHHYdJr
iDgA0ii0Dw==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.538110238381217*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ManipulateSystem", "[", "\n", 
  RowBox[{
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"CircleOfRays", "[", 
          RowBox[{
           RowBox[{"15", " ", "inch"}], ",", " ", 
           RowBox[{"NumberOfRays", "->", "6"}]}], "]"}], ",", 
         RowBox[{"15", " ", "inch"}], ",", "180"}], "]"}], ",", "\n", "\t", 
       RowBox[{"CassegrainTelescope", "[", 
        RowBox[{"2.5", ",", 
         RowBox[{"20", " ", "inch"}], ",", 
         RowBox[{"4", " ", "inch"}], ",", 
         RowBox[{"10", " ", "inch"}], ",", " ", 
         RowBox[{"OpenSide", "->", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              StyleBox["-",
               FontFamily->"Symbol",
               FontWeight->"Plain"], ".25"}], " ", "Pi"}], ",", 
            RowBox[{"1.3", " ", "Pi"}]}], "}"}]}], ",", " ", 
         RowBox[{"GraphicDesign", "->", "Solid"}]}], "]"}]}], "}"}], ",", 
     "\n", "\t", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "90"}], "}"}]}], "]"}], ",", 
   RowBox[{"Boxed", "->", "False"}], ",", " ", 
   RowBox[{"PlotType", " ", "\[Rule]", " ", "Full3D"}], ",", " ", 
   RowBox[{"PlotLabel", " ", "->", "\"\<Cassegrain Telescope Assembly\>\""}], 
   ",", 
   RowBox[{"SymbolicRanges", " ", "->", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Mx1", "->", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1500"}], ",", " ", "0"}], "}"}]}], ",", 
      RowBox[{"Mx2", "->", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1500"}], ",", " ", "0"}], "}"}]}], ",", " ", 
      RowBox[{"md2", "->", 
       RowBox[{"{", 
        RowBox[{"1", ",", "500"}], "}"}]}], ",", 
      RowBox[{"mf1", "->", 
       RowBox[{"{", 
        RowBox[{"500", ",", " ", "2000"}], "}"}]}], ",", 
      RowBox[{"mf2", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "500"}], ",", " ", 
         RowBox[{"-", "100"}]}], "}"}]}], ",", "  ", 
      RowBox[{"HoleDiameter", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "300"}], "}"}]}]}], " ", "}"}]}], ",", " ", 
   RowBox[{"SliderLabelReplacements", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
      "\"\<HoleDiameter\>\"", " ", "\[Rule]", " ", 
       "\"\<Primary Mirror Hole Diameter\>\""}], ",", " ", 
      RowBox[{"\"\<md2\>\"", "\[Rule]", "\"\<Secondary Mirror Diameter\>\""}],
       ",", 
      RowBox[{"\"\<mf1\>\"", "->", "\"\<Primary Mirror Focallength\>\""}], 
      ",", " ", "\n", 
      RowBox[{
      "\"\<mf2\>\"", " ", "->", "\"\<Secondary Mirror Focallength\>\""}], ",",
       " ", 
      RowBox[{
      "\"\<Mx1\>\"", " ", "\[Rule]", " ", 
       "\"\<Primary Mirror Position x\>\""}], ",", " ", 
      RowBox[{
      "\"\<Mx2\>\"", " ", "\[Rule]", " ", 
       "\"\<Secondary Mirror Position x\>\""}]}], "}"}]}], ",", " ", 
   RowBox[{"Axes", " ", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{"ImageSize", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"800", ",", " ", "450"}], "}"}]}]}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.510626386422254*^9, 3.510626392552518*^9}, {
  3.510626515462055*^9, 3.510626528780177*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`HoleDiameter$$ = 
    76.19999999999999, $CellContext`md2$$ = 101.6, $CellContext`mf1$$ = 
    1270., $CellContext`mf2$$ = -314.4761904761905, $CellContext`Mx1$$ = \
-1270., $CellContext`Mx2$$ = -254., \
$CellContext`staticpolygons1389120122132243176903$$ = {
     AbsoluteThickness[1], 
     AbsolutePointSize[1], 
     EdgeForm[], 
     RGBColor[0.4, 0.6, 0.8], 
     Polygon[CompressedData["
1:eJyV1F1o1nUYxvGNmpDZQR2EYEUpHcQieqMTZ/uLRIWKNl9mLf+1zdlWYyOT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      "]], 
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGITIAaxua4vLrBNm3KgtvNgROL8YAetZ32/xXeWOKzg
Lbnl8H8ShrgLCMyYiCH+qEpknbvhBAzxv0kn9adN6cUQN7+QyTz3WBeGeKEt
0EU/2jHEV68CAq1WDPGn4t51G2OaMMTtQB6TrccQ3/QEqKGxEkNcbX/Ep+6n
xRjiJsZAMDmHZPEjL0V9mUOSHVSsFeQNLIrg4jWXYx5uW5DloDftYOXlrhy4
+DTd12Y59/McSksmLSlcmQQX/1Z2LrRycr7DHIG/QpN2+sPF9fdummy2IsfB
YzbHtt5I4wMw8VDbTZqxxWkOK6pSgnelhcHFT6s15SaHRTsYgPRlJMLF19xj
vXW7x8rhO8ie4BS4+MOLnpOOLfWFuGt+MlzcCORur8QDX5btPJR7MA4u7lXm
YJdgkHmg4bL2LDaNAIR7zsh+1zfKOyCw5bPlVxZ1B1zisPBHF4fFF7o4LH7R
xWHpAV0cln7QxWHpDV0clj7RxWHpGV0clv7RxWH5BV0clr/QxWH5kVRxd2j4
d0DDHyauA42vP9D4golfhMbvdGj8wsRPQ9PDN2h6gIlfhqYffWj6gbsHLb3B
xA2h6VMHmj5h4t+h6XkNND3DxGHpvxKa/mHildD8YgzNLzDxA9D8pQrNX7jK
MQBdQUph
      "]]}, $CellContext`staticpolygons1489120122132243178052$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIAaxweBCuQOYPpAPoRtSDqCJH8AvXuqA3Rxc4gTM
PzL3AHHiGOYTECfafAf84lDzcbmHVPMJhw8uewmIEx2PBPxLINyINp9AfBEO
T1zmwMUBwkGWEA==
      "]]}, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`HoleDiameter$$], 76.19999999999999}, 0., 300.}, {{
       Hold[$CellContext`md2$$], 101.6}, 1., 500.}, {{
       Hold[$CellContext`mf1$$], 1270.}, 500., 2000.}, {{
       Hold[$CellContext`mf2$$], -314.4761904761905}, -500., -100.}, {{
       Hold[$CellContext`Mx1$$], -1270.}, -1500., 0.}, {{
       Hold[$CellContext`Mx2$$], -254.}, -1500., 0.}, {
      Hold[
       Style[
        Grid[{{"Primary Mirror Hole Diameter", 
           Manipulator[
            
            Dynamic[$CellContext`nonexistantvariable159389120122132243998339; \
$CellContext`HoleDiameter$$, ($CellContext`HoleDiameter$$ = #)& ], {0., 
            300.}], 
           
           Dynamic[$CellContext`nonexistantvariable159389120122132243998339; \
$CellContext`HoleDiameter$$, ($CellContext`HoleDiameter$$ = #)& ]}}]]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style[
        Grid[{{"Secondary Mirror Diameter", 
           Manipulator[
            
            Dynamic[$CellContext`nonexistantvariable159389120122132243998545; \
$CellContext`md2$$, ($CellContext`md2$$ = #)& ], {1., 500.}], 
           
           Dynamic[$CellContext`nonexistantvariable159389120122132243998545; \
$CellContext`md2$$, ($CellContext`md2$$ = #)& ]}}]]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style[
        Grid[{{"Primary Mirror Focallength", 
           Manipulator[
            
            Dynamic[$CellContext`nonexistantvariable159389120122132243998700; \
$CellContext`mf1$$, ($CellContext`mf1$$ = #)& ], {500., 2000.}], 
           
           Dynamic[$CellContext`nonexistantvariable159389120122132243998700; \
$CellContext`mf1$$, ($CellContext`mf1$$ = #)& ]}}]]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style[
        Grid[{{"Secondary Mirror Focallength", 
           Manipulator[
            
            Dynamic[$CellContext`nonexistantvariable159389120122132243998855; \
$CellContext`mf2$$, ($CellContext`mf2$$ = #)& ], {-500., -100.}], 
           
           Dynamic[$CellContext`nonexistantvariable159389120122132243998855; \
$CellContext`mf2$$, ($CellContext`mf2$$ = #)& ]}}]]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style[
        Grid[{{"Primary Mirror Position x", 
           Manipulator[
            
            Dynamic[$CellContext`nonexistantvariable159389120122132243999008; \
$CellContext`Mx1$$, ($CellContext`Mx1$$ = #)& ], {-1500., 0.}], 
           
           Dynamic[$CellContext`nonexistantvariable159389120122132243999008; \
$CellContext`Mx1$$, ($CellContext`Mx1$$ = #)& ]}}]]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style[
        Grid[{{"Secondary Mirror Position x", 
           Manipulator[
            
            Dynamic[$CellContext`nonexistantvariable159389120122132243999160; \
$CellContext`Mx2$$, ($CellContext`Mx2$$ = #)& ], {-1500., 0.}], 
           
           Dynamic[$CellContext`nonexistantvariable159389120122132243999160; \
$CellContext`Mx2$$, ($CellContext`Mx2$$ = #)& ]}}]]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{
              "Primary Mirror Hole Diameter", "Secondary Mirror Diameter", 
               "Primary Mirror Focallength", "Secondary Mirror Focallength", 
               "Primary Mirror Position x", 
               "Secondary Mirror Position x"}, {$CellContext`HoleDiameter$$, \
$CellContext`md2$$, $CellContext`mf1$$, $CellContext`mf2$$, \
$CellContext`Mx1$$, $CellContext`Mx2$$}}], 
           Optica`Optica`SymbolicRanges -> {$CellContext`HoleDiameter$$ -> {
              0., 300.}, $CellContext`md2$$ -> {1., 
              500.}, $CellContext`mf1$$ -> {500., 
              2000.}, $CellContext`mf2$$ -> {-500., -100.}, \
$CellContext`Mx1$$ -> {-1500., 0.}, $CellContext`Mx2$$ -> {-1500., 0.}}}; 
        Optica`Optica`$OpticalSystemScript = 
         "{Move[CircleOfRays[381., NumberOfRays -> 6], {381., 0, 90.}, {-1., \
0, 0}]}"; Print[
          InputForm[
           StringJoin["SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "Primary Mirror Hole Diameter", "Secondary Mirror Diameter", 
                "Primary Mirror Focallength", "Secondary Mirror Focallength", 
                "Primary Mirror Position x", 
                "Secondary Mirror Position x"}, {$CellContext`HoleDiameter$$, \
$CellContext`md2$$, $CellContext`mf1$$, $CellContext`mf2$$, \
$CellContext`Mx1$$, $CellContext`Mx2$$}}]]]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`staticpolygons1389120122132243176903$$], {
        AbsoluteThickness[1], 
        AbsolutePointSize[1], 
        EdgeForm[], 
        RGBColor[0.4, 0.6, 0.8], 
        Polygon[CompressedData["
1:eJyV1F1o1nUYxvGNmpDZQR2EYEUpHcQieqMTZ/uLRIWKNl9mLf+1zdlWYyOT
yHykLHozhMcwEIkOyg7UEbKDAsF4QIKgoOyVSIhiwtZBRJBIEORg13NwwZff
fR88MC5++3Iz9nxuGZrsG7mio6OjefnTdfkz//Pi0eXjLwwcbv249svzK5ZO
tN78fuyH3qXLq29/md764MV3cN97qtlx9aKx1id37pkZeXdjSx3avUPvqa/9
3IX+v/puGGx9tfeuo0/+V7f7tNM9/p762gdHHnjm4SvXt/7ZNPNe5/Hhdod2
umfM3qtP+8pHjp+YHV1ZXXPTsRvf2rij3aHdO/Se+trPf3PzsW2TA9XMsqf2
9Q4Ntju00z3+nvraN6+avm37czurqRd3bDq9c2u7Qzvd07fw/uOF9+rT/tv8
738wXh1Z82pz6Mw97Q7t3vH3hxfee9/3JfN/r+Zkta7/5Im3125ofy9o9w69
p772i/P/H3MT1ZZHzz123f6hdp92usffU1/77Jml60999nT19fz34/Hxdod2
usffU197faTn7+kDw1XPtode7lqxq92hne7x99TX/vznfV2XejZXf3w08ue1
U7vbHdqp434e3bBm9fWHDuGedTXqPPW1Z12NOk997e4wuV26x/1Un/asq1Hn
qa8962rUeeprd4fJ7dI97qf6tLvD5HbUefnpfd+zrkadp772rKtR56mvPetq
1Hnqa8+6GnWe+trdYXK71Hc/B89+132hu4l71tWo89TXnnU16jz1tbvD5Hbp
HvdTfdqzrkadp772rKtR56mv3R0mt0v3uJ/q0+4Ok9tR5+Wn933Puhp1nvra
s65Gnae+9qyrUeeprz3ratR56mt3h8ntUt/97Jv44vbRgwdxz7oadZ762rOu
Rp2nvnZ3mNwu3eN+qk971tWo89TXnnU16jz1tbvD5HbpHvdTfdrdYXI76rz8
9L7vWVejzlNfe9bVqPPU1551Neo89bVnXY06T33t7jC5Xeq7n79vmetcdPYA
7llXo85TX3vW1ajz1NfuDpPbpXvcT/Vpz7oadZ762rOuRp2nvnZ3mNwu3eN+
qk+7O0xuR52Xn973Petq1Hnqa8+6GnWe+tqzrkadp772rKtR56mv3R0mt0t9
9/PZVYt/+vDSG7hnXY06T33tWVejzlNfuztMbpfucT/Vpz3ratR56mvPuhp1
nvra3WFyu3SP+6k+7e4wuR11Xn563/esq1Hnqa8962rUeeprz7oadZ762rOu
Rp2nvnZ3mNwu9d3Pjlu7p1bf8RruWVejzlNfe9bVqPPU1+4Ok9ule9xP9WnP
uhp1nvras65Gnae+dneY3C7d436qT7s7TG5HnZef3vc962rUeeprz7oadZ76
2rOuRp2nvvasq1Hnqa/dHSa3S333s7lk3f5fh1/BPetq1Hnqa8+6GnWe+trd
YXK7dI/7qT7tWVejzlNfe9bVqPPU1+4Ok9ule9xP9Wl3h8ntqPPy0/u+Z12N
Ok997VlXo85TX3vW1ajz1NeedTXqPPW1u8PkdqnvfvbO/jz1790v4Z51Neo8
9bVnXY06T33t7jC5XbrH/VSf9qyrUeeprz3ratR56mt3h8nt0j3up/q0u8Pk
dtR5+el937OuRp2nvvasq1Hnqa8962rUeeprz7oadZ762t1hcpv6FTj8xKfL
+u97fw/u7l4FrlKf3lNfu7tXgaule/w99bW7wxW4XbrH/VSfdnevAlepT++p
r93dq8DV0j3+nvra3eEK3C7d436qT7s7XIHb1Pf38tP7vrt7FbhKfXpPfe3u
XgWulu7x99TX7u5V4GrpHn9Pfe3kHu10j7+nvnZ3WB3avVODw/te396566rd
uLt7NbhKfXpPfe3uXg2ulu7x99TX7g7X4HbpHvdTfdrdvRpcpT69p752d68G
V0v3+Hvqa3eHa3C7dI/7qT7t7nANblPf38tP7/vu7tXgKvXpPfW1u3s1uFq6
x99TX7u7V4OrpXv8PfW1k3u00z3+nvra3WF1aPdOAxy+9+T9/QNz47i7ew1w
lfr0nvra3b0GuFq6x99TX7s73AC3S/e4n+rT7u41wFXq03vqa3f3GuBq6R5/
T33t7nAD3C7d436qT7s73AC3qe/v5af3fXf3GuAq9ek99bW7ew1wtXSPv6e+
dnevAa6W7vH31NdO7tFO9/h76mt3h9Wh3Tv/A/0Kxr4=
         "]], 
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGITIAaxua4vLrBNm3KgtvNgROL8YAetZ32/xXeWOKzg
Lbnl8H8ShrgLCMyYiCH+qEpknbvhBAzxv0kn9adN6cUQN7+QyTz3WBeGeKEt
0EU/2jHEV68CAq1WDPGn4t51G2OaMMTtQB6TrccQ3/QEqKGxEkNcbX/Ep+6n
xRjiJsZAMDmHZPEjL0V9mUOSHVSsFeQNLIrg4jWXYx5uW5DloDftYOXlrhy4
+DTd12Y59/McSksmLSlcmQQX/1Z2LrRycr7DHIG/QpN2+sPF9fdummy2IsfB
YzbHtt5I4wMw8VDbTZqxxWkOK6pSgnelhcHFT6s15SaHRTsYgPRlJMLF19xj
vXW7x8rhO8ie4BS4+MOLnpOOLfWFuGt+MlzcCORur8QDX5btPJR7MA4u7lXm
YJdgkHmg4bL2LDaNAIR7zsh+1zfKOyCw5bPlVxZ1B1zisPBHF4fFF7o4LH7R
xWHpAV0cln7QxWHpDV0clj7RxWHpGV0clv7RxWH5BV0clr/QxWH5kVRxd2j4
d0DDHyauA42vP9D4golfhMbvdGj8wsRPQ9PDN2h6gIlfhqYffWj6gbsHLb3B
xA2h6VMHmj5h4t+h6XkNND3DxGHpvxKa/mHildD8YgzNLzDxA9D8pQrNX7jK
MQBdQUph
         "]]}}}, {{
       Hold[$CellContext`staticpolygons1489120122132243178052$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIAaxweBCuQOYPpAPoRtSDqCJH8AvXuqA3Rxc4gTM
PzL3AHHiGOYTECfafAf84lDzcbmHVPMJhw8uewmIEx2PBPxLINyINp9AfBEO
T1zmwMUBwkGWEA==
         "]]}}}}, Typeset`size$$ = {
    815., {241.34375, 246.65625}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`HoleDiameter$132862$$ = 
    0, $CellContext`md2$132863$$ = 0, $CellContext`mf1$132864$$ = 
    0, $CellContext`mf2$132865$$ = 0, $CellContext`Mx1$132866$$ = 
    0, $CellContext`Mx2$132867$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`HoleDiameter$$ = 
        76.19999999999999, $CellContext`md2$$ = 101.6, $CellContext`mf1$$ = 
        1270., $CellContext`mf2$$ = -314.4761904761905, $CellContext`Mx1$$ = \
-1270., $CellContext`Mx2$$ = -254., \
$CellContext`staticpolygons1389120122132243176903$$ = {
          AbsoluteThickness[1], 
          AbsolutePointSize[1], 
          EdgeForm[], 
          RGBColor[0.4, 0.6, 0.8], 
          Polygon[CompressedData["
1:eJyV1F1o1nUYxvGNmpDZQR2EYEUpHcQieqMTZ/uLRIWKNl9mLf+1zdlWYyOT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           "]], 
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGITIAaxua4vLrBNm3KgtvNgROL8YAetZ32/xXeWOKzg
Lbnl8H8ShrgLCMyYiCH+qEpknbvhBAzxv0kn9adN6cUQN7+QyTz3WBeGeKEt
0EU/2jHEV68CAq1WDPGn4t51G2OaMMTtQB6TrccQ3/QEqKGxEkNcbX/Ep+6n
xRjiJsZAMDmHZPEjL0V9mUOSHVSsFeQNLIrg4jWXYx5uW5DloDftYOXlrhy4
+DTd12Y59/McSksmLSlcmQQX/1Z2LrRycr7DHIG/QpN2+sPF9fdummy2IsfB
YzbHtt5I4wMw8VDbTZqxxWkOK6pSgnelhcHFT6s15SaHRTsYgPRlJMLF19xj
vXW7x8rhO8ie4BS4+MOLnpOOLfWFuGt+MlzcCORur8QDX5btPJR7MA4u7lXm
YJdgkHmg4bL2LDaNAIR7zsh+1zfKOyCw5bPlVxZ1B1zisPBHF4fFF7o4LH7R
xWHpAV0cln7QxWHpDV0clj7RxWHpGV0clv7RxWH5BV0clr/QxWH5kVRxd2j4
d0DDHyauA42vP9D4golfhMbvdGj8wsRPQ9PDN2h6gIlfhqYffWj6gbsHLb3B
xA2h6VMHmj5h4t+h6XkNND3DxGHpvxKa/mHildD8YgzNLzDxA9D8pQrNX7jK
MQBdQUph
           "]]}, $CellContext`staticpolygons1489120122132243178052$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIAaxweBCuQOYPpAPoRtSDqCJH8AvXuqA3Rxc4gTM
PzL3AHHiGOYTECfafAf84lDzcbmHVPMJhw8uewmIEx2PBPxLINyINp9AfBEO
T1zmwMUBwkGWEA==
           "]]}}, "ControllerVariables" :> {
        Hold[$CellContext`HoleDiameter$$, $CellContext`HoleDiameter$132862$$, 
         0], 
        Hold[$CellContext`md2$$, $CellContext`md2$132863$$, 0], 
        Hold[$CellContext`mf1$$, $CellContext`mf1$132864$$, 0], 
        Hold[$CellContext`mf2$$, $CellContext`mf2$132865$$, 0], 
        Hold[$CellContext`Mx1$$, $CellContext`Mx1$132866$$, 0], 
        Hold[$CellContext`Mx2$$, $CellContext`Mx2$132867$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         OpenerView[{"Cassegrain Telescope Assembly", 
           Show[{
             Graphics3D[{{
                Opacity[1], 
                Dynamic[
                 GeometricTransformation[{
                   AbsoluteThickness[1], 
                   AbsolutePointSize[1], 
                   EdgeForm[], 
                   RGBColor[0.4, 0.6, 0.8], 
                   Polygon[
                    (Map[
                    Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], CompressedData["
1:eJwt2FMUWMcCQNGksW3btm3btm3btm3btm2bDRr77a6+jz33f86aO0jQsF3F
tn8FCBBgvuHfb0CCEJSQhCIc4YlMFGIQk7jEIxGJSU4K0pCWjGQiG9nJTR4K
UJCiFKMUpSlPBapQlZrUoh71aUwTWtCStrSjE53pTg/60JeBDGIYwxnNGCYw
kalMYxaz/50DFrCEpaxkFetYz2a2sIOd7GUfhzjMcU5whrNc5BLXuM5t7vCA
hzzlGa94zTve84nPfOcHfwL8FyYwQQhBSMISjkhEJjoxiENcEpKIZCQnNWnI
QEayko1c5CY/BShCUUpSinKUpzJVqEFN6lKPRjSmOS1oQ1s60oludKc3fRjA
QIYyjFGMZjwTmMJUZjKLecxnMUtYwUrWso5NbGY7O9jDXg5yiGMc5zRnuMBF
rnKNW9zmPg94wlNe8oq3vOMjn/jGd37zh0AWTmCCE4IwhCUikYhGdGIThwQk
JCnJSEVq0pOBLGQlJ7nIR34KU4QSlKQs5ahEZapTgzrUpSGNaEZzWtOGDnSk
K93oRW/6M4AhDGUkoxjHeCYzhRnMZC7zWMRilrOCNaxlI5vYxnZ2s4cDHOQo
xzjFac5zgStc5Sa3uMd9HvOEF7zkDW/5wEe+8o1f/P73fxZIG4IRnNCEIQIR
iUo0YhGb+CQgCUlJSSrSkZ7MZCEHOclLPgpRmOKUoAxlqUglqlGd2tShAQ1p
SjNa0Zr2dKALXelJL/rRn8EMYQQjGcs4JjGZ6cxgDnNZyCKWsZzVrGEDG9nK
Nnaxm/0c4AhHOckpznGey1zhBje5yz0e8ZjnvOBv3vAPH/jCV37yi4CBtSEo
wQhFaMITgShEJSaxiEd8EpOEFKQkLenIRGayk4M85KUghShGcUpThgpUpCrV
qEVt6tOAJjSlJa1oR3s604Ue9KQv/RjEYIYzgjGMZSKTmMZ0ZjOHBSxkKctY
xWrWs4EtbGUnu9jHfg5zhBOc5CznuMRlrnODO9zlIY94xnNe8zfv+YfPfOEH
PwP/t/EHJAhBCUkowhGeyEQhBjGJSzwSkZjkpCANaclIJrKRndzkoQAFKUox
SlGa8lSgClWpSS3qUZ/GNKEFLWlLOzrRme70oA99GcgghjGc0YxhAhOZyjRm
MZv5LGAJS1nJKtaxns1sYQc72cs+DnGY45zgDGe5yCWucZ3b3OEBD3nKM17x
mne85xOf+c4P/vz/QBaYIIQgJGEJRyQiE50YxCEuCUlEMpKTmjRkICNZyUYu
cpOfAhShKCUpRTnKU5kq1KAmdalHIxrTnBa0oS0d6UQ3utObPgxgIEMZxihG
M54JTGEqM5nFPOazmCWsYCVrWccmNrOdHexhLwc5xDGOc5ozXOAiV7nGLW5z
nwc84SkvecVb3vGRT3zjO7/5Q6Bg2hCcEIQhLBGJRDSiE5s4JCAhSUlGKlKT
ngxkISs5yUU+8lOYIpSgJGUpRyUqU50a1KEuDWlEM5rTmjZ0oCNd6UYvetOf
AQxhKCMZxTjGM5kpzGAmc5nHIhaznBWsYS0b2cQ2trObPRzgIEc5xilOc54L
XOEqN7nFPe7zmCe84CVveMsHPvKVb/ziN38F14ZgBCc0YYhARKISjVjEJj4J
SEJSUpKKdKQnM1nIQU7yko9CFKY4JShDWSpSiWpUpzZ1aEBDmtKMVrSmPR3o
Qld60ot+9GcwQxjBSMYyjklMZjozmMNcFrKIZSxnNWvYwEa2so1d7GY/BzjC
UU5yinOc5zJXuMFN7nKPRzzmOS/4mzf8wwe+8JWf/CJgCG0ISjBCEZrwRCAK
UYlJLOIRn8QkIQUpSUs6MpGZ7OQgD3kpSCGKUZzSlKECFalKNWpRm/o0oAlN
aUkr2tGeznShBz3pSz8GMZjhjGAMY5nIJKYxndnMYQELWcoyVrGa9WxgC1vZ
yS72sZ/DHOEEJznLOS5xmevc4A53ecgjnvGc1/zNe/7hM1/4wc8Q/134AxKE
oIQkFOEIT2SiEIOYxCUeiUhMclKQhrRkJBPZyE5u8lCAghSlGKUoTXkqUIWq
1KQW9ahPY5rQgpa0pR2d6Ex3etCHvgxkEMMYzmjGMIGJTGUas5jNfBawhKWs
ZBXrWM9mtrCDnexlH4c4zHFOcIazXOQS17jObe7wgIc85RmveM073vOJz3zn
B3/+/xATmCCEICRhCUckIhOdGMQhLglJRDKSk5o0ZCAjWclGLnKTnwIUoSgl
KUU5ylOZKtSgJnWpRyMa05wWtKEtHelEN7rTmz4MYCBDGcYoRjOeCUxhKjOZ
xTzms5glrGAla1nHJjaznR3sYS8HOcQxjnOaM1zgIle5xi1uc58HPOEpL3nF
W97xkU984zu/+UOg0NoQnBCEISwRiUQ0ohObOCQgIUlJRipSk54MZCErOclF
PvJTmCKUoCRlKUclKlOdGtShLg1pRDOa05o2dKAjXelGL3rTnwEMYSgjGcU4
xjOZKcxgJnOZxyIWs5wVrGEtG9nENrazmz0c4CBHOcYpTnOeC1zhKje5xT3u
85gnvOAlb3jLBz7ylW/84jd/hdGGYAQnNGGIQESiEo1YxCY+/wPYMbr1
                    
                    "]]& )[
                    $CellContext`polygons1189120122132243055523[$CellContext`\
mf1$$, $CellContext`HoleDiameter$$]]], 
                   GrayLevel[0], 
                   AbsoluteThickness[0.5], 
                   Line[
                    (Map[
                    Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], {{1, 49}, {50, 98}, {99, 
                    147}, {148, 196}}]& )[
                    $CellContext`lines1189120122132243059218[$CellContext`mf1$\
$, $CellContext`HoleDiameter$$]]]}, {{{-1, 0, 0}, {0, -1, 0}, {0, 0, 
                   1}}, {$CellContext`Mx1$$, 0, 90.}}]], 
                Dynamic[
                 GeometricTransformation[{
                   AbsoluteThickness[1], 
                   AbsolutePointSize[1], 
                   EdgeForm[], 
                   RGBColor[0.4, 0.6, 0.8], 
                   Polygon[
                    (Map[
                    Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], CompressedData["
1:eJwt2NMWGMYCQNHkxrZt27Zt2zYb27Zt27Zt20bju7vahz3zAWcNEzRsV7Ht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                    
                    "]]& )[
                    $CellContext`polygons1289120122132243166881[$CellContext`\
md2$$, $CellContext`mf2$$]]], 
                   GrayLevel[0], 
                   AbsoluteThickness[0.5], 
                   Line[
                    (Map[
                    Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], {{1, 49}, {50, 98}}]& )[
                    $CellContext`lines1289120122132243167984[$CellContext`md2$\
$, $CellContext`mf2$$]]]}, {{{1, 0, 0}, {0, 1, 0}, {0, 0, 
                   1}}, {$CellContext`Mx2$$, 0, 
                    90.}}]], \
$CellContext`staticpolygons1389120122132243176903$$, \
$CellContext`staticpolygons1489120122132243178052$$, 
                Opacity[1], 
                RGBColor[
                0.038747429704798886`, 0.9161617552424038, 
                 0.039847212269181365`], 
                AbsoluteThickness[Medium], 
                Line[
                 Dynamic[
                  Refresh[
                   Map[{
                    Part[#, {1, 2, 3}], 
                    Part[#, {4, 5, 6}]}& , 
                    Select[
                    $CellContext`raytracefunction189120122132243225911[$\
CellContext`HoleDiameter$$, $CellContext`md2$$, $CellContext`mf1$$, \
$CellContext`mf2$$, $CellContext`Mx1$$, $CellContext`Mx2$$], And[
                    Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]], 
                   TrackedSymbols :> {$CellContext`HoleDiameter$$, \
$CellContext`md2$$, $CellContext`mf1$$, $CellContext`mf2$$, \
$CellContext`Mx1$$, $CellContext`Mx2$$}], SynchronousUpdating -> 
                  False]]}}]}, {
            PlotLabel -> "Cassegrain Telescope Assembly", Boxed -> False, 
             Axes -> True, ImageSize -> {800, 450}, ImageSize -> 800, 
             AspectRatio -> Automatic}]}, True], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`HoleDiameter$$, 76.19999999999999}, 
         0., 300., ControlType -> None}, {{$CellContext`md2$$, 101.6}, 1., 
         500., ControlType -> None}, {{$CellContext`mf1$$, 1270.}, 500., 
         2000., ControlType -> 
         None}, {{$CellContext`mf2$$, -314.4761904761905}, -500., -100., 
         ControlType -> None}, {{$CellContext`Mx1$$, -1270.}, -1500., 0., 
         ControlType -> None}, {{$CellContext`Mx2$$, -254.}, -1500., 0., 
         ControlType -> None}, 
        Style[
         Grid[{{"Primary Mirror Hole Diameter", 
            Manipulator[
             
             Dynamic[$CellContext`nonexistantvariable159389120122132243998339; \
$CellContext`HoleDiameter$$, ($CellContext`HoleDiameter$$ = #)& ], {0., 
             300.}], 
            
            Dynamic[$CellContext`nonexistantvariable159389120122132243998339; \
$CellContext`HoleDiameter$$, ($CellContext`HoleDiameter$$ = #)& ]}}]], 
        Style[
         Grid[{{"Secondary Mirror Diameter", 
            Manipulator[
             
             Dynamic[$CellContext`nonexistantvariable159389120122132243998545; \
$CellContext`md2$$, ($CellContext`md2$$ = #)& ], {1., 500.}], 
            
            Dynamic[$CellContext`nonexistantvariable159389120122132243998545; \
$CellContext`md2$$, ($CellContext`md2$$ = #)& ]}}]], 
        Style[
         Grid[{{"Primary Mirror Focallength", 
            Manipulator[
             
             Dynamic[$CellContext`nonexistantvariable159389120122132243998700; \
$CellContext`mf1$$, ($CellContext`mf1$$ = #)& ], {500., 2000.}], 
            
            Dynamic[$CellContext`nonexistantvariable159389120122132243998700; \
$CellContext`mf1$$, ($CellContext`mf1$$ = #)& ]}}]], 
        Style[
         Grid[{{"Secondary Mirror Focallength", 
            Manipulator[
             
             Dynamic[$CellContext`nonexistantvariable159389120122132243998855; \
$CellContext`mf2$$, ($CellContext`mf2$$ = #)& ], {-500., -100.}], 
            
            Dynamic[$CellContext`nonexistantvariable159389120122132243998855; \
$CellContext`mf2$$, ($CellContext`mf2$$ = #)& ]}}]], 
        Style[
         Grid[{{"Primary Mirror Position x", 
            Manipulator[
             
             Dynamic[$CellContext`nonexistantvariable159389120122132243999008; \
$CellContext`Mx1$$, ($CellContext`Mx1$$ = #)& ], {-1500., 0.}], 
            
            Dynamic[$CellContext`nonexistantvariable159389120122132243999008; \
$CellContext`Mx1$$, ($CellContext`Mx1$$ = #)& ]}}]], 
        Style[
         Grid[{{"Secondary Mirror Position x", 
            Manipulator[
             
             Dynamic[$CellContext`nonexistantvariable159389120122132243999160; \
$CellContext`Mx2$$, ($CellContext`Mx2$$ = #)& ], {-1500., 0.}], 
            
            Dynamic[$CellContext`nonexistantvariable159389120122132243999160; \
$CellContext`Mx2$$, ($CellContext`Mx2$$ = #)& ]}}]], 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{
               "Primary Mirror Hole Diameter", "Secondary Mirror Diameter", 
                "Primary Mirror Focallength", "Secondary Mirror Focallength", 
                "Primary Mirror Position x", 
                
                "Secondary Mirror Position x"}, {$CellContext`HoleDiameter$$, \
$CellContext`md2$$, $CellContext`mf1$$, $CellContext`mf2$$, \
$CellContext`Mx1$$, $CellContext`Mx2$$}}], 
            Optica`Optica`SymbolicRanges -> {$CellContext`HoleDiameter$$ -> {
               0., 300.}, $CellContext`md2$$ -> {1., 
               500.}, $CellContext`mf1$$ -> {500., 
               2000.}, $CellContext`mf2$$ -> {-500., -100.}, \
$CellContext`Mx1$$ -> {-1500., 0.}, $CellContext`Mx2$$ -> {-1500., 0.}}}; 
         Optica`Optica`$OpticalSystemScript = 
          "{Move[CircleOfRays[381., NumberOfRays -> 6], {381., 0, 90.}, {-1., \
0, 0}]}"; Print[
           InputForm[
            StringJoin["SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "Primary Mirror Hole Diameter", "Secondary Mirror Diameter", 
                 "Primary Mirror Focallength", "Secondary Mirror Focallength",
                  "Primary Mirror Position x", 
                 "Secondary Mirror Position x"}, \
{$CellContext`HoleDiameter$$, $CellContext`md2$$, $CellContext`mf1$$, \
$CellContext`mf2$$, $CellContext`Mx1$$, $CellContext`Mx2$$}}]]]]], ImageSize -> 
         Automatic], {{$CellContext`staticpolygons1389120122132243176903$$, {
           AbsoluteThickness[1], 
           AbsolutePointSize[1], 
           EdgeForm[], 
           RGBColor[0.4, 0.6, 0.8], 
           Polygon[CompressedData["
1:eJyV1F1o1nUYxvGNmpDZQR2EYEUpHcQieqMTZ/uLRIWKNl9mLf+1zdlWYyOT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            "]], 
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGITIAaxua4vLrBNm3KgtvNgROL8YAetZ32/xXeWOKzg
Lbnl8H8ShrgLCMyYiCH+qEpknbvhBAzxv0kn9adN6cUQN7+QyTz3WBeGeKEt
0EU/2jHEV68CAq1WDPGn4t51G2OaMMTtQB6TrccQ3/QEqKGxEkNcbX/Ep+6n
xRjiJsZAMDmHZPEjL0V9mUOSHVSsFeQNLIrg4jWXYx5uW5DloDftYOXlrhy4
+DTd12Y59/McSksmLSlcmQQX/1Z2LrRycr7DHIG/QpN2+sPF9fdummy2IsfB
YzbHtt5I4wMw8VDbTZqxxWkOK6pSgnelhcHFT6s15SaHRTsYgPRlJMLF19xj
vXW7x8rhO8ie4BS4+MOLnpOOLfWFuGt+MlzcCORur8QDX5btPJR7MA4u7lXm
YJdgkHmg4bL2LDaNAIR7zsh+1zfKOyCw5bPlVxZ1B1zisPBHF4fFF7o4LH7R
xWHpAV0cln7QxWHpDV0clj7RxWHpGV0clv7RxWH5BV0clr/QxWH5kVRxd2j4
d0DDHyauA42vP9D4golfhMbvdGj8wsRPQ9PDN2h6gIlfhqYffWj6gbsHLb3B
xA2h6VMHmj5h4t+h6XkNND3DxGHpvxKa/mHildD8YgzNLzDxA9D8pQrNX7jK
MQBdQUph
            "]]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons1489120122132243178052$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIAaxweBCuQOYPpAPoRtSDqCJH8AvXuqA3Rxc4gTM
PzL3AHHiGOYTECfafAf84lDzcbmHVPMJhw8uewmIEx2PBPxLINyINp9AfBEO
T1zmwMUBwkGWEA==
            "]]}}, ControlType -> None}}, 
      "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1, 2, 3, 4, 5, 6}, SynchronousInitialization -> 
        False, SynchronousUpdating -> False, 
        BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{858., {377.34375, 382.65625}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`raytracefunction189120122132243225911 = 
       Compile[{{$CellContext`HoleDiameter$$, 
           Blank[Real]}, {$CellContext`md2$$, 
           Blank[Real]}, {$CellContext`mf1$$, 
           Blank[Real]}, {$CellContext`mf2$$, 
           Blank[Real]}, {$CellContext`Mx1$$, 
           Blank[Real]}, {$CellContext`Mx2$$, 
           Blank[Real]}}, 
         Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
           Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`activeregion$ = 
           1.; $CellContext`allcreatedamplitudes$ = {{
             0. + 0. I, 0. + 0. I, 0. + 
              0. I}}; $CellContext`allcreatedrays$ = {{
            1.}}; $CellContext`allowzeroraylength$ = 
           True; $CellContext`alternateindex$ = 
           1.; $CellContext`amplitude$ = {
            1. + 0. I, 0. + 0. I, 0. + 0. I}; $CellContext`axismagnitude$ = 
           1.; $CellContext`axismatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}; $CellContext`clonedata$ = {{
            1.}}; $CellContext`clonegenerationnumber$ = 
           1.; $CellContext`cloneinput$ = {1.}; $CellContext`clonenumber$ = 
           1; $CellContext`cloneposition$ = {0., 0., 
            0.}; $CellContext`clonereportedrays$ = {{
            1.}}; $CellContext`clonerotation$ = {{
            1.}}; $CellContext`clonescale$ = 
           1.; $CellContext`clonescalevector$ = {
            1.}; $CellContext`clonesorthistogram$ = {
            1}; $CellContext`clonetraceinput$ = {{
            1.}}; $CellContext`clonetraceoutput$ = {{
            1.}}; $CellContext`closestdistances$ = {
            1.}; $CellContext`closestposition$ = 
           0; $CellContext`closestpositions$ = {
            0}; $CellContext`closestraylength$ = 
           1.; $CellContext`completedray$ = {
            1.}; $CellContext`componentnumber$ = -1.; $CellContext`cosangle$ = 
           1.; $CellContext`crossmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}; $CellContext`deflecteddummyrayspresent$ = 
           False; $CellContext`deflectedlocalrays$ = {{
            1.}}; $CellContext`deflectedrays$ = {{
            1.}}; $CellContext`deflectedrayspresent$ = 
           False; $CellContext`dummymatrix$ = {{
            1.}}; $CellContext`dummymatrixlist$ = {{{
            1.}}}; $CellContext`dummyvector$ = {1.}; $CellContext`frontid$ = 
           1.; $CellContext`generationlimit$ = 
           200.; $CellContext`generationnumber$ = 
           1.; $CellContext`holeintersections$ = {{-1., 0., 
            0.}}; $CellContext`holeQ$ = 
           False; $CellContext`holeQlist$ = {0}; $CellContext`hor$ = 
           1. + 0. I; $CellContext`index$ = 1.; $CellContext`index1$ = 
           1.; $CellContext`index2$ = 
           1.; $CellContext`inrays$ = {{1.}}; $CellContext`intensity$ = 
           1.; $CellContext`intensityscale$ = 
           1.; $CellContext`intersectionnumber$ = 
           1.; $CellContext`intersections$ = {{-1., 0., 
            0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
            0.}}}; $CellContext`intersectionspresent$ = 
           False; $CellContext`localdummyoutrayspresent$ = 
           False; $CellContext`localoutrays$ = {{
            1.}}; $CellContext`localoutrayspresent$ = 
           False; $CellContext`magnitude$ = 
           1.; $CellContext`maxclonegenerationnumber$ = 
           1.; $CellContext`maximumposition$ = 
           1; $CellContext`minimumraylength$ = 
           0.0001; $CellContext`minresonateraylength$ = 1.; $CellContext`n12$ = 
           1.; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newdeflectedrays$ = {{1.}}; $CellContext`newdistance$ = 
           1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`nonintersectingrays$ = {{
            1.}}; $CellContext`normalizedpolarization$ = {1., 
            1.}; $CellContext`oldgenerationnumber$ = 
           1.; $CellContext`opticallength$ = 
           1.; $CellContext`originalray$ = {
            1.}; $CellContext`originalraytilt$ = {
            1.}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 1., 
            0.}, {0., 0., 1.}}; $CellContext`originalsurfnorm$ = {{
            1.}}; $CellContext`outrays$ = {{
            1.}}; $CellContext`parallelamplitude$ = 
           1. + 0. I; $CellContext`PAxis$ = {1., 0., 
            0.}; $CellContext`perpendicularamplitude$ = 
           1. + 0. I; $CellContext`phaseshift$ = 0.; $CellContext`pol1$ = 
           1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
           1.; $CellContext`previoustilt$ = {1., 0., 
            0.}; $CellContext`propagate$ = 
           True; $CellContext`propagatedrays$ = {{1.}}; $CellContext`r1$ = 
           1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 1.; $CellContext`r4$ = 
           1.; $CellContext`r5$ = 1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
           1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
           1.; $CellContext`ray1$ = 1.; $CellContext`ray2$ = 
           1.; $CellContext`ray3$ = 1.; $CellContext`LocRayL$ = 
           1.; $CellContext`rayslot$ = 1.; $CellContext`raysreported$ = 
           False; $CellContext`raytiltx$ = 1.; $CellContext`raytiltz$ = 
           1.; $CellContext`reporteddummyrayspresent$ = 
           False; $CellContext`reportedlocalrays$ = {{
            1.}}; $CellContext`reportedrays$ = {{
            1.}}; $CellContext`reportedrayspresent$ = 
           False; $CellContext`resonateintersections$ = {{-1., 0., 
            0.}}; $CellContext`resonatenumber$ = 
           0; $CellContext`resonateraylength$ = 1.; $CellContext`rex$ = 
           1.; $CellContext`rey$ = 1.; $CellContext`rez$ = 
           1.; $CellContext`rsx$ = 1.; $CellContext`LocRSx$ = 
           1.; $CellContext`rsy$ = 1.; $CellContext`LocRSy$ = 
           1.; $CellContext`rsz$ = 1.; $CellContext`LocRSz$ = 1.; 
          Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
           1.; $CellContext`LocRTz$ = 1.; $CellContext`rx$ = 
           1.; $CellContext`rxhlp$ = 1.; $CellContext`ry$ = 
           1.; $CellContext`ryhlp$ = 1.; $CellContext`rz$ = 
           1.; $CellContext`rzhlp$ = 1.; $CellContext`LocSCx$ = 
           1.; $CellContext`LocSCy$ = 1.; $CellContext`sid$ = 
           1.; $CellContext`sinangle$ = 1.; $CellContext`sno1$ = 
           1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
           1.; $CellContext`sno4$ = 
           1.; $CellContext`surfaceid$ = -1.; $CellContext`surfacenumber$ = \
-1.; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}; $CellContext`surfacetranslationvector$ = {0., 0., 
            0.}; $CellContext`surfnorm$ = {{1.}}; $CellContext`symr1$ = 
           1.; $CellContext`symr2$ = 1.; $CellContext`symr3$ = 
           1.; $CellContext`symr4$ = 1.; $CellContext`symr5$ = 
           1.; $CellContext`symr6$ = 1.; $CellContext`symr7$ = 
           1.; $CellContext`symr8$ = 1.; $CellContext`symr9$ = 
           1.; $CellContext`tempclonedata$ = {{
            1.}}; $CellContext`terminatedeflection$ = 
           False; $CellContext`thresholdintensity$ = 
           1.; $CellContext`tiltmagnitude$ = 
           1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}}; $CellContext`LocTV1$ = 1.; $CellContext`LocTV10$ = 
           1.; $CellContext`LocTV2$ = 1.; $CellContext`LocTV3$ = 
           1.; $CellContext`LocTV4$ = 1.; $CellContext`LocTV5$ = 
           1.; $CellContext`LocTV6$ = 1.; $CellContext`LocTV7$ = 
           1.; $CellContext`LocTV8$ = 1.; $CellContext`LocTV9$ = 
           1.; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
            0.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`ver$ = 0. + 0. I; $CellContext`wavelength$ = 
           1.; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`xunit$ = 
           1.; $CellContext`YAxis$ = {1., 0., 0.}; $CellContext`yunit$ = 
           1.; $CellContext`ZAxis$ = {1., 0., 0.}; $CellContext`zunit$ = 
           1.; $CellContext`propagatedrays$ = CompressedData["
1:eJxTTMoPSmViYGBgA2J1Bii4UO4AodMPgOmGMAe84gwf9jPgBQTl7RdI6d9V
YXtoD+FHOoSFgsBRe5iKJ0rBXVKMH+xx6cdvPgR4KDE4ItMIfRIO2N1LyFw0
eWD4MILp8AO8W5+Wet3Pd8ArPmTDjcEBQqGHG8MB4szFDLe//4HgfLgDH1q4
YRUfsuHG4QCh0cON4wBx5mKGG4ROdwDlYSz5FFV8yIabgAOERg83gQPEmYsZ
bmxgOtxBLOv06yn7gg7gFR+y4SbiAKHRw03kAHHmYobbN0h+PCCHFm5YxYds
uMHCCz3cJA4QZy5CHgCc6ODz
            "]; $CellContext`propagatedrays$ = 
           Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
              1.; $CellContext`frontid$ = 
              1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
           200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
           0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

             "]; $CellContext`deflectedrayspresent$ = 
            True; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = True; While[
             And[$CellContext`deflectedrayspresent$, $CellContext`propagate$],
              AddTo[$CellContext`generationnumber$, 
               1.]; ($CellContext`deflecteddummyrayspresent$ = 
               False; $CellContext`deflectedrayspresent$ = 
               False; $CellContext`reportedrayspresent$ = 
               False; $CellContext`reporteddummyrayspresent$ = 
               True; $CellContext`localdummyoutrayspresent$ = 
               False; $CellContext`localoutrayspresent$ = 
               False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
               Map[Flatten[#, 1]& , 
                 Transpose[
                  
                  Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
-($CellContext`rex$ - 1. 
                    Re[$CellContext`Mx1$$]); $CellContext`ry$ = \
-$CellContext`rey$; $CellContext`rz$ = -90. + $CellContext`rez$; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, Optica`Optica`TempVar3, 
                    Optica`Optica`TempVar4, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar4 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar2 = (-2) $CellContext`mf1$$ \
$CellContext`xunit$ - $CellContext`ry$ $CellContext`yunit$ - $CellContext`rz$ \
$CellContext`zunit$; 
                    Optica`Optica`TempVar1 = $CellContext`ry$^2 + \
$CellContext`rz$^2 + 4 $CellContext`rx$ $CellContext`mf1$$; 
                    Optica`Optica`TempVar4 = $CellContext`yunit$^2 + \
$CellContext`zunit$^2; Optica`Optica`TempVar4 = Re[Optica`Optica`TempVar4]; 
                    Optica`Optica`TempVar3 = 
                    Optica`Optica`TempVar2^2 - Optica`Optica`TempVar1 
                    Optica`Optica`TempVar4; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Optica`Optica`TempVar3^(2^(-1)); 
                    If[N[
                    Chop[Optica`Optica`TempVar4]] != 0., 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {(Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3)/
                    Optica`Optica`TempVar4, ($CellContext`ry$ 
                    Optica`Optica`TempVar4 + (Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3) $CellContext`yunit$)/
                    Optica`Optica`TempVar4, ($CellContext`rz$ 
                    Optica`Optica`TempVar4 + (Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3) $CellContext`zunit$)/
                    Optica`Optica`TempVar4}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    64516.], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {(Optica`Optica`TempVar2 + Optica`Optica`TempVar3)/
                    Optica`Optica`TempVar4, ($CellContext`ry$ 
                    Optica`Optica`TempVar4 + (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$)/
                    Optica`Optica`TempVar4, ($CellContext`rz$ 
                    Optica`Optica`TempVar4 + (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$)/
                    Optica`Optica`TempVar4}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    64516.], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-(Optica`Optica`TempVar1/(
                    4 $CellContext`mf1$$ $CellContext`xunit$)), \
$CellContext`ry$, $CellContext`rz$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    64516.], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 132253.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; $CellContext`intersections$ = Union[
                    Map[If[Part[#, 2]^2 + Part[#, 3]^2 <= 
                    0.25 Abs[$CellContext`HoleDiameter$$]^2, \
$CellContext`holeQ$ = True; {-1., 0., 
                    0.}, #]& , $CellContext`unfilteredintersections$]]; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(
                    50.800000000000004` + $CellContext`rex$ - 1. 
                    Re[$CellContext`Mx1$$]); $CellContext`ry$ = \
-$CellContext`rey$; $CellContext`rz$ = -90. + $CellContext`rez$; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 
                    64516.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 
                    0.}]& )[{-($CellContext`rx$/$CellContext`xunit$), \
$CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$)/$CellContext`xunit$, $CellContext`rz$ - \
($CellContext`rx$ $CellContext`zunit$)/$CellContext`xunit$}]}, {{-1., 0., 
                    0.}}]; AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 132254.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; $CellContext`intersections$ = Union[
                    Map[
                    If[Part[#, 2]^2 + Part[#, 3]^2 <= 
                    0.25 Abs[$CellContext`HoleDiameter$$]^2, \
$CellContext`holeQ$ = True; {-1., 0., 
                    0.}, #]& , $CellContext`unfilteredintersections$]]; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                    Re[$CellContext`Mx2$$]; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -90. + $CellContext`rez$; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, Optica`Optica`TempVar3, 
                    Optica`Optica`TempVar4, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar4 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar2 = (-2) $CellContext`mf2$$ \
$CellContext`xunit$ - $CellContext`ry$ $CellContext`yunit$ - $CellContext`rz$ \
$CellContext`zunit$; 
                    Optica`Optica`TempVar1 = $CellContext`ry$^2 + \
$CellContext`rz$^2 + 4 $CellContext`rx$ $CellContext`mf2$$; 
                    Optica`Optica`TempVar4 = $CellContext`yunit$^2 + \
$CellContext`zunit$^2; Optica`Optica`TempVar4 = Re[Optica`Optica`TempVar4]; 
                    Optica`Optica`TempVar3 = 
                    Optica`Optica`TempVar2^2 - Optica`Optica`TempVar1 
                    Optica`Optica`TempVar4; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Optica`Optica`TempVar3^(2^(-1)); 
                    If[N[
                    Chop[Optica`Optica`TempVar4]] != 0., 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {(Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3)/
                    Optica`Optica`TempVar4, ($CellContext`ry$ 
                    Optica`Optica`TempVar4 + (Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3) $CellContext`yunit$)/
                    Optica`Optica`TempVar4, ($CellContext`rz$ 
                    Optica`Optica`TempVar4 + (Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3) $CellContext`zunit$)/
                    Optica`Optica`TempVar4}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.25 Abs[$CellContext`md2$$]^2], {$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {(Optica`Optica`TempVar2 + Optica`Optica`TempVar3)/
                    Optica`Optica`TempVar4, ($CellContext`ry$ 
                    Optica`Optica`TempVar4 + (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$)/
                    Optica`Optica`TempVar4, ($CellContext`rz$ 
                    Optica`Optica`TempVar4 + (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$)/
                    Optica`Optica`TempVar4}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.25 Abs[$CellContext`md2$$]^2], {$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-(Optica`Optica`TempVar1/(
                    4 $CellContext`mf2$$ $CellContext`xunit$)), \
$CellContext`ry$, $CellContext`rz$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.25 Abs[$CellContext`md2$$]^2], {$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, {-1., 0., 0.}]}], {{-1., 0., 
                    0.}}]]; AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 132321.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -10.16 + \
$CellContext`rex$ - 1. 
                    Re[$CellContext`Mx2$$]; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -90. + $CellContext`rez$; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 
                    0.25 Abs[$CellContext`md2$$]^2], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 
                    0.}]& )[{-($CellContext`rx$/$CellContext`xunit$), \
$CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$)/$CellContext`xunit$, $CellContext`rz$ - \
($CellContext`rx$ $CellContext`zunit$)/$CellContext`xunit$}]}, {{-1., 0., 
                    0.}}]; AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 132322.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
-($CellContext`rex$ - 1. 
                    Re[$CellContext`Mx1$$]); $CellContext`ry$ = \
-$CellContext`rey$; $CellContext`rz$ = -90. + $CellContext`rez$; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    132253.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 1., 
                    132253.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-$CellContext`rxhlp$ + 
                    Re[$CellContext`Mx1$$]; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    90. + $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., $CellContext`ray2$/(
                    2. $CellContext`mf1$$), $CellContext`ray3$/(
                    2. $CellContext`mf1$$)}, {(-$CellContext`ray2$)/(
                    2. $CellContext`mf1$$), 1., 0.}, {(-$CellContext`ray3$)/(
                    2. $CellContext`mf1$$), 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0, 0}, {0, -1., 0}, {
                    0, 0, 1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`Mx1$$], 0., 
                    90.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - 2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(
                    50.800000000000004` + $CellContext`rex$ - 1. 
                    Re[$CellContext`Mx1$$]); $CellContext`ry$ = \
-$CellContext`rey$; $CellContext`rz$ = -90. + $CellContext`rez$; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    132254.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 2., 
                    132254.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-50.800000000000004` - 1. $CellContext`rxhlp$ + 
                    Re[$CellContext`Mx1$$]; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    90. + $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0, 0}, {0, -1., 0}, {
                    0, 0, 1.}}; $CellContext`surfacetranslationvector$ = \
{-50.800000000000004` + Re[$CellContext`Mx1$$], 0., 
                    90.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    
                    2.830549017940716*^-12/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                    Re[$CellContext`Mx2$$]; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -90. + $CellContext`rez$; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    132321.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 3., 
                    132321.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ + 
                    Re[$CellContext`Mx2$$]; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = 
                    90. + $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., $CellContext`ray2$/(
                    2. $CellContext`mf2$$), $CellContext`ray3$/(
                    2. $CellContext`mf2$$)}, {(-$CellContext`ray2$)/(
                    2. $CellContext`mf2$$), 1., 0.}, {(-$CellContext`ray3$)/(
                    2. $CellContext`mf2$$), 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0, 0}, {0, 1., 0}, {
                    0, 0, 1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`Mx2$$], 0., 
                    90.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - 2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -10.16 + \
$CellContext`rex$ - 1. 
                    Re[$CellContext`Mx2$$]; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -90. + $CellContext`rez$; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    132322.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 4., 
                    132322.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10.16 + $CellContext`rxhlp$ + 
                    Re[$CellContext`Mx2$$]; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = 
                    90. + $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0, 0}, {0, 1., 0}, {
                    0, 0, 1.}}; $CellContext`surfacetranslationvector$ = {
                    10.16 + Re[$CellContext`Mx2$$], 0., 
                    90.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    
                    2.830549017940716*^-12/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                
                And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                 1., 1.]; 
              If[$CellContext`localoutrayspresent$, 
                If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                   Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 1.,
                   1.]; $CellContext`outrays$ = 
                 Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1., 
                1.]; If[
                
                And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                 Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                1., 1.]); 
             If[$CellContext`reportedrayspresent$, $CellContext`raysreported$ = 
                True; $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
            If[Length[$CellContext`outrays$] > 1, 
              Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
             
             And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
              Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
             1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

             "]; $CellContext`deflectedrayspresent$ = 
            True; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = True; While[
             And[$CellContext`deflectedrayspresent$, $CellContext`propagate$],
              AddTo[$CellContext`generationnumber$, 
               1.]; ($CellContext`deflecteddummyrayspresent$ = 
               False; $CellContext`deflectedrayspresent$ = 
               False; $CellContext`reportedrayspresent$ = 
               False; $CellContext`reporteddummyrayspresent$ = 
               True; $CellContext`localdummyoutrayspresent$ = 
               False; $CellContext`localoutrayspresent$ = 
               False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
               Map[Flatten[#, 1]& , 
                 Transpose[
                  
                  Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-381. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-90. + $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 254., Part[#, 2] >= -254., 
                    Part[#, 3] >= -254., Part[#, 3] <= 254.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 
                    0.}]& )[{-($CellContext`rx$/$CellContext`xunit$), \
$CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$)/$CellContext`xunit$, $CellContext`rz$ - \
($CellContext`rx$ $CellContext`zunit$)/$CellContext`xunit$}]}, {{-1., 0., 
                    0.}}]; AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 132470.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    254. + $CellContext`rey$; $CellContext`ry$ = -(
                    762. + $CellContext`rex$); $CellContext`rz$ = -90. + \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 1143., Part[#, 2] >= -1143., 
                    Part[#, 3] >= -254., Part[#, 3] <= 254.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 
                    0.}]& )[{-($CellContext`rx$/$CellContext`xunit$), \
$CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$)/$CellContext`xunit$, $CellContext`rz$ - \
($CellContext`rx$ $CellContext`zunit$)/$CellContext`xunit$}]}, {{-1., 0., 
                    0.}}]; AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 132471.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    1905. + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -90. + $CellContext`rez$; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 254., Part[#, 2] >= -254., 
                    Part[#, 3] >= -254., Part[#, 3] <= 254.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 
                    0.}]& )[{-($CellContext`rx$/$CellContext`xunit$), \
$CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$)/$CellContext`xunit$, $CellContext`rz$ - \
($CellContext`rx$ $CellContext`zunit$)/$CellContext`xunit$}]}, {{-1., 0., 
                    0.}}]; AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 132472.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-254. + \
$CellContext`rey$); $CellContext`ry$ = 
                    762. + $CellContext`rex$; $CellContext`rz$ = -90. + \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 1143., Part[#, 2] >= -1143., 
                    Part[#, 3] >= -254., Part[#, 3] <= 254.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 
                    0.}]& )[{-($CellContext`rx$/$CellContext`xunit$), \
$CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$)/$CellContext`xunit$, $CellContext`rz$ - \
($CellContext`rx$ $CellContext`zunit$)/$CellContext`xunit$}]}, {{-1., 0., 
                    0.}}]; AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 132473.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    164. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(
                    762. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 254., Part[#, 2] >= -254., 
                    Part[#, 3] >= -1143., Part[#, 3] <= 1143.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 
                    0.}]& )[{-($CellContext`rx$/$CellContext`xunit$), \
$CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$)/$CellContext`xunit$, $CellContext`rz$ - \
($CellContext`rx$ $CellContext`zunit$)/$CellContext`xunit$}]}, {{-1., 0., 
                    0.}}]; AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 132474.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-344. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(762. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 254., Part[#, 2] >= -254., 
                    Part[#, 3] >= -1143., Part[#, 3] <= 1143.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 
                    0.}]& )[{-($CellContext`rx$/$CellContext`xunit$), \
$CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$)/$CellContext`xunit$, $CellContext`rz$ - \
($CellContext`rx$ $CellContext`zunit$)/$CellContext`xunit$}]}, {{-1., 0., 
                    0.}}]; AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 132475.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-381. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-90. + $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    132470.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 1., 
                    132470.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    381. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    90. + $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0, 0}, {0, -1., 0}, {
                    0, 0, 1.}}; $CellContext`surfacetranslationvector$ = {
                    381., 0, 90.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    254. + $CellContext`rey$; $CellContext`ry$ = -(
                    762. + $CellContext`rex$); $CellContext`rz$ = -90. + \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    132471.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 2., 
                    132471.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-762. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -254. + \
$CellContext`rxhlp$; $CellContext`rez$ = 
                    90. + $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0, 1., 0}, {-1., 0, 0}, {
                    0, 0, 1.}}; $CellContext`surfacetranslationvector$ = \
{-762., -254., 90.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    1905. + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -90. + $CellContext`rez$; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    132472.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 3., 
                    132472.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-1905. + $CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = 90. + $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0, 0}, {0, 1., 0}, {
                    0, 0, 1.}}; $CellContext`surfacetranslationvector$ = \
{-1905., 0, 90.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-254. + \
$CellContext`rey$); $CellContext`ry$ = 
                    762. + $CellContext`rex$; $CellContext`rz$ = -90. + \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    132473.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 4., 
                    132473.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-762. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    254. - 1. $CellContext`rxhlp$; $CellContext`rez$ = 
                    90. + $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0, -1., 0}, {1., 0, 0}, {
                    0, 0, 1.}}; $CellContext`surfacetranslationvector$ = \
{-762., 254., 90.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    164. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(
                    762. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 5., 
                    132474.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 5., 
                    132474.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-762. - 1. $CellContext`rzhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = -164. + $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0, 0, 1.}, {
                    0, 1., 0}, {-1., 0, 
                    0}}; $CellContext`surfacetranslationvector$ = {-762., 
                    0, -164.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-344. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(762. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 6., 
                    
                    132475.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 6., 
                    132475.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-762. - 1. $CellContext`rzhlp$; $CellContext`rey$ = -$CellContext`ryhlp$; \
$CellContext`rez$ = 344. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0, 0, -1.}, {
                    0, -1., 0}, {-1., 0, 
                    0}}; $CellContext`surfacetranslationvector$ = {-762., 0, 
                    344.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                
                And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                 1., 1.]; 
              If[$CellContext`localoutrayspresent$, 
                If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                   Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 1.,
                   1.]; $CellContext`outrays$ = 
                 Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1., 
                1.]; If[
                
                And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                 Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                1., 1.]); 
             If[$CellContext`reportedrayspresent$, $CellContext`raysreported$ = 
                True; $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
            If[Length[$CellContext`outrays$] > 1, 
              Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
             
             And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
              Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
          If[Length[$CellContext`reportedrays$] > 
            2, $CellContext`reportedrays$ = 
            Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
          Map[{
             Part[#, 1], 
             Part[#, 2], 
             Part[#, 3], 
             Part[#, 4], 
             Part[#, 5], 
             
             Part[#, 6]}& , $CellContext`reportedrays$]]]; \
$CellContext`polygons1189120122132243055523 = 
       Compile[{$CellContext`mf1, $CellContext`HoleDiameter}, {{
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (254. - 0.5 
                Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (154.62540296821504` - 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (154.62540296821504` - 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.16666666666666666` (179.60512242138304` - 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.16666666666666666` (179.60512242138304` - 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (154.62540296821504` - 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (154.62540296821504` - 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (254. - 0.5 
                Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (254. - 0.5 
                Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (179.60512242138304` - 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (179.60512242138304` - 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (154.62540296821504` - 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (154.62540296821504` - 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (127. - 0.25 
                Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (127. - 0.25 
                Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-254. + 
                0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 0.5 
           Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. - 0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 0.5 
           Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-254. + 
                0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 0.5 
           Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. - 0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.16666666666666666` (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.16666666666666666` (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 0.25 
           Abs[$CellContext`HoleDiameter], 0. - 0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 0.25 
           Abs[$CellContext`HoleDiameter], 0. - 0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 0.25 
           Abs[$CellContext`HoleDiameter], 0. - 0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-254. + 
                0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. - 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-254. + 
                0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. - 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (127. - 0.25 
                Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.25 Abs[$CellContext`HoleDiameter], 0. - 0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.25 Abs[$CellContext`HoleDiameter], 0. - 0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (127. - 0.25 
                Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (154.62540296821504` - 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.25 Abs[$CellContext`HoleDiameter], 0. - 0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (154.62540296821504` - 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (179.60512242138304` - 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (179.60512242138304` - 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (254. - 0.5 
                Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. - 0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (254. - 0.5 
                Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (254. - 0.5 
                Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (154.62540296821504` - 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (154.62540296821504` - 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.16666666666666666` (179.60512242138304` - 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (154.62540296821504` - 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.16666666666666666` (179.60512242138304` - 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (154.62540296821504` - 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.16666666666666666` (179.60512242138304` - 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (154.62540296821504` - 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (154.62540296821504` - 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (254. - 0.5 
                Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (254. - 0.5 
                Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (254. - 0.5 
                Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (179.60512242138304` - 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (179.60512242138304` - 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (154.62540296821504` - 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (179.60512242138304` - 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (154.62540296821504` - 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (127. - 0.25 
                Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (154.62540296821504` - 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (127. - 0.25 
                Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (127. - 0.25 
                Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-254. + 
                0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-254. + 
                0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-254. + 
                0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.3333333333333333 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.16666666666666666` (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.16666666666666666` (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.3333333333333333 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.16666666666666666` (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-254. + 
                0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-254. + 
                0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (-254. + 
                0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (127. - 0.25 
                Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (127. - 0.25 
                Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (154.62540296821504` - 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (127. - 0.25 
                Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (154.62540296821504` - 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (179.60512242138304` - 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (154.62540296821504` - 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (179.60512242138304` - 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (179.60512242138304` - 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (234.66540125786682` - 
                0.46193976625564337` Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.16666666666666666` (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (254. - 0.5 
                Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.16666666666666666` (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.5 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.5 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.5 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.5 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.3333333333333333 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.3333333333333333 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.5 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.3333333333333333 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3333333333333333 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.3333333333333333 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.5 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.5 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.5 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.5 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter])
                  + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.6666666666666666 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.5 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.5 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.6666666666666666 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.5 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.5 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.5 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.8333333333333334 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.6666666666666666 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.6666666666666666 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.8333333333333334 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.6666666666666666 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.6666666666666666 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.6666666666666666 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (254. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 254. + 
           0. Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (33.1536528238931 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (251.82699478894784` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           251.82699478894784` + 0. Abs[$CellContext`HoleDiameter], 
           33.1536528238931 + 
           0. 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (33.1536528238931 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (251.82699478894784` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           251.82699478894784` + 0. Abs[$CellContext`HoleDiameter], 
           33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (65.74003745604026 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (245.3451598774233 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           245.3451598774233 + 0. Abs[$CellContext`HoleDiameter], 
           65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (65.74003745604026 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (245.3451598774233 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           245.3451598774233 + 0. Abs[$CellContext`HoleDiameter], 
           65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (97.2015918207328 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (234.66540125786682` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           234.66540125786682` + 0. Abs[$CellContext`HoleDiameter], 
           97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (97.2015918207328 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (234.66540125786682` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           234.66540125786682` + 0. Abs[$CellContext`HoleDiameter], 
           97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (127. + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (219.9704525612474 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           219.9704525612474 + 0. Abs[$CellContext`HoleDiameter], 127. + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (127. + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (219.9704525612474 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           219.9704525612474 + 0. Abs[$CellContext`HoleDiameter], 127. + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (154.62540296821504` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (201.51174843397374` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           201.51174843397374` + 0. Abs[$CellContext`HoleDiameter], 
           154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (154.62540296821504` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (201.51174843397374` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           201.51174843397374` + 0. Abs[$CellContext`HoleDiameter], 
           154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.5) (179.60512242138304` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           179.60512242138304` + 0. Abs[$CellContext`HoleDiameter], 
           179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (179.60512242138304` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           179.60512242138304` + 0. Abs[$CellContext`HoleDiameter], 
           179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (154.62540296821504` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (201.51174843397374` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           154.62540296821504` + 0. Abs[$CellContext`HoleDiameter], 
           201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (154.62540296821504` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (201.51174843397374` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           154.62540296821504` + 0. Abs[$CellContext`HoleDiameter], 
           201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (127. + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (219.9704525612474 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 127. + 
           0. Abs[$CellContext`HoleDiameter], 219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.30438071450436033` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (127. + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (219.9704525612474 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 127. + 
           0. Abs[$CellContext`HoleDiameter], 219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (97.2015918207328 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (234.66540125786682` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           97.2015918207328 + 0. Abs[$CellContext`HoleDiameter], 
           234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (127. - 0.25 
                 Abs[$CellContext`HoleDiameter]) + 
               0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (97.2015918207328 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (234.66540125786682` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           97.2015918207328 + 0. Abs[$CellContext`HoleDiameter], 
           234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (65.74003745604026 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (245.3451598774233 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           65.74003745604026 + 0. Abs[$CellContext`HoleDiameter], 
           245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                 Abs[$CellContext`HoleDiameter]) + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (65.74003745604026 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (245.3451598774233 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           65.74003745604026 + 0. Abs[$CellContext`HoleDiameter], 
           245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (33.1536528238931 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (251.82699478894784` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           33.1536528238931 + 0. Abs[$CellContext`HoleDiameter], 
           251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                 Abs[$CellContext`HoleDiameter]) + 
               0.12940952255126034` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (33.1536528238931 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (251.82699478894784` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           33.1536528238931 + 0. Abs[$CellContext`HoleDiameter], 
           251.82699478894784` + 0. Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (254. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 
           254. + 0. Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                 Abs[$CellContext`HoleDiameter]) + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (254. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 
           254. + 0. 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (-33.1536528238931 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (251.82699478894784` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-33.1536528238931 + 0. Abs[$CellContext`HoleDiameter], 251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (-33.1536528238931 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (251.82699478894784` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-33.1536528238931 + 0. Abs[$CellContext`HoleDiameter], 251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (-65.74003745604026 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (245.3451598774233 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-65.74003745604026 + 0. Abs[$CellContext`HoleDiameter], 245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (-65.74003745604026 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (245.3451598774233 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-65.74003745604026 + 0. Abs[$CellContext`HoleDiameter], 245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (-97.2015918207328 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (234.66540125786682` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-97.2015918207328 + 0. Abs[$CellContext`HoleDiameter], 234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (-97.2015918207328 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (234.66540125786682` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-97.2015918207328 + 0. Abs[$CellContext`HoleDiameter], 234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (-127. + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (219.9704525612474 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, -127. + 
           0. Abs[$CellContext`HoleDiameter], 219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (-127. + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (219.9704525612474 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, -127. + 
           0. Abs[$CellContext`HoleDiameter], 219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-154.62540296821504` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (201.51174843397374` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-154.62540296821504` + 0. Abs[$CellContext`HoleDiameter], 201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (-154.62540296821504` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (201.51174843397374` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-154.62540296821504` + 0. Abs[$CellContext`HoleDiameter], 201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-179.60512242138304` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (179.60512242138304` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-179.60512242138304` + 0. Abs[$CellContext`HoleDiameter], 179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (-179.60512242138304` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (179.60512242138304` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-179.60512242138304` + 0. Abs[$CellContext`HoleDiameter], 179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-201.51174843397374` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (154.62540296821504` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-201.51174843397374` + 0. Abs[$CellContext`HoleDiameter], 154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (-201.51174843397374` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (154.62540296821504` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-201.51174843397374` + 0. Abs[$CellContext`HoleDiameter], 154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (-219.9704525612474 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (127. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-219.9704525612474 + 0. Abs[$CellContext`HoleDiameter], 127. + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-219.9704525612474 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (127. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-219.9704525612474 + 0. Abs[$CellContext`HoleDiameter], 127. + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-234.66540125786682` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (97.2015918207328 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-234.66540125786682` + 0. Abs[$CellContext`HoleDiameter], 97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (-234.66540125786682` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (97.2015918207328 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-234.66540125786682` + 0. Abs[$CellContext`HoleDiameter], 97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (-245.3451598774233 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (65.74003745604026 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-245.3451598774233 + 0. Abs[$CellContext`HoleDiameter], 65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (-245.3451598774233 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (65.74003745604026 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-245.3451598774233 + 0. Abs[$CellContext`HoleDiameter], 65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-251.82699478894784` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (33.1536528238931 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-251.82699478894784` + 0. Abs[$CellContext`HoleDiameter], 33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (-251.82699478894784` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (33.1536528238931 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-251.82699478894784` + 0. Abs[$CellContext`HoleDiameter], 33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (-254. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, -254. + 
           0. Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (-254. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, -254. + 
           0. Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (-251.82699478894784` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-33.1536528238931 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-251.82699478894784` + 0. Abs[$CellContext`HoleDiameter], -33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-251.82699478894784` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-33.1536528238931 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-251.82699478894784` + 0. Abs[$CellContext`HoleDiameter], -33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (-245.3451598774233 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-65.74003745604026 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-245.3451598774233 + 0. Abs[$CellContext`HoleDiameter], -65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-245.3451598774233 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-65.74003745604026 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-245.3451598774233 + 0. Abs[$CellContext`HoleDiameter], -65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-234.66540125786682` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-97.2015918207328 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-234.66540125786682` + 0. Abs[$CellContext`HoleDiameter], -97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-234.66540125786682` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-97.2015918207328 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-234.66540125786682` + 0. Abs[$CellContext`HoleDiameter], -97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (-219.9704525612474 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-127. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-219.9704525612474 + 0. Abs[$CellContext`HoleDiameter], -127. + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-219.9704525612474 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-127. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-219.9704525612474 + 0. Abs[$CellContext`HoleDiameter], -127. + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-201.51174843397374` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-154.62540296821504` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter], -154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-201.51174843397374` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-154.62540296821504` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter], -154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.5) (-179.60512242138304` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter], -179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.8333333333333334 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.8333333333333334 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (-179.60512242138304` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter], -179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-201.51174843397374` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-154.62540296821504` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter], -201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.8333333333333334 (-179.60512242138304` + 
                0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
              0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-201.51174843397374` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-154.62540296821504` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter], -201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (-219.9704525612474 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-127. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, -127. + 
           0. Abs[$CellContext`HoleDiameter], -219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-154.62540296821504` + 
                0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
              0.30438071450436033` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-219.9704525612474 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-127. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, -127. + 
           0. Abs[$CellContext`HoleDiameter], -219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-234.66540125786682` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-97.2015918207328 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-97.2015918207328 + 0. Abs[$CellContext`HoleDiameter], -234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-127. + 
                0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-234.66540125786682` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-97.2015918207328 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-97.2015918207328 + 0. Abs[$CellContext`HoleDiameter], -234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (-245.3451598774233 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-65.74003745604026 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-65.74003745604026 + 0. Abs[$CellContext`HoleDiameter], -245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-97.2015918207328 + 
                0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
              0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-245.3451598774233 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-65.74003745604026 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-65.74003745604026 + 0. Abs[$CellContext`HoleDiameter], -245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-251.82699478894784` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-33.1536528238931 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-33.1536528238931 + 0. Abs[$CellContext`HoleDiameter], -251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-65.74003745604026 + 
                0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
              0.12940952255126034` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-251.82699478894784` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (-33.1536528238931 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, \
-33.1536528238931 + 0. Abs[$CellContext`HoleDiameter], -251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (-254. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           0., -254. + 0. Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-33.1536528238931 + 
                0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
              0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (-254. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           0., -254. + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-251.82699478894784` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (33.1536528238931 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter], -251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0., 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-251.82699478894784` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (33.1536528238931 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter], -251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (-245.3451598774233 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (65.74003745604026 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter], -245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-251.82699478894784` + 
                 0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
                Abs[$CellContext`HoleDiameter]) + 
              0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-245.3451598774233 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (65.74003745604026 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter], -245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-234.66540125786682` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (97.2015918207328 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter], -234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-245.3451598774233 + 
                 0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
                Abs[$CellContext`HoleDiameter]) + 
              0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-234.66540125786682` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (97.2015918207328 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter], -234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (-219.9704525612474 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (127. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 127. + 
           0. Abs[$CellContext`HoleDiameter], -219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-234.66540125786682` + 
                 0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
                Abs[$CellContext`HoleDiameter]) + 
              0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-219.9704525612474 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (127. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 127. + 
           0. Abs[$CellContext`HoleDiameter], -219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-201.51174843397374` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (154.62540296821504` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter], -201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-219.9704525612474 + 
                 0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
              0.25 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-201.51174843397374` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (154.62540296821504` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter], -201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-179.60512242138304` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (179.60512242138304` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter], -179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-201.51174843397374` + 
                 0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
                Abs[$CellContext`HoleDiameter]) + 
              0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-179.60512242138304` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (179.60512242138304` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter], -179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) \
(-154.62540296821504` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (201.51174843397374` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter], -154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-179.60512242138304` + 
                 0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
                Abs[$CellContext`HoleDiameter]) + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-154.62540296821504` + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (201.51174843397374` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter], -154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (-127. + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (219.9704525612474 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           219.9704525612474 + 0. Abs[$CellContext`HoleDiameter], -127. + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-154.62540296821504` + 
                 0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
               0.30438071450436033` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
                Abs[$CellContext`HoleDiameter]) + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (-127. + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (219.9704525612474 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           219.9704525612474 + 0. Abs[$CellContext`HoleDiameter], -127. + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (-97.2015918207328 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (234.66540125786682` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter], -97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-127. + 
                 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
                Abs[$CellContext`HoleDiameter]) + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-97.2015918207328 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (234.66540125786682` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter], -97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (-65.74003745604026 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (245.3451598774233 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter], -65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-97.2015918207328 + 
                 0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
               0.1913417161825449 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
                Abs[$CellContext`HoleDiameter]) + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-65.74003745604026 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (245.3451598774233 + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter], -65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (-33.1536528238931 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (251.82699478894784` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter], -33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-65.74003745604026 + 
                 0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
               0.12940952255126034` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
                Abs[$CellContext`HoleDiameter]) + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.8333333333333334 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (-33.1536528238931 + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (251.82699478894784` + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 
           251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter], -33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          0./$CellContext`mf1 - (
            0.25 (254. + 
              0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 254. + 
           0. Abs[$CellContext`HoleDiameter], 0.}, {
          0./$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 
           0.}, {((-0.25) (0. + 
               0.8333333333333334 (-33.1536528238931 + 
                 0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
               0.06526309611002579 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
                Abs[$CellContext`HoleDiameter]) + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.06526309611002579 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.06526309611002579 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.12940952255126034` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.06526309611002579 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.12940952255126034` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.1913417161825449 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.12940952255126034` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.1913417161825449 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.1913417161825449 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.30438071450436033` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.30438071450436033` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.35355339059327373` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.30438071450436033` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.35355339059327373` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.3966766701456176 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.35355339059327373` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.3966766701456176 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4330127018922193 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.3966766701456176 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4330127018922193 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.46193976625564337` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4330127018922193 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.46193976625564337` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4829629131445341 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.46193976625564337` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4829629131445341 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4957224306869052 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4829629131445341 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4957224306869052 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. - 0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. - 0.4957224306869052 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4957224306869052 
           Abs[$CellContext`HoleDiameter], 0. - 0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. - 0.4957224306869052 
           Abs[$CellContext`HoleDiameter], 0. - 0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4829629131445341 
           Abs[$CellContext`HoleDiameter], 0. - 0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4957224306869052 
           Abs[$CellContext`HoleDiameter], 0. - 0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4829629131445341 
           Abs[$CellContext`HoleDiameter], 0. - 0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.46193976625564337` 
           Abs[$CellContext`HoleDiameter], 0. - 0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4829629131445341 
           Abs[$CellContext`HoleDiameter], 0. - 0.12940952255126034` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.46193976625564337` 
           Abs[$CellContext`HoleDiameter], 0. - 0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4330127018922193 
           Abs[$CellContext`HoleDiameter], 0. - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.46193976625564337` 
           Abs[$CellContext`HoleDiameter], 0. - 0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4330127018922193 
           Abs[$CellContext`HoleDiameter], 0. - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.3966766701456176 
           Abs[$CellContext`HoleDiameter], 0. - 0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4330127018922193 
           Abs[$CellContext`HoleDiameter], 0. - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.3966766701456176 
           Abs[$CellContext`HoleDiameter], 0. - 0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.35355339059327373` 
           Abs[$CellContext`HoleDiameter], 0. - 0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.3966766701456176 
           Abs[$CellContext`HoleDiameter], 0. - 0.30438071450436033` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.35355339059327373` 
           Abs[$CellContext`HoleDiameter], 0. - 0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.30438071450436033` 
           Abs[$CellContext`HoleDiameter], 0. - 0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.35355339059327373` 
           Abs[$CellContext`HoleDiameter], 0. - 0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.30438071450436033` 
           Abs[$CellContext`HoleDiameter], 0. - 0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.25 Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.30438071450436033` 
           Abs[$CellContext`HoleDiameter], 0. - 0.3966766701456176 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.25 Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.1913417161825449 
           Abs[$CellContext`HoleDiameter], 0. - 0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.25 Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.1913417161825449 
           Abs[$CellContext`HoleDiameter], 0. - 0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.12940952255126034` 
           Abs[$CellContext`HoleDiameter], 0. - 0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.1913417161825449 
           Abs[$CellContext`HoleDiameter], 0. - 0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.12940952255126034` 
           Abs[$CellContext`HoleDiameter], 0. - 0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.06526309611002579 
           Abs[$CellContext`HoleDiameter], 0. - 0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.12940952255126034` 
           Abs[$CellContext`HoleDiameter], 0. - 0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.06526309611002579 
           Abs[$CellContext`HoleDiameter], 0. - 0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. - 0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.06526309611002579 
           Abs[$CellContext`HoleDiameter], 0. - 0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. - 0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. - 0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 0.25 Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 0.25 Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 0.25 Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.16666666666666666` (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.16666666666666666` (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.16666666666666666` (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.3333333333333333 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.3333333333333333 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.3333333333333333 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.5 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 0.5 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 0.25 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.5 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.5 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.6666666666666666 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.6666666666666666 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.6666666666666666 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 254. + 0. Abs[$CellContext`HoleDiameter], 
           0.}, {50.800000000000004`, 251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter], 33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter], 33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter], 65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter], 65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter], 97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter], 97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter], 127. + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter], 127. + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter], 154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter], 154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter], 179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter], 179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter], 201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter], 201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 127. + 0. Abs[$CellContext`HoleDiameter], 
           219.9704525612474 + 0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 127. + 0. Abs[$CellContext`HoleDiameter], 
           219.9704525612474 + 0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter], 234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter], 234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter], 245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter], 245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter], 251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter], 251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 254. + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 254. + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter], 251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter], 251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter], 245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter], 245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter], 234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter], 234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -127. + 0. Abs[$CellContext`HoleDiameter], 
           219.9704525612474 + 0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -127. + 0. Abs[$CellContext`HoleDiameter], 
           219.9704525612474 + 0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter], 201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter], 201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter], 179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter], 179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter], 154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter], 154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter], 127. + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter], 127. + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter], 97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter], 97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter], 65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter], 65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter], 33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter], 33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -254. + 0. Abs[$CellContext`HoleDiameter], 
           0.}, {50.800000000000004`, 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, -254. + 0. Abs[$CellContext`HoleDiameter], 
           0.}, {50.800000000000004`, -251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter], -33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter], -33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter], -65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter], -65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter], -97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter], -97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter], -127. + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter], -127. + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter], -154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter], -154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter], -179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter], -179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter], -201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter], -201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -127. + 
           0. Abs[$CellContext`HoleDiameter], -219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -127. + 
           0. Abs[$CellContext`HoleDiameter], -219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter], -234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter], -234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter], -245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter], -245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter], -251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, -33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter], -251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., -254. + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., -254. + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter], -251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0., 0. + 
           0.8333333333333334 (-254. + 0.5 Abs[$CellContext`HoleDiameter]) - 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter], -251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter], -245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (33.1536528238931 - 0.06526309611002579 
             Abs[$CellContext`HoleDiameter]) + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-251.82699478894784` + 
             0.4957224306869052 Abs[$CellContext`HoleDiameter]) - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter], -245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter], -234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (65.74003745604026 - 0.12940952255126034` 
             Abs[$CellContext`HoleDiameter]) + 
           0.12940952255126034` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-245.3451598774233 + 
             0.4829629131445341 Abs[$CellContext`HoleDiameter]) - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter], -234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 127. + 
           0. Abs[$CellContext`HoleDiameter], -219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (97.2015918207328 - 0.1913417161825449 
             Abs[$CellContext`HoleDiameter]) + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-234.66540125786682` + 
             0.46193976625564337` Abs[$CellContext`HoleDiameter]) - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 127. + 
           0. Abs[$CellContext`HoleDiameter], -219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter], -201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (127. - 0.25 Abs[$CellContext`HoleDiameter]) + 
           0.25 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-219.9704525612474 + 
             0.4330127018922193 Abs[$CellContext`HoleDiameter]) - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter], -201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter], -179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (154.62540296821504` - 0.30438071450436033` 
             Abs[$CellContext`HoleDiameter]) + 
           0.30438071450436033` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-201.51174843397374` + 
             0.3966766701456176 Abs[$CellContext`HoleDiameter]) - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter], -179.60512242138304` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter], -154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (179.60512242138304` - 0.35355339059327373` 
             Abs[$CellContext`HoleDiameter]) + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-179.60512242138304` + 
             0.35355339059327373` Abs[$CellContext`HoleDiameter]) - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 201.51174843397374` + 
           0. Abs[$CellContext`HoleDiameter], -154.62540296821504` + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter], -127. + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (201.51174843397374` - 0.3966766701456176 
             Abs[$CellContext`HoleDiameter]) + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-154.62540296821504` + 
             0.30438071450436033` Abs[$CellContext`HoleDiameter]) - 
           0.30438071450436033` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 219.9704525612474 + 
           0. Abs[$CellContext`HoleDiameter], -127. + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter], -97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (219.9704525612474 - 0.4330127018922193 
             Abs[$CellContext`HoleDiameter]) + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-127. + 0.25 Abs[$CellContext`HoleDiameter]) - 
           0.25 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 234.66540125786682` + 
           0. Abs[$CellContext`HoleDiameter], -97.2015918207328 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter], -65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (234.66540125786682` - 0.46193976625564337` 
             Abs[$CellContext`HoleDiameter]) + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-97.2015918207328 + 
             0.1913417161825449 Abs[$CellContext`HoleDiameter]) - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 245.3451598774233 + 
           0. Abs[$CellContext`HoleDiameter], -65.74003745604026 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter], -33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (245.3451598774233 - 0.4829629131445341 
             Abs[$CellContext`HoleDiameter]) + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-65.74003745604026 + 
             0.12940952255126034` Abs[$CellContext`HoleDiameter]) - 
           0.12940952255126034` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 251.82699478894784` + 
           0. Abs[$CellContext`HoleDiameter], -33.1536528238931 + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 254. + 0. Abs[$CellContext`HoleDiameter], 
           0.}, {50.800000000000004`, 0. + 
           0.8333333333333334 (254. - 0.5 Abs[$CellContext`HoleDiameter]) + 
           0.5 Abs[$CellContext`HoleDiameter], 0.}, {
          50.800000000000004`, 0. + 
           0.8333333333333334 (251.82699478894784` - 0.4957224306869052 
             Abs[$CellContext`HoleDiameter]) + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.8333333333333334 (-33.1536528238931 + 
             0.06526309611002579 Abs[$CellContext`HoleDiameter]) - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {(-16129.)/$CellContext`mf1, 254.,
            0.}, {50.800000000000004`, 254., 0.}, {50.800000000000004`, 
          251.82699478894784`, 
          33.1536528238931}, {(-16129.)/$CellContext`mf1, 251.82699478894784`,
            33.1536528238931}, {(-16129.)/$CellContext`mf1, 254., 
           0.}, {(-16129.)/$CellContext`mf1, 251.82699478894784`, 
           33.1536528238931}, {50.800000000000004`, 251.82699478894784`, 
          33.1536528238931}, {50.800000000000004`, 245.34515987742336`, 
          65.74003745604027}, {(-16129.)/$CellContext`mf1, 
           245.34515987742336`, 
           65.74003745604027}, {(-16129.)/$CellContext`mf1, 
           251.82699478894784`, 
           33.1536528238931}, {(-16129.)/$CellContext`mf1, 
           245.34515987742336`, 65.74003745604027}, {50.800000000000004`, 
          245.34515987742336`, 65.74003745604027}, {50.800000000000004`, 
          234.66540125786682`, 
          97.2015918207328}, {(-16128.999999999998`)/$CellContext`mf1, 
           234.66540125786682`, 
           97.2015918207328}, {(-16129.)/$CellContext`mf1, 
           245.34515987742336`, 
           65.74003745604027}, {(-16128.999999999998`)/$CellContext`mf1, 
           234.66540125786682`, 97.2015918207328}, {50.800000000000004`, 
          234.66540125786682`, 97.2015918207328}, {50.800000000000004`, 
          219.97045256124744`, 
          126.99999999999999`}, {(-16129.000000000004`)/$CellContext`mf1, 
           219.97045256124744`, 
           126.99999999999999`}, {(-16128.999999999998`)/$CellContext`mf1, 
           234.66540125786682`, 
           97.2015918207328}, {(-16129.000000000004`)/$CellContext`mf1, 
           219.97045256124744`, 126.99999999999999`}, {50.800000000000004`, 
          219.97045256124744`, 126.99999999999999`}, {50.800000000000004`, 
          201.51174843397374`, 
          154.625402968215}, {(-16128.999999999998`)/$CellContext`mf1, 
           201.51174843397374`, 
           154.625402968215}, {(-16129.000000000004`)/$CellContext`mf1, 
           219.97045256124744`, 
           126.99999999999999`}, {(-16128.999999999998`)/$CellContext`mf1, 
           201.51174843397374`, 154.625402968215}, {50.800000000000004`, 
          201.51174843397374`, 154.625402968215}, {50.800000000000004`, 
          179.6051224213831, 
          179.60512242138304`}, {(-16129.)/$CellContext`mf1, 
           179.6051224213831, 
           179.60512242138304`}, {(-16128.999999999998`)/$CellContext`mf1, 
           201.51174843397374`, 
           154.625402968215}, {(-16128.999999999996`)/$CellContext`mf1, 
           179.60512242138307`, 179.60512242138304`}, {50.800000000000004`, 
          179.60512242138307`, 179.60512242138304`}, {50.800000000000004`, 
          154.62540296821507`, 
          201.5117484339737}, {(-16129.)/$CellContext`mf1, 
           154.62540296821507`, 
           201.5117484339737}, {(-16128.999999999996`)/$CellContext`mf1, 
           179.60512242138307`, 
           179.60512242138304`}, {(-16129.)/$CellContext`mf1, 
           154.62540296821507`, 201.5117484339737}, {50.800000000000004`, 
          154.62540296821507`, 201.5117484339737}, {50.800000000000004`, 
          127.00000000000003`, 
          219.9704525612474}, {(-16129.000000000002`)/$CellContext`mf1, 
           127.00000000000003`, 
           219.9704525612474}, {(-16129.)/$CellContext`mf1, 
           154.62540296821507`, 
           201.5117484339737}, {(-16129.000000000002`)/$CellContext`mf1, 
           127.00000000000003`, 219.9704525612474}, {50.800000000000004`, 
          127.00000000000003`, 219.9704525612474}, {50.800000000000004`, 
          97.20159182073282, 
          234.66540125786682`}, {(-16128.999999999998`)/$CellContext`mf1, 
           97.20159182073282, 
           234.66540125786682`}, {(-16129.000000000002`)/$CellContext`mf1, 
           127.00000000000003`, 
           219.9704525612474}, {(-16128.999999999998`)/$CellContext`mf1, 
           97.20159182073282, 234.66540125786682`}, {50.800000000000004`, 
          97.20159182073282, 234.66540125786682`}, {50.800000000000004`, 
          65.74003745604027, 
          245.34515987742336`}, {(-16129.)/$CellContext`mf1, 
           65.74003745604027, 
           245.34515987742336`}, {(-16128.999999999998`)/$CellContext`mf1, 
           97.20159182073282, 
           234.66540125786682`}, {(-16129.)/$CellContext`mf1, 
           65.74003745604033, 245.34515987742333`}, {50.800000000000004`, 
          65.74003745604033, 245.34515987742333`}, {50.800000000000004`, 
          33.15365282389313, 
          251.82699478894784`}, {(-16129.000000000002`)/$CellContext`mf1, 
           33.15365282389313, 
           251.82699478894784`}, {(-16129.)/$CellContext`mf1, 
           65.74003745604033, 
           245.34515987742333`}, {(-16129.000000000002`)/$CellContext`mf1, 
           33.15365282389313, 251.82699478894784`}, {50.800000000000004`, 
          33.15365282389313, 251.82699478894784`}, {50.800000000000004`, 
          1.5553014349171386`*^-14, 
          254.}, {(-16129.)/$CellContext`mf1, 1.5553014349171386`*^-14, 
           254.}, {(-16129.000000000002`)/$CellContext`mf1, 33.15365282389313,
            251.82699478894784`}, {(-16129.)/$CellContext`mf1, 
           1.5553014349171386`*^-14, 254.}, {50.800000000000004`, 
          1.5553014349171386`*^-14, 254.}, {
          50.800000000000004`, -33.153652823893104`, 
          251.82699478894784`}, {(-16129.)/$CellContext`mf1, \
-33.153652823893104`, 251.82699478894784`}, {(-16129.)/$CellContext`mf1, 
           1.5553014349171386`*^-14, 
           254.}, {(-16129.000000000004`)/$CellContext`mf1, \
-33.15365282389305, 251.82699478894787`}, {
          50.800000000000004`, -33.15365282389305, 251.82699478894787`}, {
          50.800000000000004`, -65.74003745604024, 
          245.34515987742336`}, {(-16129.)/$CellContext`mf1, \
-65.74003745604024, 
           245.34515987742336`}, {(-16129.000000000004`)/$CellContext`mf1, \
-33.15365282389305, 
           251.82699478894787`}, {(-16129.)/$CellContext`mf1, \
-65.74003745604024, 245.34515987742336`}, {
          50.800000000000004`, -65.74003745604024, 245.34515987742336`}, {
          50.800000000000004`, -97.20159182073279, 
          234.66540125786682`}, {(-16128.999999999996`)/$CellContext`mf1, \
-97.20159182073279, 
           234.66540125786682`}, {(-16129.)/$CellContext`mf1, \
-65.74003745604024, 
           245.34515987742336`}, {(-16128.999999999998`)/$CellContext`mf1, \
-97.20159182073273, 234.66540125786685`}, {
          50.800000000000004`, -97.20159182073273, 234.66540125786685`}, {
          50.800000000000004`, -126.99999999999994`, 
          219.97045256124747`}, {(-16129.000000000002`)/$CellContext`mf1, \
-126.99999999999994`, 
           219.97045256124747`}, {(-16128.999999999998`)/$CellContext`mf1, \
-97.20159182073273, 
           234.66540125786685`}, {(-16129.000000000002`)/$CellContext`mf1, \
-126.99999999999994`, 219.97045256124747`}, {
          50.800000000000004`, -126.99999999999994`, 219.97045256124747`}, {
          50.800000000000004`, -154.62540296821496`, 
          201.5117484339738}, {(-16129.)/$CellContext`mf1, \
-154.62540296821496`, 
           201.5117484339738}, {(-16129.000000000002`)/$CellContext`mf1, \
-126.99999999999994`, 
           219.97045256124747`}, {(-16129.)/$CellContext`mf1, \
-154.62540296821496`, 201.5117484339738}, {
          50.800000000000004`, -154.62540296821496`, 201.5117484339738}, {
          50.800000000000004`, -179.60512242138296`, 
          179.60512242138316`}, {(-16128.999999999998`)/$CellContext`mf1, \
-179.60512242138296`, 
           179.60512242138316`}, {(-16129.)/$CellContext`mf1, \
-154.62540296821496`, 
           201.5117484339738}, {(-16128.999999999996`)/$CellContext`mf1, \
-179.60512242138304`, 179.60512242138307`}, {
          50.800000000000004`, -179.60512242138304`, 179.60512242138307`}, {
          50.800000000000004`, -201.51174843397368`, 
          154.6254029682151}, {(-16129.)/$CellContext`mf1, \
-201.51174843397368`, 
           154.6254029682151}, {(-16128.999999999996`)/$CellContext`mf1, \
-179.60512242138304`, 
           179.60512242138307`}, {(-16129.)/$CellContext`mf1, \
-201.51174843397368`, 154.6254029682151}, {
          50.800000000000004`, -201.51174843397368`, 154.6254029682151}, {
          50.800000000000004`, -219.97045256124738`, 
          127.00000000000009`}, {(-16129.000000000002`)/$CellContext`mf1, \
-219.97045256124738`, 
           127.00000000000009`}, {(-16129.)/$CellContext`mf1, \
-201.51174843397368`, 
           154.6254029682151}, {(-16129.000000000002`)/$CellContext`mf1, \
-219.97045256124738`, 127.00000000000009`}, {
          50.800000000000004`, -219.97045256124738`, 127.00000000000009`}, {
          50.800000000000004`, -234.66540125786676`, 
          97.20159182073293}, {(-16128.999999999996`)/$CellContext`mf1, \
-234.66540125786676`, 
           97.20159182073293}, {(-16129.000000000002`)/$CellContext`mf1, \
-219.97045256124738`, 
           127.00000000000009`}, {(-16128.999999999998`)/$CellContext`mf1, \
-234.66540125786682`, 97.20159182073282}, {
          50.800000000000004`, -234.66540125786682`, 97.20159182073282}, {
          50.800000000000004`, -245.34515987742333`, 
          65.74003745604034}, {(-16129.)/$CellContext`mf1, \
-245.34515987742333`, 
           65.74003745604034}, {(-16128.999999999998`)/$CellContext`mf1, \
-234.66540125786682`, 
           97.20159182073282}, {(-16129.)/$CellContext`mf1, \
-245.34515987742333`, 65.74003745604034}, {
          50.800000000000004`, -245.34515987742333`, 65.74003745604034}, {
          50.800000000000004`, -251.82699478894784`, 
          33.153652823893204`}, {(-16129.000000000002`)/$CellContext`mf1, \
-251.82699478894784`, 
           33.153652823893204`}, {(-16129.)/$CellContext`mf1, \
-245.34515987742333`, 
           65.74003745604034}, {(-16129.000000000002`)/$CellContext`mf1, \
-251.82699478894784`, 33.153652823893204`}, {
          50.800000000000004`, -251.82699478894784`, 33.153652823893204`}, {
          50.800000000000004`, -254., 
          1.4390468800025868`*^-13}, {(-16129.)/$CellContext`mf1, -254., 
           1.4390468800025868`*^-13}, \
{(-16129.000000000002`)/$CellContext`mf1, -251.82699478894784`, 
           33.153652823893204`}, {(-16129.)/$CellContext`mf1, -254., 
           3.110602869834277*^-14}, {50.800000000000004`, -254., 
          3.110602869834277*^-14}, {
          
          50.800000000000004`, -251.82699478894787`, -33.15365282389303}, \
{(-16129.000000000004`)/$CellContext`mf1, -251.82699478894787`, \
-33.15365282389303}, {(-16129.)/$CellContext`mf1, -254., 
           3.110602869834277*^-14}, {(-16129.000000000004`)/$CellContext`mf1, \
-251.82699478894787`, -33.15365282389303}, {
          50.800000000000004`, -251.82699478894787`, -33.15365282389303}, {
          50.800000000000004`, -245.34515987742338`, -65.74003745604017}, \
{(-16129.000000000002`)/$CellContext`mf1, -245.34515987742338`, \
-65.74003745604017}, {(-16129.000000000004`)/$CellContext`mf1, \
-251.82699478894787`, -33.15365282389303}, \
{(-16129.000000000002`)/$CellContext`mf1, -245.34515987742338`, \
-65.74003745604017}, {
          50.800000000000004`, -245.34515987742338`, -65.74003745604017}, {
          50.800000000000004`, -234.66540125786688`, -97.20159182073266}, \
{(-16128.999999999998`)/$CellContext`mf1, -234.66540125786688`, \
-97.20159182073266}, {(-16129.000000000002`)/$CellContext`mf1, \
-245.34515987742338`, -65.74003745604017}, \
{(-16128.999999999998`)/$CellContext`mf1, -234.66540125786688`, \
-97.20159182073266}, {
          50.800000000000004`, -234.66540125786688`, -97.20159182073266}, {
          50.800000000000004`, -219.97045256124753`, -126.99999999999984`}, \
{(-16129.000000000004`)/$CellContext`mf1, -219.97045256124753`, \
-126.99999999999984`}, {(-16128.999999999998`)/$CellContext`mf1, \
-234.66540125786688`, -97.20159182073266}, \
{(-16129.000000000002`)/$CellContext`mf1, -219.97045256124747`, \
-126.99999999999994`}, {
          50.800000000000004`, -219.97045256124747`, -126.99999999999994`}, {
          50.800000000000004`, -201.5117484339738, -154.62540296821496`}, \
{(-16129.)/$CellContext`mf1, -201.5117484339738, -154.62540296821496`}, \
{(-16129.000000000002`)/$CellContext`mf1, -219.97045256124747`, \
-126.99999999999994`}, {(-16129.)/$CellContext`mf1, -201.5117484339738, \
-154.62540296821496`}, {
          50.800000000000004`, -201.5117484339738, -154.62540296821496`}, {
          
          50.800000000000004`, -179.60512242138316`, -179.60512242138296`}, \
{(-16128.999999999998`)/$CellContext`mf1, -179.60512242138316`, \
-179.60512242138296`}, {(-16129.)/$CellContext`mf1, -201.5117484339738, \
-154.62540296821496`}, {(-16128.999999999998`)/$CellContext`mf1, \
-179.60512242138316`, -179.60512242138296`}, {
          50.800000000000004`, -179.60512242138316`, -179.60512242138296`}, {
          50.800000000000004`, -154.6254029682151, -201.51174843397368`}, \
{(-16129.)/$CellContext`mf1, -154.6254029682151, -201.51174843397368`}, \
{(-16128.999999999998`)/$CellContext`mf1, -179.60512242138316`, \
-179.60512242138296`}, {(-16129.)/$CellContext`mf1, -154.6254029682151, \
-201.51174843397368`}, {
          50.800000000000004`, -154.6254029682151, -201.51174843397368`}, {
          50.800000000000004`, -127.00000000000011`, -219.97045256124736`}, \
{(-16129.)/$CellContext`mf1, -127.00000000000011`, -219.97045256124736`}, \
{(-16129.)/$CellContext`mf1, -154.6254029682151, -201.51174843397368`}, \
{(-16129.)/$CellContext`mf1, -127.00000000000011`, -219.97045256124736`}, {
          50.800000000000004`, -127.00000000000011`, -219.97045256124736`}, {
          50.800000000000004`, -97.20159182073294, -234.66540125786676`}, \
{(-16128.999999999998`)/$CellContext`mf1, -97.20159182073294, \
-234.66540125786676`}, {(-16129.)/$CellContext`mf1, -127.00000000000011`, \
-219.97045256124736`}, {(-16128.999999999998`)/$CellContext`mf1, \
-97.20159182073294, -234.66540125786676`}, {
          50.800000000000004`, -97.20159182073294, -234.66540125786676`}, {
          50.800000000000004`, -65.74003745604045, -245.3451598774233}, \
{(-16129.)/$CellContext`mf1, -65.74003745604045, -245.3451598774233}, \
{(-16128.999999999998`)/$CellContext`mf1, -97.20159182073294, \
-234.66540125786676`}, {(-16129.)/$CellContext`mf1, -65.74003745604045, \
-245.3451598774233}, {
          50.800000000000004`, -65.74003745604045, -245.3451598774233}, {
          50.800000000000004`, -33.15365282389334, -251.82699478894781`}, \
{(-16129.)/$CellContext`mf1, -33.15365282389334, -251.82699478894781`}, \
{(-16129.)/$CellContext`mf1, -65.74003745604045, -245.3451598774233}, \
{(-16129.)/$CellContext`mf1, -33.15365282389334, -251.82699478894781`}, {
          50.800000000000004`, -33.15365282389334, -251.82699478894781`}, {
          50.800000000000004`, -2.7225636165134593`*^-13, -254.}, \
{(-16129.)/$CellContext`mf1, -2.7225636165134593`*^-13, -254.}, \
{(-16129.)/$CellContext`mf1, -33.15365282389334, -251.82699478894781`}, \
{(-16129.)/$CellContext`mf1, -4.6659043047514155`*^-14, -254.}, {
          50.800000000000004`, -4.6659043047514155`*^-14, -254.}, {
          50.800000000000004`, 
          33.15365282389301, -251.82699478894787`}, \
{(-16129.000000000002`)/$CellContext`mf1, 
           33.15365282389301, -251.82699478894787`}, \
{(-16129.)/$CellContext`mf1, -4.6659043047514155`*^-14, -254.}, \
{(-16129.000000000002`)/$CellContext`mf1, 
           33.15365282389301, -251.82699478894787`}, {50.800000000000004`, 
          33.15365282389301, -251.82699478894787`}, {50.800000000000004`, 
          65.74003745604016, -245.34515987742338`}, \
{(-16129.)/$CellContext`mf1, 
           65.74003745604016, -245.34515987742338`}, \
{(-16129.000000000002`)/$CellContext`mf1, 
           33.15365282389301, -251.82699478894787`}, \
{(-16129.)/$CellContext`mf1, 65.74003745604016, -245.34515987742338`}, {
          50.800000000000004`, 65.74003745604016, -245.34515987742338`}, {
          50.800000000000004`, 
          97.20159182073265, -234.66540125786688`}, \
{(-16128.999999999998`)/$CellContext`mf1, 
           97.20159182073265, -234.66540125786688`}, \
{(-16129.)/$CellContext`mf1, 
           65.74003745604016, -245.34515987742338`}, \
{(-16128.999999999998`)/$CellContext`mf1, 
           97.20159182073265, -234.66540125786688`}, {50.800000000000004`, 
          97.20159182073265, -234.66540125786688`}, {50.800000000000004`, 
          126.99999999999982`, -219.97045256124753`}, \
{(-16129.)/$CellContext`mf1, 
           126.99999999999982`, -219.97045256124753`}, \
{(-16128.999999999998`)/$CellContext`mf1, 
           97.20159182073265, -234.66540125786688`}, \
{(-16129.)/$CellContext`mf1, 126.99999999999982`, -219.97045256124753`}, {
          50.800000000000004`, 126.99999999999982`, -219.97045256124753`}, {
          50.800000000000004`, 
          154.62540296821484`, -201.51174843397388`}, \
{(-16129.)/$CellContext`mf1, 
           154.62540296821484`, -201.51174843397388`}, \
{(-16129.)/$CellContext`mf1, 
           126.99999999999982`, -219.97045256124753`}, \
{(-16129.)/$CellContext`mf1, 154.62540296821484`, -201.51174843397388`}, {
          50.800000000000004`, 154.62540296821484`, -201.51174843397388`}, {
          50.800000000000004`, 
          179.60512242138284`, -179.60512242138327`}, \
{(-16128.999999999998`)/$CellContext`mf1, 
           179.60512242138284`, -179.60512242138327`}, \
{(-16129.)/$CellContext`mf1, 
           154.62540296821484`, -201.51174843397388`}, \
{(-16129.)/$CellContext`mf1, 179.60512242138304`, -179.6051224213831}, {
          50.800000000000004`, 179.60512242138304`, -179.6051224213831}, {
          50.800000000000004`, 
          201.51174843397368`, -154.6254029682151}, \
{(-16129.)/$CellContext`mf1, 
           201.51174843397368`, -154.6254029682151}, \
{(-16129.)/$CellContext`mf1, 
           179.60512242138304`, -179.6051224213831}, \
{(-16129.)/$CellContext`mf1, 201.51174843397368`, -154.6254029682151}, {
          50.800000000000004`, 201.51174843397368`, -154.6254029682151}, {
          50.800000000000004`, 
          219.97045256124736`, -127.00000000000011`}, \
{(-16129.)/$CellContext`mf1, 
           219.97045256124736`, -127.00000000000011`}, \
{(-16129.)/$CellContext`mf1, 
           201.51174843397368`, -154.6254029682151}, \
{(-16129.)/$CellContext`mf1, 219.97045256124736`, -127.00000000000011`}, {
          50.800000000000004`, 219.97045256124736`, -127.00000000000011`}, {
          50.800000000000004`, 
          234.66540125786676`, -97.20159182073296}, \
{(-16128.999999999998`)/$CellContext`mf1, 
           234.66540125786676`, -97.20159182073296}, \
{(-16129.)/$CellContext`mf1, 
           219.97045256124736`, -127.00000000000011`}, \
{(-16128.999999999998`)/$CellContext`mf1, 
           234.66540125786676`, -97.20159182073296}, {50.800000000000004`, 
          234.66540125786676`, -97.20159182073296}, {50.800000000000004`, 
          245.3451598774233, -65.74003745604047}, {(-16129.)/$CellContext`mf1,
            245.3451598774233, -65.74003745604047}, \
{(-16128.999999999998`)/$CellContext`mf1, 
           234.66540125786676`, -97.20159182073296}, \
{(-16129.)/$CellContext`mf1, 245.3451598774233, -65.74003745604047}, {
          50.800000000000004`, 245.3451598774233, -65.74003745604047}, {
          50.800000000000004`, 
          251.82699478894781`, -33.15365282389335}, \
{(-16129.000000000002`)/$CellContext`mf1, 
           251.82699478894781`, -33.15365282389335}, \
{(-16129.)/$CellContext`mf1, 
           245.3451598774233, -65.74003745604047}, \
{(-16129.000000000002`)/$CellContext`mf1, 
           251.82699478894781`, -33.15365282389335}, {50.800000000000004`, 
          251.82699478894781`, -33.15365282389335}, {50.800000000000004`, 
          254., -2.8780937600051737`*^-13}, {(-16129.)/$CellContext`mf1, 
           254., -2.8780937600051737`*^-13}, \
{(-16129.000000000002`)/$CellContext`mf1, 
           251.82699478894781`, -33.15365282389335}, {((-0.25) (0. - 0.5 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1,
            0. - 0.5 Abs[$CellContext`HoleDiameter], 0. + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.5 Abs[$CellContext`HoleDiameter], 0. + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4957224306869052 
           Abs[$CellContext`HoleDiameter], 0. - 0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.5 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1,
            0. - 0.5 Abs[$CellContext`HoleDiameter], 0. + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4957224306869052 
           Abs[$CellContext`HoleDiameter], 0. - 0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.48296291314453416` 
           Abs[$CellContext`HoleDiameter], 0. - 0.12940952255126037` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.48296291314453416` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.12940952255126037` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.48296291314453416` Abs[$CellContext`HoleDiameter], 0. - 
           0.12940952255126037` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.06526309611002579 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.06526309611002579 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.48296291314453416` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.12940952255126037` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.48296291314453416` Abs[$CellContext`HoleDiameter], 0. - 
           0.12940952255126037` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.48296291314453416` 
           Abs[$CellContext`HoleDiameter], 0. - 0.12940952255126037` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.46193976625564337` 
           Abs[$CellContext`HoleDiameter], 0. - 0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.48296291314453416` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.12940952255126037` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.48296291314453416` Abs[$CellContext`HoleDiameter], 0. - 
           0.12940952255126037` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. - 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.46193976625564337` 
           Abs[$CellContext`HoleDiameter], 0. - 0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.43301270189221935` 
           Abs[$CellContext`HoleDiameter], 0. - 0.24999999999999997` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.43301270189221935` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.24999999999999997` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.43301270189221935` Abs[$CellContext`HoleDiameter], 0. - 
           0.24999999999999997` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.1913417161825449 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. - 
           0.1913417161825449 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.43301270189221935` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.24999999999999997` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.43301270189221935` Abs[$CellContext`HoleDiameter], 0. - 
           0.24999999999999997` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.43301270189221935` 
           Abs[$CellContext`HoleDiameter], 0. - 0.24999999999999997` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.3966766701456176 
           Abs[$CellContext`HoleDiameter], 0. - 0.3043807145043603 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.3043807145043603 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. - 
           0.3043807145043603 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.43301270189221935` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.24999999999999997` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.43301270189221935` Abs[$CellContext`HoleDiameter], 0. - 
           0.24999999999999997` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.3043807145043603 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. - 
           0.3043807145043603 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.3966766701456176 
           Abs[$CellContext`HoleDiameter], 0. - 0.3043807145043603 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.35355339059327384` 
           Abs[$CellContext`HoleDiameter], 0. - 0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.35355339059327384` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.35355339059327373` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.35355339059327384` Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.3043807145043603 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. - 
           0.3043807145043603 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. - 0.3535533905932738 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.3535533905932738 Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.3535533905932738 
           Abs[$CellContext`HoleDiameter], 0. - 0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.3043807145043604 
           Abs[$CellContext`HoleDiameter], 0. - 0.3966766701456175 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456175 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.3043807145043604 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.3043807145043604 Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456175 
           Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. - 0.3535533905932738 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.3535533905932738 Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327373` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456175 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.3043807145043604 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.3043807145043604 Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456175 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.3043807145043604 
           Abs[$CellContext`HoleDiameter], 0. - 0.3966766701456175 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.25000000000000006` 
           Abs[$CellContext`HoleDiameter], 0. - 0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.25000000000000006` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.25000000000000006` Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456175 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.3043807145043604 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.3043807145043604 Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456175 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.25000000000000006` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.25000000000000006` Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.25000000000000006` 
           Abs[$CellContext`HoleDiameter], 0. - 0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.19134171618254492` 
           Abs[$CellContext`HoleDiameter], 0. - 0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.19134171618254492` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.19134171618254492` Abs[$CellContext`HoleDiameter], 0. - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.25000000000000006` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.25000000000000006` Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922193 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.19134171618254492` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.19134171618254492` Abs[$CellContext`HoleDiameter], 0. - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.19134171618254492` 
           Abs[$CellContext`HoleDiameter], 0. - 0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.12940952255126037` 
           Abs[$CellContext`HoleDiameter], 0. - 0.48296291314453416` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.48296291314453416` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.12940952255126037` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.12940952255126037` Abs[$CellContext`HoleDiameter], 0. - 
           0.48296291314453416` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.19134171618254492` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.19134171618254492` Abs[$CellContext`HoleDiameter], 0. - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.12940952255126048` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.12940952255126048` Abs[$CellContext`HoleDiameter], 0. - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.12940952255126048` 
           Abs[$CellContext`HoleDiameter], 0. - 0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.06526309611002586 
           Abs[$CellContext`HoleDiameter], 0. - 0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.06526309611002586 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.06526309611002586 Abs[$CellContext`HoleDiameter], 0. - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.12940952255126048` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.12940952255126048` Abs[$CellContext`HoleDiameter], 0. - 
           0.4829629131445341 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.06526309611002586 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.06526309611002586 Abs[$CellContext`HoleDiameter], 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.06526309611002586 
           Abs[$CellContext`HoleDiameter], 0. - 0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 3.061616997868383*^-17 
           Abs[$CellContext`HoleDiameter], 0. - 0.5 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.5 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 3.061616997868383*^-17 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           3.061616997868383*^-17 Abs[$CellContext`HoleDiameter], 0. - 0.5 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.06526309611002586 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.06526309611002586 Abs[$CellContext`HoleDiameter], 0. - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.5 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 3.061616997868383*^-17 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           3.061616997868383*^-17 Abs[$CellContext`HoleDiameter], 0. - 0.5 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 3.061616997868383*^-17 
           Abs[$CellContext`HoleDiameter], 0. - 0.5 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.0652630961100258 Abs[$CellContext`HoleDiameter], 0. - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.0652630961100258 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.0652630961100258 Abs[$CellContext`HoleDiameter], 0. - 
           0.4957224306869052 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.5 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 3.061616997868383*^-17 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           3.061616997868383*^-17 Abs[$CellContext`HoleDiameter], 0. - 0.5 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.49572243068690525` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.06526309611002569 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.06526309611002569 Abs[$CellContext`HoleDiameter], 0. - 
           0.49572243068690525` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.06526309611002569 Abs[$CellContext`HoleDiameter], 0. - 
           0.49572243068690525` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.12940952255126031` Abs[$CellContext`HoleDiameter], 0. - 
           0.48296291314453416` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.48296291314453416` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.12940952255126031` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.12940952255126031` Abs[$CellContext`HoleDiameter], 0. - 
           0.48296291314453416` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.49572243068690525` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.06526309611002569 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.06526309611002569 Abs[$CellContext`HoleDiameter], 0. - 
           0.49572243068690525` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.48296291314453416` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.12940952255126031` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.12940952255126031` Abs[$CellContext`HoleDiameter], 0. - 
           0.48296291314453416` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.12940952255126031` Abs[$CellContext`HoleDiameter], 0. - 
           0.48296291314453416` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.19134171618254486` Abs[$CellContext`HoleDiameter], 0. - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.19134171618254486` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.19134171618254486` Abs[$CellContext`HoleDiameter], 0. - 
           0.46193976625564337` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.48296291314453416` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.12940952255126031` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.12940952255126031` Abs[$CellContext`HoleDiameter], 0. - 
           0.48296291314453416` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4619397662556434 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.19134171618254475` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.19134171618254475` Abs[$CellContext`HoleDiameter], 0. - 
           0.4619397662556434 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.19134171618254475` Abs[$CellContext`HoleDiameter], 0. - 
           0.4619397662556434 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.2499999999999999 Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922194 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922194 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.2499999999999999 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.2499999999999999 Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922194 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4619397662556434 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.19134171618254475` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.19134171618254475` Abs[$CellContext`HoleDiameter], 0. - 
           0.4619397662556434 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922194 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.2499999999999999 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.2499999999999999 Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922194 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.2499999999999999 Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922194 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.30438071450436016` Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456177 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456177 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.30438071450436016` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.30438071450436016` Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456177 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922194 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.2499999999999999 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.2499999999999999 Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922194 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456177 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.30438071450436016` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.30438071450436016` Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456177 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.30438071450436016` Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456177 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.35355339059327356` Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327395` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.35355339059327395` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.35355339059327356` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.35355339059327356` Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327395` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456177 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.30438071450436016` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.30438071450436016` Abs[$CellContext`HoleDiameter], 0. - 
           0.3966766701456177 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3535533905932738 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. - 
           0.3535533905932738 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. - 
           0.3535533905932738 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.39667667014561747` Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436044` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.30438071450436044` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.39667667014561747` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.39667667014561747` Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436044` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3535533905932738 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. - 
           0.3535533905932738 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.30438071450436044` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.39667667014561747` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.39667667014561747` Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436044` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.39667667014561747` Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436044` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.43301270189221924` Abs[$CellContext`HoleDiameter], 0. - 
           0.25000000000000017` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.25000000000000017` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.43301270189221924` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.43301270189221924` Abs[$CellContext`HoleDiameter], 0. - 
           0.25000000000000017` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.30438071450436044` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.39667667014561747` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.39667667014561747` Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436044` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.25000000000000017` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.43301270189221924` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.43301270189221924` Abs[$CellContext`HoleDiameter], 0. - 
           0.25000000000000017` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.43301270189221924` Abs[$CellContext`HoleDiameter], 0. - 
           0.25000000000000017` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.46193976625564326` Abs[$CellContext`HoleDiameter], 0. - 
           0.19134171618254514` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.19134171618254514` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564326` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.46193976625564326` Abs[$CellContext`HoleDiameter], 0. - 
           0.19134171618254514` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.25000000000000017` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.43301270189221924` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.43301270189221924` Abs[$CellContext`HoleDiameter], 0. - 
           0.25000000000000017` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.19134171618254492` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. - 
           0.19134171618254492` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. - 
           0.19134171618254492` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. - 
           0.1294095225512605 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.1294095225512605 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. - 
           0.1294095225512605 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.19134171618254492` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. - 
           0.19134171618254492` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.1294095225512605 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. - 
           0.1294095225512605 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. - 
           0.1294095225512605 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.065263096110026 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.065263096110026 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.065263096110026 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.1294095225512605 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. - 
           0.1294095225512605 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.065263096110026 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.065263096110026 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.065263096110026 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 0.5 Abs[$CellContext`HoleDiameter], 0. - 
           2.83276944882399*^-16 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               2.83276944882399*^-16 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 Abs[$CellContext`HoleDiameter], 0. - 2.83276944882399*^-16 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.065263096110026 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. - 
           0.065263096110026 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               6.123233995736766*^-17 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 Abs[$CellContext`HoleDiameter], 0. - 6.123233995736766*^-17 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 0.5 Abs[$CellContext`HoleDiameter], 0. - 
           6.123233995736766*^-17 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.49572243068690525` Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002566 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.06526309611002566 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.49572243068690525` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.49572243068690525` Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002566 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               6.123233995736766*^-17 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 Abs[$CellContext`HoleDiameter], 0. - 6.123233995736766*^-17 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.06526309611002566 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.49572243068690525` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.49572243068690525` Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002566 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.49572243068690525` Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002566 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4829629131445342 Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126018` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.12940952255126018` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445342 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4829629131445342 Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126018` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.06526309611002566 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.49572243068690525` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.49572243068690525` Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002566 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.12940952255126018` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445342 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4829629131445342 Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126018` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4829629131445342 Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126018` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4619397662556435 Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825446 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.1913417161825446 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4619397662556435 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4619397662556435 Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825446 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.12940952255126018` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445342 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4829629131445342 Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126018` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.1913417161825446 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4619397662556435 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4619397662556435 Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825446 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4619397662556435 Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825446 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4330127018922195 Abs[$CellContext`HoleDiameter], 0. + 
           0.2499999999999997 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.2499999999999997 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922195 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4330127018922195 Abs[$CellContext`HoleDiameter], 0. + 
           0.2499999999999997 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.1913417161825446 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4619397662556435 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4619397662556435 Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825446 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.2499999999999999 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922194 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4330127018922194 Abs[$CellContext`HoleDiameter], 0. + 
           0.2499999999999999 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4330127018922194 Abs[$CellContext`HoleDiameter], 0. + 
           0.2499999999999999 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3966766701456177 Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436016` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.30438071450436016` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456177 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3966766701456177 Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436016` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.2499999999999999 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922194 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4330127018922194 Abs[$CellContext`HoleDiameter], 0. + 
           0.2499999999999999 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.30438071450436016` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456177 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3966766701456177 Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436016` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3966766701456177 Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436016` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.35355339059327395` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327356` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.35355339059327356` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.35355339059327395` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.35355339059327395` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327356` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.30438071450436016` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456177 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3966766701456177 Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436016` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.35355339059327356` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.35355339059327395` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.35355339059327395` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327356` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.35355339059327395` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327356` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.30438071450436044` Abs[$CellContext`HoleDiameter], 0. + 
           0.39667667014561747` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.30438071450436044` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.39667667014561747` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.30438071450436044` Abs[$CellContext`HoleDiameter], 0. + 
           0.39667667014561747` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.35355339059327356` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.35355339059327395` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.35355339059327395` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327356` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.30438071450436044` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.39667667014561747` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.30438071450436044` Abs[$CellContext`HoleDiameter], 0. + 
           0.39667667014561747` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.30438071450436044` Abs[$CellContext`HoleDiameter], 0. + 
           0.39667667014561747` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.2500000000000002 Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922192 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.2500000000000002 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922192 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.2500000000000002 Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922192 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.30438071450436044` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.39667667014561747` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.30438071450436044` Abs[$CellContext`HoleDiameter], 0. + 
           0.39667667014561747` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.2500000000000002 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922192 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.2500000000000002 Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922192 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.2500000000000002 Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922192 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.19134171618254517` Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564326` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.19134171618254517` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564326` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.19134171618254517` Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564326` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.2500000000000002 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922192 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.2500000000000002 Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922192 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.19134171618254517` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564326` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.19134171618254517` Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564326` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.19134171618254517` Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564326` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.12940952255126073` Abs[$CellContext`HoleDiameter], 0. + 
           0.48296291314453405` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.12940952255126073` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.48296291314453405` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.12940952255126073` Abs[$CellContext`HoleDiameter], 0. + 
           0.48296291314453405` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.19134171618254517` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564326` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.19134171618254517` Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564326` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.12940952255126073` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.48296291314453405` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.12940952255126073` Abs[$CellContext`HoleDiameter], 0. + 
           0.48296291314453405` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.12940952255126073` Abs[$CellContext`HoleDiameter], 0. + 
           0.48296291314453405` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.06526309611002626 Abs[$CellContext`HoleDiameter], 0. + 
           0.49572243068690514` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.06526309611002626 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.49572243068690514` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.06526309611002626 Abs[$CellContext`HoleDiameter], 0. + 
           0.49572243068690514` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.12940952255126073` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.48296291314453405` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.12940952255126073` Abs[$CellContext`HoleDiameter], 0. + 
           0.48296291314453405` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.06526309611002626 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.49572243068690514` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.06526309611002626 Abs[$CellContext`HoleDiameter], 0. + 
           0.49572243068690514` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.06526309611002626 Abs[$CellContext`HoleDiameter], 0. + 
           0.49572243068690514` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           5.359377197861141*^-16 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               5.359377197861141*^-16 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           5.359377197861141*^-16 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.06526309611002626 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.49572243068690514` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.06526309611002626 Abs[$CellContext`HoleDiameter], 0. + 
           0.49572243068690514` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               9.184850993605148*^-17 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           9.184850993605148*^-17 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           9.184850993605148*^-17 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.06526309611002562 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.49572243068690525` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.06526309611002562 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.49572243068690525` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.06526309611002562 Abs[$CellContext`HoleDiameter], 0. + 
           0.49572243068690525` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               9.184850993605148*^-17 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           9.184850993605148*^-17 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.06526309611002562 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.49572243068690525` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.06526309611002562 Abs[$CellContext`HoleDiameter], 0. + 
           0.49572243068690525` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.06526309611002562 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.49572243068690525` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.12940952255126015` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445342 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.12940952255126015` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445342 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.12940952255126015` Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445342 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.06526309611002562 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.49572243068690525` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.06526309611002562 Abs[$CellContext`HoleDiameter], 0. + 
           0.49572243068690525` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.12940952255126015` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445342 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.12940952255126015` Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445342 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.12940952255126015` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445342 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.19134171618254459` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4619397662556435 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.19134171618254459` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4619397662556435 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.19134171618254459` Abs[$CellContext`HoleDiameter], 0. + 
           0.4619397662556435 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.12940952255126015` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445342 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.12940952255126015` Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445342 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.19134171618254459` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4619397662556435 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.19134171618254459` Abs[$CellContext`HoleDiameter], 0. + 
           0.4619397662556435 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.19134171618254459` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4619397662556435 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.24999999999999964` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922195 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.24999999999999964` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922195 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.24999999999999964` Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922195 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.19134171618254459` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4619397662556435 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.19134171618254459` Abs[$CellContext`HoleDiameter], 0. + 
           0.4619397662556435 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.24999999999999964` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922195 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.24999999999999964` Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922195 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.24999999999999964` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922195 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.30438071450435994` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.39667667014561786` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.30438071450435994` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.39667667014561786` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.30438071450435994` Abs[$CellContext`HoleDiameter], 0. + 
           0.39667667014561786` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.24999999999999964` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922195 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.24999999999999964` Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922195 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.30438071450435994` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.39667667014561786` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.30438071450435994` Abs[$CellContext`HoleDiameter], 0. + 
           0.39667667014561786` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.30438071450435994` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.39667667014561786` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.35355339059327334` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.3535533905932742 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.35355339059327334` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3535533905932742 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.35355339059327334` Abs[$CellContext`HoleDiameter], 0. + 
           0.3535533905932742 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.30438071450435994` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.39667667014561786` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.30438071450435994` Abs[$CellContext`HoleDiameter], 0. + 
           0.39667667014561786` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.35355339059327384` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327384` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.35355339059327373` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327384` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.39667667014561747` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436044` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.39667667014561747` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.30438071450436044` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.39667667014561747` Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436044` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.35355339059327384` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327384` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.39667667014561747` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.30438071450436044` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.39667667014561747` Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436044` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.39667667014561747` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436044` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4330127018922192 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.2500000000000002 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922192 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.2500000000000002 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4330127018922192 Abs[$CellContext`HoleDiameter], 0. + 
           0.2500000000000002 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.39667667014561747` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.30438071450436044` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.39667667014561747` Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436044` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922192 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.2500000000000002 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4330127018922192 Abs[$CellContext`HoleDiameter], 0. + 
           0.2500000000000002 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4330127018922192 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.2500000000000002 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.46193976625564326` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825452 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564326` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.1913417161825452 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.46193976625564326` Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825452 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922192 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.2500000000000002 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4330127018922192 Abs[$CellContext`HoleDiameter], 0. + 
           0.2500000000000002 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564326` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.1913417161825452 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.46193976625564326` Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825452 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.46193976625564326` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825452 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.48296291314453405` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126076` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.48296291314453405` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.12940952255126076` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.48296291314453405` Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126076` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564326` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.1913417161825452 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.46193976625564326` Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825452 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.48296291314453405` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.12940952255126076` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.48296291314453405` Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126076` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.48296291314453405` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126076` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.49572243068690514` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002629 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.49572243068690514` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.06526309611002629 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.49572243068690514` Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002629 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.48296291314453405` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.12940952255126076` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.48296291314453405` Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126076` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.49572243068690514` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.06526309611002629 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.49572243068690514` Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002629 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.49572243068690514` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002629 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.5 Abs[$CellContext`HoleDiameter], 0. + 
           5.66553889764798*^-16 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.5 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              5.66553889764798*^-16 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 0.5 
           Abs[$CellContext`HoleDiameter], 0. + 
           5.66553889764798*^-16 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.49572243068690514` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.06526309611002629 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.49572243068690514` Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002629 
            Abs[$CellContext`HoleDiameter]}}]; \
$CellContext`lines1189120122132243059218 = 
       Compile[{$CellContext`mf1, $CellContext`HoleDiameter}, {{((-0.25) (0. + 
               0. Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 Abs[$CellContext`HoleDiameter], 0. + 
           0. Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.06526309611002579 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002579 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.12940952255126037` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.48296291314453416` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.48296291314453416` Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126037` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.1913417161825449 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825449 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.24999999999999997` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.43301270189221935` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.43301270189221935` Abs[$CellContext`HoleDiameter], 0. + 
           0.24999999999999997` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3043807145043603 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456176 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3043807145043603 
            Abs[$CellContext`HoleDiameter]}, {((-0.5) (0. + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3535533905932738 Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327373` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.3043807145043604 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456175 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.3043807145043604 Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456175 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.25000000000000006` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922193 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.25000000000000006` Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922193 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.19134171618254492` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.19134171618254492` Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564337` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.12940952255126048` 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.12940952255126048` Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445341 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               0.06526309611002586 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.06526309611002586 Abs[$CellContext`HoleDiameter], 0. + 
           0.4957224306869052 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. + 
               3.061616997868383*^-17 
                Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           3.061616997868383*^-17 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.06526309611002569 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.49572243068690525` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.06526309611002569 Abs[$CellContext`HoleDiameter], 0. + 
           0.49572243068690525` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.12940952255126031` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.48296291314453416` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.12940952255126031` Abs[$CellContext`HoleDiameter], 0. + 
           0.48296291314453416` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.19134171618254475` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4619397662556434 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.19134171618254475` Abs[$CellContext`HoleDiameter], 0. + 
           0.4619397662556434 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.2499999999999999 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922194 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.2499999999999999 Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922194 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.30438071450436016` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3966766701456177 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.30438071450436016` Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456177 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.3535533905932738 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. + 
           0.3535533905932738 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.39667667014561747` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.30438071450436044` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.39667667014561747` Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436044` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.43301270189221924` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.25000000000000017` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.43301270189221924` Abs[$CellContext`HoleDiameter], 0. + 
           0.25000000000000017` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564337` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.19134171618254492` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.19134171618254492` 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445341 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.1294095225512605 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4829629131445341 Abs[$CellContext`HoleDiameter], 0. + 
           0.1294095225512605 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4957224306869052 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.065263096110026 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.065263096110026 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.5 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              6.123233995736766*^-17 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 0.5 
           Abs[$CellContext`HoleDiameter], 0. + 
           6.123233995736766*^-17 
            Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.49572243068690525` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.06526309611002566 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.49572243068690525` Abs[$CellContext`HoleDiameter], 0. - 
           0.06526309611002566 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445342 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.12940952255126018` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4829629131445342 Abs[$CellContext`HoleDiameter], 0. - 
           0.12940952255126018` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4619397662556435 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.1913417161825446 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4619397662556435 Abs[$CellContext`HoleDiameter], 0. - 
           0.1913417161825446 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922194 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.2499999999999999 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.4330127018922194 Abs[$CellContext`HoleDiameter], 0. - 
           0.2499999999999999 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.3966766701456177 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.30438071450436016` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.3966766701456177 Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436016` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.35355339059327395` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.35355339059327356` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.35355339059327395` Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327356` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.39667667014561747` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.30438071450436044` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.30438071450436044` Abs[$CellContext`HoleDiameter], 0. - 
           0.39667667014561747` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922192 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.2500000000000002 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.2500000000000002 Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922192 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.46193976625564326` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.19134171618254517` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.19134171618254517` Abs[$CellContext`HoleDiameter], 0. - 
           0.46193976625564326` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.48296291314453405` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.12940952255126073` 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.12940952255126073` Abs[$CellContext`HoleDiameter], 0. - 
           0.48296291314453405` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.49572243068690514` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 0.06526309611002626 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           0.06526309611002626 Abs[$CellContext`HoleDiameter], 0. - 
           0.49572243068690514` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 0.5 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. - 9.184850993605148*^-17 
              Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. - 
           9.184850993605148*^-17 Abs[$CellContext`HoleDiameter], 0. - 0.5 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.49572243068690525` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.06526309611002562 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.06526309611002562 Abs[$CellContext`HoleDiameter], 0. - 
           0.49572243068690525` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4829629131445342 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.12940952255126015` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.12940952255126015` Abs[$CellContext`HoleDiameter], 0. - 
           0.4829629131445342 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4619397662556435 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.19134171618254459` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.19134171618254459` Abs[$CellContext`HoleDiameter], 0. - 
           0.4619397662556435 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.4330127018922195 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.24999999999999964` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.24999999999999964` Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922195 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.39667667014561786` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.30438071450435994` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.30438071450435994` Abs[$CellContext`HoleDiameter], 0. - 
           0.39667667014561786` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.35355339059327384` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.35355339059327373` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327384` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.30438071450436044` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.39667667014561747` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.39667667014561747` Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436044` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.2500000000000002 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.4330127018922192 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.4330127018922192 Abs[$CellContext`HoleDiameter], 0. - 
           0.2500000000000002 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.1913417161825452 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.46193976625564326` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.46193976625564326` Abs[$CellContext`HoleDiameter], 0. - 
           0.1913417161825452 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.12940952255126076` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.48296291314453405` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.48296291314453405` Abs[$CellContext`HoleDiameter], 0. - 
           0.12940952255126076` 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               0.06526309611002629 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.49572243068690514` 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.49572243068690514` Abs[$CellContext`HoleDiameter], 0. - 
           0.06526309611002629 
           Abs[$CellContext`HoleDiameter]}, {((-0.25) (0. - 
               1.2246467991473532`*^-16 
               Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1 - (
            0.25 (0. + 
              0.5 Abs[$CellContext`HoleDiameter])^2)/$CellContext`mf1, 0. + 
           0.5 Abs[$CellContext`HoleDiameter], 0. - 1.2246467991473532`*^-16 
           Abs[$CellContext`HoleDiameter]}, {(-16129.)/$CellContext`mf1, 254.,
            0.}, {(-16129.)/$CellContext`mf1, 251.82699478894784`, 
           33.1536528238931}, {(-16129.)/$CellContext`mf1, 
           245.34515987742336`, 
           65.74003745604027}, {(-16128.999999999998`)/$CellContext`mf1, 
           234.66540125786682`, 
           97.2015918207328}, {(-16129.000000000004`)/$CellContext`mf1, 
           219.97045256124744`, 
           126.99999999999999`}, {(-16128.999999999998`)/$CellContext`mf1, 
           201.51174843397374`, 
           154.625402968215}, {(-16128.999999999996`)/$CellContext`mf1, 
           179.60512242138307`, 
           179.60512242138304`}, {(-16129.)/$CellContext`mf1, 
           154.62540296821507`, 
           201.5117484339737}, {(-16129.000000000002`)/$CellContext`mf1, 
           127.00000000000003`, 
           219.9704525612474}, {(-16128.999999999998`)/$CellContext`mf1, 
           97.20159182073282, 
           234.66540125786682`}, {(-16129.)/$CellContext`mf1, 
           65.74003745604033, 
           245.34515987742333`}, {(-16129.000000000002`)/$CellContext`mf1, 
           33.15365282389313, 
           251.82699478894784`}, {(-16129.)/$CellContext`mf1, 
           1.5553014349171386`*^-14, 
           254.}, {(-16129.000000000004`)/$CellContext`mf1, \
-33.15365282389305, 
           251.82699478894787`}, {(-16129.)/$CellContext`mf1, \
-65.74003745604024, 
           245.34515987742336`}, {(-16128.999999999998`)/$CellContext`mf1, \
-97.20159182073273, 
           234.66540125786685`}, {(-16129.000000000002`)/$CellContext`mf1, \
-126.99999999999994`, 
           219.97045256124747`}, {(-16129.)/$CellContext`mf1, \
-154.62540296821496`, 
           201.5117484339738}, {(-16128.999999999996`)/$CellContext`mf1, \
-179.60512242138304`, 
           179.60512242138307`}, {(-16129.)/$CellContext`mf1, \
-201.51174843397368`, 
           154.6254029682151}, {(-16129.000000000002`)/$CellContext`mf1, \
-219.97045256124738`, 
           127.00000000000009`}, {(-16128.999999999998`)/$CellContext`mf1, \
-234.66540125786682`, 
           97.20159182073282}, {(-16129.)/$CellContext`mf1, \
-245.34515987742333`, 
           65.74003745604034}, {(-16129.000000000002`)/$CellContext`mf1, \
-251.82699478894784`, 
           33.153652823893204`}, {(-16129.)/$CellContext`mf1, -254., 
           3.110602869834277*^-14}, {(-16129.000000000004`)/$CellContext`mf1,
            -251.82699478894787`, -33.15365282389303}, \
{(-16129.000000000002`)/$CellContext`mf1, -245.34515987742338`, \
-65.74003745604017}, {(-16128.999999999998`)/$CellContext`mf1, \
-234.66540125786688`, -97.20159182073266}, \
{(-16129.000000000002`)/$CellContext`mf1, -219.97045256124747`, \
-126.99999999999994`}, {(-16129.)/$CellContext`mf1, -201.5117484339738, \
-154.62540296821496`}, {(-16128.999999999998`)/$CellContext`mf1, \
-179.60512242138316`, -179.60512242138296`}, {(-16129.)/$CellContext`mf1, \
-154.6254029682151, -201.51174843397368`}, {(-16129.)/$CellContext`mf1, \
-127.00000000000011`, -219.97045256124736`}, \
{(-16128.999999999998`)/$CellContext`mf1, -97.20159182073294, \
-234.66540125786676`}, {(-16129.)/$CellContext`mf1, -65.74003745604045, \
-245.3451598774233}, {(-16129.)/$CellContext`mf1, -33.15365282389334, \
-251.82699478894781`}, {(-16129.)/$CellContext`mf1, \
-4.6659043047514155`*^-14, -254.}, {(-16129.000000000002`)/$CellContext`mf1, 
           33.15365282389301, -251.82699478894787`}, \
{(-16129.)/$CellContext`mf1, 
           65.74003745604016, -245.34515987742338`}, \
{(-16128.999999999998`)/$CellContext`mf1, 
           97.20159182073265, -234.66540125786688`}, \
{(-16129.)/$CellContext`mf1, 
           126.99999999999982`, -219.97045256124753`}, \
{(-16129.)/$CellContext`mf1, 
           154.62540296821484`, -201.51174843397388`}, \
{(-16129.)/$CellContext`mf1, 
           179.60512242138304`, -179.6051224213831}, \
{(-16129.)/$CellContext`mf1, 
           201.51174843397368`, -154.6254029682151}, \
{(-16129.)/$CellContext`mf1, 
           219.97045256124736`, -127.00000000000011`}, \
{(-16128.999999999998`)/$CellContext`mf1, 
           234.66540125786676`, -97.20159182073296}, \
{(-16129.)/$CellContext`mf1, 
           245.3451598774233, -65.74003745604047}, \
{(-16129.000000000002`)/$CellContext`mf1, 
           251.82699478894781`, -33.15365282389335}, \
{(-16129.)/$CellContext`mf1, 254., -6.221205739668554*^-14}, {
          50.800000000000004`, 0. + 0.5 Abs[$CellContext`HoleDiameter], 0. + 
           0. Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter], 0. + 
           0.06526309611002579 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.48296291314453416` Abs[$CellContext`HoleDiameter], 0. + 
           0.12940952255126037` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter], 0. + 
           0.1913417161825449 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.43301270189221935` Abs[$CellContext`HoleDiameter], 0. + 
           0.24999999999999997` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3966766701456176 Abs[$CellContext`HoleDiameter], 0. + 
           0.3043807145043603 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3535533905932738 Abs[$CellContext`HoleDiameter], 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.3043807145043604 Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456175 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.25000000000000006` Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922193 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.19134171618254492` Abs[$CellContext`HoleDiameter], 0. + 
           0.46193976625564337` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.12940952255126048` Abs[$CellContext`HoleDiameter], 0. + 
           0.4829629131445341 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.06526309611002586 Abs[$CellContext`HoleDiameter], 0. + 
           0.4957224306869052 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           3.061616997868383*^-17 Abs[$CellContext`HoleDiameter], 0. + 
           0.5 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.06526309611002569 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.49572243068690525` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.12940952255126031` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.48296291314453416` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.19134171618254475` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4619397662556434 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.2499999999999999 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.4330127018922194 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.30438071450436016` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.3966766701456177 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.35355339059327373` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.3535533905932738 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.39667667014561747` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.30438071450436044` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.43301270189221924` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.25000000000000017` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.46193976625564337` 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.19134171618254492` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4829629131445341 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.1294095225512605 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4957224306869052 
           Abs[$CellContext`HoleDiameter], 0. + 
           0.065263096110026 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.5 Abs[$CellContext`HoleDiameter], 0. + 
           6.123233995736766*^-17 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.49572243068690525` 
           Abs[$CellContext`HoleDiameter], 0. - 0.06526309611002566 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4829629131445342 
           Abs[$CellContext`HoleDiameter], 0. - 0.12940952255126018` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4619397662556435 
           Abs[$CellContext`HoleDiameter], 0. - 0.1913417161825446 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.4330127018922194 
           Abs[$CellContext`HoleDiameter], 0. - 0.2499999999999999 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.3966766701456177 
           Abs[$CellContext`HoleDiameter], 0. - 0.30438071450436016` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.35355339059327395` 
           Abs[$CellContext`HoleDiameter], 0. - 0.35355339059327356` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.30438071450436044` 
           Abs[$CellContext`HoleDiameter], 0. - 0.39667667014561747` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.2500000000000002 
           Abs[$CellContext`HoleDiameter], 0. - 0.4330127018922192 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.19134171618254517` 
           Abs[$CellContext`HoleDiameter], 0. - 0.46193976625564326` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.12940952255126073` 
           Abs[$CellContext`HoleDiameter], 0. - 0.48296291314453405` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 0.06526309611002626 
           Abs[$CellContext`HoleDiameter], 0. - 0.49572243068690514` 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. - 9.184850993605148*^-17 
           Abs[$CellContext`HoleDiameter], 0. - 0.5 
           Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.06526309611002562 Abs[$CellContext`HoleDiameter], 0. - 
           0.49572243068690525` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.12940952255126015` Abs[$CellContext`HoleDiameter], 0. - 
           0.4829629131445342 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.19134171618254459` Abs[$CellContext`HoleDiameter], 0. - 
           0.4619397662556435 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.24999999999999964` Abs[$CellContext`HoleDiameter], 0. - 
           0.4330127018922195 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.30438071450435994` Abs[$CellContext`HoleDiameter], 0. - 
           0.39667667014561786` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.35355339059327373` Abs[$CellContext`HoleDiameter], 0. - 
           0.35355339059327384` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.39667667014561747` Abs[$CellContext`HoleDiameter], 0. - 
           0.30438071450436044` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.4330127018922192 Abs[$CellContext`HoleDiameter], 0. - 
           0.2500000000000002 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.46193976625564326` Abs[$CellContext`HoleDiameter], 0. - 
           0.1913417161825452 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.48296291314453405` Abs[$CellContext`HoleDiameter], 0. - 
           0.12940952255126076` Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 
           0.49572243068690514` Abs[$CellContext`HoleDiameter], 0. - 
           0.06526309611002629 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 0. + 0.5 Abs[$CellContext`HoleDiameter], 0. - 
           1.2246467991473532`*^-16 Abs[$CellContext`HoleDiameter]}, {
          50.800000000000004`, 254., 0.}, {50.800000000000004`, 
          251.82699478894784`, 33.1536528238931}, {50.800000000000004`, 
          245.34515987742336`, 65.74003745604027}, {50.800000000000004`, 
          234.66540125786682`, 97.2015918207328}, {50.800000000000004`, 
          219.97045256124744`, 126.99999999999999`}, {50.800000000000004`, 
          201.51174843397374`, 154.625402968215}, {50.800000000000004`, 
          179.60512242138307`, 179.60512242138304`}, {50.800000000000004`, 
          154.62540296821507`, 201.5117484339737}, {50.800000000000004`, 
          127.00000000000003`, 219.9704525612474}, {50.800000000000004`, 
          97.20159182073282, 234.66540125786682`}, {50.800000000000004`, 
          65.74003745604033, 245.34515987742333`}, {50.800000000000004`, 
          33.15365282389313, 251.82699478894784`}, {50.800000000000004`, 
          1.5553014349171386`*^-14, 254.}, {
          50.800000000000004`, -33.15365282389305, 251.82699478894787`}, {
          50.800000000000004`, -65.74003745604024, 245.34515987742336`}, {
          50.800000000000004`, -97.20159182073273, 234.66540125786685`}, {
          50.800000000000004`, -126.99999999999994`, 219.97045256124747`}, {
          50.800000000000004`, -154.62540296821496`, 201.5117484339738}, {
          50.800000000000004`, -179.60512242138304`, 179.60512242138307`}, {
          50.800000000000004`, -201.51174843397368`, 154.6254029682151}, {
          50.800000000000004`, -219.97045256124738`, 127.00000000000009`}, {
          50.800000000000004`, -234.66540125786682`, 97.20159182073282}, {
          50.800000000000004`, -245.34515987742333`, 65.74003745604034}, {
          50.800000000000004`, -251.82699478894784`, 33.153652823893204`}, {
          50.800000000000004`, -254., 3.110602869834277*^-14}, {
          50.800000000000004`, -251.82699478894787`, -33.15365282389303}, {
          50.800000000000004`, -245.34515987742338`, -65.74003745604017}, {
          50.800000000000004`, -234.66540125786688`, -97.20159182073266}, {
          50.800000000000004`, -219.97045256124747`, -126.99999999999994`}, {
          50.800000000000004`, -201.5117484339738, -154.62540296821496`}, {
          50.800000000000004`, -179.60512242138316`, -179.60512242138296`}, {
          50.800000000000004`, -154.6254029682151, -201.51174843397368`}, {
          50.800000000000004`, -127.00000000000011`, -219.97045256124736`}, {
          50.800000000000004`, -97.20159182073294, -234.66540125786676`}, {
          50.800000000000004`, -65.74003745604045, -245.3451598774233}, {
          50.800000000000004`, -33.15365282389334, -251.82699478894781`}, {
          50.800000000000004`, -4.6659043047514155`*^-14, -254.}, {
          50.800000000000004`, 33.15365282389301, -251.82699478894787`}, {
          50.800000000000004`, 65.74003745604016, -245.34515987742338`}, {
          50.800000000000004`, 97.20159182073265, -234.66540125786688`}, {
          50.800000000000004`, 126.99999999999982`, -219.97045256124753`}, {
          50.800000000000004`, 154.62540296821484`, -201.51174843397388`}, {
          50.800000000000004`, 179.60512242138304`, -179.6051224213831}, {
          50.800000000000004`, 201.51174843397368`, -154.6254029682151}, {
          50.800000000000004`, 219.97045256124736`, -127.00000000000011`}, {
          50.800000000000004`, 234.66540125786676`, -97.20159182073296}, {
          50.800000000000004`, 245.3451598774233, -65.74003745604047}, {
          50.800000000000004`, 251.82699478894781`, -33.15365282389335}, {
          50.800000000000004`, 
          254., -6.221205739668554*^-14}}]; \
$CellContext`polygons1289120122132243166881 = 
       Compile[{$CellContext`md2, $CellContext`mf2}, {{(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.08333333333333333 $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.0826204051144842 $CellContext`md2, 
           0.010877182685004297` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.08333333333333333 $CellContext`md2, 
           0. $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.16666666666666666` $CellContext`md2, 
           0. $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.1652408102289684 $CellContext`md2, 
           0.021754365370008594` $CellContext`md2}, \
{((-0.0017361111111111108`) $CellContext`md2^2)/$CellContext`mf2, 
           0.0826204051144842 $CellContext`md2, 
           0.010877182685004297` $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.08333333333333333 $CellContext`md2, 
           0. $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.16666666666666666` $CellContext`md2, 
           0. $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.25 $CellContext`md2, 
           
           0. $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.2478612153434526 $CellContext`md2, 
           0.03263154805501289 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.1652408102289684 $CellContext`md2, 
           0.021754365370008594` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.16666666666666666` $CellContext`md2, 
           0. $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.25 $CellContext`md2, 
           0. $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.3333333333333333 $CellContext`md2, 
           0. $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.3304816204579368 $CellContext`md2, 
           0.04350873074001719 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.2478612153434526 $CellContext`md2, 
           0.03263154805501289 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.25 $CellContext`md2, 
           0. $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.3333333333333333 $CellContext`md2, 
           0. $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.41666666666666663` $CellContext`md2, 
           0. $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.413102025572421 $CellContext`md2, 
           0.054385913425021484` $CellContext`md2}, \
{((-0.027777777777777773`) $CellContext`md2^2)/$CellContext`mf2, 
           0.3304816204579368 $CellContext`md2, 
           0.04350873074001719 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.3333333333333333 $CellContext`md2, 
           0. $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.41666666666666663` $CellContext`md2, 
           0. $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 0.49999999999999994` $CellContext`md2, 
           
           0. $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 0.49572243068690514` $CellContext`md2, 
           0.06526309611002577 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.413102025572421 $CellContext`md2, 
           0.054385913425021484` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.41666666666666663` $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.0826204051144842 $CellContext`md2, 
           0.010877182685004297` $CellContext`md2}, \
{((-0.0017361111111111108`) $CellContext`md2^2)/$CellContext`mf2, 
           0.08049381885742235 $CellContext`md2, 
           0.021568253758543394` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.0826204051144842 $CellContext`md2, 
           0.010877182685004297` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.1652408102289684 $CellContext`md2, 
           0.021754365370008594` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.1609876377148447 $CellContext`md2, 
           0.04313650751708679 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.08049381885742235 $CellContext`md2, 
           0.021568253758543394` $CellContext`md2}, \
{((-0.0017361111111111108`) $CellContext`md2^2)/$CellContext`mf2, 
           0.0826204051144842 $CellContext`md2, 
           0.010877182685004297` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.1652408102289684 $CellContext`md2, 
           0.021754365370008594` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.2478612153434526 $CellContext`md2, 
           0.03263154805501289 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.24148145657226708` $CellContext`md2, 
           0.06470476127563018 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.1609876377148447 $CellContext`md2, 
           0.04313650751708679 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.1652408102289684 $CellContext`md2, 
           0.021754365370008594` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.2478612153434526 $CellContext`md2, 
           0.03263154805501289 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.3304816204579368 $CellContext`md2, 
           0.04350873074001719 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.3219752754296894 $CellContext`md2, 
           0.08627301503417358 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.24148145657226708` $CellContext`md2, 
           0.06470476127563018 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.2478612153434526 $CellContext`md2, 
           0.03263154805501289 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.3304816204579368 $CellContext`md2, 
           0.04350873074001719 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.413102025572421 $CellContext`md2, 
           0.054385913425021484` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.40246909428711175` $CellContext`md2, 
           0.10784126879271697` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.3219752754296894 $CellContext`md2, 
           0.08627301503417358 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.3304816204579368 $CellContext`md2, 
           
           0.04350873074001719 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.413102025572421 $CellContext`md2, 
           0.054385913425021484` $CellContext`md2}, \
{((-0.062499999999999986`) $CellContext`md2^2)/$CellContext`mf2, 
           0.49572243068690514` $CellContext`md2, 
           0.06526309611002577 $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 0.4829629131445341 $CellContext`md2, 
           0.12940952255126034` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.40246909428711175` $CellContext`md2, 
           0.10784126879271697` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.413102025572421 $CellContext`md2, 
           0.054385913425021484` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.08049381885742235 $CellContext`md2, 
           0.021568253758543394` $CellContext`md2}, \
{((-0.0017361111111111106`) $CellContext`md2^2)/$CellContext`mf2, 
           0.07698996104260722 $CellContext`md2, 
           0.031890286030424146` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.08049381885742235 $CellContext`md2, 
           0.021568253758543394` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.1609876377148447 $CellContext`md2, 
           0.04313650751708679 $CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 0.15397992208521444` $CellContext`md2, 
           0.06378057206084829 $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 0.07698996104260722 $CellContext`md2, 
           0.031890286030424146` $CellContext`md2}, \
{((-0.0017361111111111108`) $CellContext`md2^2)/$CellContext`mf2, 
           0.08049381885742235 $CellContext`md2, 
           0.021568253758543394` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.1609876377148447 $CellContext`md2, 
           0.04313650751708679 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.24148145657226708` $CellContext`md2, 
           0.06470476127563018 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.23096988312782168` $CellContext`md2, 
           0.09567085809127245 $CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 0.15397992208521444` $CellContext`md2, 
           0.06378057206084829 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.1609876377148447 $CellContext`md2, 
           0.04313650751708679 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.24148145657226708` $CellContext`md2, 
           0.06470476127563018 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.3219752754296894 $CellContext`md2, 
           0.08627301503417358 $CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.3079598441704289 $CellContext`md2, 
           0.12756114412169658` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.23096988312782168` $CellContext`md2, 
           0.09567085809127245 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.24148145657226708` $CellContext`md2, 
           0.06470476127563018 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.3219752754296894 $CellContext`md2, 
           0.08627301503417358 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.40246909428711175` $CellContext`md2, 
           0.10784126879271697` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.3849498052130361 $CellContext`md2, 
           
           0.15945143015212074` $CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.3079598441704289 $CellContext`md2, 
           0.12756114412169658` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.3219752754296894 $CellContext`md2, 
           0.08627301503417358 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.40246909428711175` $CellContext`md2, 
           0.10784126879271697` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 0.4829629131445341 $CellContext`md2, 
           0.12940952255126034` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 0.4619397662556433 $CellContext`md2, 
           0.19134171618254486` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.3849498052130361 $CellContext`md2, 
           0.15945143015212074` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.40246909428711175` $CellContext`md2, 
           0.10784126879271697` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 0.07698996104260722 $CellContext`md2, 
           0.031890286030424146` $CellContext`md2}, \
{((-0.0017361111111111108`) $CellContext`md2^2)/$CellContext`mf2, 
           0.07216878364870322 $CellContext`md2, 
           0.04166666666666666 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 0.07698996104260722 $CellContext`md2, 
           0.031890286030424146` $CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 0.15397992208521444` $CellContext`md2, 
           0.06378057206084829 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.14433756729740643` $CellContext`md2, 
           0.08333333333333331 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.07216878364870322 $CellContext`md2, 
           0.04166666666666666 $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 0.07698996104260722 $CellContext`md2, 
           0.031890286030424146` $CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 0.15397992208521444` $CellContext`md2, 
           0.06378057206084829 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.23096988312782168` $CellContext`md2, 
           0.09567085809127245 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.21650635094610968` $CellContext`md2, 
           0.12499999999999999` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.14433756729740643` $CellContext`md2, 
           0.08333333333333331 $CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 0.15397992208521444` $CellContext`md2, 
           0.06378057206084829 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.23096988312782168` $CellContext`md2, 
           0.09567085809127245 $CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.3079598441704289 $CellContext`md2, 
           0.12756114412169658` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.28867513459481287` $CellContext`md2, 
           0.16666666666666663` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.21650635094610968` $CellContext`md2, 
           0.12499999999999999` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.23096988312782168` $CellContext`md2, 
           0.09567085809127245 $CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.3079598441704289 $CellContext`md2, 
           
           0.12756114412169658` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.3849498052130361 $CellContext`md2, 
           0.15945143015212074` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.3608439182435161 $CellContext`md2, 
           0.2083333333333333 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.28867513459481287` $CellContext`md2, 
           0.16666666666666663` $CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.3079598441704289 $CellContext`md2, 
           0.12756114412169658` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.3849498052130361 $CellContext`md2, 
           0.15945143015212074` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 0.4619397662556433 $CellContext`md2, 
           0.19134171618254486` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 0.4330127018922193 $CellContext`md2, 
           0.24999999999999994` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.3608439182435161 $CellContext`md2, 
           0.2083333333333333 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.3849498052130361 $CellContext`md2, 
           0.15945143015212074` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.07216878364870322 $CellContext`md2, 
           0.04166666666666666 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.06611277835760293 $CellContext`md2, 
           0.05073011908406004 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.07216878364870322 $CellContext`md2, 
           0.04166666666666666 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.14433756729740643` $CellContext`md2, 
           0.08333333333333331 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.13222555671520586` $CellContext`md2, 
           0.10146023816812008` $CellContext`md2}, \
{((-0.0017361111111111108`) $CellContext`md2^2)/$CellContext`mf2, 
           0.06611277835760293 $CellContext`md2, 
           0.05073011908406004 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.07216878364870322 $CellContext`md2, 
           0.04166666666666666 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.14433756729740643` $CellContext`md2, 
           0.08333333333333331 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.21650635094610968` $CellContext`md2, 
           0.12499999999999999` $CellContext`md2}, {((-0.015624999999999998`) \
$CellContext`md2^2)/$CellContext`mf2, 0.1983383350728088 $CellContext`md2, 
           0.15219035725218014` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.13222555671520586` $CellContext`md2, 
           0.10146023816812008` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.14433756729740643` $CellContext`md2, 
           0.08333333333333331 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.21650635094610968` $CellContext`md2, 
           0.12499999999999999` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.28867513459481287` $CellContext`md2, 
           0.16666666666666663` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.2644511134304117 $CellContext`md2, 
           0.20292047633624016` $CellContext`md2}, {((-0.015624999999999998`) \
$CellContext`md2^2)/$CellContext`mf2, 0.1983383350728088 $CellContext`md2, 
           
           0.15219035725218014` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.21650635094610968` $CellContext`md2, 
           0.12499999999999999` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.28867513459481287` $CellContext`md2, 
           0.16666666666666663` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.3608439182435161 $CellContext`md2, 
           0.2083333333333333 $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, 0.3305638917880146 $CellContext`md2, 
           0.2536505954203002 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.2644511134304117 $CellContext`md2, 
           0.20292047633624016` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.28867513459481287` $CellContext`md2, 
           0.16666666666666663` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.3608439182435161 $CellContext`md2, 
           0.2083333333333333 $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 0.4330127018922193 $CellContext`md2, 
           0.24999999999999994` $CellContext`md2}, {((-0.06249999999999997) \
$CellContext`md2^2)/$CellContext`mf2, 0.3966766701456175 $CellContext`md2, 
           0.3043807145043602 $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, 0.3305638917880146 $CellContext`md2, 
           0.2536505954203002 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.3608439182435161 $CellContext`md2, 
           0.2083333333333333 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.06611277835760293 $CellContext`md2, 
           0.05073011908406004 $CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, 0.058925565098878974` $CellContext`md2, 
           0.05892556509887895 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.06611277835760293 $CellContext`md2, 
           0.05073011908406004 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.13222555671520586` $CellContext`md2, 
           0.10146023816812008` $CellContext`md2}, {((-0.006944444444444445) \
$CellContext`md2^2)/$CellContext`mf2, 0.11785113019775795` $CellContext`md2, 
           0.1178511301977579 $CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, 0.058925565098878974` $CellContext`md2, 
           0.05892556509887895 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.06611277835760293 $CellContext`md2, 
           0.05073011908406004 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.13222555671520586` $CellContext`md2, 
           0.10146023816812008` $CellContext`md2}, {((-0.015624999999999998`) \
$CellContext`md2^2)/$CellContext`mf2, 0.1983383350728088 $CellContext`md2, 
           0.15219035725218014` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.17677669529663692` $CellContext`md2, 
           0.17677669529663687` $CellContext`md2}, {((-0.006944444444444445) \
$CellContext`md2^2)/$CellContext`mf2, 0.11785113019775795` $CellContext`md2, 
           0.1178511301977579 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.13222555671520586` $CellContext`md2, 
           0.10146023816812008` $CellContext`md2}, {((-0.015624999999999998`) \
$CellContext`md2^2)/$CellContext`mf2, 0.1983383350728088 $CellContext`md2, 
           0.15219035725218014` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.2644511134304117 $CellContext`md2, 
           
           0.20292047633624016` $CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, 0.2357022603955159 $CellContext`md2, 
           0.2357022603955158 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.17677669529663692` $CellContext`md2, 
           0.17677669529663687` $CellContext`md2}, {((-0.015624999999999998`) \
$CellContext`md2^2)/$CellContext`mf2, 0.1983383350728088 $CellContext`md2, 
           0.15219035725218014` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.2644511134304117 $CellContext`md2, 
           0.20292047633624016` $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, 0.3305638917880146 $CellContext`md2, 
           0.2536505954203002 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.29462782549439487` $CellContext`md2, 
           0.29462782549439476` $CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, 0.2357022603955159 $CellContext`md2, 
           0.2357022603955158 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.2644511134304117 $CellContext`md2, 
           0.20292047633624016` $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, 0.3305638917880146 $CellContext`md2, 
           0.2536505954203002 $CellContext`md2}, {((-0.06249999999999997) \
$CellContext`md2^2)/$CellContext`mf2, 0.3966766701456175 $CellContext`md2, 
           0.3043807145043602 $CellContext`md2}, {((-0.06249999999999999) \
$CellContext`md2^2)/$CellContext`mf2, 0.3535533905932738 $CellContext`md2, 
           0.3535533905932737 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.29462782549439487` $CellContext`md2, 
           0.29462782549439476` $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, 0.3305638917880146 $CellContext`md2, 
           0.2536505954203002 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.05892556509887896 $CellContext`md2, 
           0.05892556509887895 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.05073011908406006 $CellContext`md2, 
           0.06611277835760292 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.05892556509887896 $CellContext`md2, 
           0.05892556509887895 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.11785113019775792` $CellContext`md2, 
           0.1178511301977579 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.10146023816812012` $CellContext`md2, 
           0.13222555671520583` $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.05073011908406006 $CellContext`md2, 
           0.06611277835760292 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.05892556509887896 $CellContext`md2, 
           0.05892556509887895 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.11785113019775792` $CellContext`md2, 
           0.1178511301977579 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.1767766952966369 $CellContext`md2, 
           0.17677669529663687` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.1521903572521802 $CellContext`md2, 
           0.19833833507280876` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.10146023816812012` $CellContext`md2, 
           0.13222555671520583` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.11785113019775792` $CellContext`md2, 
           
           0.1178511301977579 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.1767766952966369 $CellContext`md2, 
           0.17677669529663687` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.23570226039551584` $CellContext`md2, 
           0.2357022603955158 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.20292047633624025` $CellContext`md2, 
           0.26445111343041167` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.1521903572521802 $CellContext`md2, 
           0.19833833507280876` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.1767766952966369 $CellContext`md2, 
           0.17677669529663687` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.23570226039551584` $CellContext`md2, 
           0.2357022603955158 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.2946278254943948 $CellContext`md2, 
           0.29462782549439476` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.2536505954203003 $CellContext`md2, 
           0.3305638917880146 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.20292047633624025` $CellContext`md2, 
           0.26445111343041167` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.23570226039551584` $CellContext`md2, 
           0.2357022603955158 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.2946278254943948 $CellContext`md2, 
           0.29462782549439476` $CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, 0.35355339059327373` $CellContext`md2, 
           0.3535533905932737 $CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, 0.30438071450436033` $CellContext`md2, 
           0.39667667014561747` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.2536505954203003 $CellContext`md2, 
           0.3305638917880146 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.2946278254943948 $CellContext`md2, 
           0.29462782549439476` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.05073011908406006 $CellContext`md2, 
           0.06611277835760292 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.04166666666666667 $CellContext`md2, 
           0.07216878364870322 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.05073011908406006 $CellContext`md2, 
           0.06611277835760292 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.10146023816812012` $CellContext`md2, 
           0.13222555671520583` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.08333333333333334 $CellContext`md2, 
           0.14433756729740643` $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.04166666666666667 $CellContext`md2, 
           0.07216878364870322 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.05073011908406006 $CellContext`md2, 
           0.06611277835760292 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.10146023816812012` $CellContext`md2, 
           0.13222555671520583` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.1521903572521802 $CellContext`md2, 
           0.19833833507280876` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.12500000000000003` $CellContext`md2, 
           
           0.21650635094610965` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.08333333333333334 $CellContext`md2, 
           0.14433756729740643` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.10146023816812012` $CellContext`md2, 
           0.13222555671520583` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.1521903572521802 $CellContext`md2, 
           0.19833833507280876` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.20292047633624025` $CellContext`md2, 
           0.26445111343041167` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.16666666666666669` $CellContext`md2, 
           0.28867513459481287` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.12500000000000003` $CellContext`md2, 
           0.21650635094610965` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.1521903572521802 $CellContext`md2, 
           0.19833833507280876` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.20292047633624025` $CellContext`md2, 
           0.26445111343041167` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.2536505954203003 $CellContext`md2, 
           0.3305638917880146 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.20833333333333337` $CellContext`md2, 
           0.360843918243516 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.16666666666666669` $CellContext`md2, 
           0.28867513459481287` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.20292047633624025` $CellContext`md2, 
           0.26445111343041167` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.2536505954203003 $CellContext`md2, 
           0.3305638917880146 $CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, 0.30438071450436033` $CellContext`md2, 
           0.39667667014561747` $CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, 0.25 $CellContext`md2, 
           0.43301270189221924` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.20833333333333337` $CellContext`md2, 
           0.360843918243516 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.2536505954203003 $CellContext`md2, 
           0.3305638917880146 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.04166666666666667 $CellContext`md2, 
           0.07216878364870322 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.03189028603042415 $CellContext`md2, 
           0.07698996104260722 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.04166666666666667 $CellContext`md2, 
           0.07216878364870322 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.08333333333333334 $CellContext`md2, 
           0.14433756729740643` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.0637805720608483 $CellContext`md2, 
           0.15397992208521444` $CellContext`md2}, \
{((-0.0017361111111111108`) $CellContext`md2^2)/$CellContext`mf2, 
           0.03189028603042415 $CellContext`md2, 
           0.07698996104260722 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.04166666666666667 $CellContext`md2, 
           0.07216878364870322 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.08333333333333334 $CellContext`md2, 
           
           0.14433756729740643` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.12500000000000003` $CellContext`md2, 
           0.21650635094610965` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.09567085809127246 $CellContext`md2, 
           0.23096988312782168` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.0637805720608483 $CellContext`md2, 
           0.15397992208521444` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.08333333333333334 $CellContext`md2, 
           0.14433756729740643` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.12500000000000003` $CellContext`md2, 
           0.21650635094610965` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.16666666666666669` $CellContext`md2, 
           0.28867513459481287` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.1275611441216966 $CellContext`md2, 
           0.3079598441704289 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.09567085809127246 $CellContext`md2, 
           0.23096988312782168` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.12500000000000003` $CellContext`md2, 
           0.21650635094610965` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.16666666666666669` $CellContext`md2, 
           0.28867513459481287` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.20833333333333337` $CellContext`md2, 
           0.360843918243516 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.15945143015212074` $CellContext`md2, 
           0.3849498052130361 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.1275611441216966 $CellContext`md2, 
           0.3079598441704289 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.16666666666666669` $CellContext`md2, 
           0.28867513459481287` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.20833333333333337` $CellContext`md2, 
           0.360843918243516 $CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, 0.25 $CellContext`md2, 
           0.43301270189221924` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 0.1913417161825449 $CellContext`md2, 
           0.4619397662556433 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.15945143015212074` $CellContext`md2, 
           0.3849498052130361 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.20833333333333337` $CellContext`md2, 
           0.360843918243516 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.03189028603042415 $CellContext`md2, 
           0.07698996104260722 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.021568253758543394` $CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.03189028603042415 $CellContext`md2, 
           0.07698996104260722 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.0637805720608483 $CellContext`md2, 
           0.15397992208521444` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.04313650751708679 $CellContext`md2, 
           0.1609876377148447 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.021568253758543394` $CellContext`md2, 
           
           0.08049381885742235 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.03189028603042415 $CellContext`md2, 
           0.07698996104260722 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.0637805720608483 $CellContext`md2, 
           0.15397992208521444` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.09567085809127246 $CellContext`md2, 
           0.23096988312782168` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.06470476127563018 $CellContext`md2, 
           0.24148145657226708` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.04313650751708679 $CellContext`md2, 
           0.1609876377148447 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.0637805720608483 $CellContext`md2, 
           0.15397992208521444` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.09567085809127246 $CellContext`md2, 
           0.23096988312782168` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.1275611441216966 $CellContext`md2, 
           0.3079598441704289 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.08627301503417358 $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.06470476127563018 $CellContext`md2, 
           0.24148145657226708` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.09567085809127246 $CellContext`md2, 
           0.23096988312782168` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.1275611441216966 $CellContext`md2, 
           0.3079598441704289 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.15945143015212074` $CellContext`md2, 
           0.3849498052130361 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.10784126879271697` $CellContext`md2, 
           0.40246909428711175` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.08627301503417358 $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.1275611441216966 $CellContext`md2, 
           0.3079598441704289 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.15945143015212074` $CellContext`md2, 
           0.3849498052130361 $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 0.1913417161825449 $CellContext`md2, 
           0.4619397662556433 $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 0.12940952255126034` $CellContext`md2, 
           0.4829629131445341 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.10784126879271697` $CellContext`md2, 
           0.40246909428711175` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 0.15945143015212074` $CellContext`md2, 
           0.3849498052130361 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.02156825375854341 $CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.01087718268500431 $CellContext`md2, 
           0.0826204051144842 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.02156825375854341 $CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.04313650751708682 $CellContext`md2, 
           
           0.1609876377148447 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.02175436537000862 $CellContext`md2, 
           0.1652408102289684 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.01087718268500431 $CellContext`md2, 
           0.0826204051144842 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 0.02156825375854341 $CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.04313650751708682 $CellContext`md2, 
           0.1609876377148447 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.06470476127563024 $CellContext`md2, 
           0.24148145657226705` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.03263154805501293 $CellContext`md2, 
           0.2478612153434526 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.02175436537000862 $CellContext`md2, 
           0.1652408102289684 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 0.04313650751708682 $CellContext`md2, 
           0.1609876377148447 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.06470476127563024 $CellContext`md2, 
           0.24148145657226705` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.08627301503417364 $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.04350873074001724 $CellContext`md2, 
           0.3304816204579368 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.03263154805501293 $CellContext`md2, 
           0.2478612153434526 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.06470476127563024 $CellContext`md2, 
           0.24148145657226705` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.08627301503417364 $CellContext`md2, 
           
           0.3219752754296894 $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, 0.10784126879271706` $CellContext`md2, 
           0.4024690942871117 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.05438591342502154 $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.04350873074001724 $CellContext`md2, 
           0.3304816204579368 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.08627301503417364 $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, 0.10784126879271706` $CellContext`md2, 
           0.4024690942871117 $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 0.12940952255126045` $CellContext`md2, 
           0.48296291314453405` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 0.06526309611002584 $CellContext`md2, 
           0.49572243068690514` $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.05438591342502154 $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, 0.10784126879271706` $CellContext`md2, 
           0.4024690942871117 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.01087718268500431 $CellContext`md2, 
           0.0826204051144842 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 5.102694996447305*^-18 $CellContext`md2,
            0.08333333333333333 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 0.01087718268500431 $CellContext`md2, 
           0.0826204051144842 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.02175436537000862 $CellContext`md2, 
           0.1652408102289684 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 1.020538999289461*^-17 $CellContext`md2,
            0.16666666666666666` $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 5.102694996447305*^-18 $CellContext`md2,
            0.08333333333333333 $CellContext`md2}, \
{((-0.0017361111111111108`) $CellContext`md2^2)/$CellContext`mf2, 
           0.01087718268500431 $CellContext`md2, 
           0.0826204051144842 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.02175436537000862 $CellContext`md2, 
           0.1652408102289684 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.03263154805501293 $CellContext`md2, 
           0.2478612153434526 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 
           1.5308084989341915`*^-17 $CellContext`md2, 
           0.25 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 1.020538999289461*^-17 $CellContext`md2,
            0.16666666666666666` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 0.02175436537000862 $CellContext`md2, 
           0.1652408102289684 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.03263154805501293 $CellContext`md2, 
           0.2478612153434526 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.04350873074001724 $CellContext`md2, 
           0.3304816204579368 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 2.041077998578922*^-17 $CellContext`md2,
            0.3333333333333333 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 
           1.5308084989341915`*^-17 $CellContext`md2, 
           
           0.25 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 0.03263154805501293 $CellContext`md2, 
           0.2478612153434526 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.04350873074001724 $CellContext`md2, 
           0.3304816204579368 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.05438591342502154 $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           2.5513474982236523`*^-17 $CellContext`md2, 
           0.41666666666666663` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 2.041077998578922*^-17 $CellContext`md2,
            0.3333333333333333 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 0.04350873074001724 $CellContext`md2, 
           0.3304816204579368 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.05438591342502154 $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 0.06526309611002584 $CellContext`md2, 
           0.49572243068690514` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 
           3.0616169978683824`*^-17 $CellContext`md2, 
           0.49999999999999994` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           2.5513474982236523`*^-17 $CellContext`md2, 
           0.41666666666666663` $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 0.05438591342502154 $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 5.102694996447305*^-18 $CellContext`md2,
            0.08333333333333333 $CellContext`md2}, \
{((-0.0017361111111111108`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.010877182685004299`) $CellContext`md2, 
           0.0826204051144842 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 5.102694996447305*^-18 $CellContext`md2,
            0.08333333333333333 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 1.020538999289461*^-17 $CellContext`md2,
            0.16666666666666666` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.021754365370008598`) \
$CellContext`md2, 
           0.1652408102289684 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.010877182685004299`) \
$CellContext`md2, 
           0.0826204051144842 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 5.102694996447305*^-18 $CellContext`md2,
            0.08333333333333333 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 1.020538999289461*^-17 $CellContext`md2,
            0.16666666666666666` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 
           1.5308084989341915`*^-17 $CellContext`md2, 
           0.25 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0326315480550129) $CellContext`md2, 
           0.2478612153434526 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.021754365370008598`) \
$CellContext`md2, 
           0.1652408102289684 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 1.020538999289461*^-17 $CellContext`md2,
            0.16666666666666666` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 
           1.5308084989341915`*^-17 $CellContext`md2, 
           0.25 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 2.041077998578922*^-17 $CellContext`md2,
            
           0.3333333333333333 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.043508730740017196`) \
$CellContext`md2, 
           0.3304816204579368 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0326315480550129) $CellContext`md2, 
           0.2478612153434526 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, 
           1.5308084989341915`*^-17 $CellContext`md2, 
           0.25 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 2.041077998578922*^-17 $CellContext`md2,
            0.3333333333333333 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           2.5513474982236523`*^-17 $CellContext`md2, 
           0.41666666666666663` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0543859134250215) $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.043508730740017196`) \
$CellContext`md2, 
           0.3304816204579368 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 2.041077998578922*^-17 $CellContext`md2,
            0.3333333333333333 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           2.5513474982236523`*^-17 $CellContext`md2, 
           0.41666666666666663` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 
           3.0616169978683824`*^-17 $CellContext`md2, 
           0.49999999999999994` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06526309611002579) $CellContext`md2,
            0.49572243068690514` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0543859134250215) $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           2.5513474982236523`*^-17 $CellContext`md2, 
           0.41666666666666663` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.010877182685004282`) \
$CellContext`md2, 
           0.08262040511448421 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.021568253758543383`) \
$CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.010877182685004282`) \
$CellContext`md2, 
           0.08262040511448421 $CellContext`md2}, {((-0.006944444444444445) \
$CellContext`md2^2)/$CellContext`mf2, (-0.021754365370008563`) \
$CellContext`md2, 
           0.16524081022896842` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.04313650751708677) $CellContext`md2,
            0.1609876377148447 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.021568253758543383`) \
$CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.010877182685004282`) \
$CellContext`md2, 
           0.08262040511448421 $CellContext`md2}, {((-0.006944444444444445) \
$CellContext`md2^2)/$CellContext`mf2, (-0.021754365370008563`) \
$CellContext`md2, 
           0.16524081022896842` $CellContext`md2}, {((-0.015625000000000003`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.032631548055012845`) \
$CellContext`md2, 
           0.24786121534345262` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06470476127563016) $CellContext`md2,
            0.24148145657226708` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.04313650751708677) $CellContext`md2,
            0.1609876377148447 $CellContext`md2}, {((-0.006944444444444445) \
$CellContext`md2^2)/$CellContext`mf2, (-0.021754365370008563`) \
$CellContext`md2, 
           0.16524081022896842` $CellContext`md2}, {((-0.015625000000000003`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.032631548055012845`) \
$CellContext`md2, 
           0.24786121534345262` $CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, (-0.043508730740017126`) \
$CellContext`md2, 
           0.33048162045793683` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08627301503417353) $CellContext`md2,
            0.3219752754296894 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06470476127563016) $CellContext`md2,
            0.24148145657226708` $CellContext`md2}, \
{((-0.015625000000000003`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.032631548055012845`) $CellContext`md2, 
           0.24786121534345262` $CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, (-0.043508730740017126`) \
$CellContext`md2, 
           0.33048162045793683` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0543859134250214) $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10784126879271692`) \
$CellContext`md2, 
           0.40246909428711175` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08627301503417353) $CellContext`md2,
            0.3219752754296894 $CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, (-0.043508730740017126`) \
$CellContext`md2, 
           0.33048162045793683` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0543859134250214) $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {((-0.06249999999999999) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06526309611002568) $CellContext`md2,
            0.4957224306869052 $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1294095225512603) $CellContext`md2, 
           0.4829629131445341 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10784126879271692`) \
$CellContext`md2, 
           0.40246909428711175` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0543859134250214) $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.021568253758543383`) \
$CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.03189028603042414) $CellContext`md2,
            0.07698996104260722 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.021568253758543383`) \
$CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.04313650751708677) $CellContext`md2,
            0.1609876377148447 $CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06378057206084828) $CellContext`md2,
            0.15397992208521444` $CellContext`md2}, \
{((-0.0017361111111111106`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.03189028603042414) $CellContext`md2, 
           0.07698996104260722 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.021568253758543383`) \
$CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.04313650751708677) $CellContext`md2,
            0.1609876377148447 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06470476127563016) $CellContext`md2,
            
           0.24148145657226708` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.09567085809127243) $CellContext`md2,
            0.23096988312782168` $CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06378057206084828) $CellContext`md2,
            0.15397992208521444` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.04313650751708677) $CellContext`md2,
            0.1609876377148447 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06470476127563016) $CellContext`md2,
            0.24148145657226708` $CellContext`md2}, \
{((-0.027777777777777773`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.08627301503417353) $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.12756114412169656`) \
$CellContext`md2, 
           0.3079598441704289 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.09567085809127243) $CellContext`md2,
            0.23096988312782168` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06470476127563016) $CellContext`md2,
            0.24148145657226708` $CellContext`md2}, \
{((-0.027777777777777773`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.08627301503417353) $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10784126879271692`) \
$CellContext`md2, 
           0.40246909428711175` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1594514301521207) $CellContext`md2, 
           0.3849498052130361 $CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.12756114412169656`) \
$CellContext`md2, 
           0.3079598441704289 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08627301503417353) $CellContext`md2,
            0.3219752754296894 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10784126879271692`) \
$CellContext`md2, 
           0.40246909428711175` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1294095225512603) $CellContext`md2, 
           0.4829629131445341 $CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, (-0.19134171618254484`) \
$CellContext`md2, 
           0.4619397662556433 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1594514301521207) $CellContext`md2, 
           0.3849498052130361 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10784126879271692`) \
$CellContext`md2, 
           0.40246909428711175` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.031890286030424125`) \
$CellContext`md2, 
           0.07698996104260723 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.041666666666666644`) \
$CellContext`md2, 
           0.07216878364870323 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.031890286030424125`) \
$CellContext`md2, 
           0.07698996104260723 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06378057206084825) $CellContext`md2,
            0.15397992208521447` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08333333333333329) $CellContext`md2,
            0.14433756729740646` $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.041666666666666644`) \
$CellContext`md2, 
           0.07216878364870323 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.031890286030424125`) \
$CellContext`md2, 
           0.07698996104260723 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06378057206084825) $CellContext`md2,
            0.15397992208521447` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.09567085809127238) $CellContext`md2,
            0.2309698831278217 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.12499999999999994`) \
$CellContext`md2, 
           0.2165063509461097 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08333333333333329) $CellContext`md2,
            0.14433756729740646` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06378057206084825) $CellContext`md2,
            0.15397992208521447` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.09567085809127238) $CellContext`md2,
            0.2309698831278217 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1275611441216965) $CellContext`md2, 
           0.30795984417042893` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.16666666666666657`) \
$CellContext`md2, 
           0.2886751345948129 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.12499999999999994`) \
$CellContext`md2, 
           0.2165063509461097 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.09567085809127238) $CellContext`md2,
            0.2309698831278217 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1275611441216965) $CellContext`md2, 
           0.30795984417042893` $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1594514301521206) $CellContext`md2, 
           0.3849498052130362 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.20833333333333323`) \
$CellContext`md2, 
           0.36084391824351614` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.16666666666666657`) \
$CellContext`md2, 
           0.2886751345948129 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1275611441216965) $CellContext`md2, 
           0.30795984417042893` $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1594514301521206) $CellContext`md2, 
           0.3849498052130362 $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.19134171618254472`) \
$CellContext`md2, 
           0.46193976625564337` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.24999999999999986`) \
$CellContext`md2, 
           0.43301270189221935` $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.20833333333333323`) \
$CellContext`md2, 
           0.36084391824351614` $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1594514301521206) $CellContext`md2, 
           0.3849498052130362 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.041666666666666644`) \
$CellContext`md2, 
           0.07216878364870323 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05073011908406003) $CellContext`md2,
            0.06611277835760294 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.041666666666666644`) \
$CellContext`md2, 
           0.07216878364870323 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08333333333333329) $CellContext`md2,
            
           0.14433756729740646` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10146023816812005`) \
$CellContext`md2, 
           0.1322255567152059 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05073011908406003) $CellContext`md2,
            0.06611277835760294 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.041666666666666644`) \
$CellContext`md2, 
           0.07216878364870323 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08333333333333329) $CellContext`md2,
            0.14433756729740646` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.12499999999999994`) \
$CellContext`md2, 
           0.2165063509461097 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.15219035725218008`) \
$CellContext`md2, 
           0.19833833507280885` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10146023816812005`) \
$CellContext`md2, 
           0.1322255567152059 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08333333333333329) $CellContext`md2,
            0.14433756729740646` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.12499999999999994`) \
$CellContext`md2, 
           0.2165063509461097 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.16666666666666657`) \
$CellContext`md2, 
           0.2886751345948129 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2029204763362401) $CellContext`md2, 
           0.2644511134304118 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.15219035725218008`) \
$CellContext`md2, 
           0.19833833507280885` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.12499999999999994`) \
$CellContext`md2, 
           0.2165063509461097 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.16666666666666657`) \
$CellContext`md2, 
           0.2886751345948129 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.20833333333333323`) \
$CellContext`md2, 
           0.36084391824351614` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2536505954203001) $CellContext`md2, 
           0.3305638917880147 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2029204763362401) $CellContext`md2, 
           0.2644511134304118 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.16666666666666657`) \
$CellContext`md2, 
           0.2886751345948129 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.20833333333333323`) \
$CellContext`md2, 
           0.36084391824351614` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.24999999999999986`) \
$CellContext`md2, 
           0.43301270189221935` $CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3043807145043601) $CellContext`md2, 
           0.39667667014561764` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2536505954203001) $CellContext`md2, 
           0.3305638917880147 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.20833333333333323`) \
$CellContext`md2, 
           0.36084391824351614` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05073011908406003) $CellContext`md2,
            0.06611277835760294 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.058925565098878925`) \
$CellContext`md2, 
           0.05892556509887899 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05073011908406003) $CellContext`md2,
            0.06611277835760294 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10146023816812005`) \
$CellContext`md2, 
           0.1322255567152059 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.11785113019775785`) \
$CellContext`md2, 
           0.11785113019775798` $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.058925565098878925`) \
$CellContext`md2, 
           0.05892556509887899 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05073011908406003) $CellContext`md2,
            0.06611277835760294 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10146023816812005`) \
$CellContext`md2, 
           0.1322255567152059 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.15219035725218008`) \
$CellContext`md2, 
           0.19833833507280885` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.17677669529663678`) \
$CellContext`md2, 
           0.17677669529663698` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.11785113019775785`) \
$CellContext`md2, 
           0.11785113019775798` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10146023816812005`) \
$CellContext`md2, 
           0.1322255567152059 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.15219035725218008`) \
$CellContext`md2, 
           0.19833833507280885` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2029204763362401) $CellContext`md2, 
           0.2644511134304118 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2357022603955157) $CellContext`md2, 
           0.23570226039551595` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.17677669529663678`) \
$CellContext`md2, 
           0.17677669529663698` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.15219035725218008`) \
$CellContext`md2, 
           0.19833833507280885` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2029204763362401) $CellContext`md2, 
           0.2644511134304118 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2536505954203001) $CellContext`md2, 
           0.3305638917880147 $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2946278254943946) $CellContext`md2, 
           0.2946278254943949 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2357022603955157) $CellContext`md2, 
           0.23570226039551595` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2029204763362401) $CellContext`md2, 
           0.2644511134304118 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2536505954203001) $CellContext`md2, 
           0.3305638917880147 $CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3043807145043601) $CellContext`md2, 
           0.39667667014561764` $CellContext`md2}, {((-0.06249999999999997) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3535533905932735) $CellContext`md2, 
           0.3535533905932739 $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2946278254943946) $CellContext`md2, 
           0.2946278254943949 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2536505954203001) $CellContext`md2, 
           0.3305638917880147 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05892556509887895) $CellContext`md2,
            0.05892556509887896 $CellContext`md2}, \
{((-0.0017361111111111106`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.0661127783576029) $CellContext`md2, 
           0.05073011908406007 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05892556509887895) $CellContext`md2,
            0.05892556509887896 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1178511301977579) $CellContext`md2, 
           0.11785113019775792` $CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1322255567152058) $CellContext`md2, 
           0.10146023816812014` $CellContext`md2}, \
{((-0.0017361111111111106`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.0661127783576029) $CellContext`md2, 
           0.05073011908406007 $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05892556509887895) $CellContext`md2,
            0.05892556509887896 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1178511301977579) $CellContext`md2, 
           0.11785113019775792` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.17677669529663687`) \
$CellContext`md2, 
           0.1767766952966369 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.19833833507280874`) \
$CellContext`md2, 
           0.15219035725218022` $CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1322255567152058) $CellContext`md2, 
           0.10146023816812014` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1178511301977579) $CellContext`md2, 
           
           0.11785113019775792` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.17677669529663687`) \
$CellContext`md2, 
           0.1767766952966369 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2357022603955158) $CellContext`md2, 
           0.23570226039551584` $CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2644511134304116) $CellContext`md2, 
           0.20292047633624027` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.19833833507280874`) \
$CellContext`md2, 
           0.15219035725218022` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.17677669529663687`) \
$CellContext`md2, 
           0.1767766952966369 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2357022603955158) $CellContext`md2, 
           0.23570226039551584` $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.29462782549439476`) \
$CellContext`md2, 
           0.2946278254943948 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.33056389178801454`) \
$CellContext`md2, 
           0.25365059542030033` $CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2644511134304116) $CellContext`md2, 
           0.20292047633624027` $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2357022603955158) $CellContext`md2, 
           0.23570226039551584` $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.29462782549439476`) \
$CellContext`md2, 
           0.2946278254943948 $CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3535533905932737) $CellContext`md2, 
           0.35355339059327373` $CellContext`md2}, {((-0.06249999999999997) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3966766701456174) $CellContext`md2, 
           0.3043807145043604 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.33056389178801454`) \
$CellContext`md2, 
           0.25365059542030033` $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.29462782549439476`) \
$CellContext`md2, 
           0.2946278254943948 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0661127783576029) $CellContext`md2, 
           0.05073011908406007 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0721687836487032) $CellContext`md2, 
           0.04166666666666669 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0661127783576029) $CellContext`md2, 
           0.05073011908406007 $CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1322255567152058) $CellContext`md2, 
           0.10146023816812014` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1443375672974064) $CellContext`md2, 
           0.08333333333333338 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0721687836487032) $CellContext`md2, 
           0.04166666666666669 $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0661127783576029) $CellContext`md2, 
           0.05073011908406007 $CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1322255567152058) $CellContext`md2, 
           0.10146023816812014` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.19833833507280874`) \
$CellContext`md2, 
           0.15219035725218022` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.21650635094610962`) \
$CellContext`md2, 
           0.12500000000000008` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1443375672974064) $CellContext`md2, 
           0.08333333333333338 $CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1322255567152058) $CellContext`md2, 
           0.10146023816812014` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.19833833507280874`) \
$CellContext`md2, 
           0.15219035725218022` $CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2644511134304116) $CellContext`md2, 
           0.20292047633624027` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2886751345948128) $CellContext`md2, 
           0.16666666666666677` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.21650635094610962`) \
$CellContext`md2, 
           0.12500000000000008` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.19833833507280874`) \
$CellContext`md2, 
           0.15219035725218022` $CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2644511134304116) $CellContext`md2, 
           0.20292047633624027` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.33056389178801454`) \
$CellContext`md2, 
           0.25365059542030033` $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.360843918243516) $CellContext`md2, 
           0.20833333333333345` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2886751345948128) $CellContext`md2, 
           0.16666666666666677` $CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2644511134304116) $CellContext`md2, 
           0.20292047633624027` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.33056389178801454`) \
$CellContext`md2, 
           
           0.25365059542030033` $CellContext`md2}, {((-0.06249999999999997) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3966766701456174) $CellContext`md2, 
           0.3043807145043604 $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4330127018922192) $CellContext`md2, 
           0.2500000000000001 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.360843918243516) $CellContext`md2, 
           0.20833333333333345` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.33056389178801454`) \
$CellContext`md2, 
           0.25365059542030033` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0721687836487032) $CellContext`md2, 
           0.04166666666666669 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0769899610426072) $CellContext`md2, 
           0.03189028603042419 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0721687836487032) $CellContext`md2, 
           0.04166666666666669 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1443375672974064) $CellContext`md2, 
           0.08333333333333338 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1539799220852144) $CellContext`md2, 
           0.06378057206084838 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0769899610426072) $CellContext`md2, 
           0.03189028603042419 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0721687836487032) $CellContext`md2, 
           0.04166666666666669 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1443375672974064) $CellContext`md2, 
           0.08333333333333338 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.21650635094610962`) \
$CellContext`md2, 
           0.12500000000000008` $CellContext`md2}, {((-0.015624999999999998`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.23096988312782163`) \
$CellContext`md2, 
           0.09567085809127257 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1539799220852144) $CellContext`md2, 
           0.06378057206084838 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1443375672974064) $CellContext`md2, 
           0.08333333333333338 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.21650635094610962`) \
$CellContext`md2, 
           0.12500000000000008` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2886751345948128) $CellContext`md2, 
           0.16666666666666677` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3079598441704288) $CellContext`md2, 
           0.12756114412169675` $CellContext`md2}, {((-0.015624999999999998`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.23096988312782163`) \
$CellContext`md2, 
           0.09567085809127257 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.21650635094610962`) \
$CellContext`md2, 
           0.12500000000000008` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2886751345948128) $CellContext`md2, 
           0.16666666666666677` $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.360843918243516) $CellContext`md2, 
           0.20833333333333345` $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.384949805213036) $CellContext`md2, 
           0.15945143015212093` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3079598441704288) $CellContext`md2, 
           
           0.12756114412169675` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2886751345948128) $CellContext`md2, 
           0.16666666666666677` $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.360843918243516) $CellContext`md2, 
           0.20833333333333345` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4330127018922192) $CellContext`md2, 
           0.2500000000000001 $CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4619397662556432) $CellContext`md2, 
           0.1913417161825451 $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.384949805213036) $CellContext`md2, 
           0.15945143015212093` $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.360843918243516) $CellContext`md2, 
           0.20833333333333345` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.07698996104260722) $CellContext`md2,
            0.03189028603042415 $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08049381885742235) $CellContext`md2,
            0.021568253758543418` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.07698996104260722) $CellContext`md2,
            0.03189028603042415 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.15397992208521444`) \
$CellContext`md2, 
           0.0637805720608483 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1609876377148447) $CellContext`md2, 
           0.043136507517086836` $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08049381885742235) $CellContext`md2,
            0.021568253758543418` $CellContext`md2}, \
{((-0.0017361111111111108`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.07698996104260722) $CellContext`md2, 
           0.03189028603042415 $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.15397992208521444`) \
$CellContext`md2, 
           0.0637805720608483 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.23096988312782168`) \
$CellContext`md2, 
           0.09567085809127246 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.24148145657226705`) \
$CellContext`md2, 
           0.06470476127563025 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1609876377148447) $CellContext`md2, 
           0.043136507517086836` $CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.15397992208521444`) \
$CellContext`md2, 
           0.0637805720608483 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.23096988312782168`) \
$CellContext`md2, 
           0.09567085809127246 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3079598441704289) $CellContext`md2, 
           0.1275611441216966 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3219752754296894) $CellContext`md2, 
           0.08627301503417367 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.24148145657226705`) \
$CellContext`md2, 
           0.06470476127563025 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.23096988312782168`) \
$CellContext`md2, 
           0.09567085809127246 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3079598441704289) $CellContext`md2, 
           0.1275611441216966 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3849498052130361) $CellContext`md2, 
           
           0.15945143015212074` $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4024690942871117) $CellContext`md2, 
           0.10784126879271708` $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3219752754296894) $CellContext`md2, 
           0.08627301503417367 $CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3079598441704289) $CellContext`md2, 
           0.1275611441216966 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3849498052130361) $CellContext`md2, 
           0.15945143015212074` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4619397662556433) $CellContext`md2, 
           0.1913417161825449 $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.48296291314453405`) \
$CellContext`md2, 
           0.12940952255126048` $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4024690942871117) $CellContext`md2, 
           0.10784126879271708` $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3849498052130361) $CellContext`md2, 
           0.15945143015212074` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08049381885742235) $CellContext`md2,
            0.021568253758543418` $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-0.0826204051144842) $CellContext`md2, 
           0.010877182685004332` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08049381885742235) $CellContext`md2,
            0.021568253758543418` $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.1609876377148447) $CellContext`md2, 
           0.043136507517086836` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1652408102289684) $CellContext`md2, 
           0.021754365370008664` $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0826204051144842) $CellContext`md2, 
           0.010877182685004332` $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08049381885742235) $CellContext`md2,
            0.021568253758543418` $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.1609876377148447) $CellContext`md2, 
           0.043136507517086836` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.24148145657226705`) \
$CellContext`md2, 
           0.06470476127563025 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2478612153434526) $CellContext`md2, 
           0.032631548055013 $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1652408102289684) $CellContext`md2, 
           0.021754365370008664` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1609876377148447) $CellContext`md2, 
           0.043136507517086836` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.24148145657226705`) \
$CellContext`md2, 
           0.06470476127563025 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3219752754296894) $CellContext`md2, 
           0.08627301503417367 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3304816204579368) $CellContext`md2, 
           0.04350873074001733 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2478612153434526) $CellContext`md2, 
           0.032631548055013 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.24148145657226705`) \
$CellContext`md2, 
           0.06470476127563025 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3219752754296894) $CellContext`md2, 
           0.08627301503417367 $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4024690942871117) $CellContext`md2, 
           0.10784126879271708` $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.413102025572421) $CellContext`md2, 
           0.05438591342502166 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3304816204579368) $CellContext`md2, 
           0.04350873074001733 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3219752754296894) $CellContext`md2, 
           0.08627301503417367 $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4024690942871117) $CellContext`md2, 
           0.10784126879271708` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.48296291314453405`) \
$CellContext`md2, 
           0.12940952255126048` $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.49572243068690514`) \
$CellContext`md2, 
           0.06526309611002598 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.413102025572421) $CellContext`md2, 
           0.05438591342502166 $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4024690942871117) $CellContext`md2, 
           0.10784126879271708` $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0826204051144842) $CellContext`md2, 
           0.010877182685004332` $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08333333333333333) $CellContext`md2,
            4.7212824147066497`*^-17 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0826204051144842) $CellContext`md2, 
           0.010877182685004332` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1652408102289684) $CellContext`md2, 
           0.021754365370008664` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.16666666666666666`) \
$CellContext`md2, 
           9.442564829413299*^-17 $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-0.08333333333333333) $CellContext`md2, 
           4.7212824147066497`*^-17 $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-0.0826204051144842) $CellContext`md2, 
           0.010877182685004332` $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1652408102289684) $CellContext`md2, 
           0.021754365370008664` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2478612153434526) $CellContext`md2, 
           0.032631548055013 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.25) $CellContext`md2, 
           1.416384724411995*^-16 $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.16666666666666666`) $CellContext`md2, 
           9.442564829413299*^-17 $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.1652408102289684) $CellContext`md2, 
           0.021754365370008664` $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2478612153434526) $CellContext`md2, 
           0.032631548055013 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3304816204579368) $CellContext`md2, 
           0.04350873074001733 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3333333333333333) $CellContext`md2, 
           1.8885129658826599`*^-16 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.25) $CellContext`md2, 
           1.416384724411995*^-16 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2478612153434526) $CellContext`md2, 
           0.032631548055013 $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3304816204579368) $CellContext`md2, 
           0.04350873074001733 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.413102025572421) $CellContext`md2, 
           0.05438591342502166 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.41666666666666663`) \
$CellContext`md2, 
           2.360641207353325*^-16 $CellContext`md2}, \
{((-0.027777777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.3333333333333333) $CellContext`md2, 
           1.8885129658826599`*^-16 $CellContext`md2}, \
{((-0.027777777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.3304816204579368) $CellContext`md2, 
           0.04350873074001733 $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.413102025572421) $CellContext`md2, 
           0.05438591342502166 $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.49572243068690514`) \
$CellContext`md2, 
           0.06526309611002598 $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.49999999999999994`) \
$CellContext`md2, 
           2.8327694488239893`*^-16 $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.41666666666666663`) $CellContext`md2, 
           2.360641207353325*^-16 $CellContext`md2}, \
{((-0.043402777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.413102025572421) $CellContext`md2, 
           0.05438591342502166 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08333333333333333) $CellContext`md2,
            1.020538999289461*^-17 $CellContext`md2}, \
{((-0.0017361111111111112`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.08262040511448421) $CellContext`md2, (-0.010877182685004276`) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08333333333333333) $CellContext`md2,
            1.020538999289461*^-17 $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.16666666666666666`) $CellContext`md2, 
           2.041077998578922*^-17 $CellContext`md2}, \
{((-0.006944444444444445) $CellContext`md2^2)/$CellContext`mf2, \
(-0.16524081022896842`) $CellContext`md2, (-0.021754365370008553`) \
$CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08262040511448421) \
$CellContext`md2, (-0.010877182685004276`) $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-0.08333333333333333) $CellContext`md2, 
           1.020538999289461*^-17 $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.16666666666666666`) $CellContext`md2, 
           2.041077998578922*^-17 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.25) $CellContext`md2, 
           3.061616997868383*^-17 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.24786121534345262`) \
$CellContext`md2, (-0.03263154805501283) $CellContext`md2}, \
{((-0.006944444444444445) $CellContext`md2^2)/$CellContext`mf2, \
(-0.16524081022896842`) $CellContext`md2, (-0.021754365370008553`) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.16666666666666666`) \
$CellContext`md2, 
           2.041077998578922*^-17 $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.25) $CellContext`md2, 
           3.061616997868383*^-17 $CellContext`md2}, \
{((-0.027777777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.3333333333333333) $CellContext`md2, 
           4.082155997157844*^-17 $CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, (-0.33048162045793683`) \
$CellContext`md2, (-0.043508730740017106`) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.24786121534345262`) \
$CellContext`md2, (-0.03263154805501283) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.25) $CellContext`md2, 
           3.061616997868383*^-17 $CellContext`md2}, \
{((-0.027777777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.3333333333333333) $CellContext`md2, 
           4.082155997157844*^-17 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.41666666666666663`) \
$CellContext`md2, 
           5.1026949964473046`*^-17 $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.413102025572421) $CellContext`md2, (-0.05438591342502138) \
$CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, (-0.33048162045793683`) \
$CellContext`md2, (-0.043508730740017106`) $CellContext`md2}, \
{((-0.027777777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.3333333333333333) $CellContext`md2, 
           4.082155997157844*^-17 $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.41666666666666663`) \
$CellContext`md2, 
           5.1026949964473046`*^-17 $CellContext`md2}, \
{((-0.062499999999999986`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.49999999999999994`) $CellContext`md2, 
           6.123233995736765*^-17 $CellContext`md2}, {((-0.06249999999999999) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4957224306869052) $CellContext`md2, \
(-0.06526309611002565) $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.413102025572421) $CellContext`md2, \
(-0.05438591342502138) $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.41666666666666663`) \
$CellContext`md2, 
           5.1026949964473046`*^-17 $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08262040511448421) \
$CellContext`md2, (-0.010877182685004276`) $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-0.08049381885742236) $CellContext`md2, (-0.021568253758543363`) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08262040511448421) \
$CellContext`md2, (-0.010877182685004276`) $CellContext`md2}, \
{((-0.006944444444444445) $CellContext`md2^2)/$CellContext`mf2, \
(-0.16524081022896842`) $CellContext`md2, (-0.021754365370008553`) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.16098763771484473`) \
$CellContext`md2, (-0.043136507517086725`) $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-0.08049381885742236) $CellContext`md2, (-0.021568253758543363`) \
$CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08262040511448421) \
$CellContext`md2, (-0.010877182685004276`) $CellContext`md2}, \
{((-0.006944444444444445) $CellContext`md2^2)/$CellContext`mf2, \
(-0.16524081022896842`) $CellContext`md2, (-0.021754365370008553`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.24786121534345262`) $CellContext`md2, (-0.03263154805501283) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.2414814565722671) $CellContext`md2, (-0.06470476127563009) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.16098763771484473`) \
$CellContext`md2, (-0.043136507517086725`) $CellContext`md2}, \
{((-0.006944444444444445) $CellContext`md2^2)/$CellContext`mf2, \
(-0.16524081022896842`) $CellContext`md2, (-0.021754365370008553`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.24786121534345262`) $CellContext`md2, (-0.03263154805501283) \
$CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, (-0.33048162045793683`) \
$CellContext`md2, (-0.043508730740017106`) $CellContext`md2}, \
{((-0.027777777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.32197527542968946`) $CellContext`md2, (-0.08627301503417345) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.2414814565722671) $CellContext`md2, (-0.06470476127563009) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.24786121534345262`) $CellContext`md2, (-0.03263154805501283) \
$CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, (-0.33048162045793683`) \
$CellContext`md2, (-0.043508730740017106`) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.413102025572421) $CellContext`md2, (-0.05438591342502138) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4024690942871118) $CellContext`md2, \
(-0.1078412687927168) $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.32197527542968946`) \
$CellContext`md2, (-0.08627301503417345) $CellContext`md2}, \
{((-0.02777777777777778) $CellContext`md2^2)/$CellContext`mf2, \
(-0.33048162045793683`) $CellContext`md2, (-0.043508730740017106`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.413102025572421) $CellContext`md2, \
(-0.05438591342502138) $CellContext`md2}, {((-0.06249999999999999) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4957224306869052) $CellContext`md2, \
(-0.06526309611002565) $CellContext`md2}, {((-0.06249999999999999) \
$CellContext`md2^2)/$CellContext`mf2, (-0.48296291314453416`) \
$CellContext`md2, (-0.12940952255126015`) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.4024690942871118) $CellContext`md2, (-0.1078412687927168) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.413102025572421) $CellContext`md2, \
(-0.05438591342502138) $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08049381885742236) \
$CellContext`md2, (-0.021568253758543363`) $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-0.07698996104260725) $CellContext`md2, (-0.0318902860304241) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08049381885742236) \
$CellContext`md2, (-0.021568253758543363`) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.16098763771484473`) $CellContext`md2, (-0.043136507517086725`) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1539799220852145) $CellContext`md2, \
(-0.0637805720608482) $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.07698996104260725) \
$CellContext`md2, (-0.0318902860304241) $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-0.08049381885742236) $CellContext`md2, (-0.021568253758543363`) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.16098763771484473`) \
$CellContext`md2, (-0.043136507517086725`) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2414814565722671) $CellContext`md2, \
(-0.06470476127563009) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.23096988312782174`) \
$CellContext`md2, (-0.0956708580912723) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.1539799220852145) $CellContext`md2, (-0.0637805720608482) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.16098763771484473`) \
$CellContext`md2, (-0.043136507517086725`) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2414814565722671) $CellContext`md2, \
(-0.06470476127563009) $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.32197527542968946`) \
$CellContext`md2, (-0.08627301503417345) $CellContext`md2}, \
{((-0.027777777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.307959844170429) $CellContext`md2, (-0.1275611441216964) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.23096988312782174`) $CellContext`md2, (-0.0956708580912723) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.2414814565722671) $CellContext`md2, (-0.06470476127563009) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.32197527542968946`) \
$CellContext`md2, (-0.08627301503417345) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.4024690942871118) $CellContext`md2, (-0.1078412687927168) \
$CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3849498052130362) $CellContext`md2, \
(-0.1594514301521205) $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.307959844170429) $CellContext`md2, \
(-0.1275611441216964) $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.32197527542968946`) \
$CellContext`md2, (-0.08627301503417345) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.4024690942871118) $CellContext`md2, (-0.1078412687927168) \
$CellContext`md2}, {((-0.06249999999999999) \
$CellContext`md2^2)/$CellContext`mf2, (-0.48296291314453416`) \
$CellContext`md2, (-0.12940952255126015`) $CellContext`md2}, \
{((-0.062499999999999986`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.4619397662556434) $CellContext`md2, (-0.19134171618254459`) \
$CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3849498052130362) $CellContext`md2, \
(-0.1594514301521205) $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4024690942871118) $CellContext`md2, \
(-0.1078412687927168) $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.07698996104260725) \
$CellContext`md2, (-0.0318902860304241) $CellContext`md2}, \
{((-0.0017361111111111108`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.07216878364870324) $CellContext`md2, (-0.041666666666666616`) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.07698996104260725) \
$CellContext`md2, (-0.0318902860304241) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.1539799220852145) $CellContext`md2, (-0.0637805720608482) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1443375672974065) $CellContext`md2, \
(-0.08333333333333323) $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.07216878364870324) \
$CellContext`md2, (-0.041666666666666616`) $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-0.07698996104260725) $CellContext`md2, (-0.0318902860304241) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1539799220852145) $CellContext`md2, \
(-0.0637805720608482) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.23096988312782174`) \
$CellContext`md2, (-0.0956708580912723) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.21650635094610976`) \
$CellContext`md2, (-0.12499999999999985`) $CellContext`md2}, \
{((-0.006944444444444443) $CellContext`md2^2)/$CellContext`mf2, \
(-0.1443375672974065) $CellContext`md2, (-0.08333333333333323) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1539799220852145) $CellContext`md2, \
(-0.0637805720608482) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.23096988312782174`) \
$CellContext`md2, (-0.0956708580912723) $CellContext`md2}, \
{((-0.027777777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.307959844170429) $CellContext`md2, (-0.1275611441216964) \
$CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.288675134594813) $CellContext`md2, \
(-0.16666666666666646`) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.21650635094610976`) \
$CellContext`md2, (-0.12499999999999985`) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.23096988312782174`) \
$CellContext`md2, (-0.0956708580912723) $CellContext`md2}, \
{((-0.027777777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.307959844170429) $CellContext`md2, (-0.1275611441216964) \
$CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3849498052130362) $CellContext`md2, \
(-0.1594514301521205) $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.36084391824351625`) \
$CellContext`md2, (-0.20833333333333307`) $CellContext`md2}, \
{((-0.027777777777777773`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.288675134594813) $CellContext`md2, (-0.16666666666666646`) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.307959844170429) $CellContext`md2, \
(-0.1275611441216964) $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3849498052130362) $CellContext`md2, \
(-0.1594514301521205) $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4619397662556434) $CellContext`md2, \
(-0.19134171618254459`) $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.43301270189221946`) \
$CellContext`md2, (-0.24999999999999967`) $CellContext`md2}, \
{((-0.043402777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.36084391824351625`) $CellContext`md2, (-0.20833333333333307`) \
$CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3849498052130362) $CellContext`md2, \
(-0.1594514301521205) $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.07216878364870323) \
$CellContext`md2, (-0.041666666666666644`) $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-0.06611277835760294) $CellContext`md2, (-0.05073011908406003) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.07216878364870323) \
$CellContext`md2, (-0.041666666666666644`) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.14433756729740646`) $CellContext`md2, (-0.08333333333333329) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1322255567152059) $CellContext`md2, \
(-0.10146023816812005`) $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06611277835760294) \
$CellContext`md2, (-0.05073011908406003) $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-0.07216878364870323) $CellContext`md2, (-0.041666666666666644`) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.14433756729740646`) \
$CellContext`md2, (-0.08333333333333329) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2165063509461097) $CellContext`md2, \
(-0.12499999999999994`) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.19833833507280885`) \
$CellContext`md2, (-0.15219035725218008`) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.1322255567152059) $CellContext`md2, (-0.10146023816812005`) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.14433756729740646`) \
$CellContext`md2, (-0.08333333333333329) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2165063509461097) $CellContext`md2, \
(-0.12499999999999994`) $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2886751345948129) $CellContext`md2, \
(-0.16666666666666657`) $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2644511134304118) $CellContext`md2, \
(-0.2029204763362401) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.19833833507280885`) \
$CellContext`md2, (-0.15219035725218008`) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2165063509461097) $CellContext`md2, \
(-0.12499999999999994`) $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2886751345948129) $CellContext`md2, \
(-0.16666666666666657`) $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.36084391824351614`) \
$CellContext`md2, (-0.20833333333333323`) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.3305638917880147) $CellContext`md2, (-0.2536505954203001) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2644511134304118) $CellContext`md2, \
(-0.2029204763362401) $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2886751345948129) $CellContext`md2, \
(-0.16666666666666657`) $CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.36084391824351614`) \
$CellContext`md2, (-0.20833333333333323`) $CellContext`md2}, \
{((-0.062499999999999986`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.43301270189221935`) $CellContext`md2, (-0.24999999999999986`) \
$CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, (-0.39667667014561764`) \
$CellContext`md2, (-0.3043807145043601) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.3305638917880147) $CellContext`md2, (-0.2536505954203001) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.36084391824351614`) \
$CellContext`md2, (-0.20833333333333323`) $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06611277835760294) \
$CellContext`md2, (-0.05073011908406003) $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-0.05892556509887899) $CellContext`md2, (-0.058925565098878925`) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06611277835760294) \
$CellContext`md2, (-0.05073011908406003) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.1322255567152059) $CellContext`md2, (-0.10146023816812005`) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.11785113019775798`) \
$CellContext`md2, (-0.11785113019775785`) $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-0.05892556509887899) $CellContext`md2, (-0.058925565098878925`) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06611277835760294) \
$CellContext`md2, (-0.05073011908406003) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.1322255567152059) $CellContext`md2, (-0.10146023816812005`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.19833833507280885`) $CellContext`md2, (-0.15219035725218008`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.17677669529663698`) $CellContext`md2, (-0.17677669529663678`) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.11785113019775798`) \
$CellContext`md2, (-0.11785113019775785`) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.1322255567152059) $CellContext`md2, (-0.10146023816812005`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.19833833507280885`) $CellContext`md2, (-0.15219035725218008`) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2644511134304118) $CellContext`md2, \
(-0.2029204763362401) $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.23570226039551595`) \
$CellContext`md2, (-0.2357022603955157) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.17677669529663698`) \
$CellContext`md2, (-0.17677669529663678`) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.19833833507280885`) \
$CellContext`md2, (-0.15219035725218008`) $CellContext`md2}, \
{((-0.027777777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.2644511134304118) $CellContext`md2, (-0.2029204763362401) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3305638917880147) $CellContext`md2, \
(-0.2536505954203001) $CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2946278254943949) $CellContext`md2, \
(-0.2946278254943946) $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.23570226039551595`) \
$CellContext`md2, (-0.2357022603955157) $CellContext`md2}, \
{((-0.027777777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.2644511134304118) $CellContext`md2, (-0.2029204763362401) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3305638917880147) $CellContext`md2, \
(-0.2536505954203001) $CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, (-0.39667667014561764`) \
$CellContext`md2, (-0.3043807145043601) $CellContext`md2}, \
{((-0.06249999999999997) $CellContext`md2^2)/$CellContext`mf2, \
(-0.3535533905932739) $CellContext`md2, (-0.3535533905932735) \
$CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2946278254943949) $CellContext`md2, \
(-0.2946278254943946) $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3305638917880147) $CellContext`md2, \
(-0.2536505954203001) $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05892556509887899) \
$CellContext`md2, (-0.058925565098878925`) $CellContext`md2}, \
{((-0.0017361111111111106`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.05073011908406007) $CellContext`md2, (-0.0661127783576029) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05892556509887899) \
$CellContext`md2, (-0.058925565098878925`) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.11785113019775798`) $CellContext`md2, (-0.11785113019775785`) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10146023816812014`) \
$CellContext`md2, (-0.1322255567152058) $CellContext`md2}, \
{((-0.0017361111111111106`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.05073011908406007) $CellContext`md2, (-0.0661127783576029) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05892556509887899) \
$CellContext`md2, (-0.058925565098878925`) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.11785113019775798`) $CellContext`md2, (-0.11785113019775785`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.17677669529663698`) $CellContext`md2, (-0.17677669529663678`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.15219035725218022`) $CellContext`md2, (-0.19833833507280874`) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10146023816812014`) \
$CellContext`md2, (-0.1322255567152058) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.11785113019775798`) $CellContext`md2, (-0.11785113019775785`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.17677669529663698`) $CellContext`md2, (-0.17677669529663678`) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.23570226039551595`) \
$CellContext`md2, (-0.2357022603955157) $CellContext`md2}, \
{((-0.02777777777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.20292047633624027`) $CellContext`md2, (-0.2644511134304116) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.15219035725218022`) $CellContext`md2, (-0.19833833507280874`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.17677669529663698`) $CellContext`md2, (-0.17677669529663678`) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.23570226039551595`) \
$CellContext`md2, (-0.2357022603955157) $CellContext`md2}, \
{((-0.04340277777777776) $CellContext`md2^2)/$CellContext`mf2, \
(-0.2946278254943949) $CellContext`md2, (-0.2946278254943946) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.25365059542030033`) \
$CellContext`md2, (-0.33056389178801454`) $CellContext`md2}, \
{((-0.02777777777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.20292047633624027`) $CellContext`md2, (-0.2644511134304116) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.23570226039551595`) \
$CellContext`md2, (-0.2357022603955157) $CellContext`md2}, \
{((-0.04340277777777776) $CellContext`md2^2)/$CellContext`mf2, \
(-0.2946278254943949) $CellContext`md2, (-0.2946278254943946) \
$CellContext`md2}, {((-0.06249999999999997) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3535533905932739) $CellContext`md2, \
(-0.3535533905932735) $CellContext`md2}, {((-0.06249999999999997) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3043807145043604) $CellContext`md2, \
(-0.3966766701456174) $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.25365059542030033`) \
$CellContext`md2, (-0.33056389178801454`) $CellContext`md2}, \
{((-0.04340277777777776) $CellContext`md2^2)/$CellContext`mf2, \
(-0.2946278254943949) $CellContext`md2, (-0.2946278254943946) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05073011908406007) \
$CellContext`md2, (-0.0661127783576029) $CellContext`md2}, \
{((-0.0017361111111111106`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.0416666666666667) $CellContext`md2, (-0.07216878364870319) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05073011908406007) \
$CellContext`md2, (-0.0661127783576029) $CellContext`md2}, \
{((-0.006944444444444442) $CellContext`md2^2)/$CellContext`mf2, \
(-0.10146023816812014`) $CellContext`md2, (-0.1322255567152058) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0833333333333334) $CellContext`md2, \
(-0.14433756729740638`) $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0416666666666667) $CellContext`md2, \
(-0.07216878364870319) $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05073011908406007) \
$CellContext`md2, (-0.0661127783576029) $CellContext`md2}, \
{((-0.006944444444444442) $CellContext`md2^2)/$CellContext`mf2, \
(-0.10146023816812014`) $CellContext`md2, (-0.1322255567152058) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.15219035725218022`) $CellContext`md2, (-0.19833833507280874`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.1250000000000001) $CellContext`md2, (-0.2165063509461096) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0833333333333334) $CellContext`md2, \
(-0.14433756729740638`) $CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10146023816812014`) \
$CellContext`md2, (-0.1322255567152058) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.15219035725218022`) \
$CellContext`md2, (-0.19833833507280874`) $CellContext`md2}, \
{((-0.02777777777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.20292047633624027`) $CellContext`md2, (-0.2644511134304116) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1666666666666668) $CellContext`md2, \
(-0.28867513459481275`) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1250000000000001) $CellContext`md2, \
(-0.2165063509461096) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.15219035725218022`) \
$CellContext`md2, (-0.19833833507280874`) $CellContext`md2}, \
{((-0.02777777777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.20292047633624027`) $CellContext`md2, (-0.2644511134304116) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.25365059542030033`) \
$CellContext`md2, (-0.33056389178801454`) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.2083333333333335) $CellContext`md2, (-0.36084391824351597`) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1666666666666668) $CellContext`md2, \
(-0.28867513459481275`) $CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.20292047633624027`) \
$CellContext`md2, (-0.2644511134304116) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.25365059542030033`) $CellContext`md2, (-0.33056389178801454`) \
$CellContext`md2}, {((-0.06249999999999997) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3043807145043604) $CellContext`md2, \
(-0.3966766701456174) $CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, (-0.25000000000000017`) \
$CellContext`md2, (-0.43301270189221913`) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.2083333333333335) $CellContext`md2, (-0.36084391824351597`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.25365059542030033`) \
$CellContext`md2, (-0.33056389178801454`) $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0416666666666667) $CellContext`md2, \
(-0.07216878364870319) $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.031890286030424195`) \
$CellContext`md2, (-0.0769899610426072) $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0416666666666667) $CellContext`md2, \
(-0.07216878364870319) $CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0833333333333334) $CellContext`md2, \
(-0.14433756729740638`) $CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06378057206084839) \
$CellContext`md2, (-0.1539799220852144) $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-0.031890286030424195`) $CellContext`md2, (-0.0769899610426072) \
$CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0416666666666667) $CellContext`md2, \
(-0.07216878364870319) $CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0833333333333334) $CellContext`md2, \
(-0.14433756729740638`) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1250000000000001) $CellContext`md2, \
(-0.2165063509461096) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.09567085809127258) \
$CellContext`md2, (-0.23096988312782163`) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.06378057206084839) $CellContext`md2, (-0.1539799220852144) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, (-0.0833333333333334) $CellContext`md2, \
(-0.14433756729740638`) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1250000000000001) $CellContext`md2, \
(-0.2165063509461096) $CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1666666666666668) $CellContext`md2, \
(-0.28867513459481275`) $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.12756114412169678`) \
$CellContext`md2, (-0.3079598441704288) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.09567085809127258) \
$CellContext`md2, (-0.23096988312782163`) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1250000000000001) $CellContext`md2, \
(-0.2165063509461096) $CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1666666666666668) $CellContext`md2, \
(-0.28867513459481275`) $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2083333333333335) $CellContext`md2, \
(-0.36084391824351597`) $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.15945143015212096`) \
$CellContext`md2, (-0.384949805213036) $CellContext`md2}, \
{((-0.027777777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.12756114412169678`) $CellContext`md2, (-0.3079598441704288) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1666666666666668) $CellContext`md2, \
(-0.28867513459481275`) $CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2083333333333335) $CellContext`md2, \
(-0.36084391824351597`) $CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, (-0.25000000000000017`) \
$CellContext`md2, (-0.43301270189221913`) $CellContext`md2}, \
{((-0.06249999999999998) $CellContext`md2^2)/$CellContext`mf2, \
(-0.19134171618254514`) $CellContext`md2, (-0.4619397662556432) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-0.15945143015212096`) \
$CellContext`md2, (-0.384949805213036) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.2083333333333335) $CellContext`md2, (-0.36084391824351597`) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.031890286030424195`) \
$CellContext`md2, (-0.0769899610426072) $CellContext`md2}, \
{((-0.0017361111111111108`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.021568253758543453`) $CellContext`md2, (-0.08049381885742234) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.031890286030424195`) \
$CellContext`md2, (-0.0769899610426072) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.06378057206084839) $CellContext`md2, (-0.1539799220852144) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.043136507517086906`) \
$CellContext`md2, (-0.16098763771484467`) $CellContext`md2}, \
{((-0.0017361111111111108`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.021568253758543453`) $CellContext`md2, (-0.08049381885742234) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-0.031890286030424195`) \
$CellContext`md2, (-0.0769899610426072) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.06378057206084839) $CellContext`md2, (-0.1539799220852144) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.09567085809127258) $CellContext`md2, (-0.23096988312782163`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.06470476127563037) $CellContext`md2, (-0.24148145657226702`) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.043136507517086906`) \
$CellContext`md2, (-0.16098763771484467`) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-0.06378057206084839) $CellContext`md2, (-0.1539799220852144) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.09567085809127258) $CellContext`md2, (-0.23096988312782163`) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.12756114412169678`) \
$CellContext`md2, (-0.3079598441704288) $CellContext`md2}, \
{((-0.027777777777777773`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.08627301503417381) $CellContext`md2, (-0.32197527542968934`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.06470476127563037) $CellContext`md2, (-0.24148145657226702`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.09567085809127258) $CellContext`md2, (-0.23096988312782163`) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.12756114412169678`) \
$CellContext`md2, (-0.3079598441704288) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.15945143015212096`) $CellContext`md2, (-0.384949805213036) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10784126879271727`) \
$CellContext`md2, (-0.4024690942871117) $CellContext`md2}, \
{((-0.027777777777777773`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.08627301503417381) $CellContext`md2, (-0.32197527542968934`) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.12756114412169678`) \
$CellContext`md2, (-0.3079598441704288) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.15945143015212096`) $CellContext`md2, (-0.384949805213036) \
$CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, (-0.19134171618254514`) \
$CellContext`md2, (-0.4619397662556432) $CellContext`md2}, \
{((-0.062499999999999986`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.1294095225512607) $CellContext`md2, (-0.482962913144534) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10784126879271727`) \
$CellContext`md2, (-0.4024690942871117) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-0.15945143015212096`) $CellContext`md2, (-0.384949805213036) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.021568253758543453`) \
$CellContext`md2, (-0.08049381885742234) $CellContext`md2}, \
{((-0.0017361111111111108`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.010877182685004375`) $CellContext`md2, (-0.08262040511448418) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.021568253758543453`) \
$CellContext`md2, (-0.08049381885742234) $CellContext`md2}, \
{((-0.006944444444444443) $CellContext`md2^2)/$CellContext`mf2, \
(-0.043136507517086906`) $CellContext`md2, (-0.16098763771484467`) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.02175436537000875) \
$CellContext`md2, (-0.16524081022896836`) $CellContext`md2}, \
{((-0.0017361111111111108`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.010877182685004375`) $CellContext`md2, (-0.08262040511448418) \
$CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.021568253758543453`) \
$CellContext`md2, (-0.08049381885742234) $CellContext`md2}, \
{((-0.006944444444444443) $CellContext`md2^2)/$CellContext`mf2, \
(-0.043136507517086906`) $CellContext`md2, (-0.16098763771484467`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.06470476127563037) $CellContext`md2, (-0.24148145657226702`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.03263154805501313) $CellContext`md2, (-0.24786121534345257`) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.02175436537000875) \
$CellContext`md2, (-0.16524081022896836`) $CellContext`md2}, \
{((-0.006944444444444443) $CellContext`md2^2)/$CellContext`mf2, \
(-0.043136507517086906`) $CellContext`md2, (-0.16098763771484467`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.06470476127563037) $CellContext`md2, (-0.24148145657226702`) \
$CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08627301503417381) \
$CellContext`md2, (-0.32197527542968934`) $CellContext`md2}, \
{((-0.027777777777777773`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.0435087307400175) $CellContext`md2, (-0.3304816204579367) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.03263154805501313) $CellContext`md2, (-0.24786121534345257`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.06470476127563037) $CellContext`md2, (-0.24148145657226702`) \
$CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08627301503417381) \
$CellContext`md2, (-0.32197527542968934`) $CellContext`md2}, \
{((-0.043402777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.10784126879271727`) $CellContext`md2, (-0.4024690942871117) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05438591342502188) \
$CellContext`md2, (-0.41310202557242093`) $CellContext`md2}, \
{((-0.027777777777777773`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.0435087307400175) $CellContext`md2, (-0.3304816204579367) \
$CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.08627301503417381) \
$CellContext`md2, (-0.32197527542968934`) $CellContext`md2}, \
{((-0.043402777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.10784126879271727`) $CellContext`md2, (-0.4024690942871117) \
$CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.1294095225512607) $CellContext`md2, \
(-0.482962913144534) $CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06526309611002624) \
$CellContext`md2, (-0.4957224306869051) $CellContext`md2}, \
{((-0.043402777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.05438591342502188) $CellContext`md2, (-0.41310202557242093`) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.10784126879271727`) \
$CellContext`md2, (-0.4024690942871117) $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.010877182685004375`) \
$CellContext`md2, (-0.08262040511448418) $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-8.932295329768567*^-17) $CellContext`md2, (-0.08333333333333333) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.010877182685004375`) \
$CellContext`md2, (-0.08262040511448418) $CellContext`md2}, \
{((-0.006944444444444443) $CellContext`md2^2)/$CellContext`mf2, \
(-0.02175436537000875) $CellContext`md2, (-0.16524081022896836`) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-1.7864590659537134`*^-16) \
$CellContext`md2, (-0.16666666666666666`) $CellContext`md2}, \
{((-0.001736111111111111) $CellContext`md2^2)/$CellContext`mf2, \
(-8.932295329768567*^-17) $CellContext`md2, (-0.08333333333333333) \
$CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.010877182685004375`) \
$CellContext`md2, (-0.08262040511448418) $CellContext`md2}, \
{((-0.006944444444444443) $CellContext`md2^2)/$CellContext`mf2, \
(-0.02175436537000875) $CellContext`md2, (-0.16524081022896836`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-0.03263154805501313) $CellContext`md2, (-0.24786121534345257`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-2.6796885989305704`*^-16) $CellContext`md2, (-0.25) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-1.7864590659537134`*^-16) $CellContext`md2, (-0.16666666666666666`) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, (-0.02175436537000875) \
$CellContext`md2, (-0.16524081022896836`) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.03263154805501313) \
$CellContext`md2, (-0.24786121534345257`) $CellContext`md2}, \
{((-0.027777777777777773`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.0435087307400175) $CellContext`md2, (-0.3304816204579367) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-3.572918131907427*^-16) \
$CellContext`md2, (-0.3333333333333333) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-2.6796885989305704`*^-16) \
$CellContext`md2, (-0.25) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.03263154805501313) \
$CellContext`md2, (-0.24786121534345257`) $CellContext`md2}, \
{((-0.027777777777777773`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.0435087307400175) $CellContext`md2, (-0.3304816204579367) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05438591342502188) \
$CellContext`md2, (-0.41310202557242093`) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-4.466147664884284*^-16) $CellContext`md2, (-0.41666666666666663`) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-3.572918131907427*^-16) \
$CellContext`md2, (-0.3333333333333333) $CellContext`md2}, \
{((-0.027777777777777773`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.0435087307400175) $CellContext`md2, (-0.3304816204579367) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05438591342502188) \
$CellContext`md2, (-0.41310202557242093`) $CellContext`md2}, \
{((-0.062499999999999986`) $CellContext`md2^2)/$CellContext`mf2, \
(-0.06526309611002624) $CellContext`md2, (-0.4957224306869051) \
$CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-5.35937719786114*^-16) \
$CellContext`md2, (-0.49999999999999994`) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-4.466147664884284*^-16) $CellContext`md2, (-0.41666666666666663`) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-0.05438591342502188) \
$CellContext`md2, (-0.41310202557242093`) $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-1.5308084989341912`*^-17) \
$CellContext`md2, (-0.08333333333333333) $CellContext`md2}, \
{((-0.0017361111111111112`) $CellContext`md2^2)/$CellContext`mf2, 
           0.01087718268500427 $CellContext`md2, (-0.08262040511448421) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-1.5308084989341912`*^-17) \
$CellContext`md2, (-0.08333333333333333) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-3.0616169978683824`*^-17) $CellContext`md2, (-0.16666666666666666`) \
$CellContext`md2}, {((-0.006944444444444445) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.02175436537000854 $CellContext`md2, (-0.16524081022896842`) \
$CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.01087718268500427 $CellContext`md2, (-0.08262040511448421) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, (-1.5308084989341912`*^-17) \
$CellContext`md2, (-0.08333333333333333) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, \
(-3.0616169978683824`*^-17) $CellContext`md2, (-0.16666666666666666`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-4.592425496802574*^-17) $CellContext`md2, (-0.25) $CellContext`md2}, \
{((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.03263154805501281 $CellContext`md2, (-0.24786121534345262`) \
$CellContext`md2}, {((-0.006944444444444445) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.02175436537000854 $CellContext`md2, (-0.16524081022896842`) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, (-3.0616169978683824`*^-17) \
$CellContext`md2, (-0.16666666666666666`) $CellContext`md2}, {((-0.015625) \
$CellContext`md2^2)/$CellContext`mf2, (-4.592425496802574*^-17) \
$CellContext`md2, (-0.25) $CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-6.123233995736765*^-17) \
$CellContext`md2, (-0.3333333333333333) $CellContext`md2}, \
{((-0.02777777777777778) $CellContext`md2^2)/$CellContext`mf2, 
           0.04350873074001708 $CellContext`md2, (-0.33048162045793683`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.03263154805501281 $CellContext`md2, (-0.24786121534345262`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, \
(-4.592425496802574*^-17) $CellContext`md2, (-0.25) $CellContext`md2}, \
{((-0.027777777777777776`) $CellContext`md2^2)/$CellContext`mf2, \
(-6.123233995736765*^-17) $CellContext`md2, (-0.3333333333333333) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-7.654042494670957*^-17) \
$CellContext`md2, (-0.41666666666666663`) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, 
           0.054385913425021346` $CellContext`md2, (-0.413102025572421) \
$CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.04350873074001708 $CellContext`md2, (-0.33048162045793683`) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, (-6.123233995736765*^-17) \
$CellContext`md2, (-0.3333333333333333) $CellContext`md2}, \
{((-0.04340277777777777) $CellContext`md2^2)/$CellContext`mf2, \
(-7.654042494670957*^-17) $CellContext`md2, (-0.41666666666666663`) \
$CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, (-9.184850993605147*^-17) \
$CellContext`md2, (-0.49999999999999994`) $CellContext`md2}, \
{((-0.06249999999999999) $CellContext`md2^2)/$CellContext`mf2, 
           0.0652630961100256 $CellContext`md2, (-0.4957224306869052) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.054385913425021346` $CellContext`md2, (-0.413102025572421) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, (-7.654042494670957*^-17) \
$CellContext`md2, (-0.41666666666666663`) $CellContext`md2}, {(
            0. $CellContext`md2^2)/$CellContext`mf2, 0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.01087718268500427 $CellContext`md2, (-0.08262040511448421) \
$CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.021568253758543356` $CellContext`md2, (-0.08049381885742236) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.01087718268500427 $CellContext`md2, (-0.08262040511448421) \
$CellContext`md2}, {((-0.006944444444444445) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.02175436537000854 $CellContext`md2, (-0.16524081022896842`) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.04313650751708671 $CellContext`md2, (-0.16098763771484473`) \
$CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.021568253758543356` $CellContext`md2, (-0.08049381885742236) \
$CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.01087718268500427 $CellContext`md2, (-0.08262040511448421) \
$CellContext`md2}, {((-0.006944444444444445) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.02175436537000854 $CellContext`md2, (-0.16524081022896842`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.03263154805501281 $CellContext`md2, (-0.24786121534345262`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.06470476127563007 $CellContext`md2, (-0.2414814565722671) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.04313650751708671 $CellContext`md2, (-0.16098763771484473`) \
$CellContext`md2}, {((-0.006944444444444445) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.02175436537000854 $CellContext`md2, (-0.16524081022896842`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.03263154805501281 $CellContext`md2, (-0.24786121534345262`) \
$CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.04350873074001708 $CellContext`md2, (-0.33048162045793683`) \
$CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08627301503417342 $CellContext`md2, (-0.32197527542968946`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.06470476127563007 $CellContext`md2, (-0.2414814565722671) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.03263154805501281 $CellContext`md2, (-0.24786121534345262`) \
$CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.04350873074001708 $CellContext`md2, (-0.33048162045793683`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.054385913425021346` $CellContext`md2, (-0.413102025572421) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.10784126879271679` $CellContext`md2, (-0.4024690942871118) \
$CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08627301503417342 $CellContext`md2, (-0.32197527542968946`) \
$CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.04350873074001708 $CellContext`md2, (-0.33048162045793683`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.054385913425021346` $CellContext`md2, (-0.413102025572421) \
$CellContext`md2}, {((-0.06249999999999999) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0652630961100256 $CellContext`md2, (-0.4957224306869052) \
$CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.12940952255126012` $CellContext`md2, (-0.48296291314453416`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.10784126879271679` $CellContext`md2, (-0.4024690942871118) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.054385913425021346` $CellContext`md2, (-0.413102025572421) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.021568253758543356` $CellContext`md2, (-0.08049381885742236) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0318902860304241 $CellContext`md2, (-0.07698996104260725) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.021568253758543356` $CellContext`md2, (-0.08049381885742236) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.04313650751708671 $CellContext`md2, (-0.16098763771484473`) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0637805720608482 $CellContext`md2, (-0.1539799220852145) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0318902860304241 $CellContext`md2, (-0.07698996104260725) \
$CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.021568253758543356` $CellContext`md2, (-0.08049381885742236) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.04313650751708671 $CellContext`md2, (-0.16098763771484473`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.06470476127563007 $CellContext`md2, (-0.2414814565722671) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.09567085809127229 $CellContext`md2, (-0.23096988312782174`) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0637805720608482 $CellContext`md2, (-0.1539799220852145) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.04313650751708671 $CellContext`md2, (-0.16098763771484473`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.06470476127563007 $CellContext`md2, (-0.2414814565722671) \
$CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08627301503417342 $CellContext`md2, (-0.32197527542968946`) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1275611441216964 $CellContext`md2, (-0.307959844170429) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.09567085809127229 $CellContext`md2, (-0.23096988312782174`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.06470476127563007 $CellContext`md2, (-0.2414814565722671) \
$CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08627301503417342 $CellContext`md2, (-0.32197527542968946`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.10784126879271679` $CellContext`md2, (-0.4024690942871118) \
$CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.15945143015212046` $CellContext`md2, (-0.3849498052130362) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1275611441216964 $CellContext`md2, (-0.307959844170429) \
$CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08627301503417342 $CellContext`md2, (-0.32197527542968946`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.10784126879271679` $CellContext`md2, (-0.4024690942871118) \
$CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.12940952255126012` $CellContext`md2, (-0.48296291314453416`) \
$CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.19134171618254456` $CellContext`md2, (-0.4619397662556434) \
$CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.15945143015212046` $CellContext`md2, (-0.3849498052130362) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.10784126879271679` $CellContext`md2, (-0.4024690942871118) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0318902860304241 $CellContext`md2, (-0.07698996104260725) \
$CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0416666666666666 $CellContext`md2, (-0.07216878364870324) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0318902860304241 $CellContext`md2, (-0.07698996104260725) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0637805720608482 $CellContext`md2, (-0.1539799220852145) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0833333333333332 $CellContext`md2, (-0.1443375672974065) \
$CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0416666666666666 $CellContext`md2, (-0.07216878364870324) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0318902860304241 $CellContext`md2, (-0.07698996104260725) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0637805720608482 $CellContext`md2, (-0.1539799220852145) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.09567085809127229 $CellContext`md2, (-0.23096988312782174`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.12499999999999982` $CellContext`md2, (-0.21650635094610976`) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0833333333333332 $CellContext`md2, (-0.1443375672974065) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0637805720608482 $CellContext`md2, (-0.1539799220852145) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.09567085809127229 $CellContext`md2, (-0.23096988312782174`) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1275611441216964 $CellContext`md2, (-0.307959844170429) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1666666666666664 $CellContext`md2, (-0.288675134594813) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.12499999999999982` $CellContext`md2, (-0.21650635094610976`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.09567085809127229 $CellContext`md2, (-0.23096988312782174`) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1275611441216964 $CellContext`md2, (-0.307959844170429) \
$CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.15945143015212046` $CellContext`md2, (-0.3849498052130362) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.208333333333333 $CellContext`md2, (-0.36084391824351625`) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1666666666666664 $CellContext`md2, (-0.288675134594813) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1275611441216964 $CellContext`md2, (-0.307959844170429) \
$CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.15945143015212046` $CellContext`md2, (-0.3849498052130362) \
$CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.19134171618254456` $CellContext`md2, (-0.4619397662556434) \
$CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.2499999999999996 $CellContext`md2, (-0.43301270189221946`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.208333333333333 $CellContext`md2, (-0.36084391824351625`) \
$CellContext`md2}, {((-0.04340277777777776) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.15945143015212046` $CellContext`md2, (-0.3849498052130362) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0416666666666666 $CellContext`md2, (-0.07216878364870324) \
$CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.050730119084059985` $CellContext`md2, (-0.06611277835760297) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0416666666666666 $CellContext`md2, (-0.07216878364870324) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0833333333333332 $CellContext`md2, (-0.1443375672974065) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.10146023816811997` $CellContext`md2, (-0.13222555671520594`) \
$CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.050730119084059985` $CellContext`md2, (-0.06611277835760297) \
$CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0416666666666666 $CellContext`md2, (-0.07216878364870324) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0833333333333332 $CellContext`md2, (-0.1443375672974065) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.12499999999999982` $CellContext`md2, (-0.21650635094610976`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.15219035725217997` $CellContext`md2, (-0.19833833507280893`) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.10146023816811997` $CellContext`md2, (-0.13222555671520594`) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0833333333333332 $CellContext`md2, (-0.1443375672974065) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.12499999999999982` $CellContext`md2, (-0.21650635094610976`) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1666666666666664 $CellContext`md2, (-0.288675134594813) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.20292047633623994` $CellContext`md2, (-0.2644511134304119) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.15219035725217997` $CellContext`md2, (-0.19833833507280893`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.12499999999999982` $CellContext`md2, (-0.21650635094610976`) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1666666666666664 $CellContext`md2, (-0.288675134594813) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.208333333333333 $CellContext`md2, (-0.36084391824351625`) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.25365059542029994` $CellContext`md2, (-0.3305638917880149) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.20292047633623994` $CellContext`md2, (-0.2644511134304119) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1666666666666664 $CellContext`md2, (-0.288675134594813) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.208333333333333 $CellContext`md2, (-0.36084391824351625`) \
$CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.2499999999999996 $CellContext`md2, (-0.43301270189221946`) \
$CellContext`md2}, {((-0.06249999999999997) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3043807145043599 $CellContext`md2, (-0.3966766701456178) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.25365059542029994` $CellContext`md2, (-0.3305638917880149) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.208333333333333 $CellContext`md2, (-0.36084391824351625`) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.050730119084059985` $CellContext`md2, (-0.06611277835760297) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.05892556509887889 $CellContext`md2, (-0.05892556509887903) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.050730119084059985` $CellContext`md2, (-0.06611277835760297) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.10146023816811997` $CellContext`md2, (-0.13222555671520594`) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.11785113019775778` $CellContext`md2, (-0.11785113019775806`) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.05892556509887889 $CellContext`md2, (-0.05892556509887903) \
$CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.050730119084059985` $CellContext`md2, (-0.06611277835760297) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.10146023816811997` $CellContext`md2, (-0.13222555671520594`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.15219035725217997` $CellContext`md2, (-0.19833833507280893`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.17677669529663667` $CellContext`md2, (-0.1767766952966371) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.11785113019775778` $CellContext`md2, (-0.11785113019775806`) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.10146023816811997` $CellContext`md2, (-0.13222555671520594`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.15219035725217997` $CellContext`md2, (-0.19833833507280893`) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.20292047633623994` $CellContext`md2, (-0.2644511134304119) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.23570226039551556` $CellContext`md2, (-0.23570226039551612`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.17677669529663667` $CellContext`md2, (-0.1767766952966371) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.15219035725217997` $CellContext`md2, (-0.19833833507280893`) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.20292047633623994` $CellContext`md2, (-0.2644511134304119) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           
           0.25365059542029994` $CellContext`md2, (-0.3305638917880149) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.2946278254943944 $CellContext`md2, (-0.29462782549439515`) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.23570226039551556` $CellContext`md2, (-0.23570226039551612`) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.20292047633623994` $CellContext`md2, (-0.2644511134304119) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.25365059542029994` $CellContext`md2, (-0.3305638917880149) \
$CellContext`md2}, {((-0.06249999999999997) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3043807145043599 $CellContext`md2, (-0.3966766701456178) \
$CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3535533905932733 $CellContext`md2, (-0.3535533905932741) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.2946278254943944 $CellContext`md2, (-0.29462782549439515`) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.25365059542029994` $CellContext`md2, (-0.3305638917880149) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.05892556509887895 $CellContext`md2, (-0.058925565098878974`) \
$CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0661127783576029 $CellContext`md2, (-0.05073011908406007) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, 
           
           0.05892556509887895 $CellContext`md2, (-0.058925565098878974`) \
$CellContext`md2}, {((-0.006944444444444445) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1178511301977579 $CellContext`md2, (-0.11785113019775795`) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1322255567152058 $CellContext`md2, (-0.10146023816812014`) \
$CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0661127783576029 $CellContext`md2, (-0.05073011908406007) \
$CellContext`md2}, {((-0.0017361111111111112`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.05892556509887895 $CellContext`md2, (-0.058925565098878974`) \
$CellContext`md2}, {((-0.006944444444444445) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1178511301977579 $CellContext`md2, (-0.11785113019775795`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.17677669529663687` $CellContext`md2, (-0.17677669529663692`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.19833833507280874` $CellContext`md2, (-0.15219035725218022`) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1322255567152058 $CellContext`md2, (-0.10146023816812014`) \
$CellContext`md2}, {((-0.006944444444444445) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1178511301977579 $CellContext`md2, (-0.11785113019775795`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.17677669529663687` $CellContext`md2, (-0.17677669529663692`) \
$CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.2357022603955158 $CellContext`md2, (-0.2357022603955159) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.2644511134304116 $CellContext`md2, (-0.20292047633624027`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.19833833507280874` $CellContext`md2, (-0.15219035725218022`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.17677669529663687` $CellContext`md2, (-0.17677669529663692`) \
$CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.2357022603955158 $CellContext`md2, (-0.2357022603955159) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.29462782549439476` $CellContext`md2, (-0.29462782549439487`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.33056389178801454` $CellContext`md2, (-0.25365059542030033`) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.2644511134304116 $CellContext`md2, (-0.20292047633624027`) \
$CellContext`md2}, {((-0.02777777777777778) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.2357022603955158 $CellContext`md2, (-0.2357022603955159) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.29462782549439476` $CellContext`md2, (-0.29462782549439487`) \
$CellContext`md2}, {((-0.06249999999999999) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3535533905932737 $CellContext`md2, (-0.3535533905932738) \
$CellContext`md2}, {((-0.06249999999999997) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3966766701456174 $CellContext`md2, (-0.3043807145043604) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.33056389178801454` $CellContext`md2, (-0.25365059542030033`) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.29462782549439476` $CellContext`md2, (-0.29462782549439487`) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0661127783576029 $CellContext`md2, (-0.05073011908406007) \
$CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.07216878364870319 $CellContext`md2, (-0.0416666666666667) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0661127783576029 $CellContext`md2, (-0.05073011908406007) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1322255567152058 $CellContext`md2, (-0.10146023816812014`) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.14433756729740638` $CellContext`md2, (-0.0833333333333334) \
$CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.07216878364870319 $CellContext`md2, (-0.0416666666666667) \
$CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0661127783576029 $CellContext`md2, (-0.05073011908406007) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1322255567152058 $CellContext`md2, (-0.10146023816812014`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.19833833507280874` $CellContext`md2, (-0.15219035725218022`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.2165063509461096 $CellContext`md2, (-0.1250000000000001) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.14433756729740638` $CellContext`md2, (-0.0833333333333334) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1322255567152058 $CellContext`md2, (-0.10146023816812014`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.19833833507280874` $CellContext`md2, (-0.15219035725218022`) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.2644511134304116 $CellContext`md2, (-0.20292047633624027`) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.28867513459481275` $CellContext`md2, (-0.1666666666666668) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.2165063509461096 $CellContext`md2, (-0.1250000000000001) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.19833833507280874` $CellContext`md2, (-0.15219035725218022`) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.2644511134304116 $CellContext`md2, (-0.20292047633624027`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.33056389178801454` $CellContext`md2, (-0.25365059542030033`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.36084391824351597` $CellContext`md2, (-0.2083333333333335) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.28867513459481275` $CellContext`md2, (-0.1666666666666668) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.2644511134304116 $CellContext`md2, (-0.20292047633624027`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.33056389178801454` $CellContext`md2, (-0.25365059542030033`) \
$CellContext`md2}, {((-0.06249999999999997) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3966766701456174 $CellContext`md2, (-0.3043807145043604) \
$CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.43301270189221913` $CellContext`md2, (-0.25000000000000017`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.36084391824351597` $CellContext`md2, (-0.2083333333333335) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           
           0.33056389178801454` $CellContext`md2, (-0.25365059542030033`) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.07216878364870319 $CellContext`md2, (-0.0416666666666667) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0769899610426072 $CellContext`md2, (-0.031890286030424195`) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.07216878364870319 $CellContext`md2, (-0.0416666666666667) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.14433756729740638` $CellContext`md2, (-0.0833333333333334) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1539799220852144 $CellContext`md2, (-0.06378057206084839) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0769899610426072 $CellContext`md2, (-0.031890286030424195`) \
$CellContext`md2}, {((-0.0017361111111111106`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.07216878364870319 $CellContext`md2, (-0.0416666666666667) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.14433756729740638` $CellContext`md2, (-0.0833333333333334) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.2165063509461096 $CellContext`md2, (-0.1250000000000001) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.23096988312782163` $CellContext`md2, (-0.0956708580912726) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1539799220852144 $CellContext`md2, (-0.06378057206084839) \
$CellContext`md2}, {((-0.006944444444444442) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.14433756729740638` $CellContext`md2, (-0.0833333333333334) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.2165063509461096 $CellContext`md2, (-0.1250000000000001) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.28867513459481275` $CellContext`md2, (-0.1666666666666668) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3079598441704288 $CellContext`md2, (-0.12756114412169678`) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.23096988312782163` $CellContext`md2, (-0.0956708580912726) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.2165063509461096 $CellContext`md2, (-0.1250000000000001) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.28867513459481275` $CellContext`md2, (-0.1666666666666668) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.36084391824351597` $CellContext`md2, (-0.2083333333333335) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.384949805213036 $CellContext`md2, (-0.159451430152121) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3079598441704288 $CellContext`md2, (-0.12756114412169678`) \
$CellContext`md2}, {((-0.02777777777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.28867513459481275` $CellContext`md2, (-0.1666666666666668) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.36084391824351597` $CellContext`md2, (-0.2083333333333335) \
$CellContext`md2}, {((-0.06249999999999998) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.43301270189221913` $CellContext`md2, (-0.25000000000000017`) \
$CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.4619397662556432 $CellContext`md2, (-0.19134171618254517`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.384949805213036 $CellContext`md2, (-0.159451430152121) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.36084391824351597` $CellContext`md2, (-0.2083333333333335) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0769899610426072 $CellContext`md2, (-0.031890286030424195`) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08049381885742234 $CellContext`md2, (-0.02156825375854346) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0769899610426072 $CellContext`md2, (-0.031890286030424195`) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1539799220852144 $CellContext`md2, (-0.06378057206084839) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.16098763771484467` $CellContext`md2, (-0.04313650751708692) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08049381885742234 $CellContext`md2, (-0.02156825375854346) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.0769899610426072 $CellContext`md2, (-0.031890286030424195`) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1539799220852144 $CellContext`md2, (-0.06378057206084839) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           
           0.23096988312782163` $CellContext`md2, (-0.0956708580912726) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.24148145657226702` $CellContext`md2, (-0.06470476127563038) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.16098763771484467` $CellContext`md2, (-0.04313650751708692) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.1539799220852144 $CellContext`md2, (-0.06378057206084839) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.23096988312782163` $CellContext`md2, (-0.0956708580912726) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3079598441704288 $CellContext`md2, (-0.12756114412169678`) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.32197527542968934` $CellContext`md2, (-0.08627301503417384) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.24148145657226702` $CellContext`md2, (-0.06470476127563038) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.23096988312782163` $CellContext`md2, (-0.0956708580912726) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3079598441704288 $CellContext`md2, (-0.12756114412169678`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.384949805213036 $CellContext`md2, (-0.159451430152121) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.4024690942871117 $CellContext`md2, (-0.10784126879271728`) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.32197527542968934` $CellContext`md2, (-0.08627301503417384) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3079598441704288 $CellContext`md2, (-0.12756114412169678`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.384949805213036 $CellContext`md2, (-0.159451430152121) \
$CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.4619397662556432 $CellContext`md2, (-0.19134171618254517`) \
$CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.482962913144534 $CellContext`md2, (-0.12940952255126073`) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.4024690942871117 $CellContext`md2, (-0.10784126879271728`) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.384949805213036 $CellContext`md2, (-0.159451430152121) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08049381885742234 $CellContext`md2, (-0.02156825375854346) \
$CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08262040511448418 $CellContext`md2, (-0.01087718268500438) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08049381885742234 $CellContext`md2, (-0.02156825375854346) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.16098763771484467` $CellContext`md2, (-0.04313650751708692) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.16524081022896836` $CellContext`md2, (-0.02175436537000876) \
$CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08262040511448418 $CellContext`md2, (-0.01087718268500438) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08049381885742234 $CellContext`md2, (-0.02156825375854346) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.16098763771484467` $CellContext`md2, (-0.04313650751708692) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.24148145657226702` $CellContext`md2, (-0.06470476127563038) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.24786121534345257` $CellContext`md2, (-0.03263154805501314) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.16524081022896836` $CellContext`md2, (-0.02175436537000876) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.16098763771484467` $CellContext`md2, (-0.04313650751708692) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.24148145657226702` $CellContext`md2, (-0.06470476127563038) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.32197527542968934` $CellContext`md2, (-0.08627301503417384) \
$CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3304816204579367 $CellContext`md2, (-0.04350873074001752) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.24786121534345257` $CellContext`md2, (-0.03263154805501314) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.24148145657226702` $CellContext`md2, (-0.06470476127563038) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.32197527542968934` $CellContext`md2, (-0.08627301503417384) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.4024690942871117 $CellContext`md2, (-0.10784126879271728`) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           
           0.41310202557242093` $CellContext`md2, (-0.0543859134250219) \
$CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3304816204579367 $CellContext`md2, (-0.04350873074001752) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.32197527542968934` $CellContext`md2, (-0.08627301503417384) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.4024690942871117 $CellContext`md2, (-0.10784126879271728`) \
$CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.482962913144534 $CellContext`md2, (-0.12940952255126073`) \
$CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.4957224306869051 $CellContext`md2, (-0.06526309611002627) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.41310202557242093` $CellContext`md2, (-0.0543859134250219) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.4024690942871117 $CellContext`md2, (-0.10784126879271728`) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08262040511448418 $CellContext`md2, (-0.01087718268500438) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08333333333333333 $CellContext`md2, (-9.442564829413299*^-17) \
$CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {(0. $CellContext`md2^2)/$CellContext`mf2, 
           0. $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08262040511448418 $CellContext`md2, (-0.01087718268500438) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 
           
           0.16524081022896836` $CellContext`md2, (-0.02175436537000876) \
$CellContext`md2}, {((-0.006944444444444444) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.16666666666666666` $CellContext`md2, (-1.8885129658826599`*^-16) \
$CellContext`md2}, {((-0.001736111111111111) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08333333333333333 $CellContext`md2, (-9.442564829413299*^-17) \
$CellContext`md2}, {((-0.0017361111111111108`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.08262040511448418 $CellContext`md2, (-0.01087718268500438) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.16524081022896836` $CellContext`md2, (-0.02175436537000876) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.24786121534345257` $CellContext`md2, (-0.03263154805501314) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.25 $CellContext`md2, (-2.83276944882399*^-16) $CellContext`md2}, \
{((-0.006944444444444444) $CellContext`md2^2)/$CellContext`mf2, 
           0.16666666666666666` $CellContext`md2, (-1.8885129658826599`*^-16) \
$CellContext`md2}, {((-0.006944444444444443) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.16524081022896836` $CellContext`md2, (-0.02175436537000876) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.24786121534345257` $CellContext`md2, (-0.03263154805501314) \
$CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3304816204579367 $CellContext`md2, (-0.04350873074001752) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3333333333333333 $CellContext`md2, (-3.7770259317653197`*^-16) \
$CellContext`md2}, {((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.25 $CellContext`md2, (-2.83276944882399*^-16) $CellContext`md2}, \
{((-0.015625) $CellContext`md2^2)/$CellContext`mf2, 
           0.24786121534345257` $CellContext`md2, (-0.03263154805501314) \
$CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3304816204579367 $CellContext`md2, (-0.04350873074001752) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.41310202557242093` $CellContext`md2, (-0.0543859134250219) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.41666666666666663` $CellContext`md2, (-4.72128241470665*^-16) \
$CellContext`md2}, {((-0.027777777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3333333333333333 $CellContext`md2, (-3.7770259317653197`*^-16) \
$CellContext`md2}, {((-0.027777777777777773`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.3304816204579367 $CellContext`md2, (-0.04350873074001752) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.41310202557242093` $CellContext`md2, (-0.0543859134250219) \
$CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.4957224306869051 $CellContext`md2, (-0.06526309611002627) \
$CellContext`md2}, {((-0.062499999999999986`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.49999999999999994` $CellContext`md2, (-5.665538897647979*^-16) \
$CellContext`md2}, {((-0.04340277777777777) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.41666666666666663` $CellContext`md2, (-4.72128241470665*^-16) \
$CellContext`md2}, {((-0.043402777777777776`) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.41310202557242093` $CellContext`md2, (-0.0543859134250219) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.08333333333333333 $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.0826204051144842 $CellContext`md2, 
           0.010877182685004297` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.08333333333333333 $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.16666666666666666` $CellContext`md2, 
           0. $CellContext`md2}, {
          10.16, 0.1652408102289684 $CellContext`md2, 
           0.021754365370008594` $CellContext`md2}, {
          10.16, 0.0826204051144842 $CellContext`md2, 
           0.010877182685004297` $CellContext`md2}, {
          10.16, 0.08333333333333333 $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.16666666666666666` $CellContext`md2, 
           0. $CellContext`md2}, {
          10.16, 0.25 $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.2478612153434526 $CellContext`md2, 
           0.03263154805501289 $CellContext`md2}, {
          10.16, 0.1652408102289684 $CellContext`md2, 
           0.021754365370008594` $CellContext`md2}, {
          10.16, 0.16666666666666666` $CellContext`md2, 
           0. $CellContext`md2}, {
          10.16, 0.25 $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.3333333333333333 $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.3304816204579368 $CellContext`md2, 
           0.04350873074001719 $CellContext`md2}, {
          10.16, 0.2478612153434526 $CellContext`md2, 
           0.03263154805501289 $CellContext`md2}, {
          10.16, 0.25 $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.3333333333333333 $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.41666666666666663` $CellContext`md2, 
           0. $CellContext`md2}, {
          10.16, 0.413102025572421 $CellContext`md2, 
           0.054385913425021484` $CellContext`md2}, {
          10.16, 0.3304816204579368 $CellContext`md2, 
           0.04350873074001719 $CellContext`md2}, {
          10.16, 0.3333333333333333 $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.41666666666666663` $CellContext`md2, 
           0. $CellContext`md2}, {
          10.16, 0.49999999999999994` $CellContext`md2, 
           0. $CellContext`md2}, {
          10.16, 0.49572243068690514` $CellContext`md2, 
           0.06526309611002577 $CellContext`md2}, {
          10.16, 0.413102025572421 $CellContext`md2, 
           0.054385913425021484` $CellContext`md2}, {
          10.16, 0.41666666666666663` $CellContext`md2, 
           0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.0826204051144842 $CellContext`md2, 
           0.010877182685004297` $CellContext`md2}, {
          10.16, 0.08049381885742235 $CellContext`md2, 
           0.021568253758543394` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.0826204051144842 $CellContext`md2, 
           0.010877182685004297` $CellContext`md2}, {
          10.16, 0.1652408102289684 $CellContext`md2, 
           0.021754365370008594` $CellContext`md2}, {
          10.16, 0.1609876377148447 $CellContext`md2, 
           0.04313650751708679 $CellContext`md2}, {
          10.16, 0.08049381885742235 $CellContext`md2, 
           0.021568253758543394` $CellContext`md2}, {
          10.16, 0.0826204051144842 $CellContext`md2, 
           0.010877182685004297` $CellContext`md2}, {
          10.16, 0.1652408102289684 $CellContext`md2, 
           0.021754365370008594` $CellContext`md2}, {
          10.16, 0.2478612153434526 $CellContext`md2, 
           0.03263154805501289 $CellContext`md2}, {
          10.16, 0.24148145657226708` $CellContext`md2, 
           0.06470476127563018 $CellContext`md2}, {
          10.16, 0.1609876377148447 $CellContext`md2, 
           0.04313650751708679 $CellContext`md2}, {
          10.16, 0.1652408102289684 $CellContext`md2, 
           0.021754365370008594` $CellContext`md2}, {
          10.16, 0.2478612153434526 $CellContext`md2, 
           0.03263154805501289 $CellContext`md2}, {
          10.16, 0.3304816204579368 $CellContext`md2, 
           0.04350873074001719 $CellContext`md2}, {
          10.16, 0.3219752754296894 $CellContext`md2, 
           0.08627301503417358 $CellContext`md2}, {
          10.16, 0.24148145657226708` $CellContext`md2, 
           0.06470476127563018 $CellContext`md2}, {
          10.16, 0.2478612153434526 $CellContext`md2, 
           0.03263154805501289 $CellContext`md2}, {
          10.16, 0.3304816204579368 $CellContext`md2, 
           0.04350873074001719 $CellContext`md2}, {
          10.16, 0.413102025572421 $CellContext`md2, 
           0.054385913425021484` $CellContext`md2}, {
          10.16, 0.40246909428711175` $CellContext`md2, 
           0.10784126879271697` $CellContext`md2}, {
          10.16, 0.3219752754296894 $CellContext`md2, 
           0.08627301503417358 $CellContext`md2}, {
          10.16, 0.3304816204579368 $CellContext`md2, 
           0.04350873074001719 $CellContext`md2}, {
          10.16, 0.413102025572421 $CellContext`md2, 
           0.054385913425021484` $CellContext`md2}, {
          10.16, 0.49572243068690514` $CellContext`md2, 
           0.06526309611002577 $CellContext`md2}, {
          10.16, 0.4829629131445341 $CellContext`md2, 
           0.12940952255126034` $CellContext`md2}, {
          10.16, 0.40246909428711175` $CellContext`md2, 
           0.10784126879271697` $CellContext`md2}, {
          10.16, 0.413102025572421 $CellContext`md2, 
           0.054385913425021484` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.08049381885742235 $CellContext`md2, 
           0.021568253758543394` $CellContext`md2}, {
          10.16, 0.07698996104260722 $CellContext`md2, 
           0.031890286030424146` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.08049381885742235 $CellContext`md2, 
           0.021568253758543394` $CellContext`md2}, {
          10.16, 0.1609876377148447 $CellContext`md2, 
           0.04313650751708679 $CellContext`md2}, {
          10.16, 0.15397992208521444` $CellContext`md2, 
           0.06378057206084829 $CellContext`md2}, {
          10.16, 0.07698996104260722 $CellContext`md2, 
           0.031890286030424146` $CellContext`md2}, {
          10.16, 0.08049381885742235 $CellContext`md2, 
           0.021568253758543394` $CellContext`md2}, {
          10.16, 0.1609876377148447 $CellContext`md2, 
           0.04313650751708679 $CellContext`md2}, {
          10.16, 0.24148145657226708` $CellContext`md2, 
           0.06470476127563018 $CellContext`md2}, {
          10.16, 0.23096988312782168` $CellContext`md2, 
           0.09567085809127245 $CellContext`md2}, {
          10.16, 0.15397992208521444` $CellContext`md2, 
           0.06378057206084829 $CellContext`md2}, {
          10.16, 0.1609876377148447 $CellContext`md2, 
           0.04313650751708679 $CellContext`md2}, {
          10.16, 0.24148145657226708` $CellContext`md2, 
           0.06470476127563018 $CellContext`md2}, {
          10.16, 0.3219752754296894 $CellContext`md2, 
           0.08627301503417358 $CellContext`md2}, {
          10.16, 0.3079598441704289 $CellContext`md2, 
           0.12756114412169658` $CellContext`md2}, {
          10.16, 0.23096988312782168` $CellContext`md2, 
           0.09567085809127245 $CellContext`md2}, {
          10.16, 0.24148145657226708` $CellContext`md2, 
           0.06470476127563018 $CellContext`md2}, {
          10.16, 0.3219752754296894 $CellContext`md2, 
           0.08627301503417358 $CellContext`md2}, {
          10.16, 0.40246909428711175` $CellContext`md2, 
           0.10784126879271697` $CellContext`md2}, {
          10.16, 0.3849498052130361 $CellContext`md2, 
           0.15945143015212074` $CellContext`md2}, {
          10.16, 0.3079598441704289 $CellContext`md2, 
           0.12756114412169658` $CellContext`md2}, {
          10.16, 0.3219752754296894 $CellContext`md2, 
           0.08627301503417358 $CellContext`md2}, {
          10.16, 0.40246909428711175` $CellContext`md2, 
           0.10784126879271697` $CellContext`md2}, {
          10.16, 0.4829629131445341 $CellContext`md2, 
           0.12940952255126034` $CellContext`md2}, {
          10.16, 0.4619397662556433 $CellContext`md2, 
           0.19134171618254486` $CellContext`md2}, {
          10.16, 0.3849498052130361 $CellContext`md2, 
           0.15945143015212074` $CellContext`md2}, {
          10.16, 0.40246909428711175` $CellContext`md2, 
           0.10784126879271697` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.07698996104260722 $CellContext`md2, 
           0.031890286030424146` $CellContext`md2}, {
          10.16, 0.07216878364870322 $CellContext`md2, 
           0.04166666666666666 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.07698996104260722 $CellContext`md2, 
           0.031890286030424146` $CellContext`md2}, {
          10.16, 0.15397992208521444` $CellContext`md2, 
           0.06378057206084829 $CellContext`md2}, {
          10.16, 0.14433756729740643` $CellContext`md2, 
           0.08333333333333331 $CellContext`md2}, {
          10.16, 0.07216878364870322 $CellContext`md2, 
           0.04166666666666666 $CellContext`md2}, {
          10.16, 0.07698996104260722 $CellContext`md2, 
           0.031890286030424146` $CellContext`md2}, {
          10.16, 0.15397992208521444` $CellContext`md2, 
           0.06378057206084829 $CellContext`md2}, {
          10.16, 0.23096988312782168` $CellContext`md2, 
           0.09567085809127245 $CellContext`md2}, {
          10.16, 0.21650635094610968` $CellContext`md2, 
           0.12499999999999999` $CellContext`md2}, {
          10.16, 0.14433756729740643` $CellContext`md2, 
           0.08333333333333331 $CellContext`md2}, {
          10.16, 0.15397992208521444` $CellContext`md2, 
           0.06378057206084829 $CellContext`md2}, {
          10.16, 0.23096988312782168` $CellContext`md2, 
           0.09567085809127245 $CellContext`md2}, {
          10.16, 0.3079598441704289 $CellContext`md2, 
           0.12756114412169658` $CellContext`md2}, {
          10.16, 0.28867513459481287` $CellContext`md2, 
           0.16666666666666663` $CellContext`md2}, {
          10.16, 0.21650635094610968` $CellContext`md2, 
           0.12499999999999999` $CellContext`md2}, {
          10.16, 0.23096988312782168` $CellContext`md2, 
           0.09567085809127245 $CellContext`md2}, {
          10.16, 0.3079598441704289 $CellContext`md2, 
           0.12756114412169658` $CellContext`md2}, {
          10.16, 0.3849498052130361 $CellContext`md2, 
           0.15945143015212074` $CellContext`md2}, {
          10.16, 0.3608439182435161 $CellContext`md2, 
           0.2083333333333333 $CellContext`md2}, {
          10.16, 0.28867513459481287` $CellContext`md2, 
           0.16666666666666663` $CellContext`md2}, {
          10.16, 0.3079598441704289 $CellContext`md2, 
           0.12756114412169658` $CellContext`md2}, {
          10.16, 0.3849498052130361 $CellContext`md2, 
           0.15945143015212074` $CellContext`md2}, {
          10.16, 0.4619397662556433 $CellContext`md2, 
           0.19134171618254486` $CellContext`md2}, {
          10.16, 0.4330127018922193 $CellContext`md2, 
           0.24999999999999994` $CellContext`md2}, {
          10.16, 0.3608439182435161 $CellContext`md2, 
           0.2083333333333333 $CellContext`md2}, {
          10.16, 0.3849498052130361 $CellContext`md2, 
           0.15945143015212074` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.07216878364870322 $CellContext`md2, 
           0.04166666666666666 $CellContext`md2}, {
          10.16, 0.06611277835760293 $CellContext`md2, 
           0.05073011908406004 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.07216878364870322 $CellContext`md2, 
           0.04166666666666666 $CellContext`md2}, {
          10.16, 0.14433756729740643` $CellContext`md2, 
           0.08333333333333331 $CellContext`md2}, {
          10.16, 0.13222555671520586` $CellContext`md2, 
           0.10146023816812008` $CellContext`md2}, {
          10.16, 0.06611277835760293 $CellContext`md2, 
           0.05073011908406004 $CellContext`md2}, {
          10.16, 0.07216878364870322 $CellContext`md2, 
           0.04166666666666666 $CellContext`md2}, {
          10.16, 0.14433756729740643` $CellContext`md2, 
           0.08333333333333331 $CellContext`md2}, {
          10.16, 0.21650635094610968` $CellContext`md2, 
           0.12499999999999999` $CellContext`md2}, {
          10.16, 0.1983383350728088 $CellContext`md2, 
           0.15219035725218014` $CellContext`md2}, {
          10.16, 0.13222555671520586` $CellContext`md2, 
           0.10146023816812008` $CellContext`md2}, {
          10.16, 0.14433756729740643` $CellContext`md2, 
           0.08333333333333331 $CellContext`md2}, {
          10.16, 0.21650635094610968` $CellContext`md2, 
           0.12499999999999999` $CellContext`md2}, {
          10.16, 0.28867513459481287` $CellContext`md2, 
           0.16666666666666663` $CellContext`md2}, {
          10.16, 0.2644511134304117 $CellContext`md2, 
           0.20292047633624016` $CellContext`md2}, {
          10.16, 0.1983383350728088 $CellContext`md2, 
           0.15219035725218014` $CellContext`md2}, {
          10.16, 0.21650635094610968` $CellContext`md2, 
           0.12499999999999999` $CellContext`md2}, {
          10.16, 0.28867513459481287` $CellContext`md2, 
           0.16666666666666663` $CellContext`md2}, {
          10.16, 0.3608439182435161 $CellContext`md2, 
           0.2083333333333333 $CellContext`md2}, {
          10.16, 0.3305638917880146 $CellContext`md2, 
           0.2536505954203002 $CellContext`md2}, {
          10.16, 0.2644511134304117 $CellContext`md2, 
           0.20292047633624016` $CellContext`md2}, {
          10.16, 0.28867513459481287` $CellContext`md2, 
           0.16666666666666663` $CellContext`md2}, {
          10.16, 0.3608439182435161 $CellContext`md2, 
           0.2083333333333333 $CellContext`md2}, {
          10.16, 0.4330127018922193 $CellContext`md2, 
           0.24999999999999994` $CellContext`md2}, {
          10.16, 0.3966766701456175 $CellContext`md2, 
           0.3043807145043602 $CellContext`md2}, {
          10.16, 0.3305638917880146 $CellContext`md2, 
           0.2536505954203002 $CellContext`md2}, {
          10.16, 0.3608439182435161 $CellContext`md2, 
           0.2083333333333333 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.06611277835760293 $CellContext`md2, 
           0.05073011908406004 $CellContext`md2}, {
          10.16, 0.058925565098878974` $CellContext`md2, 
           0.05892556509887895 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.06611277835760293 $CellContext`md2, 
           0.05073011908406004 $CellContext`md2}, {
          10.16, 0.13222555671520586` $CellContext`md2, 
           0.10146023816812008` $CellContext`md2}, {
          10.16, 0.11785113019775795` $CellContext`md2, 
           0.1178511301977579 $CellContext`md2}, {
          10.16, 0.058925565098878974` $CellContext`md2, 
           0.05892556509887895 $CellContext`md2}, {
          10.16, 0.06611277835760293 $CellContext`md2, 
           0.05073011908406004 $CellContext`md2}, {
          10.16, 0.13222555671520586` $CellContext`md2, 
           0.10146023816812008` $CellContext`md2}, {
          10.16, 0.1983383350728088 $CellContext`md2, 
           0.15219035725218014` $CellContext`md2}, {
          10.16, 0.17677669529663692` $CellContext`md2, 
           0.17677669529663687` $CellContext`md2}, {
          10.16, 0.11785113019775795` $CellContext`md2, 
           0.1178511301977579 $CellContext`md2}, {
          10.16, 0.13222555671520586` $CellContext`md2, 
           0.10146023816812008` $CellContext`md2}, {
          10.16, 0.1983383350728088 $CellContext`md2, 
           0.15219035725218014` $CellContext`md2}, {
          10.16, 0.2644511134304117 $CellContext`md2, 
           0.20292047633624016` $CellContext`md2}, {
          10.16, 0.2357022603955159 $CellContext`md2, 
           0.2357022603955158 $CellContext`md2}, {
          10.16, 0.17677669529663692` $CellContext`md2, 
           0.17677669529663687` $CellContext`md2}, {
          10.16, 0.1983383350728088 $CellContext`md2, 
           0.15219035725218014` $CellContext`md2}, {
          10.16, 0.2644511134304117 $CellContext`md2, 
           0.20292047633624016` $CellContext`md2}, {
          10.16, 0.3305638917880146 $CellContext`md2, 
           0.2536505954203002 $CellContext`md2}, {
          10.16, 0.29462782549439487` $CellContext`md2, 
           0.29462782549439476` $CellContext`md2}, {
          10.16, 0.2357022603955159 $CellContext`md2, 
           0.2357022603955158 $CellContext`md2}, {
          10.16, 0.2644511134304117 $CellContext`md2, 
           0.20292047633624016` $CellContext`md2}, {
          10.16, 0.3305638917880146 $CellContext`md2, 
           0.2536505954203002 $CellContext`md2}, {
          10.16, 0.3966766701456175 $CellContext`md2, 
           0.3043807145043602 $CellContext`md2}, {
          10.16, 0.3535533905932738 $CellContext`md2, 
           0.3535533905932737 $CellContext`md2}, {
          10.16, 0.29462782549439487` $CellContext`md2, 
           0.29462782549439476` $CellContext`md2}, {
          10.16, 0.3305638917880146 $CellContext`md2, 
           0.2536505954203002 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.05892556509887896 $CellContext`md2, 
           0.05892556509887895 $CellContext`md2}, {
          10.16, 0.05073011908406006 $CellContext`md2, 
           0.06611277835760292 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.05892556509887896 $CellContext`md2, 
           0.05892556509887895 $CellContext`md2}, {
          10.16, 0.11785113019775792` $CellContext`md2, 
           0.1178511301977579 $CellContext`md2}, {
          10.16, 0.10146023816812012` $CellContext`md2, 
           0.13222555671520583` $CellContext`md2}, {
          10.16, 0.05073011908406006 $CellContext`md2, 
           0.06611277835760292 $CellContext`md2}, {
          10.16, 0.05892556509887896 $CellContext`md2, 
           0.05892556509887895 $CellContext`md2}, {
          10.16, 0.11785113019775792` $CellContext`md2, 
           0.1178511301977579 $CellContext`md2}, {
          10.16, 0.1767766952966369 $CellContext`md2, 
           0.17677669529663687` $CellContext`md2}, {
          10.16, 0.1521903572521802 $CellContext`md2, 
           0.19833833507280876` $CellContext`md2}, {
          10.16, 0.10146023816812012` $CellContext`md2, 
           0.13222555671520583` $CellContext`md2}, {
          10.16, 0.11785113019775792` $CellContext`md2, 
           0.1178511301977579 $CellContext`md2}, {
          10.16, 0.1767766952966369 $CellContext`md2, 
           0.17677669529663687` $CellContext`md2}, {
          10.16, 0.23570226039551584` $CellContext`md2, 
           0.2357022603955158 $CellContext`md2}, {
          10.16, 0.20292047633624025` $CellContext`md2, 
           0.26445111343041167` $CellContext`md2}, {
          10.16, 0.1521903572521802 $CellContext`md2, 
           0.19833833507280876` $CellContext`md2}, {
          10.16, 0.1767766952966369 $CellContext`md2, 
           0.17677669529663687` $CellContext`md2}, {
          10.16, 0.23570226039551584` $CellContext`md2, 
           0.2357022603955158 $CellContext`md2}, {
          10.16, 0.2946278254943948 $CellContext`md2, 
           0.29462782549439476` $CellContext`md2}, {
          10.16, 0.2536505954203003 $CellContext`md2, 
           0.3305638917880146 $CellContext`md2}, {
          10.16, 0.20292047633624025` $CellContext`md2, 
           0.26445111343041167` $CellContext`md2}, {
          10.16, 0.23570226039551584` $CellContext`md2, 
           0.2357022603955158 $CellContext`md2}, {
          10.16, 0.2946278254943948 $CellContext`md2, 
           0.29462782549439476` $CellContext`md2}, {
          10.16, 0.35355339059327373` $CellContext`md2, 
           0.3535533905932737 $CellContext`md2}, {
          10.16, 0.30438071450436033` $CellContext`md2, 
           0.39667667014561747` $CellContext`md2}, {
          10.16, 0.2536505954203003 $CellContext`md2, 
           0.3305638917880146 $CellContext`md2}, {
          10.16, 0.2946278254943948 $CellContext`md2, 
           0.29462782549439476` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.05073011908406006 $CellContext`md2, 
           0.06611277835760292 $CellContext`md2}, {
          10.16, 0.04166666666666667 $CellContext`md2, 
           0.07216878364870322 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.05073011908406006 $CellContext`md2, 
           0.06611277835760292 $CellContext`md2}, {
          10.16, 0.10146023816812012` $CellContext`md2, 
           0.13222555671520583` $CellContext`md2}, {
          10.16, 0.08333333333333334 $CellContext`md2, 
           0.14433756729740643` $CellContext`md2}, {
          10.16, 0.04166666666666667 $CellContext`md2, 
           0.07216878364870322 $CellContext`md2}, {
          10.16, 0.05073011908406006 $CellContext`md2, 
           0.06611277835760292 $CellContext`md2}, {
          10.16, 0.10146023816812012` $CellContext`md2, 
           0.13222555671520583` $CellContext`md2}, {
          10.16, 0.1521903572521802 $CellContext`md2, 
           0.19833833507280876` $CellContext`md2}, {
          10.16, 0.12500000000000003` $CellContext`md2, 
           0.21650635094610965` $CellContext`md2}, {
          10.16, 0.08333333333333334 $CellContext`md2, 
           0.14433756729740643` $CellContext`md2}, {
          10.16, 0.10146023816812012` $CellContext`md2, 
           0.13222555671520583` $CellContext`md2}, {
          10.16, 0.1521903572521802 $CellContext`md2, 
           0.19833833507280876` $CellContext`md2}, {
          10.16, 0.20292047633624025` $CellContext`md2, 
           0.26445111343041167` $CellContext`md2}, {
          10.16, 0.16666666666666669` $CellContext`md2, 
           0.28867513459481287` $CellContext`md2}, {
          10.16, 0.12500000000000003` $CellContext`md2, 
           0.21650635094610965` $CellContext`md2}, {
          10.16, 0.1521903572521802 $CellContext`md2, 
           0.19833833507280876` $CellContext`md2}, {
          10.16, 0.20292047633624025` $CellContext`md2, 
           0.26445111343041167` $CellContext`md2}, {
          10.16, 0.2536505954203003 $CellContext`md2, 
           0.3305638917880146 $CellContext`md2}, {
          10.16, 0.20833333333333337` $CellContext`md2, 
           0.360843918243516 $CellContext`md2}, {
          10.16, 0.16666666666666669` $CellContext`md2, 
           0.28867513459481287` $CellContext`md2}, {
          10.16, 0.20292047633624025` $CellContext`md2, 
           0.26445111343041167` $CellContext`md2}, {
          10.16, 0.2536505954203003 $CellContext`md2, 
           0.3305638917880146 $CellContext`md2}, {
          10.16, 0.30438071450436033` $CellContext`md2, 
           0.39667667014561747` $CellContext`md2}, {
          10.16, 0.25 $CellContext`md2, 
           0.43301270189221924` $CellContext`md2}, {
          10.16, 0.20833333333333337` $CellContext`md2, 
           0.360843918243516 $CellContext`md2}, {
          10.16, 0.2536505954203003 $CellContext`md2, 
           0.3305638917880146 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.04166666666666667 $CellContext`md2, 
           0.07216878364870322 $CellContext`md2}, {
          10.16, 0.03189028603042415 $CellContext`md2, 
           0.07698996104260722 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.04166666666666667 $CellContext`md2, 
           0.07216878364870322 $CellContext`md2}, {
          10.16, 0.08333333333333334 $CellContext`md2, 
           0.14433756729740643` $CellContext`md2}, {
          10.16, 0.0637805720608483 $CellContext`md2, 
           0.15397992208521444` $CellContext`md2}, {
          10.16, 0.03189028603042415 $CellContext`md2, 
           0.07698996104260722 $CellContext`md2}, {
          10.16, 0.04166666666666667 $CellContext`md2, 
           0.07216878364870322 $CellContext`md2}, {
          10.16, 0.08333333333333334 $CellContext`md2, 
           0.14433756729740643` $CellContext`md2}, {
          10.16, 0.12500000000000003` $CellContext`md2, 
           0.21650635094610965` $CellContext`md2}, {
          10.16, 0.09567085809127246 $CellContext`md2, 
           0.23096988312782168` $CellContext`md2}, {
          10.16, 0.0637805720608483 $CellContext`md2, 
           0.15397992208521444` $CellContext`md2}, {
          10.16, 0.08333333333333334 $CellContext`md2, 
           0.14433756729740643` $CellContext`md2}, {
          10.16, 0.12500000000000003` $CellContext`md2, 
           0.21650635094610965` $CellContext`md2}, {
          10.16, 0.16666666666666669` $CellContext`md2, 
           0.28867513459481287` $CellContext`md2}, {
          10.16, 0.1275611441216966 $CellContext`md2, 
           0.3079598441704289 $CellContext`md2}, {
          10.16, 0.09567085809127246 $CellContext`md2, 
           0.23096988312782168` $CellContext`md2}, {
          10.16, 0.12500000000000003` $CellContext`md2, 
           0.21650635094610965` $CellContext`md2}, {
          10.16, 0.16666666666666669` $CellContext`md2, 
           0.28867513459481287` $CellContext`md2}, {
          10.16, 0.20833333333333337` $CellContext`md2, 
           0.360843918243516 $CellContext`md2}, {
          10.16, 0.15945143015212074` $CellContext`md2, 
           0.3849498052130361 $CellContext`md2}, {
          10.16, 0.1275611441216966 $CellContext`md2, 
           0.3079598441704289 $CellContext`md2}, {
          10.16, 0.16666666666666669` $CellContext`md2, 
           0.28867513459481287` $CellContext`md2}, {
          10.16, 0.20833333333333337` $CellContext`md2, 
           0.360843918243516 $CellContext`md2}, {
          10.16, 0.25 $CellContext`md2, 
           0.43301270189221924` $CellContext`md2}, {
          10.16, 0.1913417161825449 $CellContext`md2, 
           0.4619397662556433 $CellContext`md2}, {
          10.16, 0.15945143015212074` $CellContext`md2, 
           0.3849498052130361 $CellContext`md2}, {
          10.16, 0.20833333333333337` $CellContext`md2, 
           0.360843918243516 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.03189028603042415 $CellContext`md2, 
           0.07698996104260722 $CellContext`md2}, {
          10.16, 0.021568253758543394` $CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.03189028603042415 $CellContext`md2, 
           0.07698996104260722 $CellContext`md2}, {
          10.16, 0.0637805720608483 $CellContext`md2, 
           0.15397992208521444` $CellContext`md2}, {
          10.16, 0.04313650751708679 $CellContext`md2, 
           0.1609876377148447 $CellContext`md2}, {
          10.16, 0.021568253758543394` $CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {
          10.16, 0.03189028603042415 $CellContext`md2, 
           0.07698996104260722 $CellContext`md2}, {
          10.16, 0.0637805720608483 $CellContext`md2, 
           0.15397992208521444` $CellContext`md2}, {
          10.16, 0.09567085809127246 $CellContext`md2, 
           0.23096988312782168` $CellContext`md2}, {
          10.16, 0.06470476127563018 $CellContext`md2, 
           0.24148145657226708` $CellContext`md2}, {
          10.16, 0.04313650751708679 $CellContext`md2, 
           0.1609876377148447 $CellContext`md2}, {
          10.16, 0.0637805720608483 $CellContext`md2, 
           0.15397992208521444` $CellContext`md2}, {
          10.16, 0.09567085809127246 $CellContext`md2, 
           0.23096988312782168` $CellContext`md2}, {
          10.16, 0.1275611441216966 $CellContext`md2, 
           0.3079598441704289 $CellContext`md2}, {
          10.16, 0.08627301503417358 $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {
          10.16, 0.06470476127563018 $CellContext`md2, 
           0.24148145657226708` $CellContext`md2}, {
          10.16, 0.09567085809127246 $CellContext`md2, 
           0.23096988312782168` $CellContext`md2}, {
          10.16, 0.1275611441216966 $CellContext`md2, 
           0.3079598441704289 $CellContext`md2}, {
          10.16, 0.15945143015212074` $CellContext`md2, 
           0.3849498052130361 $CellContext`md2}, {
          10.16, 0.10784126879271697` $CellContext`md2, 
           0.40246909428711175` $CellContext`md2}, {
          10.16, 0.08627301503417358 $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {
          10.16, 0.1275611441216966 $CellContext`md2, 
           0.3079598441704289 $CellContext`md2}, {
          10.16, 0.15945143015212074` $CellContext`md2, 
           0.3849498052130361 $CellContext`md2}, {
          10.16, 0.1913417161825449 $CellContext`md2, 
           0.4619397662556433 $CellContext`md2}, {
          10.16, 0.12940952255126034` $CellContext`md2, 
           0.4829629131445341 $CellContext`md2}, {
          10.16, 0.10784126879271697` $CellContext`md2, 
           0.40246909428711175` $CellContext`md2}, {
          10.16, 0.15945143015212074` $CellContext`md2, 
           0.3849498052130361 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.02156825375854341 $CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {
          10.16, 0.01087718268500431 $CellContext`md2, 
           0.0826204051144842 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.02156825375854341 $CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {
          10.16, 0.04313650751708682 $CellContext`md2, 
           0.1609876377148447 $CellContext`md2}, {
          10.16, 0.02175436537000862 $CellContext`md2, 
           0.1652408102289684 $CellContext`md2}, {
          10.16, 0.01087718268500431 $CellContext`md2, 
           0.0826204051144842 $CellContext`md2}, {
          10.16, 0.02156825375854341 $CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {
          10.16, 0.04313650751708682 $CellContext`md2, 
           0.1609876377148447 $CellContext`md2}, {
          10.16, 0.06470476127563024 $CellContext`md2, 
           0.24148145657226705` $CellContext`md2}, {
          10.16, 0.03263154805501293 $CellContext`md2, 
           0.2478612153434526 $CellContext`md2}, {
          10.16, 0.02175436537000862 $CellContext`md2, 
           0.1652408102289684 $CellContext`md2}, {
          10.16, 0.04313650751708682 $CellContext`md2, 
           0.1609876377148447 $CellContext`md2}, {
          10.16, 0.06470476127563024 $CellContext`md2, 
           0.24148145657226705` $CellContext`md2}, {
          10.16, 0.08627301503417364 $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {
          10.16, 0.04350873074001724 $CellContext`md2, 
           0.3304816204579368 $CellContext`md2}, {
          10.16, 0.03263154805501293 $CellContext`md2, 
           0.2478612153434526 $CellContext`md2}, {
          10.16, 0.06470476127563024 $CellContext`md2, 
           0.24148145657226705` $CellContext`md2}, {
          10.16, 0.08627301503417364 $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {
          10.16, 0.10784126879271706` $CellContext`md2, 
           0.4024690942871117 $CellContext`md2}, {
          10.16, 0.05438591342502154 $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {
          10.16, 0.04350873074001724 $CellContext`md2, 
           0.3304816204579368 $CellContext`md2}, {
          10.16, 0.08627301503417364 $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {
          10.16, 0.10784126879271706` $CellContext`md2, 
           0.4024690942871117 $CellContext`md2}, {
          10.16, 0.12940952255126045` $CellContext`md2, 
           0.48296291314453405` $CellContext`md2}, {
          10.16, 0.06526309611002584 $CellContext`md2, 
           0.49572243068690514` $CellContext`md2}, {
          10.16, 0.05438591342502154 $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {
          10.16, 0.10784126879271706` $CellContext`md2, 
           0.4024690942871117 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.01087718268500431 $CellContext`md2, 
           0.0826204051144842 $CellContext`md2}, {
          10.16, 5.102694996447305*^-18 $CellContext`md2, 
           0.08333333333333333 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.01087718268500431 $CellContext`md2, 
           0.0826204051144842 $CellContext`md2}, {
          10.16, 0.02175436537000862 $CellContext`md2, 
           0.1652408102289684 $CellContext`md2}, {
          10.16, 1.020538999289461*^-17 $CellContext`md2, 
           0.16666666666666666` $CellContext`md2}, {
          10.16, 5.102694996447305*^-18 $CellContext`md2, 
           0.08333333333333333 $CellContext`md2}, {
          10.16, 0.01087718268500431 $CellContext`md2, 
           0.0826204051144842 $CellContext`md2}, {
          10.16, 0.02175436537000862 $CellContext`md2, 
           0.1652408102289684 $CellContext`md2}, {
          10.16, 0.03263154805501293 $CellContext`md2, 
           0.2478612153434526 $CellContext`md2}, {
          10.16, 1.5308084989341915`*^-17 $CellContext`md2, 
           0.25 $CellContext`md2}, {
          10.16, 1.020538999289461*^-17 $CellContext`md2, 
           0.16666666666666666` $CellContext`md2}, {
          10.16, 0.02175436537000862 $CellContext`md2, 
           0.1652408102289684 $CellContext`md2}, {
          10.16, 0.03263154805501293 $CellContext`md2, 
           0.2478612153434526 $CellContext`md2}, {
          10.16, 0.04350873074001724 $CellContext`md2, 
           0.3304816204579368 $CellContext`md2}, {
          10.16, 2.041077998578922*^-17 $CellContext`md2, 
           0.3333333333333333 $CellContext`md2}, {
          10.16, 1.5308084989341915`*^-17 $CellContext`md2, 
           0.25 $CellContext`md2}, {
          10.16, 0.03263154805501293 $CellContext`md2, 
           0.2478612153434526 $CellContext`md2}, {
          10.16, 0.04350873074001724 $CellContext`md2, 
           0.3304816204579368 $CellContext`md2}, {
          10.16, 0.05438591342502154 $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {
          10.16, 2.5513474982236523`*^-17 $CellContext`md2, 
           0.41666666666666663` $CellContext`md2}, {
          10.16, 2.041077998578922*^-17 $CellContext`md2, 
           0.3333333333333333 $CellContext`md2}, {
          10.16, 0.04350873074001724 $CellContext`md2, 
           0.3304816204579368 $CellContext`md2}, {
          10.16, 0.05438591342502154 $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {
          10.16, 0.06526309611002584 $CellContext`md2, 
           0.49572243068690514` $CellContext`md2}, {
          10.16, 3.0616169978683824`*^-17 $CellContext`md2, 
           0.49999999999999994` $CellContext`md2}, {
          10.16, 2.5513474982236523`*^-17 $CellContext`md2, 
           0.41666666666666663` $CellContext`md2}, {
          10.16, 0.05438591342502154 $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 5.102694996447305*^-18 $CellContext`md2, 
           0.08333333333333333 $CellContext`md2}, {
          10.16, (-0.010877182685004299`) $CellContext`md2, 
           0.0826204051144842 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 5.102694996447305*^-18 $CellContext`md2, 
           0.08333333333333333 $CellContext`md2}, {
          10.16, 1.020538999289461*^-17 $CellContext`md2, 
           0.16666666666666666` $CellContext`md2}, {
          10.16, (-0.021754365370008598`) $CellContext`md2, 
           0.1652408102289684 $CellContext`md2}, {
          10.16, (-0.010877182685004299`) $CellContext`md2, 
           0.0826204051144842 $CellContext`md2}, {
          10.16, 5.102694996447305*^-18 $CellContext`md2, 
           0.08333333333333333 $CellContext`md2}, {
          10.16, 1.020538999289461*^-17 $CellContext`md2, 
           0.16666666666666666` $CellContext`md2}, {
          10.16, 1.5308084989341915`*^-17 $CellContext`md2, 
           0.25 $CellContext`md2}, {
          10.16, (-0.0326315480550129) $CellContext`md2, 
           0.2478612153434526 $CellContext`md2}, {
          10.16, (-0.021754365370008598`) $CellContext`md2, 
           0.1652408102289684 $CellContext`md2}, {
          10.16, 1.020538999289461*^-17 $CellContext`md2, 
           0.16666666666666666` $CellContext`md2}, {
          10.16, 1.5308084989341915`*^-17 $CellContext`md2, 
           0.25 $CellContext`md2}, {
          10.16, 2.041077998578922*^-17 $CellContext`md2, 
           0.3333333333333333 $CellContext`md2}, {
          10.16, (-0.043508730740017196`) $CellContext`md2, 
           0.3304816204579368 $CellContext`md2}, {
          10.16, (-0.0326315480550129) $CellContext`md2, 
           0.2478612153434526 $CellContext`md2}, {
          10.16, 1.5308084989341915`*^-17 $CellContext`md2, 
           0.25 $CellContext`md2}, {
          10.16, 2.041077998578922*^-17 $CellContext`md2, 
           0.3333333333333333 $CellContext`md2}, {
          10.16, 2.5513474982236523`*^-17 $CellContext`md2, 
           0.41666666666666663` $CellContext`md2}, {
          10.16, (-0.0543859134250215) $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {
          10.16, (-0.043508730740017196`) $CellContext`md2, 
           0.3304816204579368 $CellContext`md2}, {
          10.16, 2.041077998578922*^-17 $CellContext`md2, 
           0.3333333333333333 $CellContext`md2}, {
          10.16, 2.5513474982236523`*^-17 $CellContext`md2, 
           0.41666666666666663` $CellContext`md2}, {
          10.16, 3.0616169978683824`*^-17 $CellContext`md2, 
           0.49999999999999994` $CellContext`md2}, {
          10.16, (-0.06526309611002579) $CellContext`md2, 
           0.49572243068690514` $CellContext`md2}, {
          10.16, (-0.0543859134250215) $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {
          10.16, 2.5513474982236523`*^-17 $CellContext`md2, 
           0.41666666666666663` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.010877182685004282`) $CellContext`md2, 
           0.08262040511448421 $CellContext`md2}, {
          10.16, (-0.021568253758543383`) $CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.010877182685004282`) $CellContext`md2, 
           0.08262040511448421 $CellContext`md2}, {
          10.16, (-0.021754365370008563`) $CellContext`md2, 
           0.16524081022896842` $CellContext`md2}, {
          10.16, (-0.04313650751708677) $CellContext`md2, 
           0.1609876377148447 $CellContext`md2}, {
          10.16, (-0.021568253758543383`) $CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {
          10.16, (-0.010877182685004282`) $CellContext`md2, 
           0.08262040511448421 $CellContext`md2}, {
          10.16, (-0.021754365370008563`) $CellContext`md2, 
           0.16524081022896842` $CellContext`md2}, {
          10.16, (-0.032631548055012845`) $CellContext`md2, 
           0.24786121534345262` $CellContext`md2}, {
          10.16, (-0.06470476127563016) $CellContext`md2, 
           0.24148145657226708` $CellContext`md2}, {
          10.16, (-0.04313650751708677) $CellContext`md2, 
           0.1609876377148447 $CellContext`md2}, {
          10.16, (-0.021754365370008563`) $CellContext`md2, 
           0.16524081022896842` $CellContext`md2}, {
          10.16, (-0.032631548055012845`) $CellContext`md2, 
           0.24786121534345262` $CellContext`md2}, {
          10.16, (-0.043508730740017126`) $CellContext`md2, 
           0.33048162045793683` $CellContext`md2}, {
          10.16, (-0.08627301503417353) $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {
          10.16, (-0.06470476127563016) $CellContext`md2, 
           0.24148145657226708` $CellContext`md2}, {
          10.16, (-0.032631548055012845`) $CellContext`md2, 
           0.24786121534345262` $CellContext`md2}, {
          10.16, (-0.043508730740017126`) $CellContext`md2, 
           0.33048162045793683` $CellContext`md2}, {
          10.16, (-0.0543859134250214) $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {
          10.16, (-0.10784126879271692`) $CellContext`md2, 
           0.40246909428711175` $CellContext`md2}, {
          10.16, (-0.08627301503417353) $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {
          10.16, (-0.043508730740017126`) $CellContext`md2, 
           0.33048162045793683` $CellContext`md2}, {
          10.16, (-0.0543859134250214) $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {
          10.16, (-0.06526309611002568) $CellContext`md2, 
           0.4957224306869052 $CellContext`md2}, {
          10.16, (-0.1294095225512603) $CellContext`md2, 
           0.4829629131445341 $CellContext`md2}, {
          10.16, (-0.10784126879271692`) $CellContext`md2, 
           0.40246909428711175` $CellContext`md2}, {
          10.16, (-0.0543859134250214) $CellContext`md2, 
           0.413102025572421 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.021568253758543383`) $CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {
          10.16, (-0.03189028603042414) $CellContext`md2, 
           0.07698996104260722 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.021568253758543383`) $CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {
          10.16, (-0.04313650751708677) $CellContext`md2, 
           0.1609876377148447 $CellContext`md2}, {
          10.16, (-0.06378057206084828) $CellContext`md2, 
           0.15397992208521444` $CellContext`md2}, {
          10.16, (-0.03189028603042414) $CellContext`md2, 
           0.07698996104260722 $CellContext`md2}, {
          10.16, (-0.021568253758543383`) $CellContext`md2, 
           0.08049381885742235 $CellContext`md2}, {
          10.16, (-0.04313650751708677) $CellContext`md2, 
           0.1609876377148447 $CellContext`md2}, {
          10.16, (-0.06470476127563016) $CellContext`md2, 
           0.24148145657226708` $CellContext`md2}, {
          10.16, (-0.09567085809127243) $CellContext`md2, 
           0.23096988312782168` $CellContext`md2}, {
          10.16, (-0.06378057206084828) $CellContext`md2, 
           0.15397992208521444` $CellContext`md2}, {
          10.16, (-0.04313650751708677) $CellContext`md2, 
           0.1609876377148447 $CellContext`md2}, {
          10.16, (-0.06470476127563016) $CellContext`md2, 
           0.24148145657226708` $CellContext`md2}, {
          10.16, (-0.08627301503417353) $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {
          10.16, (-0.12756114412169656`) $CellContext`md2, 
           0.3079598441704289 $CellContext`md2}, {
          10.16, (-0.09567085809127243) $CellContext`md2, 
           0.23096988312782168` $CellContext`md2}, {
          10.16, (-0.06470476127563016) $CellContext`md2, 
           0.24148145657226708` $CellContext`md2}, {
          10.16, (-0.08627301503417353) $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {
          10.16, (-0.10784126879271692`) $CellContext`md2, 
           0.40246909428711175` $CellContext`md2}, {
          10.16, (-0.1594514301521207) $CellContext`md2, 
           0.3849498052130361 $CellContext`md2}, {
          10.16, (-0.12756114412169656`) $CellContext`md2, 
           0.3079598441704289 $CellContext`md2}, {
          10.16, (-0.08627301503417353) $CellContext`md2, 
           0.3219752754296894 $CellContext`md2}, {
          10.16, (-0.10784126879271692`) $CellContext`md2, 
           0.40246909428711175` $CellContext`md2}, {
          10.16, (-0.1294095225512603) $CellContext`md2, 
           0.4829629131445341 $CellContext`md2}, {
          10.16, (-0.19134171618254484`) $CellContext`md2, 
           0.4619397662556433 $CellContext`md2}, {
          10.16, (-0.1594514301521207) $CellContext`md2, 
           0.3849498052130361 $CellContext`md2}, {
          10.16, (-0.10784126879271692`) $CellContext`md2, 
           0.40246909428711175` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.031890286030424125`) $CellContext`md2, 
           0.07698996104260723 $CellContext`md2}, {
          10.16, (-0.041666666666666644`) $CellContext`md2, 
           0.07216878364870323 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.031890286030424125`) $CellContext`md2, 
           0.07698996104260723 $CellContext`md2}, {
          10.16, (-0.06378057206084825) $CellContext`md2, 
           0.15397992208521447` $CellContext`md2}, {
          10.16, (-0.08333333333333329) $CellContext`md2, 
           0.14433756729740646` $CellContext`md2}, {
          10.16, (-0.041666666666666644`) $CellContext`md2, 
           0.07216878364870323 $CellContext`md2}, {
          10.16, (-0.031890286030424125`) $CellContext`md2, 
           0.07698996104260723 $CellContext`md2}, {
          10.16, (-0.06378057206084825) $CellContext`md2, 
           0.15397992208521447` $CellContext`md2}, {
          10.16, (-0.09567085809127238) $CellContext`md2, 
           0.2309698831278217 $CellContext`md2}, {
          10.16, (-0.12499999999999994`) $CellContext`md2, 
           0.2165063509461097 $CellContext`md2}, {
          10.16, (-0.08333333333333329) $CellContext`md2, 
           0.14433756729740646` $CellContext`md2}, {
          10.16, (-0.06378057206084825) $CellContext`md2, 
           0.15397992208521447` $CellContext`md2}, {
          10.16, (-0.09567085809127238) $CellContext`md2, 
           0.2309698831278217 $CellContext`md2}, {
          10.16, (-0.1275611441216965) $CellContext`md2, 
           0.30795984417042893` $CellContext`md2}, {
          10.16, (-0.16666666666666657`) $CellContext`md2, 
           0.2886751345948129 $CellContext`md2}, {
          10.16, (-0.12499999999999994`) $CellContext`md2, 
           0.2165063509461097 $CellContext`md2}, {
          10.16, (-0.09567085809127238) $CellContext`md2, 
           0.2309698831278217 $CellContext`md2}, {
          10.16, (-0.1275611441216965) $CellContext`md2, 
           0.30795984417042893` $CellContext`md2}, {
          10.16, (-0.1594514301521206) $CellContext`md2, 
           0.3849498052130362 $CellContext`md2}, {
          10.16, (-0.20833333333333323`) $CellContext`md2, 
           0.36084391824351614` $CellContext`md2}, {
          10.16, (-0.16666666666666657`) $CellContext`md2, 
           0.2886751345948129 $CellContext`md2}, {
          10.16, (-0.1275611441216965) $CellContext`md2, 
           0.30795984417042893` $CellContext`md2}, {
          10.16, (-0.1594514301521206) $CellContext`md2, 
           0.3849498052130362 $CellContext`md2}, {
          10.16, (-0.19134171618254472`) $CellContext`md2, 
           0.46193976625564337` $CellContext`md2}, {
          10.16, (-0.24999999999999986`) $CellContext`md2, 
           0.43301270189221935` $CellContext`md2}, {
          10.16, (-0.20833333333333323`) $CellContext`md2, 
           0.36084391824351614` $CellContext`md2}, {
          10.16, (-0.1594514301521206) $CellContext`md2, 
           0.3849498052130362 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.041666666666666644`) $CellContext`md2, 
           0.07216878364870323 $CellContext`md2}, {
          10.16, (-0.05073011908406003) $CellContext`md2, 
           0.06611277835760294 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.041666666666666644`) $CellContext`md2, 
           0.07216878364870323 $CellContext`md2}, {
          10.16, (-0.08333333333333329) $CellContext`md2, 
           0.14433756729740646` $CellContext`md2}, {
          10.16, (-0.10146023816812005`) $CellContext`md2, 
           0.1322255567152059 $CellContext`md2}, {
          10.16, (-0.05073011908406003) $CellContext`md2, 
           0.06611277835760294 $CellContext`md2}, {
          10.16, (-0.041666666666666644`) $CellContext`md2, 
           0.07216878364870323 $CellContext`md2}, {
          10.16, (-0.08333333333333329) $CellContext`md2, 
           0.14433756729740646` $CellContext`md2}, {
          10.16, (-0.12499999999999994`) $CellContext`md2, 
           0.2165063509461097 $CellContext`md2}, {
          10.16, (-0.15219035725218008`) $CellContext`md2, 
           0.19833833507280885` $CellContext`md2}, {
          10.16, (-0.10146023816812005`) $CellContext`md2, 
           0.1322255567152059 $CellContext`md2}, {
          10.16, (-0.08333333333333329) $CellContext`md2, 
           0.14433756729740646` $CellContext`md2}, {
          10.16, (-0.12499999999999994`) $CellContext`md2, 
           0.2165063509461097 $CellContext`md2}, {
          10.16, (-0.16666666666666657`) $CellContext`md2, 
           0.2886751345948129 $CellContext`md2}, {
          10.16, (-0.2029204763362401) $CellContext`md2, 
           0.2644511134304118 $CellContext`md2}, {
          10.16, (-0.15219035725218008`) $CellContext`md2, 
           0.19833833507280885` $CellContext`md2}, {
          10.16, (-0.12499999999999994`) $CellContext`md2, 
           0.2165063509461097 $CellContext`md2}, {
          10.16, (-0.16666666666666657`) $CellContext`md2, 
           0.2886751345948129 $CellContext`md2}, {
          10.16, (-0.20833333333333323`) $CellContext`md2, 
           0.36084391824351614` $CellContext`md2}, {
          10.16, (-0.2536505954203001) $CellContext`md2, 
           0.3305638917880147 $CellContext`md2}, {
          10.16, (-0.2029204763362401) $CellContext`md2, 
           0.2644511134304118 $CellContext`md2}, {
          10.16, (-0.16666666666666657`) $CellContext`md2, 
           0.2886751345948129 $CellContext`md2}, {
          10.16, (-0.20833333333333323`) $CellContext`md2, 
           0.36084391824351614` $CellContext`md2}, {
          10.16, (-0.24999999999999986`) $CellContext`md2, 
           0.43301270189221935` $CellContext`md2}, {
          10.16, (-0.3043807145043601) $CellContext`md2, 
           0.39667667014561764` $CellContext`md2}, {
          10.16, (-0.2536505954203001) $CellContext`md2, 
           0.3305638917880147 $CellContext`md2}, {
          10.16, (-0.20833333333333323`) $CellContext`md2, 
           0.36084391824351614` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.05073011908406003) $CellContext`md2, 
           0.06611277835760294 $CellContext`md2}, {
          10.16, (-0.058925565098878925`) $CellContext`md2, 
           0.05892556509887899 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.05073011908406003) $CellContext`md2, 
           0.06611277835760294 $CellContext`md2}, {
          10.16, (-0.10146023816812005`) $CellContext`md2, 
           0.1322255567152059 $CellContext`md2}, {
          10.16, (-0.11785113019775785`) $CellContext`md2, 
           0.11785113019775798` $CellContext`md2}, {
          10.16, (-0.058925565098878925`) $CellContext`md2, 
           0.05892556509887899 $CellContext`md2}, {
          10.16, (-0.05073011908406003) $CellContext`md2, 
           0.06611277835760294 $CellContext`md2}, {
          10.16, (-0.10146023816812005`) $CellContext`md2, 
           0.1322255567152059 $CellContext`md2}, {
          10.16, (-0.15219035725218008`) $CellContext`md2, 
           0.19833833507280885` $CellContext`md2}, {
          10.16, (-0.17677669529663678`) $CellContext`md2, 
           0.17677669529663698` $CellContext`md2}, {
          10.16, (-0.11785113019775785`) $CellContext`md2, 
           0.11785113019775798` $CellContext`md2}, {
          10.16, (-0.10146023816812005`) $CellContext`md2, 
           0.1322255567152059 $CellContext`md2}, {
          10.16, (-0.15219035725218008`) $CellContext`md2, 
           0.19833833507280885` $CellContext`md2}, {
          10.16, (-0.2029204763362401) $CellContext`md2, 
           0.2644511134304118 $CellContext`md2}, {
          10.16, (-0.2357022603955157) $CellContext`md2, 
           0.23570226039551595` $CellContext`md2}, {
          10.16, (-0.17677669529663678`) $CellContext`md2, 
           0.17677669529663698` $CellContext`md2}, {
          10.16, (-0.15219035725218008`) $CellContext`md2, 
           0.19833833507280885` $CellContext`md2}, {
          10.16, (-0.2029204763362401) $CellContext`md2, 
           0.2644511134304118 $CellContext`md2}, {
          10.16, (-0.2536505954203001) $CellContext`md2, 
           0.3305638917880147 $CellContext`md2}, {
          10.16, (-0.2946278254943946) $CellContext`md2, 
           0.2946278254943949 $CellContext`md2}, {
          10.16, (-0.2357022603955157) $CellContext`md2, 
           0.23570226039551595` $CellContext`md2}, {
          10.16, (-0.2029204763362401) $CellContext`md2, 
           0.2644511134304118 $CellContext`md2}, {
          10.16, (-0.2536505954203001) $CellContext`md2, 
           0.3305638917880147 $CellContext`md2}, {
          10.16, (-0.3043807145043601) $CellContext`md2, 
           0.39667667014561764` $CellContext`md2}, {
          10.16, (-0.3535533905932735) $CellContext`md2, 
           0.3535533905932739 $CellContext`md2}, {
          10.16, (-0.2946278254943946) $CellContext`md2, 
           0.2946278254943949 $CellContext`md2}, {
          10.16, (-0.2536505954203001) $CellContext`md2, 
           0.3305638917880147 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.05892556509887895) $CellContext`md2, 
           0.05892556509887896 $CellContext`md2}, {
          10.16, (-0.0661127783576029) $CellContext`md2, 
           0.05073011908406007 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.05892556509887895) $CellContext`md2, 
           0.05892556509887896 $CellContext`md2}, {
          10.16, (-0.1178511301977579) $CellContext`md2, 
           0.11785113019775792` $CellContext`md2}, {
          10.16, (-0.1322255567152058) $CellContext`md2, 
           0.10146023816812014` $CellContext`md2}, {
          10.16, (-0.0661127783576029) $CellContext`md2, 
           0.05073011908406007 $CellContext`md2}, {
          10.16, (-0.05892556509887895) $CellContext`md2, 
           0.05892556509887896 $CellContext`md2}, {
          10.16, (-0.1178511301977579) $CellContext`md2, 
           0.11785113019775792` $CellContext`md2}, {
          10.16, (-0.17677669529663687`) $CellContext`md2, 
           0.1767766952966369 $CellContext`md2}, {
          10.16, (-0.19833833507280874`) $CellContext`md2, 
           0.15219035725218022` $CellContext`md2}, {
          10.16, (-0.1322255567152058) $CellContext`md2, 
           0.10146023816812014` $CellContext`md2}, {
          10.16, (-0.1178511301977579) $CellContext`md2, 
           0.11785113019775792` $CellContext`md2}, {
          10.16, (-0.17677669529663687`) $CellContext`md2, 
           0.1767766952966369 $CellContext`md2}, {
          10.16, (-0.2357022603955158) $CellContext`md2, 
           0.23570226039551584` $CellContext`md2}, {
          10.16, (-0.2644511134304116) $CellContext`md2, 
           0.20292047633624027` $CellContext`md2}, {
          10.16, (-0.19833833507280874`) $CellContext`md2, 
           0.15219035725218022` $CellContext`md2}, {
          10.16, (-0.17677669529663687`) $CellContext`md2, 
           0.1767766952966369 $CellContext`md2}, {
          10.16, (-0.2357022603955158) $CellContext`md2, 
           0.23570226039551584` $CellContext`md2}, {
          10.16, (-0.29462782549439476`) $CellContext`md2, 
           0.2946278254943948 $CellContext`md2}, {
          10.16, (-0.33056389178801454`) $CellContext`md2, 
           0.25365059542030033` $CellContext`md2}, {
          10.16, (-0.2644511134304116) $CellContext`md2, 
           0.20292047633624027` $CellContext`md2}, {
          10.16, (-0.2357022603955158) $CellContext`md2, 
           0.23570226039551584` $CellContext`md2}, {
          10.16, (-0.29462782549439476`) $CellContext`md2, 
           0.2946278254943948 $CellContext`md2}, {
          10.16, (-0.3535533905932737) $CellContext`md2, 
           0.35355339059327373` $CellContext`md2}, {
          10.16, (-0.3966766701456174) $CellContext`md2, 
           0.3043807145043604 $CellContext`md2}, {
          10.16, (-0.33056389178801454`) $CellContext`md2, 
           0.25365059542030033` $CellContext`md2}, {
          10.16, (-0.29462782549439476`) $CellContext`md2, 
           0.2946278254943948 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.0661127783576029) $CellContext`md2, 
           0.05073011908406007 $CellContext`md2}, {
          10.16, (-0.0721687836487032) $CellContext`md2, 
           0.04166666666666669 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.0661127783576029) $CellContext`md2, 
           0.05073011908406007 $CellContext`md2}, {
          10.16, (-0.1322255567152058) $CellContext`md2, 
           0.10146023816812014` $CellContext`md2}, {
          10.16, (-0.1443375672974064) $CellContext`md2, 
           0.08333333333333338 $CellContext`md2}, {
          10.16, (-0.0721687836487032) $CellContext`md2, 
           0.04166666666666669 $CellContext`md2}, {
          10.16, (-0.0661127783576029) $CellContext`md2, 
           0.05073011908406007 $CellContext`md2}, {
          10.16, (-0.1322255567152058) $CellContext`md2, 
           0.10146023816812014` $CellContext`md2}, {
          10.16, (-0.19833833507280874`) $CellContext`md2, 
           0.15219035725218022` $CellContext`md2}, {
          10.16, (-0.21650635094610962`) $CellContext`md2, 
           0.12500000000000008` $CellContext`md2}, {
          10.16, (-0.1443375672974064) $CellContext`md2, 
           0.08333333333333338 $CellContext`md2}, {
          10.16, (-0.1322255567152058) $CellContext`md2, 
           0.10146023816812014` $CellContext`md2}, {
          10.16, (-0.19833833507280874`) $CellContext`md2, 
           0.15219035725218022` $CellContext`md2}, {
          10.16, (-0.2644511134304116) $CellContext`md2, 
           0.20292047633624027` $CellContext`md2}, {
          10.16, (-0.2886751345948128) $CellContext`md2, 
           0.16666666666666677` $CellContext`md2}, {
          10.16, (-0.21650635094610962`) $CellContext`md2, 
           0.12500000000000008` $CellContext`md2}, {
          10.16, (-0.19833833507280874`) $CellContext`md2, 
           0.15219035725218022` $CellContext`md2}, {
          10.16, (-0.2644511134304116) $CellContext`md2, 
           0.20292047633624027` $CellContext`md2}, {
          10.16, (-0.33056389178801454`) $CellContext`md2, 
           0.25365059542030033` $CellContext`md2}, {
          10.16, (-0.360843918243516) $CellContext`md2, 
           0.20833333333333345` $CellContext`md2}, {
          10.16, (-0.2886751345948128) $CellContext`md2, 
           0.16666666666666677` $CellContext`md2}, {
          10.16, (-0.2644511134304116) $CellContext`md2, 
           0.20292047633624027` $CellContext`md2}, {
          10.16, (-0.33056389178801454`) $CellContext`md2, 
           0.25365059542030033` $CellContext`md2}, {
          10.16, (-0.3966766701456174) $CellContext`md2, 
           0.3043807145043604 $CellContext`md2}, {
          10.16, (-0.4330127018922192) $CellContext`md2, 
           0.2500000000000001 $CellContext`md2}, {
          10.16, (-0.360843918243516) $CellContext`md2, 
           0.20833333333333345` $CellContext`md2}, {
          10.16, (-0.33056389178801454`) $CellContext`md2, 
           0.25365059542030033` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.0721687836487032) $CellContext`md2, 
           0.04166666666666669 $CellContext`md2}, {
          10.16, (-0.0769899610426072) $CellContext`md2, 
           0.03189028603042419 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.0721687836487032) $CellContext`md2, 
           0.04166666666666669 $CellContext`md2}, {
          10.16, (-0.1443375672974064) $CellContext`md2, 
           0.08333333333333338 $CellContext`md2}, {
          10.16, (-0.1539799220852144) $CellContext`md2, 
           0.06378057206084838 $CellContext`md2}, {
          10.16, (-0.0769899610426072) $CellContext`md2, 
           0.03189028603042419 $CellContext`md2}, {
          10.16, (-0.0721687836487032) $CellContext`md2, 
           0.04166666666666669 $CellContext`md2}, {
          10.16, (-0.1443375672974064) $CellContext`md2, 
           0.08333333333333338 $CellContext`md2}, {
          10.16, (-0.21650635094610962`) $CellContext`md2, 
           0.12500000000000008` $CellContext`md2}, {
          10.16, (-0.23096988312782163`) $CellContext`md2, 
           0.09567085809127257 $CellContext`md2}, {
          10.16, (-0.1539799220852144) $CellContext`md2, 
           0.06378057206084838 $CellContext`md2}, {
          10.16, (-0.1443375672974064) $CellContext`md2, 
           0.08333333333333338 $CellContext`md2}, {
          10.16, (-0.21650635094610962`) $CellContext`md2, 
           0.12500000000000008` $CellContext`md2}, {
          10.16, (-0.2886751345948128) $CellContext`md2, 
           0.16666666666666677` $CellContext`md2}, {
          10.16, (-0.3079598441704288) $CellContext`md2, 
           0.12756114412169675` $CellContext`md2}, {
          10.16, (-0.23096988312782163`) $CellContext`md2, 
           0.09567085809127257 $CellContext`md2}, {
          10.16, (-0.21650635094610962`) $CellContext`md2, 
           0.12500000000000008` $CellContext`md2}, {
          10.16, (-0.2886751345948128) $CellContext`md2, 
           0.16666666666666677` $CellContext`md2}, {
          10.16, (-0.360843918243516) $CellContext`md2, 
           0.20833333333333345` $CellContext`md2}, {
          10.16, (-0.384949805213036) $CellContext`md2, 
           0.15945143015212093` $CellContext`md2}, {
          10.16, (-0.3079598441704288) $CellContext`md2, 
           0.12756114412169675` $CellContext`md2}, {
          10.16, (-0.2886751345948128) $CellContext`md2, 
           0.16666666666666677` $CellContext`md2}, {
          10.16, (-0.360843918243516) $CellContext`md2, 
           0.20833333333333345` $CellContext`md2}, {
          10.16, (-0.4330127018922192) $CellContext`md2, 
           0.2500000000000001 $CellContext`md2}, {
          10.16, (-0.4619397662556432) $CellContext`md2, 
           0.1913417161825451 $CellContext`md2}, {
          10.16, (-0.384949805213036) $CellContext`md2, 
           0.15945143015212093` $CellContext`md2}, {
          10.16, (-0.360843918243516) $CellContext`md2, 
           0.20833333333333345` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.07698996104260722) $CellContext`md2, 
           0.03189028603042415 $CellContext`md2}, {
          10.16, (-0.08049381885742235) $CellContext`md2, 
           0.021568253758543418` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.07698996104260722) $CellContext`md2, 
           0.03189028603042415 $CellContext`md2}, {
          10.16, (-0.15397992208521444`) $CellContext`md2, 
           0.0637805720608483 $CellContext`md2}, {
          10.16, (-0.1609876377148447) $CellContext`md2, 
           0.043136507517086836` $CellContext`md2}, {
          10.16, (-0.08049381885742235) $CellContext`md2, 
           0.021568253758543418` $CellContext`md2}, {
          10.16, (-0.07698996104260722) $CellContext`md2, 
           0.03189028603042415 $CellContext`md2}, {
          10.16, (-0.15397992208521444`) $CellContext`md2, 
           0.0637805720608483 $CellContext`md2}, {
          10.16, (-0.23096988312782168`) $CellContext`md2, 
           0.09567085809127246 $CellContext`md2}, {
          10.16, (-0.24148145657226705`) $CellContext`md2, 
           0.06470476127563025 $CellContext`md2}, {
          10.16, (-0.1609876377148447) $CellContext`md2, 
           0.043136507517086836` $CellContext`md2}, {
          10.16, (-0.15397992208521444`) $CellContext`md2, 
           0.0637805720608483 $CellContext`md2}, {
          10.16, (-0.23096988312782168`) $CellContext`md2, 
           0.09567085809127246 $CellContext`md2}, {
          10.16, (-0.3079598441704289) $CellContext`md2, 
           0.1275611441216966 $CellContext`md2}, {
          10.16, (-0.3219752754296894) $CellContext`md2, 
           0.08627301503417367 $CellContext`md2}, {
          10.16, (-0.24148145657226705`) $CellContext`md2, 
           0.06470476127563025 $CellContext`md2}, {
          10.16, (-0.23096988312782168`) $CellContext`md2, 
           0.09567085809127246 $CellContext`md2}, {
          10.16, (-0.3079598441704289) $CellContext`md2, 
           0.1275611441216966 $CellContext`md2}, {
          10.16, (-0.3849498052130361) $CellContext`md2, 
           0.15945143015212074` $CellContext`md2}, {
          10.16, (-0.4024690942871117) $CellContext`md2, 
           0.10784126879271708` $CellContext`md2}, {
          10.16, (-0.3219752754296894) $CellContext`md2, 
           0.08627301503417367 $CellContext`md2}, {
          10.16, (-0.3079598441704289) $CellContext`md2, 
           0.1275611441216966 $CellContext`md2}, {
          10.16, (-0.3849498052130361) $CellContext`md2, 
           0.15945143015212074` $CellContext`md2}, {
          10.16, (-0.4619397662556433) $CellContext`md2, 
           0.1913417161825449 $CellContext`md2}, {
          10.16, (-0.48296291314453405`) $CellContext`md2, 
           0.12940952255126048` $CellContext`md2}, {
          10.16, (-0.4024690942871117) $CellContext`md2, 
           0.10784126879271708` $CellContext`md2}, {
          10.16, (-0.3849498052130361) $CellContext`md2, 
           0.15945143015212074` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.08049381885742235) $CellContext`md2, 
           0.021568253758543418` $CellContext`md2}, {
          10.16, (-0.0826204051144842) $CellContext`md2, 
           0.010877182685004332` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.08049381885742235) $CellContext`md2, 
           0.021568253758543418` $CellContext`md2}, {
          10.16, (-0.1609876377148447) $CellContext`md2, 
           0.043136507517086836` $CellContext`md2}, {
          10.16, (-0.1652408102289684) $CellContext`md2, 
           0.021754365370008664` $CellContext`md2}, {
          10.16, (-0.0826204051144842) $CellContext`md2, 
           0.010877182685004332` $CellContext`md2}, {
          10.16, (-0.08049381885742235) $CellContext`md2, 
           0.021568253758543418` $CellContext`md2}, {
          10.16, (-0.1609876377148447) $CellContext`md2, 
           0.043136507517086836` $CellContext`md2}, {
          10.16, (-0.24148145657226705`) $CellContext`md2, 
           0.06470476127563025 $CellContext`md2}, {
          10.16, (-0.2478612153434526) $CellContext`md2, 
           0.032631548055013 $CellContext`md2}, {
          10.16, (-0.1652408102289684) $CellContext`md2, 
           0.021754365370008664` $CellContext`md2}, {
          10.16, (-0.1609876377148447) $CellContext`md2, 
           0.043136507517086836` $CellContext`md2}, {
          10.16, (-0.24148145657226705`) $CellContext`md2, 
           0.06470476127563025 $CellContext`md2}, {
          10.16, (-0.3219752754296894) $CellContext`md2, 
           0.08627301503417367 $CellContext`md2}, {
          10.16, (-0.3304816204579368) $CellContext`md2, 
           0.04350873074001733 $CellContext`md2}, {
          10.16, (-0.2478612153434526) $CellContext`md2, 
           0.032631548055013 $CellContext`md2}, {
          10.16, (-0.24148145657226705`) $CellContext`md2, 
           0.06470476127563025 $CellContext`md2}, {
          10.16, (-0.3219752754296894) $CellContext`md2, 
           0.08627301503417367 $CellContext`md2}, {
          10.16, (-0.4024690942871117) $CellContext`md2, 
           0.10784126879271708` $CellContext`md2}, {
          10.16, (-0.413102025572421) $CellContext`md2, 
           0.05438591342502166 $CellContext`md2}, {
          10.16, (-0.3304816204579368) $CellContext`md2, 
           0.04350873074001733 $CellContext`md2}, {
          10.16, (-0.3219752754296894) $CellContext`md2, 
           0.08627301503417367 $CellContext`md2}, {
          10.16, (-0.4024690942871117) $CellContext`md2, 
           0.10784126879271708` $CellContext`md2}, {
          10.16, (-0.48296291314453405`) $CellContext`md2, 
           0.12940952255126048` $CellContext`md2}, {
          10.16, (-0.49572243068690514`) $CellContext`md2, 
           0.06526309611002598 $CellContext`md2}, {
          10.16, (-0.413102025572421) $CellContext`md2, 
           0.05438591342502166 $CellContext`md2}, {
          10.16, (-0.4024690942871117) $CellContext`md2, 
           0.10784126879271708` $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.0826204051144842) $CellContext`md2, 
           0.010877182685004332` $CellContext`md2}, {
          10.16, (-0.08333333333333333) $CellContext`md2, 
           4.7212824147066497`*^-17 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.0826204051144842) $CellContext`md2, 
           0.010877182685004332` $CellContext`md2}, {
          10.16, (-0.1652408102289684) $CellContext`md2, 
           0.021754365370008664` $CellContext`md2}, {
          10.16, (-0.16666666666666666`) $CellContext`md2, 
           9.442564829413299*^-17 $CellContext`md2}, {
          10.16, (-0.08333333333333333) $CellContext`md2, 
           4.7212824147066497`*^-17 $CellContext`md2}, {
          10.16, (-0.0826204051144842) $CellContext`md2, 
           0.010877182685004332` $CellContext`md2}, {
          10.16, (-0.1652408102289684) $CellContext`md2, 
           0.021754365370008664` $CellContext`md2}, {
          10.16, (-0.2478612153434526) $CellContext`md2, 
           0.032631548055013 $CellContext`md2}, {
          10.16, (-0.25) $CellContext`md2, 
           1.416384724411995*^-16 $CellContext`md2}, {
          10.16, (-0.16666666666666666`) $CellContext`md2, 
           9.442564829413299*^-17 $CellContext`md2}, {
          10.16, (-0.1652408102289684) $CellContext`md2, 
           0.021754365370008664` $CellContext`md2}, {
          10.16, (-0.2478612153434526) $CellContext`md2, 
           0.032631548055013 $CellContext`md2}, {
          10.16, (-0.3304816204579368) $CellContext`md2, 
           0.04350873074001733 $CellContext`md2}, {
          10.16, (-0.3333333333333333) $CellContext`md2, 
           1.8885129658826599`*^-16 $CellContext`md2}, {
          10.16, (-0.25) $CellContext`md2, 
           1.416384724411995*^-16 $CellContext`md2}, {
          10.16, (-0.2478612153434526) $CellContext`md2, 
           0.032631548055013 $CellContext`md2}, {
          10.16, (-0.3304816204579368) $CellContext`md2, 
           0.04350873074001733 $CellContext`md2}, {
          10.16, (-0.413102025572421) $CellContext`md2, 
           0.05438591342502166 $CellContext`md2}, {
          10.16, (-0.41666666666666663`) $CellContext`md2, 
           2.360641207353325*^-16 $CellContext`md2}, {
          10.16, (-0.3333333333333333) $CellContext`md2, 
           1.8885129658826599`*^-16 $CellContext`md2}, {
          10.16, (-0.3304816204579368) $CellContext`md2, 
           0.04350873074001733 $CellContext`md2}, {
          10.16, (-0.413102025572421) $CellContext`md2, 
           0.05438591342502166 $CellContext`md2}, {
          10.16, (-0.49572243068690514`) $CellContext`md2, 
           0.06526309611002598 $CellContext`md2}, {
          10.16, (-0.49999999999999994`) $CellContext`md2, 
           2.8327694488239893`*^-16 $CellContext`md2}, {
          10.16, (-0.41666666666666663`) $CellContext`md2, 
           2.360641207353325*^-16 $CellContext`md2}, {
          10.16, (-0.413102025572421) $CellContext`md2, 
           0.05438591342502166 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.08333333333333333) $CellContext`md2, 
           1.020538999289461*^-17 $CellContext`md2}, {
          10.16, (-0.08262040511448421) $CellContext`md2, \
(-0.010877182685004276`) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.08333333333333333) $CellContext`md2, 
           1.020538999289461*^-17 $CellContext`md2}, {
          10.16, (-0.16666666666666666`) $CellContext`md2, 
           2.041077998578922*^-17 $CellContext`md2}, {
          10.16, (-0.16524081022896842`) $CellContext`md2, \
(-0.021754365370008553`) $CellContext`md2}, {
          10.16, (-0.08262040511448421) $CellContext`md2, \
(-0.010877182685004276`) $CellContext`md2}, {
          10.16, (-0.08333333333333333) $CellContext`md2, 
           1.020538999289461*^-17 $CellContext`md2}, {
          10.16, (-0.16666666666666666`) $CellContext`md2, 
           2.041077998578922*^-17 $CellContext`md2}, {
          10.16, (-0.25) $CellContext`md2, 
           3.061616997868383*^-17 $CellContext`md2}, {
          10.16, (-0.24786121534345262`) $CellContext`md2, \
(-0.03263154805501283) $CellContext`md2}, {
          10.16, (-0.16524081022896842`) $CellContext`md2, \
(-0.021754365370008553`) $CellContext`md2}, {
          10.16, (-0.16666666666666666`) $CellContext`md2, 
           2.041077998578922*^-17 $CellContext`md2}, {
          10.16, (-0.25) $CellContext`md2, 
           3.061616997868383*^-17 $CellContext`md2}, {
          10.16, (-0.3333333333333333) $CellContext`md2, 
           4.082155997157844*^-17 $CellContext`md2}, {
          10.16, (-0.33048162045793683`) $CellContext`md2, \
(-0.043508730740017106`) $CellContext`md2}, {
          10.16, (-0.24786121534345262`) $CellContext`md2, \
(-0.03263154805501283) $CellContext`md2}, {
          10.16, (-0.25) $CellContext`md2, 
           3.061616997868383*^-17 $CellContext`md2}, {
          10.16, (-0.3333333333333333) $CellContext`md2, 
           4.082155997157844*^-17 $CellContext`md2}, {
          10.16, (-0.41666666666666663`) $CellContext`md2, 
           5.1026949964473046`*^-17 $CellContext`md2}, {
          10.16, (-0.413102025572421) $CellContext`md2, \
(-0.05438591342502138) $CellContext`md2}, {
          10.16, (-0.33048162045793683`) $CellContext`md2, \
(-0.043508730740017106`) $CellContext`md2}, {
          10.16, (-0.3333333333333333) $CellContext`md2, 
           4.082155997157844*^-17 $CellContext`md2}, {
          10.16, (-0.41666666666666663`) $CellContext`md2, 
           5.1026949964473046`*^-17 $CellContext`md2}, {
          10.16, (-0.49999999999999994`) $CellContext`md2, 
           6.123233995736765*^-17 $CellContext`md2}, {
          10.16, (-0.4957224306869052) $CellContext`md2, \
(-0.06526309611002565) $CellContext`md2}, {
          10.16, (-0.413102025572421) $CellContext`md2, \
(-0.05438591342502138) $CellContext`md2}, {
          10.16, (-0.41666666666666663`) $CellContext`md2, 
           5.1026949964473046`*^-17 $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.08262040511448421) $CellContext`md2, \
(-0.010877182685004276`) $CellContext`md2}, {
          10.16, (-0.08049381885742236) $CellContext`md2, \
(-0.021568253758543363`) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.08262040511448421) $CellContext`md2, \
(-0.010877182685004276`) $CellContext`md2}, {
          10.16, (-0.16524081022896842`) $CellContext`md2, \
(-0.021754365370008553`) $CellContext`md2}, {
          10.16, (-0.16098763771484473`) $CellContext`md2, \
(-0.043136507517086725`) $CellContext`md2}, {
          10.16, (-0.08049381885742236) $CellContext`md2, \
(-0.021568253758543363`) $CellContext`md2}, {
          10.16, (-0.08262040511448421) $CellContext`md2, \
(-0.010877182685004276`) $CellContext`md2}, {
          10.16, (-0.16524081022896842`) $CellContext`md2, \
(-0.021754365370008553`) $CellContext`md2}, {
          10.16, (-0.24786121534345262`) $CellContext`md2, \
(-0.03263154805501283) $CellContext`md2}, {
          10.16, (-0.2414814565722671) $CellContext`md2, \
(-0.06470476127563009) $CellContext`md2}, {
          10.16, (-0.16098763771484473`) $CellContext`md2, \
(-0.043136507517086725`) $CellContext`md2}, {
          10.16, (-0.16524081022896842`) $CellContext`md2, \
(-0.021754365370008553`) $CellContext`md2}, {
          10.16, (-0.24786121534345262`) $CellContext`md2, \
(-0.03263154805501283) $CellContext`md2}, {
          10.16, (-0.33048162045793683`) $CellContext`md2, \
(-0.043508730740017106`) $CellContext`md2}, {
          10.16, (-0.32197527542968946`) $CellContext`md2, \
(-0.08627301503417345) $CellContext`md2}, {
          10.16, (-0.2414814565722671) $CellContext`md2, \
(-0.06470476127563009) $CellContext`md2}, {
          10.16, (-0.24786121534345262`) $CellContext`md2, \
(-0.03263154805501283) $CellContext`md2}, {
          10.16, (-0.33048162045793683`) $CellContext`md2, \
(-0.043508730740017106`) $CellContext`md2}, {
          
          10.16, (-0.413102025572421) $CellContext`md2, \
(-0.05438591342502138) $CellContext`md2}, {
          10.16, (-0.4024690942871118) $CellContext`md2, \
(-0.1078412687927168) $CellContext`md2}, {
          10.16, (-0.32197527542968946`) $CellContext`md2, \
(-0.08627301503417345) $CellContext`md2}, {
          10.16, (-0.33048162045793683`) $CellContext`md2, \
(-0.043508730740017106`) $CellContext`md2}, {
          10.16, (-0.413102025572421) $CellContext`md2, \
(-0.05438591342502138) $CellContext`md2}, {
          10.16, (-0.4957224306869052) $CellContext`md2, \
(-0.06526309611002565) $CellContext`md2}, {
          10.16, (-0.48296291314453416`) $CellContext`md2, \
(-0.12940952255126015`) $CellContext`md2}, {
          10.16, (-0.4024690942871118) $CellContext`md2, \
(-0.1078412687927168) $CellContext`md2}, {
          10.16, (-0.413102025572421) $CellContext`md2, \
(-0.05438591342502138) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.08049381885742236) $CellContext`md2, \
(-0.021568253758543363`) $CellContext`md2}, {
          10.16, (-0.07698996104260725) $CellContext`md2, \
(-0.0318902860304241) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.08049381885742236) $CellContext`md2, \
(-0.021568253758543363`) $CellContext`md2}, {
          10.16, (-0.16098763771484473`) $CellContext`md2, \
(-0.043136507517086725`) $CellContext`md2}, {
          10.16, (-0.1539799220852145) $CellContext`md2, \
(-0.0637805720608482) $CellContext`md2}, {
          10.16, (-0.07698996104260725) $CellContext`md2, \
(-0.0318902860304241) $CellContext`md2}, {
          10.16, (-0.08049381885742236) $CellContext`md2, \
(-0.021568253758543363`) $CellContext`md2}, {
          10.16, (-0.16098763771484473`) $CellContext`md2, \
(-0.043136507517086725`) $CellContext`md2}, {
          10.16, (-0.2414814565722671) $CellContext`md2, \
(-0.06470476127563009) $CellContext`md2}, {
          10.16, (-0.23096988312782174`) $CellContext`md2, \
(-0.0956708580912723) $CellContext`md2}, {
          10.16, (-0.1539799220852145) $CellContext`md2, \
(-0.0637805720608482) $CellContext`md2}, {
          10.16, (-0.16098763771484473`) $CellContext`md2, \
(-0.043136507517086725`) $CellContext`md2}, {
          10.16, (-0.2414814565722671) $CellContext`md2, \
(-0.06470476127563009) $CellContext`md2}, {
          10.16, (-0.32197527542968946`) $CellContext`md2, \
(-0.08627301503417345) $CellContext`md2}, {
          10.16, (-0.307959844170429) $CellContext`md2, (-0.1275611441216964) \
$CellContext`md2}, {
          10.16, (-0.23096988312782174`) $CellContext`md2, \
(-0.0956708580912723) $CellContext`md2}, {
          10.16, (-0.2414814565722671) $CellContext`md2, \
(-0.06470476127563009) $CellContext`md2}, {
          10.16, (-0.32197527542968946`) $CellContext`md2, \
(-0.08627301503417345) $CellContext`md2}, {
          10.16, (-0.4024690942871118) $CellContext`md2, \
(-0.1078412687927168) $CellContext`md2}, {
          10.16, (-0.3849498052130362) $CellContext`md2, \
(-0.1594514301521205) $CellContext`md2}, {
          10.16, (-0.307959844170429) $CellContext`md2, (-0.1275611441216964) \
$CellContext`md2}, {
          10.16, (-0.32197527542968946`) $CellContext`md2, \
(-0.08627301503417345) $CellContext`md2}, {
          10.16, (-0.4024690942871118) $CellContext`md2, \
(-0.1078412687927168) $CellContext`md2}, {
          10.16, (-0.48296291314453416`) $CellContext`md2, \
(-0.12940952255126015`) $CellContext`md2}, {
          10.16, (-0.4619397662556434) $CellContext`md2, \
(-0.19134171618254459`) $CellContext`md2}, {
          10.16, (-0.3849498052130362) $CellContext`md2, \
(-0.1594514301521205) $CellContext`md2}, {
          10.16, (-0.4024690942871118) $CellContext`md2, \
(-0.1078412687927168) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.07698996104260725) $CellContext`md2, \
(-0.0318902860304241) $CellContext`md2}, {
          10.16, (-0.07216878364870324) $CellContext`md2, \
(-0.041666666666666616`) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.07698996104260725) $CellContext`md2, \
(-0.0318902860304241) $CellContext`md2}, {
          10.16, (-0.1539799220852145) $CellContext`md2, \
(-0.0637805720608482) $CellContext`md2}, {
          10.16, (-0.1443375672974065) $CellContext`md2, \
(-0.08333333333333323) $CellContext`md2}, {
          10.16, (-0.07216878364870324) $CellContext`md2, \
(-0.041666666666666616`) $CellContext`md2}, {
          10.16, (-0.07698996104260725) $CellContext`md2, \
(-0.0318902860304241) $CellContext`md2}, {
          10.16, (-0.1539799220852145) $CellContext`md2, \
(-0.0637805720608482) $CellContext`md2}, {
          10.16, (-0.23096988312782174`) $CellContext`md2, \
(-0.0956708580912723) $CellContext`md2}, {
          10.16, (-0.21650635094610976`) $CellContext`md2, \
(-0.12499999999999985`) $CellContext`md2}, {
          10.16, (-0.1443375672974065) $CellContext`md2, \
(-0.08333333333333323) $CellContext`md2}, {
          10.16, (-0.1539799220852145) $CellContext`md2, \
(-0.0637805720608482) $CellContext`md2}, {
          10.16, (-0.23096988312782174`) $CellContext`md2, \
(-0.0956708580912723) $CellContext`md2}, {
          10.16, (-0.307959844170429) $CellContext`md2, (-0.1275611441216964) \
$CellContext`md2}, {
          10.16, (-0.288675134594813) $CellContext`md2, \
(-0.16666666666666646`) $CellContext`md2}, {
          10.16, (-0.21650635094610976`) $CellContext`md2, \
(-0.12499999999999985`) $CellContext`md2}, {
          10.16, (-0.23096988312782174`) $CellContext`md2, \
(-0.0956708580912723) $CellContext`md2}, {
          10.16, (-0.307959844170429) $CellContext`md2, (-0.1275611441216964) \
$CellContext`md2}, {
          10.16, (-0.3849498052130362) $CellContext`md2, \
(-0.1594514301521205) $CellContext`md2}, {
          10.16, (-0.36084391824351625`) $CellContext`md2, \
(-0.20833333333333307`) $CellContext`md2}, {
          10.16, (-0.288675134594813) $CellContext`md2, \
(-0.16666666666666646`) $CellContext`md2}, {
          10.16, (-0.307959844170429) $CellContext`md2, (-0.1275611441216964) \
$CellContext`md2}, {
          
          10.16, (-0.3849498052130362) $CellContext`md2, \
(-0.1594514301521205) $CellContext`md2}, {
          10.16, (-0.4619397662556434) $CellContext`md2, \
(-0.19134171618254459`) $CellContext`md2}, {
          10.16, (-0.43301270189221946`) $CellContext`md2, \
(-0.24999999999999967`) $CellContext`md2}, {
          10.16, (-0.36084391824351625`) $CellContext`md2, \
(-0.20833333333333307`) $CellContext`md2}, {
          10.16, (-0.3849498052130362) $CellContext`md2, \
(-0.1594514301521205) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.07216878364870323) $CellContext`md2, \
(-0.041666666666666644`) $CellContext`md2}, {
          10.16, (-0.06611277835760294) $CellContext`md2, \
(-0.05073011908406003) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.07216878364870323) $CellContext`md2, \
(-0.041666666666666644`) $CellContext`md2}, {
          10.16, (-0.14433756729740646`) $CellContext`md2, \
(-0.08333333333333329) $CellContext`md2}, {
          10.16, (-0.1322255567152059) $CellContext`md2, \
(-0.10146023816812005`) $CellContext`md2}, {
          10.16, (-0.06611277835760294) $CellContext`md2, \
(-0.05073011908406003) $CellContext`md2}, {
          10.16, (-0.07216878364870323) $CellContext`md2, \
(-0.041666666666666644`) $CellContext`md2}, {
          10.16, (-0.14433756729740646`) $CellContext`md2, \
(-0.08333333333333329) $CellContext`md2}, {
          10.16, (-0.2165063509461097) $CellContext`md2, \
(-0.12499999999999994`) $CellContext`md2}, {
          10.16, (-0.19833833507280885`) $CellContext`md2, \
(-0.15219035725218008`) $CellContext`md2}, {
          10.16, (-0.1322255567152059) $CellContext`md2, \
(-0.10146023816812005`) $CellContext`md2}, {
          10.16, (-0.14433756729740646`) $CellContext`md2, \
(-0.08333333333333329) $CellContext`md2}, {
          10.16, (-0.2165063509461097) $CellContext`md2, \
(-0.12499999999999994`) $CellContext`md2}, {
          10.16, (-0.2886751345948129) $CellContext`md2, \
(-0.16666666666666657`) $CellContext`md2}, {
          10.16, (-0.2644511134304118) $CellContext`md2, \
(-0.2029204763362401) $CellContext`md2}, {
          10.16, (-0.19833833507280885`) $CellContext`md2, \
(-0.15219035725218008`) $CellContext`md2}, {
          10.16, (-0.2165063509461097) $CellContext`md2, \
(-0.12499999999999994`) $CellContext`md2}, {
          10.16, (-0.2886751345948129) $CellContext`md2, \
(-0.16666666666666657`) $CellContext`md2}, {
          10.16, (-0.36084391824351614`) $CellContext`md2, \
(-0.20833333333333323`) $CellContext`md2}, {
          10.16, (-0.3305638917880147) $CellContext`md2, \
(-0.2536505954203001) $CellContext`md2}, {
          10.16, (-0.2644511134304118) $CellContext`md2, \
(-0.2029204763362401) $CellContext`md2}, {
          10.16, (-0.2886751345948129) $CellContext`md2, \
(-0.16666666666666657`) $CellContext`md2}, {
          10.16, (-0.36084391824351614`) $CellContext`md2, \
(-0.20833333333333323`) $CellContext`md2}, {
          10.16, (-0.43301270189221935`) $CellContext`md2, \
(-0.24999999999999986`) $CellContext`md2}, {
          10.16, (-0.39667667014561764`) $CellContext`md2, \
(-0.3043807145043601) $CellContext`md2}, {
          10.16, (-0.3305638917880147) $CellContext`md2, \
(-0.2536505954203001) $CellContext`md2}, {
          10.16, (-0.36084391824351614`) $CellContext`md2, \
(-0.20833333333333323`) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.06611277835760294) $CellContext`md2, \
(-0.05073011908406003) $CellContext`md2}, {
          10.16, (-0.05892556509887899) $CellContext`md2, \
(-0.058925565098878925`) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.06611277835760294) $CellContext`md2, \
(-0.05073011908406003) $CellContext`md2}, {
          10.16, (-0.1322255567152059) $CellContext`md2, \
(-0.10146023816812005`) $CellContext`md2}, {
          10.16, (-0.11785113019775798`) $CellContext`md2, \
(-0.11785113019775785`) $CellContext`md2}, {
          10.16, (-0.05892556509887899) $CellContext`md2, \
(-0.058925565098878925`) $CellContext`md2}, {
          10.16, (-0.06611277835760294) $CellContext`md2, \
(-0.05073011908406003) $CellContext`md2}, {
          10.16, (-0.1322255567152059) $CellContext`md2, \
(-0.10146023816812005`) $CellContext`md2}, {
          10.16, (-0.19833833507280885`) $CellContext`md2, \
(-0.15219035725218008`) $CellContext`md2}, {
          10.16, (-0.17677669529663698`) $CellContext`md2, \
(-0.17677669529663678`) $CellContext`md2}, {
          10.16, (-0.11785113019775798`) $CellContext`md2, \
(-0.11785113019775785`) $CellContext`md2}, {
          10.16, (-0.1322255567152059) $CellContext`md2, \
(-0.10146023816812005`) $CellContext`md2}, {
          10.16, (-0.19833833507280885`) $CellContext`md2, \
(-0.15219035725218008`) $CellContext`md2}, {
          10.16, (-0.2644511134304118) $CellContext`md2, \
(-0.2029204763362401) $CellContext`md2}, {
          10.16, (-0.23570226039551595`) $CellContext`md2, \
(-0.2357022603955157) $CellContext`md2}, {
          10.16, (-0.17677669529663698`) $CellContext`md2, \
(-0.17677669529663678`) $CellContext`md2}, {
          10.16, (-0.19833833507280885`) $CellContext`md2, \
(-0.15219035725218008`) $CellContext`md2}, {
          10.16, (-0.2644511134304118) $CellContext`md2, \
(-0.2029204763362401) $CellContext`md2}, {
          10.16, (-0.3305638917880147) $CellContext`md2, \
(-0.2536505954203001) $CellContext`md2}, {
          10.16, (-0.2946278254943949) $CellContext`md2, \
(-0.2946278254943946) $CellContext`md2}, {
          10.16, (-0.23570226039551595`) $CellContext`md2, \
(-0.2357022603955157) $CellContext`md2}, {
          10.16, (-0.2644511134304118) $CellContext`md2, \
(-0.2029204763362401) $CellContext`md2}, {
          10.16, (-0.3305638917880147) $CellContext`md2, \
(-0.2536505954203001) $CellContext`md2}, {
          10.16, (-0.39667667014561764`) $CellContext`md2, \
(-0.3043807145043601) $CellContext`md2}, {
          10.16, (-0.3535533905932739) $CellContext`md2, \
(-0.3535533905932735) $CellContext`md2}, {
          10.16, (-0.2946278254943949) $CellContext`md2, \
(-0.2946278254943946) $CellContext`md2}, {
          
          10.16, (-0.3305638917880147) $CellContext`md2, \
(-0.2536505954203001) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.05892556509887899) $CellContext`md2, \
(-0.058925565098878925`) $CellContext`md2}, {
          10.16, (-0.05073011908406007) $CellContext`md2, \
(-0.0661127783576029) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.05892556509887899) $CellContext`md2, \
(-0.058925565098878925`) $CellContext`md2}, {
          10.16, (-0.11785113019775798`) $CellContext`md2, \
(-0.11785113019775785`) $CellContext`md2}, {
          10.16, (-0.10146023816812014`) $CellContext`md2, \
(-0.1322255567152058) $CellContext`md2}, {
          10.16, (-0.05073011908406007) $CellContext`md2, \
(-0.0661127783576029) $CellContext`md2}, {
          10.16, (-0.05892556509887899) $CellContext`md2, \
(-0.058925565098878925`) $CellContext`md2}, {
          10.16, (-0.11785113019775798`) $CellContext`md2, \
(-0.11785113019775785`) $CellContext`md2}, {
          10.16, (-0.17677669529663698`) $CellContext`md2, \
(-0.17677669529663678`) $CellContext`md2}, {
          10.16, (-0.15219035725218022`) $CellContext`md2, \
(-0.19833833507280874`) $CellContext`md2}, {
          10.16, (-0.10146023816812014`) $CellContext`md2, \
(-0.1322255567152058) $CellContext`md2}, {
          10.16, (-0.11785113019775798`) $CellContext`md2, \
(-0.11785113019775785`) $CellContext`md2}, {
          10.16, (-0.17677669529663698`) $CellContext`md2, \
(-0.17677669529663678`) $CellContext`md2}, {
          10.16, (-0.23570226039551595`) $CellContext`md2, \
(-0.2357022603955157) $CellContext`md2}, {
          10.16, (-0.20292047633624027`) $CellContext`md2, \
(-0.2644511134304116) $CellContext`md2}, {
          10.16, (-0.15219035725218022`) $CellContext`md2, \
(-0.19833833507280874`) $CellContext`md2}, {
          10.16, (-0.17677669529663698`) $CellContext`md2, \
(-0.17677669529663678`) $CellContext`md2}, {
          10.16, (-0.23570226039551595`) $CellContext`md2, \
(-0.2357022603955157) $CellContext`md2}, {
          10.16, (-0.2946278254943949) $CellContext`md2, \
(-0.2946278254943946) $CellContext`md2}, {
          10.16, (-0.25365059542030033`) $CellContext`md2, \
(-0.33056389178801454`) $CellContext`md2}, {
          10.16, (-0.20292047633624027`) $CellContext`md2, \
(-0.2644511134304116) $CellContext`md2}, {
          10.16, (-0.23570226039551595`) $CellContext`md2, \
(-0.2357022603955157) $CellContext`md2}, {
          10.16, (-0.2946278254943949) $CellContext`md2, \
(-0.2946278254943946) $CellContext`md2}, {
          10.16, (-0.3535533905932739) $CellContext`md2, \
(-0.3535533905932735) $CellContext`md2}, {
          10.16, (-0.3043807145043604) $CellContext`md2, \
(-0.3966766701456174) $CellContext`md2}, {
          10.16, (-0.25365059542030033`) $CellContext`md2, \
(-0.33056389178801454`) $CellContext`md2}, {
          10.16, (-0.2946278254943949) $CellContext`md2, \
(-0.2946278254943946) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.05073011908406007) $CellContext`md2, \
(-0.0661127783576029) $CellContext`md2}, {
          10.16, (-0.0416666666666667) $CellContext`md2, \
(-0.07216878364870319) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.05073011908406007) $CellContext`md2, \
(-0.0661127783576029) $CellContext`md2}, {
          10.16, (-0.10146023816812014`) $CellContext`md2, \
(-0.1322255567152058) $CellContext`md2}, {
          10.16, (-0.0833333333333334) $CellContext`md2, \
(-0.14433756729740638`) $CellContext`md2}, {
          10.16, (-0.0416666666666667) $CellContext`md2, \
(-0.07216878364870319) $CellContext`md2}, {
          10.16, (-0.05073011908406007) $CellContext`md2, \
(-0.0661127783576029) $CellContext`md2}, {
          10.16, (-0.10146023816812014`) $CellContext`md2, \
(-0.1322255567152058) $CellContext`md2}, {
          10.16, (-0.15219035725218022`) $CellContext`md2, \
(-0.19833833507280874`) $CellContext`md2}, {
          10.16, (-0.1250000000000001) $CellContext`md2, \
(-0.2165063509461096) $CellContext`md2}, {
          10.16, (-0.0833333333333334) $CellContext`md2, \
(-0.14433756729740638`) $CellContext`md2}, {
          10.16, (-0.10146023816812014`) $CellContext`md2, \
(-0.1322255567152058) $CellContext`md2}, {
          10.16, (-0.15219035725218022`) $CellContext`md2, \
(-0.19833833507280874`) $CellContext`md2}, {
          10.16, (-0.20292047633624027`) $CellContext`md2, \
(-0.2644511134304116) $CellContext`md2}, {
          10.16, (-0.1666666666666668) $CellContext`md2, \
(-0.28867513459481275`) $CellContext`md2}, {
          10.16, (-0.1250000000000001) $CellContext`md2, \
(-0.2165063509461096) $CellContext`md2}, {
          10.16, (-0.15219035725218022`) $CellContext`md2, \
(-0.19833833507280874`) $CellContext`md2}, {
          10.16, (-0.20292047633624027`) $CellContext`md2, \
(-0.2644511134304116) $CellContext`md2}, {
          10.16, (-0.25365059542030033`) $CellContext`md2, \
(-0.33056389178801454`) $CellContext`md2}, {
          10.16, (-0.2083333333333335) $CellContext`md2, \
(-0.36084391824351597`) $CellContext`md2}, {
          10.16, (-0.1666666666666668) $CellContext`md2, \
(-0.28867513459481275`) $CellContext`md2}, {
          10.16, (-0.20292047633624027`) $CellContext`md2, \
(-0.2644511134304116) $CellContext`md2}, {
          10.16, (-0.25365059542030033`) $CellContext`md2, \
(-0.33056389178801454`) $CellContext`md2}, {
          10.16, (-0.3043807145043604) $CellContext`md2, \
(-0.3966766701456174) $CellContext`md2}, {
          10.16, (-0.25000000000000017`) $CellContext`md2, \
(-0.43301270189221913`) $CellContext`md2}, {
          10.16, (-0.2083333333333335) $CellContext`md2, \
(-0.36084391824351597`) $CellContext`md2}, {
          10.16, (-0.25365059542030033`) $CellContext`md2, \
(-0.33056389178801454`) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.0416666666666667) $CellContext`md2, \
(-0.07216878364870319) $CellContext`md2}, {
          10.16, (-0.031890286030424195`) $CellContext`md2, \
(-0.0769899610426072) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.0416666666666667) $CellContext`md2, \
(-0.07216878364870319) $CellContext`md2}, {
          10.16, (-0.0833333333333334) $CellContext`md2, \
(-0.14433756729740638`) $CellContext`md2}, {
          10.16, (-0.06378057206084839) $CellContext`md2, \
(-0.1539799220852144) $CellContext`md2}, {
          10.16, (-0.031890286030424195`) $CellContext`md2, \
(-0.0769899610426072) $CellContext`md2}, {
          10.16, (-0.0416666666666667) $CellContext`md2, \
(-0.07216878364870319) $CellContext`md2}, {
          10.16, (-0.0833333333333334) $CellContext`md2, \
(-0.14433756729740638`) $CellContext`md2}, {
          10.16, (-0.1250000000000001) $CellContext`md2, \
(-0.2165063509461096) $CellContext`md2}, {
          10.16, (-0.09567085809127258) $CellContext`md2, \
(-0.23096988312782163`) $CellContext`md2}, {
          10.16, (-0.06378057206084839) $CellContext`md2, \
(-0.1539799220852144) $CellContext`md2}, {
          10.16, (-0.0833333333333334) $CellContext`md2, \
(-0.14433756729740638`) $CellContext`md2}, {
          10.16, (-0.1250000000000001) $CellContext`md2, \
(-0.2165063509461096) $CellContext`md2}, {
          10.16, (-0.1666666666666668) $CellContext`md2, \
(-0.28867513459481275`) $CellContext`md2}, {
          10.16, (-0.12756114412169678`) $CellContext`md2, \
(-0.3079598441704288) $CellContext`md2}, {
          10.16, (-0.09567085809127258) $CellContext`md2, \
(-0.23096988312782163`) $CellContext`md2}, {
          10.16, (-0.1250000000000001) $CellContext`md2, \
(-0.2165063509461096) $CellContext`md2}, {
          10.16, (-0.1666666666666668) $CellContext`md2, \
(-0.28867513459481275`) $CellContext`md2}, {
          10.16, (-0.2083333333333335) $CellContext`md2, \
(-0.36084391824351597`) $CellContext`md2}, {
          10.16, (-0.15945143015212096`) $CellContext`md2, \
(-0.384949805213036) $CellContext`md2}, {
          10.16, (-0.12756114412169678`) $CellContext`md2, \
(-0.3079598441704288) $CellContext`md2}, {
          10.16, (-0.1666666666666668) $CellContext`md2, \
(-0.28867513459481275`) $CellContext`md2}, {
          
          10.16, (-0.2083333333333335) $CellContext`md2, \
(-0.36084391824351597`) $CellContext`md2}, {
          10.16, (-0.25000000000000017`) $CellContext`md2, \
(-0.43301270189221913`) $CellContext`md2}, {
          10.16, (-0.19134171618254514`) $CellContext`md2, \
(-0.4619397662556432) $CellContext`md2}, {
          10.16, (-0.15945143015212096`) $CellContext`md2, \
(-0.384949805213036) $CellContext`md2}, {
          10.16, (-0.2083333333333335) $CellContext`md2, \
(-0.36084391824351597`) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.031890286030424195`) $CellContext`md2, \
(-0.0769899610426072) $CellContext`md2}, {
          10.16, (-0.021568253758543453`) $CellContext`md2, \
(-0.08049381885742234) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.031890286030424195`) $CellContext`md2, \
(-0.0769899610426072) $CellContext`md2}, {
          10.16, (-0.06378057206084839) $CellContext`md2, \
(-0.1539799220852144) $CellContext`md2}, {
          10.16, (-0.043136507517086906`) $CellContext`md2, \
(-0.16098763771484467`) $CellContext`md2}, {
          10.16, (-0.021568253758543453`) $CellContext`md2, \
(-0.08049381885742234) $CellContext`md2}, {
          10.16, (-0.031890286030424195`) $CellContext`md2, \
(-0.0769899610426072) $CellContext`md2}, {
          10.16, (-0.06378057206084839) $CellContext`md2, \
(-0.1539799220852144) $CellContext`md2}, {
          10.16, (-0.09567085809127258) $CellContext`md2, \
(-0.23096988312782163`) $CellContext`md2}, {
          10.16, (-0.06470476127563037) $CellContext`md2, \
(-0.24148145657226702`) $CellContext`md2}, {
          10.16, (-0.043136507517086906`) $CellContext`md2, \
(-0.16098763771484467`) $CellContext`md2}, {
          10.16, (-0.06378057206084839) $CellContext`md2, \
(-0.1539799220852144) $CellContext`md2}, {
          10.16, (-0.09567085809127258) $CellContext`md2, \
(-0.23096988312782163`) $CellContext`md2}, {
          10.16, (-0.12756114412169678`) $CellContext`md2, \
(-0.3079598441704288) $CellContext`md2}, {
          10.16, (-0.08627301503417381) $CellContext`md2, \
(-0.32197527542968934`) $CellContext`md2}, {
          10.16, (-0.06470476127563037) $CellContext`md2, \
(-0.24148145657226702`) $CellContext`md2}, {
          10.16, (-0.09567085809127258) $CellContext`md2, \
(-0.23096988312782163`) $CellContext`md2}, {
          10.16, (-0.12756114412169678`) $CellContext`md2, \
(-0.3079598441704288) $CellContext`md2}, {
          10.16, (-0.15945143015212096`) $CellContext`md2, \
(-0.384949805213036) $CellContext`md2}, {
          10.16, (-0.10784126879271727`) $CellContext`md2, \
(-0.4024690942871117) $CellContext`md2}, {
          10.16, (-0.08627301503417381) $CellContext`md2, \
(-0.32197527542968934`) $CellContext`md2}, {
          10.16, (-0.12756114412169678`) $CellContext`md2, \
(-0.3079598441704288) $CellContext`md2}, {
          10.16, (-0.15945143015212096`) $CellContext`md2, \
(-0.384949805213036) $CellContext`md2}, {
          10.16, (-0.19134171618254514`) $CellContext`md2, \
(-0.4619397662556432) $CellContext`md2}, {
          10.16, (-0.1294095225512607) $CellContext`md2, (-0.482962913144534) \
$CellContext`md2}, {
          10.16, (-0.10784126879271727`) $CellContext`md2, \
(-0.4024690942871117) $CellContext`md2}, {
          10.16, (-0.15945143015212096`) $CellContext`md2, \
(-0.384949805213036) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.021568253758543453`) $CellContext`md2, \
(-0.08049381885742234) $CellContext`md2}, {
          10.16, (-0.010877182685004375`) $CellContext`md2, \
(-0.08262040511448418) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.021568253758543453`) $CellContext`md2, \
(-0.08049381885742234) $CellContext`md2}, {
          10.16, (-0.043136507517086906`) $CellContext`md2, \
(-0.16098763771484467`) $CellContext`md2}, {
          10.16, (-0.02175436537000875) $CellContext`md2, \
(-0.16524081022896836`) $CellContext`md2}, {
          10.16, (-0.010877182685004375`) $CellContext`md2, \
(-0.08262040511448418) $CellContext`md2}, {
          10.16, (-0.021568253758543453`) $CellContext`md2, \
(-0.08049381885742234) $CellContext`md2}, {
          10.16, (-0.043136507517086906`) $CellContext`md2, \
(-0.16098763771484467`) $CellContext`md2}, {
          10.16, (-0.06470476127563037) $CellContext`md2, \
(-0.24148145657226702`) $CellContext`md2}, {
          10.16, (-0.03263154805501313) $CellContext`md2, \
(-0.24786121534345257`) $CellContext`md2}, {
          10.16, (-0.02175436537000875) $CellContext`md2, \
(-0.16524081022896836`) $CellContext`md2}, {
          10.16, (-0.043136507517086906`) $CellContext`md2, \
(-0.16098763771484467`) $CellContext`md2}, {
          10.16, (-0.06470476127563037) $CellContext`md2, \
(-0.24148145657226702`) $CellContext`md2}, {
          10.16, (-0.08627301503417381) $CellContext`md2, \
(-0.32197527542968934`) $CellContext`md2}, {
          10.16, (-0.0435087307400175) $CellContext`md2, \
(-0.3304816204579367) $CellContext`md2}, {
          10.16, (-0.03263154805501313) $CellContext`md2, \
(-0.24786121534345257`) $CellContext`md2}, {
          10.16, (-0.06470476127563037) $CellContext`md2, \
(-0.24148145657226702`) $CellContext`md2}, {
          10.16, (-0.08627301503417381) $CellContext`md2, \
(-0.32197527542968934`) $CellContext`md2}, {
          10.16, (-0.10784126879271727`) $CellContext`md2, \
(-0.4024690942871117) $CellContext`md2}, {
          10.16, (-0.05438591342502188) $CellContext`md2, \
(-0.41310202557242093`) $CellContext`md2}, {
          10.16, (-0.0435087307400175) $CellContext`md2, \
(-0.3304816204579367) $CellContext`md2}, {
          10.16, (-0.08627301503417381) $CellContext`md2, \
(-0.32197527542968934`) $CellContext`md2}, {
          10.16, (-0.10784126879271727`) $CellContext`md2, \
(-0.4024690942871117) $CellContext`md2}, {
          10.16, (-0.1294095225512607) $CellContext`md2, (-0.482962913144534) \
$CellContext`md2}, {
          10.16, (-0.06526309611002624) $CellContext`md2, \
(-0.4957224306869051) $CellContext`md2}, {
          10.16, (-0.05438591342502188) $CellContext`md2, \
(-0.41310202557242093`) $CellContext`md2}, {
          
          10.16, (-0.10784126879271727`) $CellContext`md2, \
(-0.4024690942871117) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.010877182685004375`) $CellContext`md2, \
(-0.08262040511448418) $CellContext`md2}, {
          10.16, (-8.932295329768567*^-17) $CellContext`md2, \
(-0.08333333333333333) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-0.010877182685004375`) $CellContext`md2, \
(-0.08262040511448418) $CellContext`md2}, {
          10.16, (-0.02175436537000875) $CellContext`md2, \
(-0.16524081022896836`) $CellContext`md2}, {
          10.16, (-1.7864590659537134`*^-16) $CellContext`md2, \
(-0.16666666666666666`) $CellContext`md2}, {
          10.16, (-8.932295329768567*^-17) $CellContext`md2, \
(-0.08333333333333333) $CellContext`md2}, {
          10.16, (-0.010877182685004375`) $CellContext`md2, \
(-0.08262040511448418) $CellContext`md2}, {
          10.16, (-0.02175436537000875) $CellContext`md2, \
(-0.16524081022896836`) $CellContext`md2}, {
          10.16, (-0.03263154805501313) $CellContext`md2, \
(-0.24786121534345257`) $CellContext`md2}, {
          10.16, (-2.6796885989305704`*^-16) $CellContext`md2, (-0.25) \
$CellContext`md2}, {
          10.16, (-1.7864590659537134`*^-16) $CellContext`md2, \
(-0.16666666666666666`) $CellContext`md2}, {
          10.16, (-0.02175436537000875) $CellContext`md2, \
(-0.16524081022896836`) $CellContext`md2}, {
          10.16, (-0.03263154805501313) $CellContext`md2, \
(-0.24786121534345257`) $CellContext`md2}, {
          10.16, (-0.0435087307400175) $CellContext`md2, \
(-0.3304816204579367) $CellContext`md2}, {
          10.16, (-3.572918131907427*^-16) $CellContext`md2, \
(-0.3333333333333333) $CellContext`md2}, {
          10.16, (-2.6796885989305704`*^-16) $CellContext`md2, (-0.25) \
$CellContext`md2}, {
          10.16, (-0.03263154805501313) $CellContext`md2, \
(-0.24786121534345257`) $CellContext`md2}, {
          10.16, (-0.0435087307400175) $CellContext`md2, \
(-0.3304816204579367) $CellContext`md2}, {
          10.16, (-0.05438591342502188) $CellContext`md2, \
(-0.41310202557242093`) $CellContext`md2}, {
          10.16, (-4.466147664884284*^-16) $CellContext`md2, \
(-0.41666666666666663`) $CellContext`md2}, {
          10.16, (-3.572918131907427*^-16) $CellContext`md2, \
(-0.3333333333333333) $CellContext`md2}, {
          10.16, (-0.0435087307400175) $CellContext`md2, \
(-0.3304816204579367) $CellContext`md2}, {
          10.16, (-0.05438591342502188) $CellContext`md2, \
(-0.41310202557242093`) $CellContext`md2}, {
          10.16, (-0.06526309611002624) $CellContext`md2, \
(-0.4957224306869051) $CellContext`md2}, {
          10.16, (-5.35937719786114*^-16) $CellContext`md2, \
(-0.49999999999999994`) $CellContext`md2}, {
          10.16, (-4.466147664884284*^-16) $CellContext`md2, \
(-0.41666666666666663`) $CellContext`md2}, {
          10.16, (-0.05438591342502188) $CellContext`md2, \
(-0.41310202557242093`) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-1.5308084989341912`*^-17) $CellContext`md2, \
(-0.08333333333333333) $CellContext`md2}, {
          10.16, 0.01087718268500427 $CellContext`md2, (-0.08262040511448421) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, (-1.5308084989341912`*^-17) $CellContext`md2, \
(-0.08333333333333333) $CellContext`md2}, {
          10.16, (-3.0616169978683824`*^-17) $CellContext`md2, \
(-0.16666666666666666`) $CellContext`md2}, {
          10.16, 0.02175436537000854 $CellContext`md2, \
(-0.16524081022896842`) $CellContext`md2}, {
          10.16, 0.01087718268500427 $CellContext`md2, (-0.08262040511448421) \
$CellContext`md2}, {
          10.16, (-1.5308084989341912`*^-17) $CellContext`md2, \
(-0.08333333333333333) $CellContext`md2}, {
          10.16, (-3.0616169978683824`*^-17) $CellContext`md2, \
(-0.16666666666666666`) $CellContext`md2}, {
          10.16, (-4.592425496802574*^-17) $CellContext`md2, (-0.25) \
$CellContext`md2}, {
          10.16, 0.03263154805501281 $CellContext`md2, \
(-0.24786121534345262`) $CellContext`md2}, {
          10.16, 0.02175436537000854 $CellContext`md2, \
(-0.16524081022896842`) $CellContext`md2}, {
          10.16, (-3.0616169978683824`*^-17) $CellContext`md2, \
(-0.16666666666666666`) $CellContext`md2}, {
          10.16, (-4.592425496802574*^-17) $CellContext`md2, (-0.25) \
$CellContext`md2}, {
          10.16, (-6.123233995736765*^-17) $CellContext`md2, \
(-0.3333333333333333) $CellContext`md2}, {
          10.16, 0.04350873074001708 $CellContext`md2, \
(-0.33048162045793683`) $CellContext`md2}, {
          10.16, 0.03263154805501281 $CellContext`md2, \
(-0.24786121534345262`) $CellContext`md2}, {
          10.16, (-4.592425496802574*^-17) $CellContext`md2, (-0.25) \
$CellContext`md2}, {
          10.16, (-6.123233995736765*^-17) $CellContext`md2, \
(-0.3333333333333333) $CellContext`md2}, {
          10.16, (-7.654042494670957*^-17) $CellContext`md2, \
(-0.41666666666666663`) $CellContext`md2}, {
          10.16, 0.054385913425021346` $CellContext`md2, (-0.413102025572421) \
$CellContext`md2}, {
          10.16, 0.04350873074001708 $CellContext`md2, \
(-0.33048162045793683`) $CellContext`md2}, {
          10.16, (-6.123233995736765*^-17) $CellContext`md2, \
(-0.3333333333333333) $CellContext`md2}, {
          10.16, (-7.654042494670957*^-17) $CellContext`md2, \
(-0.41666666666666663`) $CellContext`md2}, {
          10.16, (-9.184850993605147*^-17) $CellContext`md2, \
(-0.49999999999999994`) $CellContext`md2}, {
          10.16, 0.0652630961100256 $CellContext`md2, (-0.4957224306869052) \
$CellContext`md2}, {
          10.16, 0.054385913425021346` $CellContext`md2, (-0.413102025572421) \
$CellContext`md2}, {
          10.16, (-7.654042494670957*^-17) $CellContext`md2, \
(-0.41666666666666663`) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.01087718268500427 $CellContext`md2, (-0.08262040511448421) \
$CellContext`md2}, {
          10.16, 0.021568253758543356` $CellContext`md2, \
(-0.08049381885742236) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 
           0.01087718268500427 $CellContext`md2, (-0.08262040511448421) \
$CellContext`md2}, {
          10.16, 0.02175436537000854 $CellContext`md2, \
(-0.16524081022896842`) $CellContext`md2}, {
          10.16, 0.04313650751708671 $CellContext`md2, \
(-0.16098763771484473`) $CellContext`md2}, {
          10.16, 0.021568253758543356` $CellContext`md2, \
(-0.08049381885742236) $CellContext`md2}, {
          10.16, 0.01087718268500427 $CellContext`md2, (-0.08262040511448421) \
$CellContext`md2}, {
          10.16, 0.02175436537000854 $CellContext`md2, \
(-0.16524081022896842`) $CellContext`md2}, {
          10.16, 0.03263154805501281 $CellContext`md2, \
(-0.24786121534345262`) $CellContext`md2}, {
          10.16, 0.06470476127563007 $CellContext`md2, (-0.2414814565722671) \
$CellContext`md2}, {
          10.16, 0.04313650751708671 $CellContext`md2, \
(-0.16098763771484473`) $CellContext`md2}, {
          10.16, 0.02175436537000854 $CellContext`md2, \
(-0.16524081022896842`) $CellContext`md2}, {
          10.16, 0.03263154805501281 $CellContext`md2, \
(-0.24786121534345262`) $CellContext`md2}, {
          10.16, 0.04350873074001708 $CellContext`md2, \
(-0.33048162045793683`) $CellContext`md2}, {
          10.16, 0.08627301503417342 $CellContext`md2, \
(-0.32197527542968946`) $CellContext`md2}, {
          10.16, 0.06470476127563007 $CellContext`md2, (-0.2414814565722671) \
$CellContext`md2}, {
          10.16, 0.03263154805501281 $CellContext`md2, \
(-0.24786121534345262`) $CellContext`md2}, {
          10.16, 0.04350873074001708 $CellContext`md2, \
(-0.33048162045793683`) $CellContext`md2}, {
          10.16, 0.054385913425021346` $CellContext`md2, (-0.413102025572421) \
$CellContext`md2}, {
          10.16, 0.10784126879271679` $CellContext`md2, (-0.4024690942871118) \
$CellContext`md2}, {
          10.16, 0.08627301503417342 $CellContext`md2, \
(-0.32197527542968946`) $CellContext`md2}, {
          10.16, 0.04350873074001708 $CellContext`md2, \
(-0.33048162045793683`) $CellContext`md2}, {
          10.16, 0.054385913425021346` $CellContext`md2, (-0.413102025572421) \
$CellContext`md2}, {
          10.16, 0.0652630961100256 $CellContext`md2, (-0.4957224306869052) \
$CellContext`md2}, {
          10.16, 0.12940952255126012` $CellContext`md2, \
(-0.48296291314453416`) $CellContext`md2}, {
          10.16, 0.10784126879271679` $CellContext`md2, (-0.4024690942871118) \
$CellContext`md2}, {
          10.16, 0.054385913425021346` $CellContext`md2, (-0.413102025572421) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.021568253758543356` $CellContext`md2, \
(-0.08049381885742236) $CellContext`md2}, {
          10.16, 0.0318902860304241 $CellContext`md2, (-0.07698996104260725) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.021568253758543356` $CellContext`md2, \
(-0.08049381885742236) $CellContext`md2}, {
          10.16, 0.04313650751708671 $CellContext`md2, \
(-0.16098763771484473`) $CellContext`md2}, {
          10.16, 0.0637805720608482 $CellContext`md2, (-0.1539799220852145) \
$CellContext`md2}, {
          10.16, 0.0318902860304241 $CellContext`md2, (-0.07698996104260725) \
$CellContext`md2}, {
          10.16, 0.021568253758543356` $CellContext`md2, \
(-0.08049381885742236) $CellContext`md2}, {
          10.16, 0.04313650751708671 $CellContext`md2, \
(-0.16098763771484473`) $CellContext`md2}, {
          10.16, 0.06470476127563007 $CellContext`md2, (-0.2414814565722671) \
$CellContext`md2}, {
          10.16, 0.09567085809127229 $CellContext`md2, \
(-0.23096988312782174`) $CellContext`md2}, {
          10.16, 0.0637805720608482 $CellContext`md2, (-0.1539799220852145) \
$CellContext`md2}, {
          10.16, 0.04313650751708671 $CellContext`md2, \
(-0.16098763771484473`) $CellContext`md2}, {
          10.16, 0.06470476127563007 $CellContext`md2, (-0.2414814565722671) \
$CellContext`md2}, {
          10.16, 0.08627301503417342 $CellContext`md2, \
(-0.32197527542968946`) $CellContext`md2}, {
          10.16, 0.1275611441216964 $CellContext`md2, (-0.307959844170429) \
$CellContext`md2}, {
          10.16, 0.09567085809127229 $CellContext`md2, \
(-0.23096988312782174`) $CellContext`md2}, {
          10.16, 0.06470476127563007 $CellContext`md2, (-0.2414814565722671) \
$CellContext`md2}, {
          10.16, 0.08627301503417342 $CellContext`md2, \
(-0.32197527542968946`) $CellContext`md2}, {
          10.16, 0.10784126879271679` $CellContext`md2, (-0.4024690942871118) \
$CellContext`md2}, {
          10.16, 0.15945143015212046` $CellContext`md2, (-0.3849498052130362) \
$CellContext`md2}, {
          10.16, 0.1275611441216964 $CellContext`md2, (-0.307959844170429) \
$CellContext`md2}, {
          10.16, 0.08627301503417342 $CellContext`md2, \
(-0.32197527542968946`) $CellContext`md2}, {
          10.16, 0.10784126879271679` $CellContext`md2, (-0.4024690942871118) \
$CellContext`md2}, {
          10.16, 0.12940952255126012` $CellContext`md2, \
(-0.48296291314453416`) $CellContext`md2}, {
          10.16, 0.19134171618254456` $CellContext`md2, (-0.4619397662556434) \
$CellContext`md2}, {
          10.16, 0.15945143015212046` $CellContext`md2, (-0.3849498052130362) \
$CellContext`md2}, {
          10.16, 0.10784126879271679` $CellContext`md2, (-0.4024690942871118) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.0318902860304241 $CellContext`md2, (-0.07698996104260725) \
$CellContext`md2}, {
          10.16, 0.0416666666666666 $CellContext`md2, (-0.07216878364870324) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.0318902860304241 $CellContext`md2, (-0.07698996104260725) \
$CellContext`md2}, {
          10.16, 0.0637805720608482 $CellContext`md2, (-0.1539799220852145) \
$CellContext`md2}, {
          10.16, 0.0833333333333332 $CellContext`md2, (-0.1443375672974065) \
$CellContext`md2}, {
          10.16, 0.0416666666666666 $CellContext`md2, (-0.07216878364870324) \
$CellContext`md2}, {
          10.16, 0.0318902860304241 $CellContext`md2, (-0.07698996104260725) \
$CellContext`md2}, {
          10.16, 0.0637805720608482 $CellContext`md2, (-0.1539799220852145) \
$CellContext`md2}, {
          10.16, 
           0.09567085809127229 $CellContext`md2, (-0.23096988312782174`) \
$CellContext`md2}, {
          10.16, 0.12499999999999982` $CellContext`md2, \
(-0.21650635094610976`) $CellContext`md2}, {
          10.16, 0.0833333333333332 $CellContext`md2, (-0.1443375672974065) \
$CellContext`md2}, {
          10.16, 0.0637805720608482 $CellContext`md2, (-0.1539799220852145) \
$CellContext`md2}, {
          10.16, 0.09567085809127229 $CellContext`md2, \
(-0.23096988312782174`) $CellContext`md2}, {
          10.16, 0.1275611441216964 $CellContext`md2, (-0.307959844170429) \
$CellContext`md2}, {
          10.16, 0.1666666666666664 $CellContext`md2, (-0.288675134594813) \
$CellContext`md2}, {
          10.16, 0.12499999999999982` $CellContext`md2, \
(-0.21650635094610976`) $CellContext`md2}, {
          10.16, 0.09567085809127229 $CellContext`md2, \
(-0.23096988312782174`) $CellContext`md2}, {
          10.16, 0.1275611441216964 $CellContext`md2, (-0.307959844170429) \
$CellContext`md2}, {
          10.16, 0.15945143015212046` $CellContext`md2, (-0.3849498052130362) \
$CellContext`md2}, {
          10.16, 0.208333333333333 $CellContext`md2, (-0.36084391824351625`) \
$CellContext`md2}, {
          10.16, 0.1666666666666664 $CellContext`md2, (-0.288675134594813) \
$CellContext`md2}, {
          10.16, 0.1275611441216964 $CellContext`md2, (-0.307959844170429) \
$CellContext`md2}, {
          10.16, 0.15945143015212046` $CellContext`md2, (-0.3849498052130362) \
$CellContext`md2}, {
          10.16, 0.19134171618254456` $CellContext`md2, (-0.4619397662556434) \
$CellContext`md2}, {
          10.16, 0.2499999999999996 $CellContext`md2, (-0.43301270189221946`) \
$CellContext`md2}, {
          10.16, 0.208333333333333 $CellContext`md2, (-0.36084391824351625`) \
$CellContext`md2}, {
          10.16, 0.15945143015212046` $CellContext`md2, (-0.3849498052130362) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.0416666666666666 $CellContext`md2, (-0.07216878364870324) \
$CellContext`md2}, {
          10.16, 0.050730119084059985` $CellContext`md2, \
(-0.06611277835760297) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.0416666666666666 $CellContext`md2, (-0.07216878364870324) \
$CellContext`md2}, {
          10.16, 0.0833333333333332 $CellContext`md2, (-0.1443375672974065) \
$CellContext`md2}, {
          10.16, 0.10146023816811997` $CellContext`md2, \
(-0.13222555671520594`) $CellContext`md2}, {
          10.16, 0.050730119084059985` $CellContext`md2, \
(-0.06611277835760297) $CellContext`md2}, {
          10.16, 0.0416666666666666 $CellContext`md2, (-0.07216878364870324) \
$CellContext`md2}, {
          10.16, 0.0833333333333332 $CellContext`md2, (-0.1443375672974065) \
$CellContext`md2}, {
          10.16, 0.12499999999999982` $CellContext`md2, \
(-0.21650635094610976`) $CellContext`md2}, {
          10.16, 0.15219035725217997` $CellContext`md2, \
(-0.19833833507280893`) $CellContext`md2}, {
          10.16, 0.10146023816811997` $CellContext`md2, \
(-0.13222555671520594`) $CellContext`md2}, {
          10.16, 0.0833333333333332 $CellContext`md2, (-0.1443375672974065) \
$CellContext`md2}, {
          10.16, 0.12499999999999982` $CellContext`md2, \
(-0.21650635094610976`) $CellContext`md2}, {
          10.16, 0.1666666666666664 $CellContext`md2, (-0.288675134594813) \
$CellContext`md2}, {
          10.16, 0.20292047633623994` $CellContext`md2, (-0.2644511134304119) \
$CellContext`md2}, {
          10.16, 0.15219035725217997` $CellContext`md2, \
(-0.19833833507280893`) $CellContext`md2}, {
          10.16, 0.12499999999999982` $CellContext`md2, \
(-0.21650635094610976`) $CellContext`md2}, {
          10.16, 0.1666666666666664 $CellContext`md2, (-0.288675134594813) \
$CellContext`md2}, {
          10.16, 0.208333333333333 $CellContext`md2, (-0.36084391824351625`) \
$CellContext`md2}, {
          10.16, 0.25365059542029994` $CellContext`md2, (-0.3305638917880149) \
$CellContext`md2}, {
          10.16, 0.20292047633623994` $CellContext`md2, (-0.2644511134304119) \
$CellContext`md2}, {
          10.16, 0.1666666666666664 $CellContext`md2, (-0.288675134594813) \
$CellContext`md2}, {
          10.16, 0.208333333333333 $CellContext`md2, (-0.36084391824351625`) \
$CellContext`md2}, {
          10.16, 0.2499999999999996 $CellContext`md2, (-0.43301270189221946`) \
$CellContext`md2}, {
          10.16, 0.3043807145043599 $CellContext`md2, (-0.3966766701456178) \
$CellContext`md2}, {
          10.16, 0.25365059542029994` $CellContext`md2, (-0.3305638917880149) \
$CellContext`md2}, {
          10.16, 0.208333333333333 $CellContext`md2, (-0.36084391824351625`) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.050730119084059985` $CellContext`md2, \
(-0.06611277835760297) $CellContext`md2}, {
          10.16, 0.05892556509887889 $CellContext`md2, (-0.05892556509887903) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.050730119084059985` $CellContext`md2, \
(-0.06611277835760297) $CellContext`md2}, {
          10.16, 0.10146023816811997` $CellContext`md2, \
(-0.13222555671520594`) $CellContext`md2}, {
          10.16, 0.11785113019775778` $CellContext`md2, \
(-0.11785113019775806`) $CellContext`md2}, {
          10.16, 0.05892556509887889 $CellContext`md2, (-0.05892556509887903) \
$CellContext`md2}, {
          10.16, 0.050730119084059985` $CellContext`md2, \
(-0.06611277835760297) $CellContext`md2}, {
          10.16, 0.10146023816811997` $CellContext`md2, \
(-0.13222555671520594`) $CellContext`md2}, {
          10.16, 0.15219035725217997` $CellContext`md2, \
(-0.19833833507280893`) $CellContext`md2}, {
          10.16, 0.17677669529663667` $CellContext`md2, (-0.1767766952966371) \
$CellContext`md2}, {
          10.16, 0.11785113019775778` $CellContext`md2, \
(-0.11785113019775806`) $CellContext`md2}, {
          10.16, 0.10146023816811997` $CellContext`md2, \
(-0.13222555671520594`) $CellContext`md2}, {
          10.16, 0.15219035725217997` $CellContext`md2, \
(-0.19833833507280893`) $CellContext`md2}, {
          10.16, 0.20292047633623994` $CellContext`md2, (-0.2644511134304119) \
$CellContext`md2}, {
          10.16, 
           0.23570226039551556` $CellContext`md2, (-0.23570226039551612`) \
$CellContext`md2}, {
          10.16, 0.17677669529663667` $CellContext`md2, (-0.1767766952966371) \
$CellContext`md2}, {
          10.16, 0.15219035725217997` $CellContext`md2, \
(-0.19833833507280893`) $CellContext`md2}, {
          10.16, 0.20292047633623994` $CellContext`md2, (-0.2644511134304119) \
$CellContext`md2}, {
          10.16, 0.25365059542029994` $CellContext`md2, (-0.3305638917880149) \
$CellContext`md2}, {
          10.16, 0.2946278254943944 $CellContext`md2, (-0.29462782549439515`) \
$CellContext`md2}, {
          10.16, 0.23570226039551556` $CellContext`md2, \
(-0.23570226039551612`) $CellContext`md2}, {
          10.16, 0.20292047633623994` $CellContext`md2, (-0.2644511134304119) \
$CellContext`md2}, {
          10.16, 0.25365059542029994` $CellContext`md2, (-0.3305638917880149) \
$CellContext`md2}, {
          10.16, 0.3043807145043599 $CellContext`md2, (-0.3966766701456178) \
$CellContext`md2}, {
          10.16, 0.3535533905932733 $CellContext`md2, (-0.3535533905932741) \
$CellContext`md2}, {
          10.16, 0.2946278254943944 $CellContext`md2, (-0.29462782549439515`) \
$CellContext`md2}, {
          10.16, 0.25365059542029994` $CellContext`md2, (-0.3305638917880149) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.05892556509887895 $CellContext`md2, \
(-0.058925565098878974`) $CellContext`md2}, {
          10.16, 0.0661127783576029 $CellContext`md2, (-0.05073011908406007) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.05892556509887895 $CellContext`md2, \
(-0.058925565098878974`) $CellContext`md2}, {
          10.16, 0.1178511301977579 $CellContext`md2, (-0.11785113019775795`) \
$CellContext`md2}, {
          10.16, 0.1322255567152058 $CellContext`md2, (-0.10146023816812014`) \
$CellContext`md2}, {
          10.16, 0.0661127783576029 $CellContext`md2, (-0.05073011908406007) \
$CellContext`md2}, {
          10.16, 0.05892556509887895 $CellContext`md2, \
(-0.058925565098878974`) $CellContext`md2}, {
          10.16, 0.1178511301977579 $CellContext`md2, (-0.11785113019775795`) \
$CellContext`md2}, {
          10.16, 0.17677669529663687` $CellContext`md2, \
(-0.17677669529663692`) $CellContext`md2}, {
          10.16, 0.19833833507280874` $CellContext`md2, \
(-0.15219035725218022`) $CellContext`md2}, {
          10.16, 0.1322255567152058 $CellContext`md2, (-0.10146023816812014`) \
$CellContext`md2}, {
          10.16, 0.1178511301977579 $CellContext`md2, (-0.11785113019775795`) \
$CellContext`md2}, {
          10.16, 0.17677669529663687` $CellContext`md2, \
(-0.17677669529663692`) $CellContext`md2}, {
          10.16, 0.2357022603955158 $CellContext`md2, (-0.2357022603955159) \
$CellContext`md2}, {
          10.16, 0.2644511134304116 $CellContext`md2, (-0.20292047633624027`) \
$CellContext`md2}, {
          10.16, 0.19833833507280874` $CellContext`md2, \
(-0.15219035725218022`) $CellContext`md2}, {
          10.16, 0.17677669529663687` $CellContext`md2, \
(-0.17677669529663692`) $CellContext`md2}, {
          10.16, 0.2357022603955158 $CellContext`md2, (-0.2357022603955159) \
$CellContext`md2}, {
          10.16, 0.29462782549439476` $CellContext`md2, \
(-0.29462782549439487`) $CellContext`md2}, {
          10.16, 0.33056389178801454` $CellContext`md2, \
(-0.25365059542030033`) $CellContext`md2}, {
          10.16, 0.2644511134304116 $CellContext`md2, (-0.20292047633624027`) \
$CellContext`md2}, {
          10.16, 0.2357022603955158 $CellContext`md2, (-0.2357022603955159) \
$CellContext`md2}, {
          10.16, 0.29462782549439476` $CellContext`md2, \
(-0.29462782549439487`) $CellContext`md2}, {
          10.16, 0.3535533905932737 $CellContext`md2, (-0.3535533905932738) \
$CellContext`md2}, {
          10.16, 0.3966766701456174 $CellContext`md2, (-0.3043807145043604) \
$CellContext`md2}, {
          10.16, 0.33056389178801454` $CellContext`md2, \
(-0.25365059542030033`) $CellContext`md2}, {
          10.16, 0.29462782549439476` $CellContext`md2, \
(-0.29462782549439487`) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 
           0.0661127783576029 $CellContext`md2, (-0.05073011908406007) \
$CellContext`md2}, {
          10.16, 0.07216878364870319 $CellContext`md2, (-0.0416666666666667) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.0661127783576029 $CellContext`md2, (-0.05073011908406007) \
$CellContext`md2}, {
          10.16, 0.1322255567152058 $CellContext`md2, (-0.10146023816812014`) \
$CellContext`md2}, {
          10.16, 0.14433756729740638` $CellContext`md2, (-0.0833333333333334) \
$CellContext`md2}, {
          10.16, 0.07216878364870319 $CellContext`md2, (-0.0416666666666667) \
$CellContext`md2}, {
          10.16, 0.0661127783576029 $CellContext`md2, (-0.05073011908406007) \
$CellContext`md2}, {
          10.16, 0.1322255567152058 $CellContext`md2, (-0.10146023816812014`) \
$CellContext`md2}, {
          10.16, 0.19833833507280874` $CellContext`md2, \
(-0.15219035725218022`) $CellContext`md2}, {
          10.16, 0.2165063509461096 $CellContext`md2, (-0.1250000000000001) \
$CellContext`md2}, {
          10.16, 0.14433756729740638` $CellContext`md2, (-0.0833333333333334) \
$CellContext`md2}, {
          10.16, 0.1322255567152058 $CellContext`md2, (-0.10146023816812014`) \
$CellContext`md2}, {
          10.16, 0.19833833507280874` $CellContext`md2, \
(-0.15219035725218022`) $CellContext`md2}, {
          10.16, 0.2644511134304116 $CellContext`md2, (-0.20292047633624027`) \
$CellContext`md2}, {
          10.16, 0.28867513459481275` $CellContext`md2, (-0.1666666666666668) \
$CellContext`md2}, {
          10.16, 0.2165063509461096 $CellContext`md2, (-0.1250000000000001) \
$CellContext`md2}, {
          10.16, 0.19833833507280874` $CellContext`md2, \
(-0.15219035725218022`) $CellContext`md2}, {
          10.16, 0.2644511134304116 $CellContext`md2, (-0.20292047633624027`) \
$CellContext`md2}, {
          10.16, 0.33056389178801454` $CellContext`md2, \
(-0.25365059542030033`) $CellContext`md2}, {
          10.16, 0.36084391824351597` $CellContext`md2, (-0.2083333333333335) \
$CellContext`md2}, {
          10.16, 0.28867513459481275` $CellContext`md2, (-0.1666666666666668) \
$CellContext`md2}, {
          10.16, 0.2644511134304116 $CellContext`md2, (-0.20292047633624027`) \
$CellContext`md2}, {
          10.16, 0.33056389178801454` $CellContext`md2, \
(-0.25365059542030033`) $CellContext`md2}, {
          10.16, 0.3966766701456174 $CellContext`md2, (-0.3043807145043604) \
$CellContext`md2}, {
          10.16, 0.43301270189221913` $CellContext`md2, \
(-0.25000000000000017`) $CellContext`md2}, {
          10.16, 0.36084391824351597` $CellContext`md2, (-0.2083333333333335) \
$CellContext`md2}, {
          10.16, 0.33056389178801454` $CellContext`md2, \
(-0.25365059542030033`) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.07216878364870319 $CellContext`md2, (-0.0416666666666667) \
$CellContext`md2}, {
          10.16, 0.0769899610426072 $CellContext`md2, \
(-0.031890286030424195`) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.07216878364870319 $CellContext`md2, (-0.0416666666666667) \
$CellContext`md2}, {
          10.16, 0.14433756729740638` $CellContext`md2, (-0.0833333333333334) \
$CellContext`md2}, {
          10.16, 0.1539799220852144 $CellContext`md2, (-0.06378057206084839) \
$CellContext`md2}, {
          10.16, 0.0769899610426072 $CellContext`md2, \
(-0.031890286030424195`) $CellContext`md2}, {
          10.16, 0.07216878364870319 $CellContext`md2, (-0.0416666666666667) \
$CellContext`md2}, {
          10.16, 0.14433756729740638` $CellContext`md2, (-0.0833333333333334) \
$CellContext`md2}, {
          10.16, 0.2165063509461096 $CellContext`md2, (-0.1250000000000001) \
$CellContext`md2}, {
          10.16, 0.23096988312782163` $CellContext`md2, (-0.0956708580912726) \
$CellContext`md2}, {
          10.16, 0.1539799220852144 $CellContext`md2, (-0.06378057206084839) \
$CellContext`md2}, {
          10.16, 0.14433756729740638` $CellContext`md2, (-0.0833333333333334) \
$CellContext`md2}, {
          10.16, 0.2165063509461096 $CellContext`md2, (-0.1250000000000001) \
$CellContext`md2}, {
          10.16, 0.28867513459481275` $CellContext`md2, (-0.1666666666666668) \
$CellContext`md2}, {
          10.16, 0.3079598441704288 $CellContext`md2, (-0.12756114412169678`) \
$CellContext`md2}, {
          10.16, 0.23096988312782163` $CellContext`md2, (-0.0956708580912726) \
$CellContext`md2}, {
          10.16, 0.2165063509461096 $CellContext`md2, (-0.1250000000000001) \
$CellContext`md2}, {
          10.16, 0.28867513459481275` $CellContext`md2, (-0.1666666666666668) \
$CellContext`md2}, {
          10.16, 0.36084391824351597` $CellContext`md2, (-0.2083333333333335) \
$CellContext`md2}, {
          10.16, 0.384949805213036 $CellContext`md2, (-0.159451430152121) \
$CellContext`md2}, {
          10.16, 0.3079598441704288 $CellContext`md2, (-0.12756114412169678`) \
$CellContext`md2}, {
          10.16, 0.28867513459481275` $CellContext`md2, (-0.1666666666666668) \
$CellContext`md2}, {
          10.16, 0.36084391824351597` $CellContext`md2, (-0.2083333333333335) \
$CellContext`md2}, {
          10.16, 0.43301270189221913` $CellContext`md2, \
(-0.25000000000000017`) $CellContext`md2}, {
          10.16, 0.4619397662556432 $CellContext`md2, (-0.19134171618254517`) \
$CellContext`md2}, {
          10.16, 0.384949805213036 $CellContext`md2, (-0.159451430152121) \
$CellContext`md2}, {
          10.16, 0.36084391824351597` $CellContext`md2, (-0.2083333333333335) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.0769899610426072 $CellContext`md2, \
(-0.031890286030424195`) $CellContext`md2}, {
          10.16, 0.08049381885742234 $CellContext`md2, (-0.02156825375854346) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.0769899610426072 $CellContext`md2, \
(-0.031890286030424195`) $CellContext`md2}, {
          10.16, 0.1539799220852144 $CellContext`md2, (-0.06378057206084839) \
$CellContext`md2}, {
          10.16, 0.16098763771484467` $CellContext`md2, \
(-0.04313650751708692) $CellContext`md2}, {
          10.16, 0.08049381885742234 $CellContext`md2, (-0.02156825375854346) \
$CellContext`md2}, {
          10.16, 0.0769899610426072 $CellContext`md2, \
(-0.031890286030424195`) $CellContext`md2}, {
          10.16, 0.1539799220852144 $CellContext`md2, (-0.06378057206084839) \
$CellContext`md2}, {
          10.16, 0.23096988312782163` $CellContext`md2, (-0.0956708580912726) \
$CellContext`md2}, {
          10.16, 0.24148145657226702` $CellContext`md2, \
(-0.06470476127563038) $CellContext`md2}, {
          10.16, 0.16098763771484467` $CellContext`md2, \
(-0.04313650751708692) $CellContext`md2}, {
          10.16, 0.1539799220852144 $CellContext`md2, (-0.06378057206084839) \
$CellContext`md2}, {
          10.16, 0.23096988312782163` $CellContext`md2, (-0.0956708580912726) \
$CellContext`md2}, {
          10.16, 0.3079598441704288 $CellContext`md2, (-0.12756114412169678`) \
$CellContext`md2}, {
          10.16, 0.32197527542968934` $CellContext`md2, \
(-0.08627301503417384) $CellContext`md2}, {
          10.16, 0.24148145657226702` $CellContext`md2, \
(-0.06470476127563038) $CellContext`md2}, {
          10.16, 0.23096988312782163` $CellContext`md2, (-0.0956708580912726) \
$CellContext`md2}, {
          10.16, 0.3079598441704288 $CellContext`md2, (-0.12756114412169678`) \
$CellContext`md2}, {
          10.16, 0.384949805213036 $CellContext`md2, (-0.159451430152121) \
$CellContext`md2}, {
          10.16, 0.4024690942871117 $CellContext`md2, (-0.10784126879271728`) \
$CellContext`md2}, {
          10.16, 0.32197527542968934` $CellContext`md2, \
(-0.08627301503417384) $CellContext`md2}, {
          10.16, 0.3079598441704288 $CellContext`md2, (-0.12756114412169678`) \
$CellContext`md2}, {
          10.16, 0.384949805213036 $CellContext`md2, (-0.159451430152121) \
$CellContext`md2}, {
          10.16, 0.4619397662556432 $CellContext`md2, (-0.19134171618254517`) \
$CellContext`md2}, {
          10.16, 0.482962913144534 $CellContext`md2, (-0.12940952255126073`) \
$CellContext`md2}, {
          10.16, 0.4024690942871117 $CellContext`md2, (-0.10784126879271728`) \
$CellContext`md2}, {
          10.16, 0.384949805213036 $CellContext`md2, (-0.159451430152121) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 
           0.08049381885742234 $CellContext`md2, (-0.02156825375854346) \
$CellContext`md2}, {
          10.16, 0.08262040511448418 $CellContext`md2, (-0.01087718268500438) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.08049381885742234 $CellContext`md2, (-0.02156825375854346) \
$CellContext`md2}, {
          10.16, 0.16098763771484467` $CellContext`md2, \
(-0.04313650751708692) $CellContext`md2}, {
          10.16, 0.16524081022896836` $CellContext`md2, \
(-0.02175436537000876) $CellContext`md2}, {
          10.16, 0.08262040511448418 $CellContext`md2, (-0.01087718268500438) \
$CellContext`md2}, {
          10.16, 0.08049381885742234 $CellContext`md2, (-0.02156825375854346) \
$CellContext`md2}, {
          10.16, 0.16098763771484467` $CellContext`md2, \
(-0.04313650751708692) $CellContext`md2}, {
          10.16, 0.24148145657226702` $CellContext`md2, \
(-0.06470476127563038) $CellContext`md2}, {
          10.16, 0.24786121534345257` $CellContext`md2, \
(-0.03263154805501314) $CellContext`md2}, {
          10.16, 0.16524081022896836` $CellContext`md2, \
(-0.02175436537000876) $CellContext`md2}, {
          10.16, 0.16098763771484467` $CellContext`md2, \
(-0.04313650751708692) $CellContext`md2}, {
          10.16, 0.24148145657226702` $CellContext`md2, \
(-0.06470476127563038) $CellContext`md2}, {
          10.16, 0.32197527542968934` $CellContext`md2, \
(-0.08627301503417384) $CellContext`md2}, {
          10.16, 0.3304816204579367 $CellContext`md2, (-0.04350873074001752) \
$CellContext`md2}, {
          10.16, 0.24786121534345257` $CellContext`md2, \
(-0.03263154805501314) $CellContext`md2}, {
          10.16, 0.24148145657226702` $CellContext`md2, \
(-0.06470476127563038) $CellContext`md2}, {
          10.16, 0.32197527542968934` $CellContext`md2, \
(-0.08627301503417384) $CellContext`md2}, {
          10.16, 0.4024690942871117 $CellContext`md2, (-0.10784126879271728`) \
$CellContext`md2}, {
          10.16, 0.41310202557242093` $CellContext`md2, (-0.0543859134250219) \
$CellContext`md2}, {
          10.16, 0.3304816204579367 $CellContext`md2, (-0.04350873074001752) \
$CellContext`md2}, {
          10.16, 0.32197527542968934` $CellContext`md2, \
(-0.08627301503417384) $CellContext`md2}, {
          10.16, 0.4024690942871117 $CellContext`md2, (-0.10784126879271728`) \
$CellContext`md2}, {
          10.16, 0.482962913144534 $CellContext`md2, (-0.12940952255126073`) \
$CellContext`md2}, {
          10.16, 0.4957224306869051 $CellContext`md2, (-0.06526309611002627) \
$CellContext`md2}, {
          10.16, 0.41310202557242093` $CellContext`md2, (-0.0543859134250219) \
$CellContext`md2}, {
          10.16, 0.4024690942871117 $CellContext`md2, (-0.10784126879271728`) \
$CellContext`md2}, {10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.08262040511448418 $CellContext`md2, (-0.01087718268500438) \
$CellContext`md2}, {
          10.16, 0.08333333333333333 $CellContext`md2, \
(-9.442564829413299*^-17) $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0. $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.08262040511448418 $CellContext`md2, (-0.01087718268500438) \
$CellContext`md2}, {
          10.16, 0.16524081022896836` $CellContext`md2, \
(-0.02175436537000876) $CellContext`md2}, {
          10.16, 0.16666666666666666` $CellContext`md2, \
(-1.8885129658826599`*^-16) $CellContext`md2}, {
          10.16, 0.08333333333333333 $CellContext`md2, \
(-9.442564829413299*^-17) $CellContext`md2}, {
          10.16, 0.08262040511448418 $CellContext`md2, (-0.01087718268500438) \
$CellContext`md2}, {
          10.16, 0.16524081022896836` $CellContext`md2, \
(-0.02175436537000876) $CellContext`md2}, {
          10.16, 0.24786121534345257` $CellContext`md2, \
(-0.03263154805501314) $CellContext`md2}, {
          10.16, 0.25 $CellContext`md2, (-2.83276944882399*^-16) \
$CellContext`md2}, {
          10.16, 0.16666666666666666` $CellContext`md2, \
(-1.8885129658826599`*^-16) $CellContext`md2}, {
          10.16, 0.16524081022896836` $CellContext`md2, \
(-0.02175436537000876) $CellContext`md2}, {
          10.16, 0.24786121534345257` $CellContext`md2, \
(-0.03263154805501314) $CellContext`md2}, {
          10.16, 0.3304816204579367 $CellContext`md2, (-0.04350873074001752) \
$CellContext`md2}, {
          10.16, 0.3333333333333333 $CellContext`md2, \
(-3.7770259317653197`*^-16) $CellContext`md2}, {
          10.16, 0.25 $CellContext`md2, (-2.83276944882399*^-16) \
$CellContext`md2}, {
          10.16, 0.24786121534345257` $CellContext`md2, \
(-0.03263154805501314) $CellContext`md2}, {
          10.16, 0.3304816204579367 $CellContext`md2, (-0.04350873074001752) \
$CellContext`md2}, {
          10.16, 0.41310202557242093` $CellContext`md2, (-0.0543859134250219) \
$CellContext`md2}, {
          10.16, 0.41666666666666663` $CellContext`md2, \
(-4.72128241470665*^-16) $CellContext`md2}, {
          10.16, 0.3333333333333333 $CellContext`md2, \
(-3.7770259317653197`*^-16) $CellContext`md2}, {
          10.16, 0.3304816204579367 $CellContext`md2, (-0.04350873074001752) \
$CellContext`md2}, {
          10.16, 0.41310202557242093` $CellContext`md2, (-0.0543859134250219) \
$CellContext`md2}, {
          10.16, 0.4957224306869051 $CellContext`md2, (-0.06526309611002627) \
$CellContext`md2}, {
          10.16, 0.49999999999999994` $CellContext`md2, \
(-5.665538897647979*^-16) $CellContext`md2}, {
          10.16, 0.41666666666666663` $CellContext`md2, \
(-4.72128241470665*^-16) $CellContext`md2}, {
          10.16, 0.41310202557242093` $CellContext`md2, (-0.0543859134250219) \
$CellContext`md2}, {((-0.25) (0. + 
               0. $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 0.5 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.5 $CellContext`md2, 0. + 0. $CellContext`md2}, {
          10.16, 0. + 0.5 $CellContext`md2, 0. + 0. $CellContext`md2}, {
          10.16, 0. + 0.4957224306869052 $CellContext`md2, 0. + 
           0.06526309611002579 $CellContext`md2}, {((-0.25) (0. + 
               0.06526309611002579 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4957224306869052 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.4957224306869052 $CellContext`md2, 0. + 
           0.06526309611002579 $CellContext`md2}, {((-0.25) (0. + 
               0. $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 0.5 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.5 $CellContext`md2, 0. + 
           0. $CellContext`md2}, {((-0.25) (0. + 
               0.06526309611002579 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4957224306869052 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.4957224306869052 $CellContext`md2, 0. + 
           0.06526309611002579 $CellContext`md2}, {
          10.16, 0. + 0.4957224306869052 $CellContext`md2, 0. + 
           0.06526309611002579 $CellContext`md2}, {
          10.16, 0. + 0.48296291314453416` $CellContext`md2, 0. + 
           0.12940952255126037` $CellContext`md2}, {((-0.25) (0. + 
               0.12940952255126037` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.48296291314453416` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.48296291314453416` $CellContext`md2, 0. + 
           0.12940952255126037` $CellContext`md2}, {((-0.25) (0. + 
               0.06526309611002579 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4957224306869052 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.4957224306869052 $CellContext`md2, 0. + 
           0.06526309611002579 $CellContext`md2}, {((-0.25) (0. + 
               0.12940952255126037` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.48296291314453416` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.48296291314453416` $CellContext`md2, 0. + 
           0.12940952255126037` $CellContext`md2}, {
          10.16, 0. + 0.48296291314453416` $CellContext`md2, 0. + 
           0.12940952255126037` $CellContext`md2}, {
          10.16, 0. + 0.46193976625564337` $CellContext`md2, 0. + 
           0.1913417161825449 $CellContext`md2}, {((-0.25) (0. + 
               0.1913417161825449 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.46193976625564337` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.46193976625564337` $CellContext`md2, 0. + 
           0.1913417161825449 $CellContext`md2}, {((-0.25) (0. + 
               0.12940952255126037` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.48296291314453416` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.48296291314453416` $CellContext`md2, 0. + 
           0.12940952255126037` $CellContext`md2}, {((-0.25) (0. + 
               0.1913417161825449 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.46193976625564337` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.46193976625564337` $CellContext`md2, 0. + 
           0.1913417161825449 $CellContext`md2}, {
          10.16, 0. + 0.46193976625564337` $CellContext`md2, 0. + 
           0.1913417161825449 $CellContext`md2}, {
          10.16, 0. + 0.43301270189221935` $CellContext`md2, 0. + 
           0.24999999999999997` $CellContext`md2}, {((-0.25) (0. + 
               0.24999999999999997` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.43301270189221935` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.43301270189221935` $CellContext`md2, 0. + 
           0.24999999999999997` $CellContext`md2}, {((-0.25) (0. + 
               0.1913417161825449 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.46193976625564337` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.46193976625564337` $CellContext`md2, 0. + 
           0.1913417161825449 $CellContext`md2}, {((-0.25) (0. + 
               0.24999999999999997` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.43301270189221935` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.43301270189221935` $CellContext`md2, 0. + 
           0.24999999999999997` $CellContext`md2}, {
          10.16, 0. + 0.43301270189221935` $CellContext`md2, 0. + 
           0.24999999999999997` $CellContext`md2}, {
          10.16, 0. + 0.3966766701456176 $CellContext`md2, 0. + 
           0.3043807145043603 $CellContext`md2}, {((-0.25) (0. + 
               0.3043807145043603 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.3966766701456176 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.3966766701456176 $CellContext`md2, 0. + 
           0.3043807145043603 $CellContext`md2}, {((-0.25) (0. + 
               0.24999999999999997` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.43301270189221935` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.43301270189221935` $CellContext`md2, 0. + 
           0.24999999999999997` $CellContext`md2}, {((-0.25) (0. + 
               0.3043807145043603 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.3966766701456176 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.3966766701456176 $CellContext`md2, 0. + 
           0.3043807145043603 $CellContext`md2}, {
          10.16, 0. + 0.3966766701456176 $CellContext`md2, 0. + 
           0.3043807145043603 $CellContext`md2}, {
          10.16, 0. + 0.35355339059327384` $CellContext`md2, 0. + 
           0.35355339059327373` $CellContext`md2}, {((-0.25) (0. + 
               0.35355339059327373` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.35355339059327384` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.35355339059327384` $CellContext`md2, 0. + 
           0.35355339059327373` $CellContext`md2}, {((-0.25) (0. + 
               0.3043807145043603 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.3966766701456176 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.3966766701456176 $CellContext`md2, 0. + 
           0.3043807145043603 $CellContext`md2}, {((-0.5) (0. + 
              0.35355339059327373` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.3535533905932738 $CellContext`md2, 0. + 
           0.35355339059327373` $CellContext`md2}, {
          10.16, 0. + 0.3535533905932738 $CellContext`md2, 0. + 
           0.35355339059327373` $CellContext`md2}, {
          10.16, 0. + 0.3043807145043604 $CellContext`md2, 0. + 
           0.3966766701456175 $CellContext`md2}, {((-0.25) (0. + 
               0.3043807145043604 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.3966766701456175 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.3043807145043604 $CellContext`md2, 0. + 
           0.3966766701456175 $CellContext`md2}, {((-0.5) (0. + 
              0.35355339059327373` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.3535533905932738 $CellContext`md2, 0. + 
           0.35355339059327373` $CellContext`md2}, {((-0.25) (0. + 
               0.3043807145043604 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.3966766701456175 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.3043807145043604 $CellContext`md2, 0. + 
           0.3966766701456175 $CellContext`md2}, {
          10.16, 0. + 0.3043807145043604 $CellContext`md2, 0. + 
           0.3966766701456175 $CellContext`md2}, {
          10.16, 0. + 0.25000000000000006` $CellContext`md2, 0. + 
           0.4330127018922193 $CellContext`md2}, {((-0.25) (0. + 
               0.25000000000000006` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4330127018922193 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.25000000000000006` $CellContext`md2, 0. + 
           0.4330127018922193 $CellContext`md2}, {((-0.25) (0. + 
               0.3043807145043604 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.3966766701456175 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.3043807145043604 $CellContext`md2, 0. + 
           0.3966766701456175 $CellContext`md2}, {((-0.25) (0. + 
               0.25000000000000006` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4330127018922193 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.25000000000000006` $CellContext`md2, 0. + 
           0.4330127018922193 $CellContext`md2}, {
          10.16, 0. + 0.25000000000000006` $CellContext`md2, 0. + 
           0.4330127018922193 $CellContext`md2}, {
          10.16, 0. + 0.19134171618254492` $CellContext`md2, 0. + 
           0.46193976625564337` $CellContext`md2}, {((-0.25) (0. + 
               0.19134171618254492` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.46193976625564337` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.19134171618254492` $CellContext`md2, 0. + 
           0.46193976625564337` $CellContext`md2}, {((-0.25) (0. + 
               0.25000000000000006` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4330127018922193 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.25000000000000006` $CellContext`md2, 0. + 
           0.4330127018922193 $CellContext`md2}, {((-0.25) (0. + 
               0.19134171618254492` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.46193976625564337` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.19134171618254492` $CellContext`md2, 0. + 
           0.46193976625564337` $CellContext`md2}, {
          10.16, 0. + 0.19134171618254492` $CellContext`md2, 0. + 
           0.46193976625564337` $CellContext`md2}, {
          10.16, 0. + 0.12940952255126037` $CellContext`md2, 0. + 
           0.48296291314453416` $CellContext`md2}, {((-0.25) (0. + 
               0.12940952255126037` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.48296291314453416` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.12940952255126037` $CellContext`md2, 0. + 
           0.48296291314453416` $CellContext`md2}, {((-0.25) (0. + 
               0.19134171618254492` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.46193976625564337` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.19134171618254492` $CellContext`md2, 0. + 
           0.46193976625564337` $CellContext`md2}, {((-0.25) (0. + 
               0.12940952255126048` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4829629131445341 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.12940952255126048` $CellContext`md2, 0. + 
           0.4829629131445341 $CellContext`md2}, {
          10.16, 0. + 0.12940952255126048` $CellContext`md2, 0. + 
           0.4829629131445341 $CellContext`md2}, {
          10.16, 0. + 0.06526309611002586 $CellContext`md2, 0. + 
           0.4957224306869052 $CellContext`md2}, {((-0.25) (0. + 
               0.06526309611002586 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4957224306869052 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.06526309611002586 $CellContext`md2, 0. + 
           0.4957224306869052 $CellContext`md2}, {((-0.25) (0. + 
               0.12940952255126048` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4829629131445341 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.12940952255126048` $CellContext`md2, 0. + 
           0.4829629131445341 $CellContext`md2}, {((-0.25) (0. + 
               0.06526309611002586 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4957224306869052 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.06526309611002586 $CellContext`md2, 0. + 
           0.4957224306869052 $CellContext`md2}, {
          10.16, 0. + 0.06526309611002586 $CellContext`md2, 0. + 
           0.4957224306869052 $CellContext`md2}, {
          10.16, 0. + 3.061616997868383*^-17 $CellContext`md2, 0. + 
           0.5 $CellContext`md2}, {((-0.25) (0. + 
               3.061616997868383*^-17 $CellContext`md2)^2)/$CellContext`mf2 - \
(0.25 (0. + 0.5 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           3.061616997868383*^-17 $CellContext`md2, 0. + 
           0.5 $CellContext`md2}, {((-0.25) (0. + 
               0.06526309611002586 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4957224306869052 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.06526309611002586 $CellContext`md2, 0. + 
           0.4957224306869052 $CellContext`md2}, {((-0.25) (0. + 
               3.061616997868383*^-17 $CellContext`md2)^2)/$CellContext`mf2 - \
(0.25 (0. + 0.5 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           3.061616997868383*^-17 $CellContext`md2, 0. + 
           0.5 $CellContext`md2}, {
          10.16, 0. + 3.061616997868383*^-17 $CellContext`md2, 0. + 
           0.5 $CellContext`md2}, {
          10.16, 0. - 0.0652630961100258 $CellContext`md2, 0. + 
           0.4957224306869052 $CellContext`md2}, {((-0.25) (0. - 
               0.0652630961100258 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4957224306869052 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.0652630961100258 $CellContext`md2, 0. + 
           0.4957224306869052 $CellContext`md2}, {((-0.25) (0. + 
               3.061616997868383*^-17 $CellContext`md2)^2)/$CellContext`mf2 - \
(0.25 (0. + 0.5 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           3.061616997868383*^-17 $CellContext`md2, 0. + 
           0.5 $CellContext`md2}, {((-0.25) (0. - 
               0.06526309611002569 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.49572243068690525` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.06526309611002569 $CellContext`md2, 0. + 
           0.49572243068690525` $CellContext`md2}, {
          10.16, 0. - 0.06526309611002569 $CellContext`md2, 0. + 
           0.49572243068690525` $CellContext`md2}, {
          10.16, 0. - 0.12940952255126031` $CellContext`md2, 0. + 
           0.48296291314453416` $CellContext`md2}, {((-0.25) (0. - 
               0.12940952255126031` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.48296291314453416` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.12940952255126031` $CellContext`md2, 0. + 
           0.48296291314453416` $CellContext`md2}, {((-0.25) (0. - 
               0.06526309611002569 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.49572243068690525` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.06526309611002569 $CellContext`md2, 0. + 
           0.49572243068690525` $CellContext`md2}, {((-0.25) (0. - 
               0.12940952255126031` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.48296291314453416` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.12940952255126031` $CellContext`md2, 0. + 
           0.48296291314453416` $CellContext`md2}, {
          10.16, 0. - 0.12940952255126031` $CellContext`md2, 0. + 
           0.48296291314453416` $CellContext`md2}, {
          10.16, 0. - 0.19134171618254486` $CellContext`md2, 0. + 
           0.46193976625564337` $CellContext`md2}, {((-0.25) (0. - 
               0.19134171618254486` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.46193976625564337` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.19134171618254486` $CellContext`md2, 0. + 
           0.46193976625564337` $CellContext`md2}, {((-0.25) (0. - 
               0.12940952255126031` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.48296291314453416` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.12940952255126031` $CellContext`md2, 0. + 
           0.48296291314453416` $CellContext`md2}, {((-0.25) (0. - 
               0.19134171618254475` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4619397662556434 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.19134171618254475` $CellContext`md2, 0. + 
           0.4619397662556434 $CellContext`md2}, {
          10.16, 0. - 0.19134171618254475` $CellContext`md2, 0. + 
           0.4619397662556434 $CellContext`md2}, {
          10.16, 0. - 0.2499999999999999 $CellContext`md2, 0. + 
           0.4330127018922194 $CellContext`md2}, {((-0.25) (0. - 
               0.2499999999999999 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4330127018922194 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.2499999999999999 $CellContext`md2, 0. + 
           0.4330127018922194 $CellContext`md2}, {((-0.25) (0. - 
               0.19134171618254475` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4619397662556434 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.19134171618254475` $CellContext`md2, 0. + 
           0.4619397662556434 $CellContext`md2}, {((-0.25) (0. - 
               0.2499999999999999 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4330127018922194 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.2499999999999999 $CellContext`md2, 0. + 
           0.4330127018922194 $CellContext`md2}, {
          10.16, 0. - 0.2499999999999999 $CellContext`md2, 0. + 
           0.4330127018922194 $CellContext`md2}, {
          10.16, 0. - 0.30438071450436016` $CellContext`md2, 0. + 
           0.3966766701456177 $CellContext`md2}, {((-0.25) (0. - 
               0.30438071450436016` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.3966766701456177 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.30438071450436016` $CellContext`md2, 0. + 
           0.3966766701456177 $CellContext`md2}, {((-0.25) (0. - 
               0.2499999999999999 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4330127018922194 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.2499999999999999 $CellContext`md2, 0. + 
           0.4330127018922194 $CellContext`md2}, {((-0.25) (0. - 
               0.30438071450436016` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.3966766701456177 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.30438071450436016` $CellContext`md2, 0. + 
           0.3966766701456177 $CellContext`md2}, {
          10.16, 0. - 0.30438071450436016` $CellContext`md2, 0. + 
           0.3966766701456177 $CellContext`md2}, {
          10.16, 0. - 0.35355339059327356` $CellContext`md2, 0. + 
           0.35355339059327395` $CellContext`md2}, {((-0.25) (0. - 
               0.35355339059327356` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.35355339059327395` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.35355339059327356` $CellContext`md2, 0. + 
           0.35355339059327395` $CellContext`md2}, {((-0.25) (0. - 
               0.30438071450436016` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.3966766701456177 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.30438071450436016` $CellContext`md2, 0. + 
           0.3966766701456177 $CellContext`md2}, {((-0.25) (0. - 
               0.35355339059327373` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.3535533905932738 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.35355339059327373` $CellContext`md2, 0. + 
           0.3535533905932738 $CellContext`md2}, {
          10.16, 0. - 0.35355339059327373` $CellContext`md2, 0. + 
           0.3535533905932738 $CellContext`md2}, {
          10.16, 0. - 0.39667667014561747` $CellContext`md2, 0. + 
           0.30438071450436044` $CellContext`md2}, {((-0.25) (0. - 
               0.39667667014561747` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.30438071450436044` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.39667667014561747` $CellContext`md2, 0. + 
           0.30438071450436044` $CellContext`md2}, {((-0.25) (0. - 
               0.35355339059327373` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.3535533905932738 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.35355339059327373` $CellContext`md2, 0. + 
           0.3535533905932738 $CellContext`md2}, {((-0.25) (0. - 
               0.39667667014561747` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.30438071450436044` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.39667667014561747` $CellContext`md2, 0. + 
           0.30438071450436044` $CellContext`md2}, {
          10.16, 0. - 0.39667667014561747` $CellContext`md2, 0. + 
           0.30438071450436044` $CellContext`md2}, {
          10.16, 0. - 0.43301270189221924` $CellContext`md2, 0. + 
           0.25000000000000017` $CellContext`md2}, {((-0.25) (0. - 
               0.43301270189221924` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.25000000000000017` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.43301270189221924` $CellContext`md2, 0. + 
           0.25000000000000017` $CellContext`md2}, {((-0.25) (0. - 
               0.39667667014561747` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.30438071450436044` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.39667667014561747` $CellContext`md2, 0. + 
           0.30438071450436044` $CellContext`md2}, {((-0.25) (0. - 
               0.43301270189221924` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.25000000000000017` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.43301270189221924` $CellContext`md2, 0. + 
           0.25000000000000017` $CellContext`md2}, {
          10.16, 0. - 0.43301270189221924` $CellContext`md2, 0. + 
           0.25000000000000017` $CellContext`md2}, {
          10.16, 0. - 0.46193976625564326` $CellContext`md2, 0. + 
           0.19134171618254514` $CellContext`md2}, {((-0.25) (0. - 
               0.46193976625564326` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.19134171618254514` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.46193976625564326` $CellContext`md2, 0. + 
           0.19134171618254514` $CellContext`md2}, {((-0.25) (0. - 
               0.43301270189221924` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.25000000000000017` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.43301270189221924` $CellContext`md2, 0. + 
           0.25000000000000017` $CellContext`md2}, {((-0.25) (0. - 
               0.46193976625564337` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.19134171618254492` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.46193976625564337` $CellContext`md2, 0. + 
           0.19134171618254492` $CellContext`md2}, {
          10.16, 0. - 0.46193976625564337` $CellContext`md2, 0. + 
           0.19134171618254492` $CellContext`md2}, {
          10.16, 0. - 0.4829629131445341 $CellContext`md2, 0. + 
           0.1294095225512605 $CellContext`md2}, {((-0.25) (0. - 
               0.4829629131445341 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.1294095225512605 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.4829629131445341 $CellContext`md2, 0. + 
           0.1294095225512605 $CellContext`md2}, {((-0.25) (0. - 
               0.46193976625564337` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.19134171618254492` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.46193976625564337` $CellContext`md2, 0. + 
           0.19134171618254492` $CellContext`md2}, {((-0.25) (0. - 
               0.4829629131445341 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.1294095225512605 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.4829629131445341 $CellContext`md2, 0. + 
           0.1294095225512605 $CellContext`md2}, {
          10.16, 0. - 0.4829629131445341 $CellContext`md2, 0. + 
           0.1294095225512605 $CellContext`md2}, {
          10.16, 0. - 0.4957224306869052 $CellContext`md2, 0. + 
           0.065263096110026 $CellContext`md2}, {((-0.25) (0. - 
               0.4957224306869052 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.065263096110026 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.4957224306869052 $CellContext`md2, 0. + 
           0.065263096110026 $CellContext`md2}, {((-0.25) (0. - 
               0.4829629131445341 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.1294095225512605 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.4829629131445341 $CellContext`md2, 0. + 
           0.1294095225512605 $CellContext`md2}, {((-0.25) (0. - 
               0.4957224306869052 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.065263096110026 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.4957224306869052 $CellContext`md2, 0. + 
           0.065263096110026 $CellContext`md2}, {
          10.16, 0. - 0.4957224306869052 $CellContext`md2, 0. + 
           0.065263096110026 $CellContext`md2}, {
          10.16, 0. - 0.5 $CellContext`md2, 0. + 
           2.83276944882399*^-16 $CellContext`md2}, {((-0.25) (0. - 
               0.5 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              2.83276944882399*^-16 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.5 $CellContext`md2, 0. + 
           2.83276944882399*^-16 $CellContext`md2}, {((-0.25) (0. - 
               0.4957224306869052 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.065263096110026 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.4957224306869052 $CellContext`md2, 0. + 
           0.065263096110026 $CellContext`md2}, {((-0.25) (0. - 
               0.5 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              6.123233995736766*^-17 $CellContext`md2)^2)/$CellContext`mf2, 
           0. - 0.5 $CellContext`md2, 0. + 
           6.123233995736766*^-17 $CellContext`md2}, {
          10.16, 0. - 0.5 $CellContext`md2, 0. + 
           6.123233995736766*^-17 $CellContext`md2}, {
          10.16, 0. - 0.49572243068690525` $CellContext`md2, 0. - 
           0.06526309611002566 $CellContext`md2}, {((-0.25) (0. - 
               0.49572243068690525` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.06526309611002566 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.49572243068690525` $CellContext`md2, 0. - 
           0.06526309611002566 $CellContext`md2}, {((-0.25) (0. - 
               0.5 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              6.123233995736766*^-17 $CellContext`md2)^2)/$CellContext`mf2, 
           0. - 0.5 $CellContext`md2, 0. + 
           6.123233995736766*^-17 $CellContext`md2}, {((-0.25) (0. - 
               0.49572243068690525` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.06526309611002566 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.49572243068690525` $CellContext`md2, 0. - 
           0.06526309611002566 $CellContext`md2}, {
          10.16, 0. - 0.49572243068690525` $CellContext`md2, 0. - 
           0.06526309611002566 $CellContext`md2}, {
          10.16, 0. - 0.4829629131445342 $CellContext`md2, 0. - 
           0.12940952255126018` $CellContext`md2}, {((-0.25) (0. - 
               0.4829629131445342 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.12940952255126018` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.4829629131445342 $CellContext`md2, 0. - 
           0.12940952255126018` $CellContext`md2}, {((-0.25) (0. - 
               0.49572243068690525` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.06526309611002566 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.49572243068690525` $CellContext`md2, 0. - 
           0.06526309611002566 $CellContext`md2}, {((-0.25) (0. - 
               0.4829629131445342 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.12940952255126018` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.4829629131445342 $CellContext`md2, 0. - 
           0.12940952255126018` $CellContext`md2}, {
          10.16, 0. - 0.4829629131445342 $CellContext`md2, 0. - 
           0.12940952255126018` $CellContext`md2}, {
          10.16, 0. - 0.4619397662556435 $CellContext`md2, 0. - 
           0.1913417161825446 $CellContext`md2}, {((-0.25) (0. - 
               0.4619397662556435 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.1913417161825446 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.4619397662556435 $CellContext`md2, 0. - 
           0.1913417161825446 $CellContext`md2}, {((-0.25) (0. - 
               0.4829629131445342 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.12940952255126018` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.4829629131445342 $CellContext`md2, 0. - 
           0.12940952255126018` $CellContext`md2}, {((-0.25) (0. - 
               0.4619397662556435 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.1913417161825446 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.4619397662556435 $CellContext`md2, 0. - 
           0.1913417161825446 $CellContext`md2}, {
          10.16, 0. - 0.4619397662556435 $CellContext`md2, 0. - 
           0.1913417161825446 $CellContext`md2}, {
          10.16, 0. - 0.4330127018922195 $CellContext`md2, 0. - 
           0.2499999999999997 $CellContext`md2}, {((-0.25) (0. - 
               0.4330127018922195 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.2499999999999997 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.4330127018922195 $CellContext`md2, 0. - 
           0.2499999999999997 $CellContext`md2}, {((-0.25) (0. - 
               0.4619397662556435 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.1913417161825446 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.4619397662556435 $CellContext`md2, 0. - 
           0.1913417161825446 $CellContext`md2}, {((-0.25) (0. - 
               0.4330127018922194 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.2499999999999999 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.4330127018922194 $CellContext`md2, 0. - 
           0.2499999999999999 $CellContext`md2}, {
          10.16, 0. - 0.4330127018922194 $CellContext`md2, 0. - 
           0.2499999999999999 $CellContext`md2}, {
          10.16, 0. - 0.3966766701456177 $CellContext`md2, 0. - 
           0.30438071450436016` $CellContext`md2}, {((-0.25) (0. - 
               0.3966766701456177 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.30438071450436016` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.3966766701456177 $CellContext`md2, 0. - 
           0.30438071450436016` $CellContext`md2}, {((-0.25) (0. - 
               0.4330127018922194 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.2499999999999999 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.4330127018922194 $CellContext`md2, 0. - 
           0.2499999999999999 $CellContext`md2}, {((-0.25) (0. - 
               0.3966766701456177 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.30438071450436016` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.3966766701456177 $CellContext`md2, 0. - 
           0.30438071450436016` $CellContext`md2}, {
          10.16, 0. - 0.3966766701456177 $CellContext`md2, 0. - 
           0.30438071450436016` $CellContext`md2}, {
          10.16, 0. - 0.35355339059327395` $CellContext`md2, 0. - 
           0.35355339059327356` $CellContext`md2}, {((-0.25) (0. - 
               0.35355339059327395` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.35355339059327356` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.35355339059327395` $CellContext`md2, 0. - 
           0.35355339059327356` $CellContext`md2}, {((-0.25) (0. - 
               0.3966766701456177 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.30438071450436016` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.3966766701456177 $CellContext`md2, 0. - 
           0.30438071450436016` $CellContext`md2}, {((-0.25) (0. - 
               0.35355339059327395` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.35355339059327356` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.35355339059327395` $CellContext`md2, 0. - 
           0.35355339059327356` $CellContext`md2}, {
          10.16, 0. - 0.35355339059327395` $CellContext`md2, 0. - 
           0.35355339059327356` $CellContext`md2}, {
          10.16, 0. - 0.30438071450436044` $CellContext`md2, 0. - 
           0.39667667014561747` $CellContext`md2}, {((-0.25) (0. - 
               0.39667667014561747` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.30438071450436044` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.30438071450436044` $CellContext`md2, 0. - 
           0.39667667014561747` $CellContext`md2}, {((-0.25) (0. - 
               0.35355339059327395` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.35355339059327356` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.35355339059327395` $CellContext`md2, 0. - 
           0.35355339059327356` $CellContext`md2}, {((-0.25) (0. - 
               0.39667667014561747` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.30438071450436044` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.30438071450436044` $CellContext`md2, 0. - 
           0.39667667014561747` $CellContext`md2}, {
          10.16, 0. - 0.30438071450436044` $CellContext`md2, 0. - 
           0.39667667014561747` $CellContext`md2}, {
          10.16, 0. - 0.2500000000000002 $CellContext`md2, 0. - 
           0.4330127018922192 $CellContext`md2}, {((-0.25) (0. - 
               0.4330127018922192 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.2500000000000002 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.2500000000000002 $CellContext`md2, 0. - 
           0.4330127018922192 $CellContext`md2}, {((-0.25) (0. - 
               0.39667667014561747` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.30438071450436044` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.30438071450436044` $CellContext`md2, 0. - 
           0.39667667014561747` $CellContext`md2}, {((-0.25) (0. - 
               0.4330127018922192 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.2500000000000002 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.2500000000000002 $CellContext`md2, 0. - 
           0.4330127018922192 $CellContext`md2}, {
          10.16, 0. - 0.2500000000000002 $CellContext`md2, 0. - 
           0.4330127018922192 $CellContext`md2}, {
          10.16, 0. - 0.19134171618254517` $CellContext`md2, 0. - 
           0.46193976625564326` $CellContext`md2}, {((-0.25) (0. - 
               0.46193976625564326` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.19134171618254517` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.19134171618254517` $CellContext`md2, 0. - 
           0.46193976625564326` $CellContext`md2}, {((-0.25) (0. - 
               0.4330127018922192 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.2500000000000002 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.2500000000000002 $CellContext`md2, 0. - 
           0.4330127018922192 $CellContext`md2}, {((-0.25) (0. - 
               0.46193976625564326` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.19134171618254517` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.19134171618254517` $CellContext`md2, 0. - 
           0.46193976625564326` $CellContext`md2}, {
          10.16, 0. - 0.19134171618254517` $CellContext`md2, 0. - 
           0.46193976625564326` $CellContext`md2}, {
          10.16, 0. - 0.12940952255126073` $CellContext`md2, 0. - 
           0.48296291314453405` $CellContext`md2}, {((-0.25) (0. - 
               0.48296291314453405` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.12940952255126073` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.12940952255126073` $CellContext`md2, 0. - 
           0.48296291314453405` $CellContext`md2}, {((-0.25) (0. - 
               0.46193976625564326` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.19134171618254517` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.19134171618254517` $CellContext`md2, 0. - 
           0.46193976625564326` $CellContext`md2}, {((-0.25) (0. - 
               0.48296291314453405` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.12940952255126073` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.12940952255126073` $CellContext`md2, 0. - 
           0.48296291314453405` $CellContext`md2}, {
          10.16, 0. - 0.12940952255126073` $CellContext`md2, 0. - 
           0.48296291314453405` $CellContext`md2}, {
          10.16, 0. - 0.06526309611002626 $CellContext`md2, 0. - 
           0.49572243068690514` $CellContext`md2}, {((-0.25) (0. - 
               0.49572243068690514` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.06526309611002626 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.06526309611002626 $CellContext`md2, 0. - 
           0.49572243068690514` $CellContext`md2}, {((-0.25) (0. - 
               0.48296291314453405` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.12940952255126073` $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.12940952255126073` $CellContext`md2, 0. - 
           0.48296291314453405` $CellContext`md2}, {((-0.25) (0. - 
               0.49572243068690514` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.06526309611002626 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.06526309611002626 $CellContext`md2, 0. - 
           0.49572243068690514` $CellContext`md2}, {
          10.16, 0. - 0.06526309611002626 $CellContext`md2, 0. - 
           0.49572243068690514` $CellContext`md2}, {
          10.16, 0. - 5.359377197861141*^-16 $CellContext`md2, 0. - 
           0.5 $CellContext`md2}, {((-0.25) (0. - 
               0.5 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              5.359377197861141*^-16 $CellContext`md2)^2)/$CellContext`mf2, 
           0. - 5.359377197861141*^-16 $CellContext`md2, 0. - 
           0.5 $CellContext`md2}, {((-0.25) (0. - 
               0.49572243068690514` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              0.06526309611002626 $CellContext`md2)^2)/$CellContext`mf2, 0. - 
           0.06526309611002626 $CellContext`md2, 0. - 
           0.49572243068690514` $CellContext`md2}, {((-0.25) (0. - 
               0.5 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              9.184850993605148*^-17 $CellContext`md2)^2)/$CellContext`mf2, 
           0. - 9.184850993605148*^-17 $CellContext`md2, 0. - 
           0.5 $CellContext`md2}, {
          10.16, 0. - 9.184850993605148*^-17 $CellContext`md2, 0. - 
           0.5 $CellContext`md2}, {
          10.16, 0. + 0.06526309611002562 $CellContext`md2, 0. - 
           0.49572243068690525` $CellContext`md2}, {((-0.25) (0. - 
               0.49572243068690525` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.06526309611002562 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.06526309611002562 $CellContext`md2, 0. - 
           0.49572243068690525` $CellContext`md2}, {((-0.25) (0. - 
               0.5 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. - 
              9.184850993605148*^-17 $CellContext`md2)^2)/$CellContext`mf2, 
           0. - 9.184850993605148*^-17 $CellContext`md2, 0. - 
           0.5 $CellContext`md2}, {((-0.25) (0. - 
               0.49572243068690525` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.06526309611002562 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.06526309611002562 $CellContext`md2, 0. - 
           0.49572243068690525` $CellContext`md2}, {
          10.16, 0. + 0.06526309611002562 $CellContext`md2, 0. - 
           0.49572243068690525` $CellContext`md2}, {
          10.16, 0. + 0.12940952255126015` $CellContext`md2, 0. - 
           0.4829629131445342 $CellContext`md2}, {((-0.25) (0. - 
               0.4829629131445342 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.12940952255126015` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.12940952255126015` $CellContext`md2, 0. - 
           0.4829629131445342 $CellContext`md2}, {((-0.25) (0. - 
               0.49572243068690525` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.06526309611002562 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.06526309611002562 $CellContext`md2, 0. - 
           0.49572243068690525` $CellContext`md2}, {((-0.25) (0. - 
               0.4829629131445342 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.12940952255126015` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.12940952255126015` $CellContext`md2, 0. - 
           0.4829629131445342 $CellContext`md2}, {
          10.16, 0. + 0.12940952255126015` $CellContext`md2, 0. - 
           0.4829629131445342 $CellContext`md2}, {
          10.16, 0. + 0.19134171618254459` $CellContext`md2, 0. - 
           0.4619397662556435 $CellContext`md2}, {((-0.25) (0. - 
               0.4619397662556435 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.19134171618254459` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.19134171618254459` $CellContext`md2, 0. - 
           0.4619397662556435 $CellContext`md2}, {((-0.25) (0. - 
               0.4829629131445342 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.12940952255126015` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.12940952255126015` $CellContext`md2, 0. - 
           0.4829629131445342 $CellContext`md2}, {((-0.25) (0. - 
               0.4619397662556435 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.19134171618254459` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.19134171618254459` $CellContext`md2, 0. - 
           0.4619397662556435 $CellContext`md2}, {
          10.16, 0. + 0.19134171618254459` $CellContext`md2, 0. - 
           0.4619397662556435 $CellContext`md2}, {
          10.16, 0. + 0.24999999999999964` $CellContext`md2, 0. - 
           0.4330127018922195 $CellContext`md2}, {((-0.25) (0. - 
               0.4330127018922195 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.24999999999999964` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.24999999999999964` $CellContext`md2, 0. - 
           0.4330127018922195 $CellContext`md2}, {((-0.25) (0. - 
               0.4619397662556435 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.19134171618254459` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.19134171618254459` $CellContext`md2, 0. - 
           0.4619397662556435 $CellContext`md2}, {((-0.25) (0. - 
               0.4330127018922195 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.24999999999999964` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.24999999999999964` $CellContext`md2, 0. - 
           0.4330127018922195 $CellContext`md2}, {
          10.16, 0. + 0.24999999999999964` $CellContext`md2, 0. - 
           0.4330127018922195 $CellContext`md2}, {
          10.16, 0. + 0.30438071450435994` $CellContext`md2, 0. - 
           0.39667667014561786` $CellContext`md2}, {((-0.25) (0. - 
               0.39667667014561786` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.30438071450435994` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.30438071450435994` $CellContext`md2, 0. - 
           0.39667667014561786` $CellContext`md2}, {((-0.25) (0. - 
               0.4330127018922195 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.24999999999999964` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.24999999999999964` $CellContext`md2, 0. - 
           0.4330127018922195 $CellContext`md2}, {((-0.25) (0. - 
               0.39667667014561786` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.30438071450435994` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.30438071450435994` $CellContext`md2, 0. - 
           0.39667667014561786` $CellContext`md2}, {
          10.16, 0. + 0.30438071450435994` $CellContext`md2, 0. - 
           0.39667667014561786` $CellContext`md2}, {
          10.16, 0. + 0.35355339059327334` $CellContext`md2, 0. - 
           0.3535533905932742 $CellContext`md2}, {((-0.25) (0. - 
               0.3535533905932742 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.35355339059327334` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.35355339059327334` $CellContext`md2, 0. - 
           0.3535533905932742 $CellContext`md2}, {((-0.25) (0. - 
               0.39667667014561786` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.30438071450435994` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.30438071450435994` $CellContext`md2, 0. - 
           0.39667667014561786` $CellContext`md2}, {((-0.25) (0. - 
               0.35355339059327384` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.35355339059327373` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.35355339059327373` $CellContext`md2, 0. - 
           0.35355339059327384` $CellContext`md2}, {
          10.16, 0. + 0.35355339059327373` $CellContext`md2, 0. - 
           0.35355339059327384` $CellContext`md2}, {
          10.16, 0. + 0.39667667014561747` $CellContext`md2, 0. - 
           0.30438071450436044` $CellContext`md2}, {((-0.25) (0. - 
               0.30438071450436044` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.39667667014561747` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.39667667014561747` $CellContext`md2, 0. - 
           0.30438071450436044` $CellContext`md2}, {((-0.25) (0. - 
               0.35355339059327384` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.35355339059327373` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.35355339059327373` $CellContext`md2, 0. - 
           0.35355339059327384` $CellContext`md2}, {((-0.25) (0. - 
               0.30438071450436044` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.39667667014561747` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.39667667014561747` $CellContext`md2, 0. - 
           0.30438071450436044` $CellContext`md2}, {
          10.16, 0. + 0.39667667014561747` $CellContext`md2, 0. - 
           0.30438071450436044` $CellContext`md2}, {
          10.16, 0. + 0.4330127018922192 $CellContext`md2, 0. - 
           0.2500000000000002 $CellContext`md2}, {((-0.25) (0. - 
               0.2500000000000002 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4330127018922192 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.4330127018922192 $CellContext`md2, 0. - 
           0.2500000000000002 $CellContext`md2}, {((-0.25) (0. - 
               0.30438071450436044` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.39667667014561747` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.39667667014561747` $CellContext`md2, 0. - 
           0.30438071450436044` $CellContext`md2}, {((-0.25) (0. - 
               0.2500000000000002 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4330127018922192 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.4330127018922192 $CellContext`md2, 0. - 
           0.2500000000000002 $CellContext`md2}, {
          10.16, 0. + 0.4330127018922192 $CellContext`md2, 0. - 
           0.2500000000000002 $CellContext`md2}, {
          10.16, 0. + 0.46193976625564326` $CellContext`md2, 0. - 
           0.1913417161825452 $CellContext`md2}, {((-0.25) (0. - 
               0.1913417161825452 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.46193976625564326` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.46193976625564326` $CellContext`md2, 0. - 
           0.1913417161825452 $CellContext`md2}, {((-0.25) (0. - 
               0.2500000000000002 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.4330127018922192 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.4330127018922192 $CellContext`md2, 0. - 
           0.2500000000000002 $CellContext`md2}, {((-0.25) (0. - 
               0.1913417161825452 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.46193976625564326` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.46193976625564326` $CellContext`md2, 0. - 
           0.1913417161825452 $CellContext`md2}, {
          10.16, 0. + 0.46193976625564326` $CellContext`md2, 0. - 
           0.1913417161825452 $CellContext`md2}, {
          10.16, 0. + 0.48296291314453405` $CellContext`md2, 0. - 
           0.12940952255126076` $CellContext`md2}, {((-0.25) (0. - 
               0.12940952255126076` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.48296291314453405` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.48296291314453405` $CellContext`md2, 0. - 
           0.12940952255126076` $CellContext`md2}, {((-0.25) (0. - 
               0.1913417161825452 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.46193976625564326` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.46193976625564326` $CellContext`md2, 0. - 
           0.1913417161825452 $CellContext`md2}, {((-0.25) (0. - 
               0.12940952255126076` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.48296291314453405` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.48296291314453405` $CellContext`md2, 0. - 
           0.12940952255126076` $CellContext`md2}, {
          10.16, 0. + 0.48296291314453405` $CellContext`md2, 0. - 
           0.12940952255126076` $CellContext`md2}, {
          10.16, 0. + 0.49572243068690514` $CellContext`md2, 0. - 
           0.06526309611002629 $CellContext`md2}, {((-0.25) (0. - 
               0.06526309611002629 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.49572243068690514` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.49572243068690514` $CellContext`md2, 0. - 
           0.06526309611002629 $CellContext`md2}, {((-0.25) (0. - 
               0.12940952255126076` $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.48296291314453405` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.48296291314453405` $CellContext`md2, 0. - 
           0.12940952255126076` $CellContext`md2}, {((-0.25) (0. - 
               0.06526309611002629 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.49572243068690514` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.49572243068690514` $CellContext`md2, 0. - 
           0.06526309611002629 $CellContext`md2}, {
          10.16, 0. + 0.49572243068690514` $CellContext`md2, 0. - 
           0.06526309611002629 $CellContext`md2}, {
          10.16, 0. + 0.5 $CellContext`md2, 0. - 
           5.66553889764798*^-16 $CellContext`md2}, {((-0.25) (0. - 
               5.66553889764798*^-16 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 0.5 $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.5 $CellContext`md2, 0. - 
           5.66553889764798*^-16 $CellContext`md2}, {((-0.25) (0. - 
               0.06526309611002629 $CellContext`md2)^2)/$CellContext`mf2 - (
            0.25 (0. + 
              0.49572243068690514` $CellContext`md2)^2)/$CellContext`mf2, 0. + 
           0.49572243068690514` $CellContext`md2, 0. - 
           0.06526309611002629 $CellContext`md2}}]; \
$CellContext`lines1289120122132243167984 = 
       Compile[{$CellContext`md2, $CellContext`mf2}, {{((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, 0.5 $CellContext`md2, 
           0. $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, 0.4957224306869052 $CellContext`md2, 
           0.06526309611002579 $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, 0.48296291314453416` $CellContext`md2, 
           0.12940952255126037` $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, 0.46193976625564337` $CellContext`md2, 
           0.1913417161825449 $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, 0.43301270189221935` $CellContext`md2, 
           0.24999999999999997` $CellContext`md2}, {((-0.06249999999999999) \
$CellContext`md2^2)/$CellContext`mf2, 0.3966766701456176 $CellContext`md2, 
           0.3043807145043603 $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, 0.3535533905932738 $CellContext`md2, 
           0.35355339059327373` $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, 0.3043807145043604 $CellContext`md2, 
           0.3966766701456175 $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, 0.25000000000000006` $CellContext`md2, 
           0.4330127018922193 $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, 0.19134171618254492` $CellContext`md2, 
           
           0.46193976625564337` $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, 0.12940952255126048` $CellContext`md2, 
           0.4829629131445341 $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, 0.06526309611002586 $CellContext`md2, 
           0.4957224306869052 $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, 3.061616997868383*^-17 $CellContext`md2,
            0.5 $CellContext`md2}, {((-0.06250000000000001) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06526309611002569) $CellContext`md2,
            0.49572243068690525` $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.12940952255126031`) \
$CellContext`md2, 
           0.48296291314453416` $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.19134171618254475`) \
$CellContext`md2, 
           0.4619397662556434 $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2499999999999999) $CellContext`md2, 
           0.4330127018922194 $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.30438071450436016`) \
$CellContext`md2, 
           0.3966766701456177 $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.35355339059327373`) \
$CellContext`md2, 
           0.3535533905932738 $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.39667667014561747`) \
$CellContext`md2, 
           0.30438071450436044` $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.43301270189221924`) \
$CellContext`md2, 
           0.25000000000000017` $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.46193976625564337`) \
$CellContext`md2, 
           0.19134171618254492` $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4829629131445341) $CellContext`md2, 
           0.1294095225512605 $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4957224306869052) $CellContext`md2, 
           0.065263096110026 $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.5) $CellContext`md2, 
           6.123233995736766*^-17 $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.49572243068690525`) \
$CellContext`md2, (-0.06526309611002566) $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4829629131445342) $CellContext`md2, \
(-0.12940952255126018`) $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4619397662556435) $CellContext`md2, \
(-0.1913417161825446) $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.4330127018922194) $CellContext`md2, \
(-0.2499999999999999) $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.3966766701456177) $CellContext`md2, \
(-0.30438071450436016`) $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.35355339059327395`) \
$CellContext`md2, (-0.35355339059327356`) $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.30438071450436044`) \
$CellContext`md2, (-0.39667667014561747`) $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.2500000000000002) $CellContext`md2, \
(-0.4330127018922192) $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.19134171618254517`) \
$CellContext`md2, (-0.46193976625564326`) $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.12940952255126073`) \
$CellContext`md2, (-0.48296291314453405`) $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-0.06526309611002626) \
$CellContext`md2, (-0.49572243068690514`) $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, (-9.184850993605148*^-17) \
$CellContext`md2, (-0.5) $CellContext`md2}, {((-0.0625) \
$CellContext`md2^2)/$CellContext`mf2, 
           0.06526309611002562 $CellContext`md2, (-0.49572243068690525`) \
$CellContext`md2}, {((-0.0625) $CellContext`md2^2)/$CellContext`mf2, 
           
           0.12940952255126015` $CellContext`md2, (-0.4829629131445342) \
$CellContext`md2}, {((-0.0625) $CellContext`md2^2)/$CellContext`mf2, 
           0.19134171618254459` $CellContext`md2, (-0.4619397662556435) \
$CellContext`md2}, {((-0.0625) $CellContext`md2^2)/$CellContext`mf2, 
           0.24999999999999964` $CellContext`md2, (-0.4330127018922195) \
$CellContext`md2}, {((-0.0625) $CellContext`md2^2)/$CellContext`mf2, 
           0.30438071450435994` $CellContext`md2, (-0.39667667014561786`) \
$CellContext`md2}, {((-0.0625) $CellContext`md2^2)/$CellContext`mf2, 
           0.35355339059327373` $CellContext`md2, (-0.35355339059327384`) \
$CellContext`md2}, {((-0.0625) $CellContext`md2^2)/$CellContext`mf2, 
           0.39667667014561747` $CellContext`md2, (-0.30438071450436044`) \
$CellContext`md2}, {((-0.0625) $CellContext`md2^2)/$CellContext`mf2, 
           0.4330127018922192 $CellContext`md2, (-0.2500000000000002) \
$CellContext`md2}, {((-0.0625) $CellContext`md2^2)/$CellContext`mf2, 
           0.46193976625564326` $CellContext`md2, (-0.1913417161825452) \
$CellContext`md2}, {((-0.0625) $CellContext`md2^2)/$CellContext`mf2, 
           0.48296291314453405` $CellContext`md2, (-0.12940952255126076`) \
$CellContext`md2}, {((-0.0625) $CellContext`md2^2)/$CellContext`mf2, 
           0.49572243068690514` $CellContext`md2, (-0.06526309611002629) \
$CellContext`md2}, {((-0.0625) $CellContext`md2^2)/$CellContext`mf2, 
           0.5 $CellContext`md2, (-1.2246467991473532`*^-16) \
$CellContext`md2}, {10.16, 0.5 $CellContext`md2, 0. $CellContext`md2}, {
          10.16, 0.4957224306869052 $CellContext`md2, 
           0.06526309611002579 $CellContext`md2}, {
          10.16, 0.48296291314453416` $CellContext`md2, 
           0.12940952255126037` $CellContext`md2}, {
          10.16, 0.46193976625564337` $CellContext`md2, 
           0.1913417161825449 $CellContext`md2}, {
          10.16, 0.43301270189221935` $CellContext`md2, 
           0.24999999999999997` $CellContext`md2}, {
          10.16, 0.3966766701456176 $CellContext`md2, 
           0.3043807145043603 $CellContext`md2}, {
          10.16, 0.3535533905932738 $CellContext`md2, 
           0.35355339059327373` $CellContext`md2}, {
          10.16, 0.3043807145043604 $CellContext`md2, 
           0.3966766701456175 $CellContext`md2}, {
          10.16, 0.25000000000000006` $CellContext`md2, 
           0.4330127018922193 $CellContext`md2}, {
          10.16, 0.19134171618254492` $CellContext`md2, 
           0.46193976625564337` $CellContext`md2}, {
          10.16, 0.12940952255126048` $CellContext`md2, 
           0.4829629131445341 $CellContext`md2}, {
          10.16, 0.06526309611002586 $CellContext`md2, 
           0.4957224306869052 $CellContext`md2}, {
          10.16, 3.061616997868383*^-17 $CellContext`md2, 
           0.5 $CellContext`md2}, {
          10.16, (-0.06526309611002569) $CellContext`md2, 
           0.49572243068690525` $CellContext`md2}, {
          10.16, (-0.12940952255126031`) $CellContext`md2, 
           0.48296291314453416` $CellContext`md2}, {
          10.16, (-0.19134171618254475`) $CellContext`md2, 
           0.4619397662556434 $CellContext`md2}, {
          10.16, (-0.2499999999999999) $CellContext`md2, 
           0.4330127018922194 $CellContext`md2}, {
          10.16, (-0.30438071450436016`) $CellContext`md2, 
           0.3966766701456177 $CellContext`md2}, {
          10.16, (-0.35355339059327373`) $CellContext`md2, 
           0.3535533905932738 $CellContext`md2}, {
          10.16, (-0.39667667014561747`) $CellContext`md2, 
           0.30438071450436044` $CellContext`md2}, {
          10.16, (-0.43301270189221924`) $CellContext`md2, 
           0.25000000000000017` $CellContext`md2}, {
          10.16, (-0.46193976625564337`) $CellContext`md2, 
           0.19134171618254492` $CellContext`md2}, {
          10.16, (-0.4829629131445341) $CellContext`md2, 
           0.1294095225512605 $CellContext`md2}, {
          10.16, (-0.4957224306869052) $CellContext`md2, 
           0.065263096110026 $CellContext`md2}, {
          10.16, (-0.5) $CellContext`md2, 
           6.123233995736766*^-17 $CellContext`md2}, {
          10.16, (-0.49572243068690525`) $CellContext`md2, \
(-0.06526309611002566) $CellContext`md2}, {
          10.16, (-0.4829629131445342) $CellContext`md2, \
(-0.12940952255126018`) $CellContext`md2}, {
          10.16, (-0.4619397662556435) $CellContext`md2, \
(-0.1913417161825446) $CellContext`md2}, {
          10.16, (-0.4330127018922194) $CellContext`md2, \
(-0.2499999999999999) $CellContext`md2}, {
          10.16, (-0.3966766701456177) $CellContext`md2, \
(-0.30438071450436016`) $CellContext`md2}, {
          10.16, (-0.35355339059327395`) $CellContext`md2, \
(-0.35355339059327356`) $CellContext`md2}, {
          10.16, (-0.30438071450436044`) $CellContext`md2, \
(-0.39667667014561747`) $CellContext`md2}, {
          10.16, (-0.2500000000000002) $CellContext`md2, \
(-0.4330127018922192) $CellContext`md2}, {
          10.16, (-0.19134171618254517`) $CellContext`md2, \
(-0.46193976625564326`) $CellContext`md2}, {
          10.16, (-0.12940952255126073`) $CellContext`md2, \
(-0.48296291314453405`) $CellContext`md2}, {
          10.16, (-0.06526309611002626) $CellContext`md2, \
(-0.49572243068690514`) $CellContext`md2}, {
          10.16, (-9.184850993605148*^-17) $CellContext`md2, (-0.5) \
$CellContext`md2}, {
          10.16, 0.06526309611002562 $CellContext`md2, \
(-0.49572243068690525`) $CellContext`md2}, {
          10.16, 0.12940952255126015` $CellContext`md2, (-0.4829629131445342) \
$CellContext`md2}, {
          10.16, 0.19134171618254459` $CellContext`md2, (-0.4619397662556435) \
$CellContext`md2}, {
          10.16, 0.24999999999999964` $CellContext`md2, (-0.4330127018922195) \
$CellContext`md2}, {
          10.16, 0.30438071450435994` $CellContext`md2, \
(-0.39667667014561786`) $CellContext`md2}, {
          10.16, 0.35355339059327373` $CellContext`md2, \
(-0.35355339059327384`) $CellContext`md2}, {
          10.16, 0.39667667014561747` $CellContext`md2, \
(-0.30438071450436044`) $CellContext`md2}, {
          10.16, 0.4330127018922192 $CellContext`md2, (-0.2500000000000002) \
$CellContext`md2}, {
          10.16, 0.46193976625564326` $CellContext`md2, (-0.1913417161825452) \
$CellContext`md2}, {
          10.16, 0.48296291314453405` $CellContext`md2, \
(-0.12940952255126076`) $CellContext`md2}, {
          10.16, 0.49572243068690514` $CellContext`md2, \
(-0.06526309611002629) $CellContext`md2}, {
          10.16, 0.5 $CellContext`md2, (-1.2246467991473532`*^-16) \
$CellContext`md2}}]); Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.538110247918705*^9}]
}, Open  ]]
},
WindowSize->{1076, 933},
WindowMargins->{{62, Automatic}, {Automatic, 0}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 5323, 130, 298, "Input"],
Cell[CellGroupData[{
Cell[5893, 154, 1231, 33, 73, "Input"],
Cell[7127, 189, 136199, 2241, 215, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[143363, 2435, 3252, 85, 163, "Input"],
Cell[146618, 2522, 2373749, 41391, 777, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
