(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[         0,          0]
NotebookDataLength[   1375493,      22901]
NotebookOptionsPosition[   1373884,      22840]
NotebookOutlinePosition[   1374578,      22867]
CellTagsIndexPosition[   1374444,      22861]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["?CustomGrid", "Input",
 CellChangeTimes->{{3.5986235002346354`*^9, 3.598623501522295*^9}}],

Cell[BoxData[
 StyleBox["\<\"CustomGrid[component, gridparameter, gridboundary, options] is \
a generic building block that models gain, absorption, or custom-defined \
actions at a surface or inside a volume within the ray trace.\\n \\nThe \
gridparameter can either be a user-defined variable name or a discrete matrix \
of data elements. When the gridparameter is a variable name, then CustomGrid \
incorporates this name as an input variable of the RayTraceFunction. Numeric \
data points must then be provided at the start of the ray-trace operation \
either within SymbolicValues or directly to the RayTraceFunction. When the \
gridparameter contains a 3-dimensional matrix of data points, then CustomGrid \
incorporates these data points directly into the ray-trace model and no \
additional inputs to the ray-trace are required. The gridboundary parameter \
specifies the dimensions of a rectangular bounding box that encloses the \
gridspace. The gridboundary parameter accepts the same types of patterns as \
the Boundary function.\\n \\nSee also: GridFunction, EmbedGridData, \
GridOrder, GridDimensions, and GridCoordinateOffset.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.598623502019421*^9},
 CellTags->"Info3598601901-9407342"]
}, Open  ]],

Cell[CellGroupData[{

Cell["?GridFunction", "Input",
 CellChangeTimes->{{3.598623505708624*^9, 3.59862350590812*^9}}],

Cell[BoxData[
 StyleBox["\<\"GridFunction -> function provides a function that determines \
the gain, absorption, and other custom behaviors for each element within the \
grid space.\\n \\nThe input parameter to the gain function is given 10 \
parameters although not all parameters need be employed by the function. For \
three-dimensional grid functions, the first three parameters are indices to \
the affected gain grid element. For two-dimensional grid functions, the first \
two parameters are indices to the affected gain grid element. For \
one-dimensional grid functions, the first parameter is an index to the \
affected gain grid element. The next parameter is the distance of the ray \
traversing across the gird element. The remaining 6 parameters are the \
starting and ending coordinates of the ray that passes through a given grid \
element volume. In addition, the gain function may also reference any number \
of internal ray-parameters such as RayStart, RayEnd, Intensity, RayLength, \
WaveLength, and Polarization. The grid function may change any ray parameter \
as well as the gridparameter name originally specified with the CustomGrid \
function. Any changed Ray parameter element such as Intensity or the \
gridparameter parameter will be used for the subsequent ray-gain grid \
interactions.\\n \\nSee also: CustomGrid, EmbedGridData, GridOrder, \
GridDimensions, and GridCoordinateOffset.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.598623506409739*^9},
 CellTags->"Info3598601906-9407342"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
gridscreen = CustomGrid[Screen[10], griddata, 1, \
GridFunction->Function[griddata[[#1]]=griddata[[#1]]+Intensity/100.;1], \
(*ReportedFunction->griddata,*)
\tEmbedGridData->False, SymbolicValues->{griddata->Table[0.,{100}]}]\
\>", "Input",
 CellChangeTimes->{{3.597237958709096*^9, 3.597237996842471*^9}, {
   3.597238330810791*^9, 3.597238335507229*^9}, {3.597238688536249*^9, 
   3.597238707368928*^9}, {3.597239042671205*^9, 3.597239076850318*^9}, {
   3.597239171591176*^9, 3.597239180812758*^9}, {3.5973441527811117`*^9, 
   3.5973442199616823`*^9}, {3.597381816363407*^9, 3.597381881967244*^9}, 
   3.5973823970689163`*^9, {3.59738363048591*^9, 3.597383634595129*^9}, {
   3.5973843277122107`*^9, 3.59738434308495*^9}, {3.597411462492382*^9, 
   3.597411467491835*^9}, {3.597457999497156*^9, 3.597458018967382*^9}, {
   3.597632038733914*^9, 3.597632058548106*^9}, {3.597632217099813*^9, 
   3.597632251225375*^9}, {3.597633026177422*^9, 3.597633037359619*^9}, {
   3.597634057038965*^9, 3.5976340779855013`*^9}, {3.5976354605428457`*^9, 
   3.597635517602868*^9}, 3.597935028617187*^9, {3.5979350824619427`*^9, 
   3.597935114386157*^9}, 3.597935437634905*^9, {3.5979372170759993`*^9, 
   3.597937221426099*^9}, {3.5979437424467907`*^9, 3.597943742789399*^9}, {
   3.597949982146311*^9, 3.597949991221162*^9}, {3.597954072812476*^9, 
   3.597954142248941*^9}, 3.597954201586076*^9, {3.597954250367436*^9, 
   3.597954296525408*^9}, {3.5979549603485603`*^9, 3.5979549969559793`*^9}, 
   3.597956746074148*^9, {3.5979751481055117`*^9, 3.597975178488409*^9}, 
   3.597975251439142*^9, {3.597975307029909*^9, 3.597975327044886*^9}, {
   3.5980174593104343`*^9, 3.5980174771063423`*^9}, {3.598018702438558*^9, 
   3.598018731005484*^9}, {3.598018781788267*^9, 3.598018783971434*^9}, {
   3.598031905538517*^9, 3.598031908143593*^9}, 3.598064115818272*^9, 
   3.5980642223435497`*^9, {3.598197311625805*^9, 3.5981973168886223`*^9}, {
   3.5981981468334103`*^9, 3.5981981533128843`*^9}, 3.598198187439753*^9, {
   3.598198793679852*^9, 3.5981987951587963`*^9}, {3.598199042192593*^9, 
   3.5981990427433977`*^9}, {3.5982002400165997`*^9, 3.598200242615312*^9}, {
   3.598200972737542*^9, 3.5982009750485687`*^9}, {3.598202591590025*^9, 
   3.598202622206437*^9}, 3.5982335430388412`*^9, {3.598362419441012*^9, 
   3.598362421311713*^9}, {3.598362470879631*^9, 3.598362475734568*^9}, {
   3.598362955403304*^9, 3.5983629573942947`*^9}, 3.598363154342114*^9, {
   3.5983631924837837`*^9, 3.5983631943001223`*^9}, {3.5984026148163157`*^9, 
   3.5984026180217113`*^9}, {3.5984085425740013`*^9, 
   3.5984085771667013`*^9}, {3.5984090815283327`*^9, 3.59840908690305*^9}, {
   3.5984350348196077`*^9, 3.598435035936314*^9}, {3.598462394154949*^9, 
   3.5984624074257603`*^9}, {3.598462454713657*^9, 3.598462455168845*^9}, {
   3.598462495119619*^9, 3.598462495623303*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"CustomGrid", "[", 
     RowBox[{
      RowBox[{"Screen", "[", "10", "]"}], ",", "griddata", ",", "1", ",", 
      RowBox[{"GridFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
            "griddata", "\[LeftDoubleBracket]", "#1", 
             "\[RightDoubleBracket]"}], "=", 
            RowBox[{
             RowBox[{
             "griddata", "\[LeftDoubleBracket]", "#1", 
              "\[RightDoubleBracket]"}], "+", 
             FractionBox["Intensity", "100.`"]}]}], ";", "1"}], ")"}], "&"}], 
        ")"}]}], ",", 
      RowBox[{"SymbolicValues", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"griddata", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
          "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", 
           ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
           "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", 
           ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
           "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", 
           ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
           "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", 
           ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
           "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", 
           ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
           "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", 
           ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
           "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", 
           ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
           "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", 
           ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
           "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", 
           ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
           "0.`"}], "}"}]}], "}"}]}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{
  3.5981981555313187`*^9, 3.598198188061347*^9, 3.5981983212575083`*^9, {
   3.598198787448887*^9, 3.5981988077112617`*^9}, 3.598198988881875*^9, 
   3.598199043251938*^9, 3.5982002431482973`*^9, 3.5982003171573544`*^9, 
   3.5982009759411993`*^9, 3.598201792737488*^9, 3.59820188406221*^9, 
   3.5982022018647823`*^9, 3.598202316979401*^9, 3.598202451805091*^9, {
   3.5982025940173817`*^9, 3.598202622648765*^9}, {3.598233538525316*^9, 
   3.598233543480609*^9}, 3.598233883610293*^9, 3.598234008010249*^9, 
   3.5982341903078327`*^9, 3.598238203600895*^9, 3.598239258684332*^9, 
   3.5982396761516037`*^9, 3.598360832562944*^9, 3.598362357744336*^9, 
   3.5983624221408243`*^9, 3.598362870938562*^9, 3.598362960999866*^9, 
   3.598363155004799*^9, 3.598363195358526*^9, 3.5983681579932747`*^9, 
   3.598373591734436*^9, 3.5983914065499496`*^9, 3.598391675245483*^9, 
   3.598391796893528*^9, 3.598391919284937*^9, 3.598400854044015*^9, 
   3.598400944572823*^9, 3.598401259451724*^9, 3.598401608207617*^9, 
   3.5984018583284273`*^9, 3.598402227710452*^9, 3.598402630001006*^9, 
   3.598405395789516*^9, {3.598408559472781*^9, 3.598408577978623*^9}, 
   3.598409057957252*^9, 3.5984093635547333`*^9, 3.59840969701506*^9, 
   3.5984341735240717`*^9, 3.598434687110642*^9, 3.5984350391212797`*^9, 
   3.598435139840987*^9, 3.598435289853179*^9, 3.598435563646282*^9, 
   3.598436795854898*^9, 3.598436984372196*^9, 3.5984373422400618`*^9, 
   3.5984424580812197`*^9, {3.5984427425268517`*^9, 3.598442770747919*^9}, 
   3.5984430489414062`*^9, 3.59844343599297*^9, 3.5984435431953287`*^9, 
   3.598443668428887*^9, 3.598443706130392*^9, 3.598460857516924*^9, 
   3.598461046484213*^9, 3.598461187374584*^9, 3.598462012748748*^9, 
   3.598462151070519*^9, 3.598462397326064*^9, {3.598462442886278*^9, 
   3.5984624601130238`*^9}, 3.598462496112122*^9, 3.598463056981743*^9, 
   3.598623283398411*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ManipulateSystem[{Move[LineOfRays[40,NumberOfRays->1000],0,0],Move[\
PlanoConvexLens[{ff,100},50,10],10],Move[gridscreen,{xs,110}],Move[Screen[50],\
125]}, 
\t{DynamicFrame[PlotType->TopView,OpticalSystem->{Move[LineOfRays[40,\
NumberOfRays->20],0,0],Move[PlanoConvexLens[{ff,100},50,10],10],Move[Screen[\
10],{xs,110}],Move[Screen[50],125]}], 
\tDynamicFrame[PlotType->ListPlot,ReportedFunction->$griddata,AspectRatio->.6]\
},EmbedRays->True, ShowSliders->{ff,xs}]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5973817082977037`*^9, 3.597381714399399*^9}, {
   3.597383106405095*^9, 3.5973831474192677`*^9}, {3.5973836057244673`*^9, 
   3.597383611171139*^9}, {3.597384353174958*^9, 3.5973843587883472`*^9}, {
   3.5973853817400723`*^9, 3.597385386187841*^9}, 3.597411474398016*^9, {
   3.597411504605047*^9, 3.597411537769678*^9}, {3.597426155137835*^9, 
   3.5974261569207373`*^9}, {3.597426459577071*^9, 3.597426460063609*^9}, {
   3.5974358681185837`*^9, 3.597435870789466*^9}, {3.597435925261199*^9, 
   3.59743595638137*^9}, 3.597444782252898*^9, {3.5974448412040577`*^9, 
   3.597444869236726*^9}, {3.597449469078992*^9, 3.59744946960637*^9}, 
   3.597449731186005*^9, {3.597449823684758*^9, 3.597449848715803*^9}, {
   3.597454592425885*^9, 3.597454593152026*^9}, {3.5974588089722567`*^9, 
   3.59745881154707*^9}, {3.5974590022953053`*^9, 3.59745901914935*^9}, 
   3.597459874232761*^9, 3.597547821366404*^9, {3.597632608343173*^9, 
   3.597632653789155*^9}, {3.597632956064898*^9, 3.597632964391678*^9}, {
   3.5976330417364407`*^9, 3.597633062841584*^9}, {3.597633207643664*^9, 
   3.597633273296908*^9}, {3.597934993772254*^9, 3.59793499742791*^9}, {
   3.597935035712966*^9, 3.597935063963784*^9}, {3.597938433212634*^9, 
   3.5979384354434013`*^9}, {3.597943775910635*^9, 3.597943777821829*^9}, {
   3.597956666532222*^9, 3.5979567093366413`*^9}, 3.5980317722125072`*^9, {
   3.598064060021538*^9, 3.598064087026854*^9}, {3.598064213281942*^9, 
   3.598064241535131*^9}, {3.598200205978129*^9, 3.598200216191757*^9}, {
   3.598200252578405*^9, 3.598200280542292*^9}, {3.598200361862123*^9, 
   3.598200363538107*^9}, {3.5982009897691507`*^9, 3.598200993935952*^9}, {
   3.598201137236236*^9, 3.598201158707644*^9}, {3.598233566164316*^9, 
   3.598233569570717*^9}, {3.598234018606045*^9, 3.5982340215787363`*^9}, {
   3.5982393556237707`*^9, 3.598239395005348*^9}, {3.598362971307336*^9, 
   3.598362992521083*^9}, {3.598363159765607*^9, 3.598363163996776*^9}, {
   3.598363210492401*^9, 3.598363274377812*^9}, {3.598363591083961*^9, 
   3.5983635991057796`*^9}, {3.598401950751361*^9, 3.598401962044096*^9}, {
   3.5984025316145477`*^9, 3.59840253329484*^9}, {3.5984028241197033`*^9, 
   3.598402828051606*^9}, {3.598403392725958*^9, 3.598403396526956*^9}, 
   3.598408564709264*^9, {3.5984342313344383`*^9, 3.5984342341384287`*^9}, {
   3.598434715339159*^9, 3.598434720642118*^9}, {3.598435326782407*^9, 
   3.598435329541696*^9}, {3.598435384139639*^9, 3.598435386274411*^9}, {
   3.598435587527646*^9, 3.598435590238103*^9}, {3.598435690984528*^9, 
   3.598435693389933*^9}, 3.598436333971613*^9, {3.598442521054516*^9, 
   3.598442529044064*^9}, {3.598460579406272*^9, 3.59846061435527*^9}, {
   3.598460821955463*^9, 3.598460845848547*^9}, {3.5984610601395273`*^9, 
   3.598461062866214*^9}, {3.598461200144246*^9, 3.598461203486764*^9}, {
   3.5984613560761337`*^9, 3.598461382522648*^9}, {3.59846147543291*^9, 
   3.5984614797678843`*^9}, {3.5984620763945093`*^9, 3.598462078897368*^9}, {
   3.59846215843312*^9, 3.598462193086844*^9}, {3.598462263678342*^9, 
   3.598462266788951*^9}, 3.598462424964086*^9, {3.598462478408889*^9, 
   3.5984624908248587`*^9}, {3.5984627790813227`*^9, 3.598462781624992*^9}, {
   3.5984628123932056`*^9, 3.598462844736147*^9}, {3.598463170802805*^9, 
   3.598463180719309*^9}, {3.598623287144732*^9, 3.5986232909436007`*^9}, {
   3.598623323585688*^9, 3.59862335990982*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`ff$$ = 
    100., $CellContext`griddata$$ = CompressedData["
1:eJxTTMoPSmVkYGBIYRgFo2AU4AMAgqoCDw==
    "], $CellContext`maxff$$ = 
    200, $CellContext`maxxs$$ = 220, $CellContext`minff$$ = 
    1., $CellContext`minxs$$ = 
    1, $CellContext`staticpolygons1213192201411311362631665$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
      
      "]]}, $CellContext`staticpolygons1313192201411311362632641$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZigAKHeAcIw/IAjB8WCgRXTeD81atAwADOZwQz
NOH8NWB5BTh/A5gvcADV/A97YPwVEHkHVL4CnP/nPwhooMkbwPkhEPfB+f/A
6i0cUO2zhPPD0NSvRjMP6h84fw2aezaguRfqHxs0/xxA5SPCA+ofNHlEeIag
hTfUP2jhZ3kAADp5fqU=
      "]]}, $CellContext`xs$$ = 110., Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`griddata$$], CompressedData["
1:eJxTTMoPSmVkYGBIYRgFo2AU4AMAgqoCDw==
       "]}}, {{
       Hold[$CellContext`ff$$], 100.}, 1., 200}, {{
       Hold[$CellContext`xs$$], 110.}, 1, 220}, {{
       Hold[$CellContext`minff$$], 1.}}, {{
       Hold[$CellContext`maxff$$], 200}}, {{
       Hold[$CellContext`minxs$$], 1}}, {{
       Hold[$CellContext`maxxs$$], 220}}, {
      Hold[
       Style[
        Grid[{{"ff", 
           InputField[
            Dynamic[$CellContext`minff$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159313192201411311363754564; $CellContext`ff$$, \
($CellContext`ff$$ = #)& ], {
             Dynamic[$CellContext`minff$$], 
             Dynamic[$CellContext`maxff$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxff$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable159313192201411311363754564; $CellContext`ff$$, \
($CellContext`ff$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minff$$], 1.}}, {{
       Hold[$CellContext`maxff$$], 200}}, {
      Hold[
       Style[
        Grid[{{"xs", 
           InputField[
            Dynamic[$CellContext`minxs$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159313192201411311363754725; $CellContext`xs$$, \
($CellContext`xs$$ = #)& ], {
             Dynamic[$CellContext`minxs$$], 
             Dynamic[$CellContext`maxxs$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxxs$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable159313192201411311363754725; $CellContext`xs$$, \
($CellContext`xs$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minxs$$], 1}}, {{
       Hold[$CellContext`maxxs$$], 220}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{
              "ff", "xs"}, {$CellContext`ff$$, $CellContext`xs$$}}], 
           Optica`Optica`SymbolicRanges -> Map[ToExpression[
               Part[#, 1]] -> {
               Part[#, 2], 
               Part[#, 3]}& , 
             Select[
              
              Transpose[{{
                "ff", "xs"}, {$CellContext`minff$$, $CellContext`minxs$$}, \
{$CellContext`maxff$$, $CellContext`maxxs$$}}], NumberQ[
               Part[#, 2]]& ]]}; 
        Optica`Optica`$OpticalSystemScript = 
         "{LineOfRays[40, NumberOfRays -> 1000], Move[PlanoConvexLens[{ff, \
100}, 50, 10], 10.], CustomGrid[Move[Screen[10], {xs, 110.}, SymbolicValues \
-> {xs -> 110}], griddata, 1, GridFunction -> ((griddata[[#1]] = \
griddata[[#1]] + Intensity/100.; 1) & ), SymbolicValues -> {xs -> 110, \
griddata -> {0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., \
0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., \
0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., \
0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., \
0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., \
0., 0., 0., 0., 0., 0., 0., 0.}}], Move[Screen[50], 125.]}"; Print[
          InputForm[
           StringJoin["{SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "ff", "xs"}, {$CellContext`ff$$, $CellContext`xs$$}}]], 
            ", SymbolicRanges -> ", 
            ToString[
             Map[StringJoin[
               Part[#, 1], "->", 
               ToString[{
                 Part[#, 2], 
                 Part[#, 3]}, InputForm]]& , 
              Select[
               
               Transpose[{{
                 "ff", "xs"}, {$CellContext`minff$$, $CellContext`minxs$$}, \
{$CellContext`maxff$$, $CellContext`maxxs$$}}], NumberQ[
                Part[#, 2]]& ]]], "}"]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`staticpolygons1213192201411311362631665$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
         "]]}}}, {{
       Hold[$CellContext`staticpolygons1313192201411311362632641$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZigAKHeAcIw/IAjB8WCgRXTeD81atAwADOZwQz
NOH8NWB5BTh/A5gvcADV/A97YPwVEHkHVL4CnP/nPwhooMkbwPkhEPfB+f/A
6i0cUO2zhPPD0NSvRjMP6h84fw2aezaguRfqHxs0/xxA5SPCA+ofNHlEeIag
hTfUP2jhZ3kAADp5fqU=
         "]]}}}}, Typeset`size$$ = {
    816., {217.125, 222.875}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`ff$539893$$ = 
    0, $CellContext`xs$539894$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`ff$$ = 
        100., $CellContext`griddata$$ = CompressedData["
1:eJxTTMoPSmVkYGBIYRgFo2AU4AMAgqoCDw==
         "], $CellContext`maxff$$ = 
        200, $CellContext`maxxs$$ = 220, $CellContext`minff$$ = 
        1., $CellContext`minxs$$ = 
        1, $CellContext`staticpolygons1213192201411311362631665$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
           
           "]]}, $CellContext`staticpolygons1313192201411311362632641$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZigAKHeAcIw/IAjB8WCgRXTeD81atAwADOZwQz
NOH8NWB5BTh/A5gvcADV/A97YPwVEHkHVL4CnP/nPwhooMkbwPkhEPfB+f/A
6i0cUO2zhPPD0NSvRjMP6h84fw2aezaguRfqHxs0/xxA5SPCA+ofNHlEeIag
hTfUP2jhZ3kAADp5fqU=
           "]]}, $CellContext`xs$$ = 110.}, 
      "ControllerVariables" :> {
        Hold[$CellContext`ff$$, $CellContext`ff$539893$$, 0], 
        Hold[$CellContext`xs$$, $CellContext`xs$539894$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         TabView[{"TopView" -> Show[{
              Graphics[{{
                 Opacity[0.8], {
                  AbsoluteThickness[1], 
                  AbsolutePointSize[1], 
                  EdgeForm[], 
                  RGBColor[0.4, 0.6, 0.8], 
                  Polygon[
                   Dynamic[
                    (Map[
                    Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], {{1, 27}}]& )[
                    $CellContext`polygons1113192201411311362630504[$\
CellContext`ff$$]]]]}, 
                 
                 GeometricTransformation[$CellContext`\
staticpolygons1213192201411311362631665$$, 
                  Dynamic[
                  BesselJ[
                    1., 3.]; {{{1, 0}, {0, 
                    1}}, {$CellContext`xs$$, 
                    0}}]], $CellContext`\
staticpolygons1313192201411311362632641$$, 
                 Opacity[1], 
                 RGBColor[
                 0.038747429704798886`, 0.9161617552424038, 
                  0.039847212269181365`], 
                 AbsoluteThickness[Medium], 
                 Line[
                  Dynamic[
                   Refresh[
                    Map[{
                    Part[#, {1, 2}], 
                    Part[#, {4, 5}]}& , 
                    Select[
                    $CellContext`raytracefunction113192201411311362634959[$\
CellContext`ff$$, $CellContext`xs$$], And[
                    Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]], 
                    TrackedSymbols :> {$CellContext`ff$$, $CellContext`xs$$}],
                    SynchronousUpdating -> False]], 
                 Tooltip[
                  Locator[
                   Dynamic[
                   BesselJ[
                    1., 3.]; {$CellContext`xs$$, 0}, ($CellContext`xs$$ = Chop[
                    Part[#, 1]])& ], 
                   Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["xs = ", 
                    ToString[$CellContext`xs$$]]]]}}]}, {
             PlotLabel -> "TopView", ImageSize -> 800, AspectRatio -> 
              Automatic}], "ListPlot" -> Dynamic[
             ListPlot[
              
              Apply[$CellContext`rayfunction213192201411311363743294, \
{$CellContext`ff$$, $CellContext`xs$$, $CellContext`griddata$$}], {
              PlotLabel -> "ListPlot", AspectRatio -> 0.6, 
               DataRange -> {-0.5, 0.5}, Frame -> True, Axes -> True, Mesh -> 
               False, ImageSize -> 600, Joined -> True, PlotRange -> All}], 
             SynchronousUpdating -> True]}, 1], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`griddata$$, CompressedData["
1:eJxTTMoPSmVkYGBIYRgFo2AU4AMAgqoCDw==
          "]}, ControlType -> 
         None}, {{$CellContext`ff$$, 100.}, 1., 200, ControlType -> 
         None}, {{$CellContext`xs$$, 110.}, 1, 220, ControlType -> 
         None}, {{$CellContext`minff$$, 1.}, ControlType -> 
         None}, {{$CellContext`maxff$$, 200}, ControlType -> 
         None}, {{$CellContext`minxs$$, 1}, ControlType -> 
         None}, {{$CellContext`maxxs$$, 220}, ControlType -> None}, 
        Style[
         Grid[{{"ff", 
            InputField[
             Dynamic[$CellContext`minff$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159313192201411311363754564; $CellContext`ff$$, \
($CellContext`ff$$ = #)& ], {
              Dynamic[$CellContext`minff$$], 
              Dynamic[$CellContext`maxff$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxff$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable159313192201411311363754564; $CellContext`ff$$, \
($CellContext`ff$$ = #)& ]}}]], {{$CellContext`minff$$, 1.}, ControlType -> 
         None}, {{$CellContext`maxff$$, 200}, ControlType -> None}, 
        Style[
         Grid[{{"xs", 
            InputField[
             Dynamic[$CellContext`minxs$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159313192201411311363754725; $CellContext`xs$$, \
($CellContext`xs$$ = #)& ], {
              Dynamic[$CellContext`minxs$$], 
              Dynamic[$CellContext`maxxs$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxxs$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable159313192201411311363754725; $CellContext`xs$$, \
($CellContext`xs$$ = #)& ]}}]], {{$CellContext`minxs$$, 1}, ControlType -> 
         None}, {{$CellContext`maxxs$$, 220}, ControlType -> None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{
               "ff", "xs"}, {$CellContext`ff$$, $CellContext`xs$$}}], 
            Optica`Optica`SymbolicRanges -> Map[ToExpression[
                Part[#, 1]] -> {
                Part[#, 2], 
                Part[#, 3]}& , 
              Select[
               
               Transpose[{{
                 "ff", "xs"}, {$CellContext`minff$$, $CellContext`minxs$$}, \
{$CellContext`maxff$$, $CellContext`maxxs$$}}], NumberQ[
                Part[#, 2]]& ]]}; 
         Optica`Optica`$OpticalSystemScript = 
          "{LineOfRays[40, NumberOfRays -> 1000], Move[PlanoConvexLens[{ff, \
100}, 50, 10], 10.], CustomGrid[Move[Screen[10], {xs, 110.}, SymbolicValues \
-> {xs -> 110}], griddata, 1, GridFunction -> ((griddata[[#1]] = \
griddata[[#1]] + Intensity/100.; 1) & ), SymbolicValues -> {xs -> 110, \
griddata -> {0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., \
0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., \
0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., \
0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., \
0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., \
0., 0., 0., 0., 0., 0., 0., 0.}}], Move[Screen[50], 125.]}"; Print[
           InputForm[
            StringJoin["{SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "ff", "xs"}, {$CellContext`ff$$, $CellContext`xs$$}}]], 
             ", SymbolicRanges -> ", 
             ToString[
              Map[StringJoin[
                Part[#, 1], "->", 
                ToString[{
                  Part[#, 2], 
                  Part[#, 3]}, InputForm]]& , 
               Select[
                
                Transpose[{{
                  "ff", "xs"}, {$CellContext`minff$$, $CellContext`minxs$$}, \
{$CellContext`maxff$$, $CellContext`maxxs$$}}], NumberQ[
                 Part[#, 2]]& ]]], "}"]]], ImageSize -> 
         Automatic], \
{{$CellContext`staticpolygons1213192201411311362631665$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
            "]]}}, 
         ControlType -> 
         None}, {{$CellContext`staticpolygons1313192201411311362632641$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZigAKHeAcIw/IAjB8WCgRXTeD81atAwADOZwQz
NOH8NWB5BTh/A5gvcADV/A97YPwVEHkHVL4CnP/nPwhooMkbwPkhEPfB+f/A
6i0cUO2zhPPD0NSvRjMP6h84fw2aezaguRfqHxs0/xxA5SPCA+ofNHlEeIag
hTfUP2jhZ3kAADp5fqU=
            "]]}}, ControlType -> None}}, 
      "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1, 2}, SynchronousInitialization -> False, 
        SynchronousUpdating -> False, 
        BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{861., {293., 298.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`raytracefunction113192201411311362634959 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`ff$$, 
            Blank[Real]}, {$CellContext`xs$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`rsx$ = 1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`propagatedrays$ = CompressedData["
1:eJzVmD9LQnEYhW8NUYPQYBCXAhNJ+0NqGbT1hn0Aq6nFIWhqqDG3JoPmlppq
bOoLBP3mvoAtDYHt4idIe++xeDM8je+FOJ0nvRwfUq534eh0/3g8iqJ07ycf
2aMSfqGhvLM9/HH83+/i4ltu4j153KHc3vSPh8Hz2tmDq3jsr/OMOr8e8Xlm
52d+P68iw8/z/9e1V682Uh/lwHGv3iLRgDd0frcluz07m9fFwHGv3iZFE97Q
+d2W9OS0avWVwHGv3qZFE97Q+d2WXHbjl5NCPnDcq7e0aMIbOr/bkqXH+6dm
Nxs47tXbrGjCGzq/25L+u7HamA8c9+ptTjThDZ3fbclrX09qJnDcq7eMaMIb
Or/bkq2vf6ypwHGv3rKiCW/o/G5LLvqXG63OM8e9esuJJryh87stOVM/JPfq
bVE04Q2d321JSd+PwnGv3gqiCW/o/G5Lks9/4bhXb8uiCW/o/G5LkusN4bhX
b6uiCW/o/G5LCnp9Kxz36m1NNOENnd9tSVO/TwnHvXoriSa8ofO7LWnr93fh
uFdvZdGEN3R+tyXJ/SLhuFdv66IJb+j8bktqen9SOO7V24Zowhs6v3s4H9wH
HcG9esPrsMnvxm+fPOs1Bw==
             "]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -10. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - ((14921604 $CellContext`ff$$)/
                    28766183) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + (
                    2 $CellContext`rx$) ((14921604 $CellContext`ff$$)/
                    28766183); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    625., Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[((-14921604) $CellContext`ff$$)/
                    28766183 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + Sqrt[(222654265932816 $CellContext`ff$$^2)/
                    827493284389489 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ff$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    625., Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[((-14921604) $CellContext`ff$$)/
                    28766183 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + Sqrt[(222654265932816 $CellContext`ff$$^2)/
                    827493284389489 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ff$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 539705.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -20. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$352}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 625.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$352 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$352), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$352, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$352}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 539706.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -10. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    539705.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`ff$$] $CellContext`ray2$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`ff$$] $CellContext`ray3$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`ff$$] $CellContext`ray2$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 1. $CellContext`ray3$^2)^0.5, 
                    1., 0.}, {(Sign[$CellContext`ff$$] $CellContext`ray3$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 1. $CellContext`ray3$^2)^0.5, 
                    0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -20. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    539706.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 
                    0}; $CellContext`activeregion$ = -1.; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
              False; $CellContext`reportedrayspresent$ = 
              False; $CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`reporteddummyrayspresent$ = 
              False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
                
                Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                   Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                   Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                   Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                    Re[$CellContext`xs$$]; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                   Chop[$CellContext`rx$]; $CellContext`ry$ = 
                   Chop[$CellContext`ry$]; $CellContext`rz$ = 
                   Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                   False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                 If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                    True; ($CellContext`intersections$ = Block[{Compile`$353}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 25.], {
                    
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$353 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$353), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$353, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$353}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 539755.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                   If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    539755.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ + 
                    Re[$CellContext`xs$$]; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`xs$$], 0., 
                    0.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`deflecteddummyrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                    "]])& , $CellContext`propagatedrays$]]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]; If[
               
               And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); (
             If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
              False; $CellContext`reportedrayspresent$ = 
              False; $CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`reporteddummyrayspresent$ = 
              False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
                
                Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                   Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                   Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                   Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -125. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                   Chop[$CellContext`rx$]; $CellContext`ry$ = 
                   Chop[$CellContext`ry$]; $CellContext`rz$ = 
                   Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                   False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                 If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                    True; ($CellContext`intersections$ = Block[{Compile`$354}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 625.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$354 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$354), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$354, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$354}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 539787.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                   If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 1., 
                    539787.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    125. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    125., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`deflecteddummyrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                    "]])& , $CellContext`propagatedrays$]]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]; If[
               
               And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); (
             If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
           Map[{
              Part[#, 1], 
              Part[#, 2], 
              Part[#, 3], 
              Part[#, 4], 
              Part[#, 5], 
              
              Part[#, 6]}& , $CellContext`reportedrays$]], \
$CellContext`compileoptionsetting$]]; \
$CellContext`rayfunction213192201411311363743294 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`ff$$, 
            Blank[Real]}, {$CellContext`xs$$, 
            Blank[Real]}, {$CellContext`griddata$$, 
            Blank[Real], 1}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`gcx$, $CellContext`gcy$, \
$CellContext`gcz$, $CellContext`gdimx$, $CellContext`gdimy$, \
$CellContext`gdimz$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`gintercepts$, \
$CellContext`gmaxlength$, $CellContext`gmm$, $CellContext`gnn$, \
$CellContext`goo$, $CellContext`grr$, $CellContext`grsx$, $CellContext`grsy$, \
$CellContext`grsz$, $CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$, $CellContext`gspacex$, $CellContext`gspacey$, \
$CellContext`gspacez$, $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`gxave$, $CellContext`gyave$, $CellContext`gzave$, \
$CellContext`holeintersections$, $CellContext`holeQ$, \
$CellContext`holeQlist$, $CellContext`hor$, $CellContext`index$, \
$CellContext`index1$, $CellContext`index2$, $CellContext`inrays$, \
$CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$, \
$CellContext`$griddata$}, $CellContext`rsx$ = 1.; $CellContext`rsy$ = 
            1.; $CellContext`rsz$ = 1.; $CellContext`rex$ = 
            1.; $CellContext`rey$ = 1.; $CellContext`rez$ = 
            1.; $CellContext`r1$ = 1.; $CellContext`r2$ = 
            1.; $CellContext`r3$ = 1.; $CellContext`r4$ = 
            1.; $CellContext`r5$ = 1.; $CellContext`r6$ = 
            1.; $CellContext`r7$ = 1.; $CellContext`r8$ = 
            1.; $CellContext`r9$ = 1.; $CellContext`symr1$ = 
            1.; $CellContext`symr2$ = 1.; $CellContext`symr3$ = 
            1.; $CellContext`symr4$ = 1.; $CellContext`symr5$ = 
            1.; $CellContext`symr6$ = 1.; $CellContext`symr7$ = 
            1.; $CellContext`symr8$ = 1.; $CellContext`symr9$ = 
            1.; $CellContext`rx$ = 1.; $CellContext`ry$ = 
            1.; $CellContext`rz$ = 1.; $CellContext`xunit$ = 
            1.; $CellContext`yunit$ = 1.; $CellContext`zunit$ = 
            1.; $CellContext`ray1$ = 1.; $CellContext`ray2$ = 
            1.; $CellContext`ray3$ = 1.; $CellContext`LocRSx$ = 
            1.; $CellContext`LocRSy$ = 1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`$griddata$ = CompressedData["
1:eJxTTMoPSmVkYGBIYRgFo2AU4AMAgqoCDw==
             
             "]; $CellContext`gintercepts$ = {{1.}}; $CellContext`gspacex$ = 
            1.; $CellContext`gspacey$ = 1.; $CellContext`gspacez$ = 
            1.; $CellContext`gxave$ = 1.; $CellContext`gyave$ = 
            1.; $CellContext`gzave$ = 1.; $CellContext`grsx$ = 
            1.; $CellContext`grsy$ = 1.; $CellContext`grsz$ = 
            1.; $CellContext`grtx$ = 1.; $CellContext`grty$ = 
            1.; $CellContext`grtz$ = 1.; $CellContext`gcx$ = 
            1.; $CellContext`gcy$ = 1.; $CellContext`gcz$ = 
            1.; $CellContext`gdimx$ = 1.; $CellContext`gdimy$ = 
            1.; $CellContext`gdimz$ = 1.; $CellContext`gu$ = 
            1.; $CellContext`gv$ = 1.; $CellContext`gw$ = 
            1.; $CellContext`gnn$ = 1; $CellContext`gmm$ = 
            1; $CellContext`goo$ = 1; $CellContext`grr$ = 
            1.; $CellContext`gmaxlength$ = 
            1.; $CellContext`$griddata$ = $CellContext`griddata$$; \
$CellContext`propagatedrays$ = CompressedData["
1:eJzV3Xl0FNUW+PtWEYIDtOIQ5hYwhLnBKSDCYRCjMrQThLkZDXOjAhEQysjV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             
             "]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$} = Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -10. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - ((14921604 $CellContext`ff$$)/
                    28766183) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + (
                    2 $CellContext`rx$) ((14921604 $CellContext`ff$$)/
                    28766183); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    625., Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[((-14921604) $CellContext`ff$$)/
                    28766183 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + Sqrt[(222654265932816 $CellContext`ff$$^2)/
                    827493284389489 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ff$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    625., 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[((-14921604) $CellContext`ff$$)/
                    28766183 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + Sqrt[(222654265932816 $CellContext`ff$$^2)/
                    827493284389489 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ff$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 539602.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -20. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$350}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 625.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$350 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$350), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$350, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$350}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 539603.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -10. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    539602.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`ff$$] $CellContext`ray2$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`ff$$] $CellContext`ray3$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`ff$$] $CellContext`ray2$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 1. $CellContext`ray3$^2)^0.5, 
                    1., 0.}, {(Sign[$CellContext`ff$$] $CellContext`ray3$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 1. $CellContext`ray3$^2)^0.5, 
                    0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 
                    1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -20. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    539603.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 
                    0}; $CellContext`activeregion$ = -1.; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGBgAmJGIFZngIEP9gNHN0SY5J89SJx6uHv346AH0B/0podm
uAEAvnFifw==
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]); $CellContext`inrays$ = \
$CellContext`deflectedlocalrays$; $CellContext`propagate$ = \
$CellContext`generationnumber$ < $CellContext`generationlimit$]; \
$CellContext`propagatedrays$ = If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`deflectedrayspresent$ = 
              False; $CellContext`deflectedlocalrays$ = 
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                  Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                  Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                  Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                   Re[$CellContext`xs$$]; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                  Chop[$CellContext`rx$]; $CellContext`ry$ = 
                  Chop[$CellContext`ry$]; $CellContext`rz$ = 
                  Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                  False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                   True; ($CellContext`intersections$ = 
                    Block[{Compile`$295}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 25.], {
                    
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$295 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$295), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$295, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$295}]}, {{-1., 0., 0.}}]]; 
                   AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 519437.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                   Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                   If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                  If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    519437.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ + 
                    Re[$CellContext`xs$$]; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`xs$$], 0., 
                    0.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`newdeflectedrays$ = \
{$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot = $CellContext`surfacerotationmatrix$; \
{$CellContext`gdimy$} = Take[
                    N[
                    Dimensions[$CellContext`$griddata$]], 
                    1]; $CellContext`gspacey$ = (
                    0.5 - -0.5)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    
                    0.5 - -0.5)/$CellContext`gdimz$; $CellContext`gyave$ = \
(-0.5 + 0.5)/2; $CellContext`gzave$ = (-0.5 + 0.5)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    
                    Join[{{($CellContext`ray2$ - -0.5)/$CellContext`gspacey$ + 
                    1., ($CellContext`ray3$ - -0.5)/$CellContext`gspacez$ + 
                    1., $CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$, 0., 0.}}, {{
                    0., 0., 0., $CellContext`gyave$, $CellContext`gzave$, 0., 
                    0.}}], And[
                    Part[#, 4] > -0.5, Part[#, 4] < 0.5, Part[#, 5] > -0.5, 
                    Part[#, 5] < 0.5]& ], {{-1., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Part[$CellContext`gintercepts$, 1, 1] > 
                    0., $CellContext`gintercepts$ = {
                    First[$CellContext`gintercepts$]}; $CellContext`gnn$ = 
                    Floor[
                    Part[$CellContext`gintercepts$, 1, 1]]; $CellContext`gmm$ = 
                    Floor[
                    Part[$CellContext`gintercepts$, 1, 2]]; $CellContext`grr$ = 
                    Part[$CellContext`gintercepts$, 1, 3]; ((
                    Part[$CellContext`$griddata$, #] = 
                    Part[$CellContext`$griddata$, #] + \
$CellContext`intensity$/100.; 
                    1)& )[$CellContext`gnn$, $CellContext`gmm$, \
$CellContext`grr$, 
                    Part[$CellContext`gintercepts$, 1, 4], 
                    Part[$CellContext`gintercepts$, 1, 5], 0., 0., 0., 0., 
                    0.]; 1., $CellContext`gintercepts$ = {{0., 0., 0., 0., 0.,
                     0., 0.}}; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); 
                    First[$CellContext`allcreatedrays$], {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}], $CellContext`deflecteddummyrayspresent$ = 
                   True; CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                   "]])& , $CellContext`propagatedrays$]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$; $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
              False; $CellContext`reportedrayspresent$ = 
              False; $CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`reporteddummyrayspresent$ = 
              False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
                
                Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                   Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                   Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                   Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -125. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                   Chop[$CellContext`rx$]; $CellContext`ry$ = 
                   Chop[$CellContext`ry$]; $CellContext`rz$ = 
                   Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                   False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                 If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                    True; ($CellContext`intersections$ = Block[{Compile`$351}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 625.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$351 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$351), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$351, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$351}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 539655.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                   If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 1., 
                    539655.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    125. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    125., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`deflecteddummyrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                    "]])& , $CellContext`propagatedrays$]]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]; If[
               
               And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); (
             If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               
               1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 
               2], $CellContext`reportedrays$]; $CellContext`$griddata$], \
$CellContext`compileoptionsetting$]]; \
$CellContext`polygons1113192201411311362630504 = 
       Compile[{$CellContext`ff}, {{
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-625. + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -25.}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-434.0277777777779 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -20.833333333333336`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-277.7777777777778 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -16.666666666666668`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-156.25000000000006` + 0.2690707829696608 $CellContext`ff^2])
             Sign[$CellContext`ff], -12.500000000000002`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-69.44444444444449 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -8.333333333333336}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-17.36111111111115 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -4.166666666666671}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-1.262177448353619*^-29 + 
              0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -3.552713678800501*^-15}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-17.361111111111093` + 0.2690707829696608 $CellContext`ff^2])
             Sign[$CellContext`ff], 4.166666666666664}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-69.44444444444437 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], 8.333333333333329}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-156.24999999999983` + 0.2690707829696608 $CellContext`ff^2])
             Sign[$CellContext`ff], 12.499999999999993`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-277.7777777777775 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], 16.666666666666657`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-434.0277777777776 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], 20.83333333333333}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-624.9999999999997 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], 24.999999999999993`}, {20., 25.}, {20., 
          20.833333333333336`}, {20., 16.666666666666668`}, {20., 
          12.500000000000002`}, {20., 8.333333333333336}, {20., 
          4.166666666666671}, {20., 3.552713678800501*^-15}, {
          20., -4.166666666666664}, {20., -8.333333333333329}, {
          20., -12.499999999999993`}, {20., -16.666666666666657`}, {
          20., -20.83333333333333}, {20., -24.999999999999993`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-625. + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -25.}}]); Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.598462836456691*^9, 3.598462853309495*^9}, 
   3.5984630609711103`*^9, {3.598463185176252*^9, 3.598463190867339*^9}, {
   3.598472026587674*^9, 3.598472045014732*^9}, {3.598488518201374*^9, 
   3.598488537875039*^9}, {3.5986232386414213`*^9, 3.598623240145561*^9}, {
   3.598623274720578*^9, 3.598623295240508*^9}, {3.598623340887285*^9, 
   3.598623367850293*^9}, {3.598623419975803*^9, 3.598623421946933*^9}, {
   3.614736840371635*^9, 3.614736841591296*^9}, {3.614736923097023*^9, 
   3.614736924175819*^9}, {3.614738901084036*^9, 3.614738902302537*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
gridscreen = CustomGrid[Screen[10], griddata, 1, \
GridFunction->Function[griddata[[#2,#1]]=griddata[[#2,#1]]+Intensity/100.;1.],\
 EmbedGridData->True, ReportedFunction->griddata, 
\tSymbolicValues->{griddata->Table[0.,{50},{50}]}]\
\>", "Input",
 CellChangeTimes->{{3.597237958709096*^9, 3.597237996842471*^9}, {
   3.597238330810791*^9, 3.597238335507229*^9}, {3.597238688536249*^9, 
   3.597238707368928*^9}, {3.597239042671205*^9, 3.597239076850318*^9}, {
   3.597239171591176*^9, 3.597239180812758*^9}, {3.5973441527811117`*^9, 
   3.5973442199616823`*^9}, {3.597381816363407*^9, 3.597381881967244*^9}, 
   3.5973823970689163`*^9, {3.59738363048591*^9, 3.597383634595129*^9}, {
   3.5973843277122107`*^9, 3.59738434308495*^9}, {3.597411462492382*^9, 
   3.597411467491835*^9}, {3.597457999497156*^9, 3.597458018967382*^9}, {
   3.597632038733914*^9, 3.597632058548106*^9}, {3.597632217099813*^9, 
   3.597632251225375*^9}, {3.597633026177422*^9, 3.597633037359619*^9}, {
   3.597634057038965*^9, 3.5976340779855013`*^9}, {3.5976354605428457`*^9, 
   3.597635517602868*^9}, 3.597935028617187*^9, {3.5979350824619427`*^9, 
   3.597935114386157*^9}, 3.597935437634905*^9, {3.5979372170759993`*^9, 
   3.597937221426099*^9}, {3.5979437424467907`*^9, 3.597943742789399*^9}, {
   3.597949982146311*^9, 3.597949991221162*^9}, {3.597954072812476*^9, 
   3.597954142248941*^9}, 3.597954201586076*^9, {3.597954250367436*^9, 
   3.597954296525408*^9}, {3.5979549603485603`*^9, 3.5979549969559793`*^9}, 
   3.597956746074148*^9, {3.5979751481055117`*^9, 3.597975178488409*^9}, 
   3.597975251439142*^9, {3.597975307029909*^9, 3.597975327044886*^9}, {
   3.5980174593104343`*^9, 3.5980174771063423`*^9}, {3.598018702438558*^9, 
   3.598018731005484*^9}, {3.598018781788267*^9, 3.598018783971434*^9}, {
   3.598031905538517*^9, 3.598031908143593*^9}, 3.598064115818272*^9, 
   3.5980642223435497`*^9, {3.598197311625805*^9, 3.5981973168886223`*^9}, {
   3.5981981468334103`*^9, 3.5981981533128843`*^9}, 3.598198187439753*^9, {
   3.598198793679852*^9, 3.5981987951587963`*^9}, {3.598199042192593*^9, 
   3.5981990427433977`*^9}, {3.5982002400165997`*^9, 3.598200242615312*^9}, {
   3.598200972737542*^9, 3.5982009750485687`*^9}, {3.598202591590025*^9, 
   3.598202622206437*^9}, {3.5982331083231287`*^9, 3.5982331322689342`*^9}, 
   3.598234610072633*^9, {3.598281539022485*^9, 3.598281596484474*^9}, {
   3.598281628495562*^9, 3.598281671733893*^9}, {3.5982948511188717`*^9, 
   3.598294866693426*^9}, {3.598294899541727*^9, 3.598294908476705*^9}, 
   3.598309356623974*^9, {3.598309387549246*^9, 3.59830939145197*^9}, {
   3.598309518132127*^9, 3.59830952967093*^9}, 3.5983095724118137`*^9, {
   3.598310143048439*^9, 3.598310179998191*^9}, {3.5983110778752747`*^9, 
   3.598311098433178*^9}, {3.59831129919524*^9, 3.598311300906159*^9}, {
   3.598358602197773*^9, 3.5983586494594393`*^9}, {3.598360961894485*^9, 
   3.598361011036282*^9}, {3.598361066211995*^9, 3.598361075383881*^9}, {
   3.5983612430713654`*^9, 3.598361263917527*^9}, {3.5983621873666477`*^9, 
   3.5983621939175663`*^9}, {3.598472148336784*^9, 3.5984721501038027`*^9}, {
   3.598472180255437*^9, 3.598472196790572*^9}, {3.598488955488246*^9, 
   3.5984890316501513`*^9}, {3.5984891402172613`*^9, 3.598489179103013*^9}, {
   3.598489223842286*^9, 3.598489243736842*^9}, {3.5984904934877567`*^9, 
   3.598490542523088*^9}, {3.5984917269487123`*^9, 3.598491766554967*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"CustomGrid", "[", 
     RowBox[{
      RowBox[{"Screen", "[", "10", "]"}], ",", "griddata", ",", "1", ",", 
      RowBox[{"GridFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"griddata", "\[LeftDoubleBracket]", 
             RowBox[{"#2", ",", "#1"}], "\[RightDoubleBracket]"}], "=", 
            RowBox[{
             RowBox[{"griddata", "\[LeftDoubleBracket]", 
              RowBox[{"#2", ",", "#1"}], "\[RightDoubleBracket]"}], "+", 
             FractionBox["Intensity", "100.`"]}]}], ";", "1.`"}], ")"}], 
         "&"}], ")"}]}], ",", 
      RowBox[{"EmbedGridData", "\[Rule]", "True"}], ",", 
      RowBox[{"ReportedFunction", "\[Rule]", "griddata"}], ",", 
      RowBox[{"SymbolicValues", "\[Rule]", 
       RowBox[{"{", "}"}]}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{
  3.5985251338496428`*^9, {3.598528927771216*^9, 3.5985289373090076`*^9}, 
   3.598529139579485*^9, 3.5985294362988243`*^9, 3.598529785272764*^9, 
   3.598529873702886*^9, 3.5986134111808977`*^9, 3.598615796078841*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ManipulateSystem[{Move[GridOfRays[{40,40},NumberOfRays->100],0,0],Move[\
PlanoConvexLens[{ff,100},50,10],10],Move[gridscreen,{xs,110}],Move[Screen[50],\
125]}, 
{DynamicFrame[PlotType->TopView,OpticalSystem->{Move[LineOfRays[40,\
NumberOfRays->20],0,0],Move[PlanoConvexLens[{ff,100},50,10],10],Move[Screen[\
10],{xs,110}],Move[Screen[50],125]}],DynamicFrame[PlotType->ListPlot3D,\
PlotLabel-> Intensity]}]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5973817082977037`*^9, 3.597381714399399*^9}, {
   3.597383106405095*^9, 3.5973831474192677`*^9}, {3.5973836057244673`*^9, 
   3.597383611171139*^9}, {3.597384353174958*^9, 3.5973843587883472`*^9}, {
   3.5973853817400723`*^9, 3.597385386187841*^9}, 3.597411474398016*^9, {
   3.597411504605047*^9, 3.597411537769678*^9}, {3.597426155137835*^9, 
   3.5974261569207373`*^9}, {3.597426459577071*^9, 3.597426460063609*^9}, {
   3.5974358681185837`*^9, 3.597435870789466*^9}, {3.597435925261199*^9, 
   3.59743595638137*^9}, 3.597444782252898*^9, {3.5974448412040577`*^9, 
   3.597444869236726*^9}, {3.597449469078992*^9, 3.59744946960637*^9}, 
   3.597449731186005*^9, {3.597449823684758*^9, 3.597449848715803*^9}, {
   3.597454592425885*^9, 3.597454593152026*^9}, {3.5974588089722567`*^9, 
   3.59745881154707*^9}, {3.5974590022953053`*^9, 3.59745901914935*^9}, 
   3.597459874232761*^9, 3.597547821366404*^9, {3.597632608343173*^9, 
   3.597632653789155*^9}, {3.597632956064898*^9, 3.597632964391678*^9}, {
   3.5976330417364407`*^9, 3.597633062841584*^9}, {3.597633207643664*^9, 
   3.597633273296908*^9}, {3.597934993772254*^9, 3.59793499742791*^9}, {
   3.597935035712966*^9, 3.597935063963784*^9}, {3.597938433212634*^9, 
   3.5979384354434013`*^9}, {3.597943775910635*^9, 3.597943777821829*^9}, {
   3.597956666532222*^9, 3.5979567093366413`*^9}, 3.5980317722125072`*^9, {
   3.598064060021538*^9, 3.598064087026854*^9}, {3.598064213281942*^9, 
   3.598064241535131*^9}, {3.598200205978129*^9, 3.598200216191757*^9}, {
   3.598200252578405*^9, 3.598200280542292*^9}, {3.598200361862123*^9, 
   3.598200363538107*^9}, {3.5982009897691507`*^9, 3.598200993935952*^9}, {
   3.598201137236236*^9, 3.598201158707644*^9}, {3.59820246112914*^9, 
   3.598202481846354*^9}, {3.598233161345736*^9, 3.5982331951113443`*^9}, {
   3.59823426574898*^9, 3.598234286577612*^9}, {3.598234316769774*^9, 
   3.598234337259926*^9}, {3.598234626979321*^9, 3.59823463915486*^9}, {
   3.5982346701678877`*^9, 3.598234709118672*^9}, {3.598234740818186*^9, 
   3.598234840053815*^9}, {3.5982348930592127`*^9, 3.598234895115028*^9}, {
   3.5982353164638147`*^9, 3.5982353516695766`*^9}, {3.59823630800804*^9, 
   3.59823630969383*^9}, {3.5982364010844193`*^9, 3.598236402026805*^9}, {
   3.598236934781481*^9, 3.598236941211789*^9}, {3.598238921703396*^9, 
   3.5982389346124487`*^9}, {3.5982391200337763`*^9, 3.598239124154553*^9}, {
   3.598239217836976*^9, 3.5982392249155483`*^9}, {3.5982394446290703`*^9, 
   3.598239445940723*^9}, {3.598280999160664*^9, 3.598281159130096*^9}, {
   3.598281317499378*^9, 3.598281334832835*^9}, 3.598287973584145*^9, {
   3.598293191842476*^9, 3.598293230736383*^9}, {3.5982946814027977`*^9, 
   3.598294684356538*^9}, {3.598294729385804*^9, 3.5982947600192127`*^9}, {
   3.598310196029866*^9, 3.598310196204924*^9}, {3.59831121944151*^9, 
   3.5983112243342657`*^9}, {3.5983113155490503`*^9, 3.598311318546649*^9}, {
   3.598311383751254*^9, 3.598311387280938*^9}, {3.598362130386321*^9, 
   3.598362136975369*^9}, 3.598472124043518*^9, {3.598472154809353*^9, 
   3.5984721734231873`*^9}, 3.598472239549612*^9, {3.598472370589409*^9, 
   3.598472405187937*^9}, 3.598473431918316*^9, {3.598489254967058*^9, 
   3.5984892797235622`*^9}, {3.598489334654168*^9, 3.598489339724307*^9}, {
   3.598490376740888*^9, 3.598490408074595*^9}, {3.5984905482038107`*^9, 
   3.598490550690796*^9}, {3.598490608759013*^9, 3.5984906204969387`*^9}, {
   3.598490859350644*^9, 3.598490862172333*^9}, {3.598490999858392*^9, 
   3.5984910065930243`*^9}, {3.5984917992190943`*^9, 3.598491813450012*^9}, {
   3.598491912149733*^9, 3.598491929964335*^9}, {3.5985232995815763`*^9, 
   3.598523311490386*^9}, {3.5985233534277067`*^9, 3.5985233848529663`*^9}, {
   3.598523423349094*^9, 3.598523431414445*^9}, {3.598528935685931*^9, 
   3.598528961564802*^9}, {3.598529021033514*^9, 3.598529054696096*^9}, {
   3.5985291717044783`*^9, 3.598529237960127*^9}, {3.598529442044526*^9, 
   3.598529446835479*^9}, 3.598529510196568*^9, {3.5985295734861307`*^9, 
   3.59852963448055*^9}, {3.598529763966462*^9, 3.598529778223288*^9}, 
   3.59852988095361*^9, {3.5986134200846663`*^9, 3.598613527800748*^9}, {
   3.598615929230233*^9, 3.598615932612814*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`ff$$ = 100., $CellContext`maxff$$ = 
    125, $CellContext`maxxs$$ = 220, $CellContext`minff$$ = 
    95, $CellContext`minxs$$ = 
    1, $CellContext`staticpolygons1213150201411393214964820$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
      
      "]]}, $CellContext`staticpolygons1313150201411393214965833$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZigAKHeAcIw/IAjB8WCgRXTeD81atAwADOZwQz
NOH8NWB5BTh/A5gvcADV/A97YPwVEHkHVL4CnP/nPwhooMkbwPkhEPfB+f/A
6i0cUO2zhPPD0NSvRjMP6h84fw2aezaguRfqHxs0/xxA5SPCA+ofNHlEeIag
hTfUP2jhZ3kAADp5fqU=
      "]]}, $CellContext`xs$$ = 110., Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`ff$$], 100.}, 1., 200}, {{
       Hold[$CellContext`xs$$], 110.}, 1, 220}, {{
       Hold[$CellContext`minff$$], 1.}}, {{
       Hold[$CellContext`maxff$$], 200}}, {{
       Hold[$CellContext`minxs$$], 1}}, {{
       Hold[$CellContext`maxxs$$], 220}}, {
      Hold[
       Style[
        Grid[{{"ff", 
           InputField[
            Dynamic[$CellContext`minff$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159313150201411393217589757; $CellContext`ff$$, \
($CellContext`ff$$ = #)& ], {
             Dynamic[$CellContext`minff$$], 
             Dynamic[$CellContext`maxff$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxff$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable159313150201411393217589757; $CellContext`ff$$, \
($CellContext`ff$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minff$$], 1.}}, {{
       Hold[$CellContext`maxff$$], 200}}, {{
       Hold[$CellContext`minff$$], 1.}}, {{
       Hold[$CellContext`maxff$$], 200}}, {{
       Hold[$CellContext`minxs$$], 1}}, {{
       Hold[$CellContext`maxxs$$], 220}}, {{
       Hold[$CellContext`minff$$], 1.}}, {{
       Hold[$CellContext`maxff$$], 200}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{
              "ff", "xs"}, {$CellContext`ff$$, $CellContext`xs$$}}], 
           Optica`Optica`SymbolicRanges -> Map[ToExpression[
               Part[#, 1]] -> {
               Part[#, 2], 
               Part[#, 3]}& , 
             Select[
              
              Transpose[{{
                "ff", "xs"}, {$CellContext`minff$$, $CellContext`minxs$$}, \
{$CellContext`maxff$$, $CellContext`maxxs$$}}], NumberQ[
               Part[#, 2]]& ]]}; 
        Optica`Optica`$OpticalSystemScript = 
         "{GridOfRays[{40, 40}, NumberOfRays -> 100], \
Move[PlanoConvexLens[{ff, 100}, 50, 10], 10.], CustomGrid[Move[Screen[10], \
{xs, 110.}, SymbolicValues -> {xs -> 110}], griddata, 1, GridFunction -> \
((griddata[[#2,#1]] = griddata[[#2,#1]] + Intensity/100.; 1.) & ), \
EmbedGridData -> True, ReportedFunction -> griddata, SymbolicValues -> {xs -> \
110}], Move[Screen[50], 125.]}"; Print[
          InputForm[
           StringJoin["{SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "ff", "xs"}, {$CellContext`ff$$, $CellContext`xs$$}}]], 
            ", SymbolicRanges -> ", 
            ToString[
             Map[StringJoin[
               Part[#, 1], "->", 
               ToString[{
                 Part[#, 2], 
                 Part[#, 3]}, InputForm]]& , 
              Select[
               
               Transpose[{{
                 "ff", "xs"}, {$CellContext`minff$$, $CellContext`minxs$$}, \
{$CellContext`maxff$$, $CellContext`maxxs$$}}], NumberQ[
                Part[#, 2]]& ]]], "}"]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`staticpolygons1213150201411393214964820$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
         "]]}}}, {{
       Hold[$CellContext`staticpolygons1313150201411393214965833$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZigAKHeAcIw/IAjB8WCgRXTeD81atAwADOZwQz
NOH8NWB5BTh/A5gvcADV/A97YPwVEHkHVL4CnP/nPwhooMkbwPkhEPfB+f/A
6i0cUO2zhPPD0NSvRjMP6h84fw2aezaguRfqHxs0/xxA5SPCA+ofNHlEeIag
hTfUP2jhZ3kAADp5fqU=
         "]]}}}}, Typeset`size$$ = {
    816., {276.125, 281.875}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`ff$120521$$ = 
    0, $CellContext`xs$120522$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`ff$$ = 100., $CellContext`maxff$$ = 
        200, $CellContext`maxxs$$ = 220, $CellContext`minff$$ = 
        1., $CellContext`minxs$$ = 
        1, $CellContext`staticpolygons1213150201411393214964820$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
           
           "]]}, $CellContext`staticpolygons1313150201411393214965833$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZigAKHeAcIw/IAjB8WCgRXTeD81atAwADOZwQz
NOH8NWB5BTh/A5gvcADV/A97YPwVEHkHVL4CnP/nPwhooMkbwPkhEPfB+f/A
6i0cUO2zhPPD0NSvRjMP6h84fw2aezaguRfqHxs0/xxA5SPCA+ofNHlEeIag
hTfUP2jhZ3kAADp5fqU=
           "]]}, $CellContext`xs$$ = 110.}, 
      "ControllerVariables" :> {
        Hold[$CellContext`ff$$, $CellContext`ff$120521$$, 0], 
        Hold[$CellContext`xs$$, $CellContext`xs$120522$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         TabView[{"TopView" -> Show[{
              Graphics[{{
                 Opacity[0.8], {
                  AbsoluteThickness[1], 
                  AbsolutePointSize[1], 
                  EdgeForm[], 
                  RGBColor[0.4, 0.6, 0.8], 
                  Polygon[
                   Dynamic[
                    (Map[
                    Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], {{1, 27}}]& )[
                    $CellContext`polygons1113150201411393214963637[$\
CellContext`ff$$]]]]}, 
                 
                 GeometricTransformation[$CellContext`\
staticpolygons1213150201411393214964820$$, 
                  Dynamic[
                  BesselJ[
                    1., 3.]; {{{1, 0}, {0, 
                    1}}, {$CellContext`xs$$, 
                    0}}]], $CellContext`\
staticpolygons1313150201411393214965833$$, 
                 Opacity[1], 
                 RGBColor[
                 0.038747429704798886`, 0.9161617552424038, 
                  0.039847212269181365`], 
                 AbsoluteThickness[Medium], 
                 Line[
                  Dynamic[
                   Refresh[
                    Map[{
                    Part[#, {1, 2}], 
                    Part[#, {4, 5}]}& , 
                    Select[
                    $CellContext`raytracefunction113150201411393214967381[$\
CellContext`ff$$, $CellContext`xs$$], And[
                    Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]], 
                    TrackedSymbols :> {$CellContext`ff$$, $CellContext`xs$$}],
                    SynchronousUpdating -> False]], 
                 Tooltip[
                  Locator[
                   Dynamic[
                   BesselJ[
                    1., 3.]; {$CellContext`xs$$, 0}, ($CellContext`xs$$ = Chop[
                    Part[#, 1]])& ], 
                   Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["xs = ", 
                    ToString[$CellContext`xs$$]]]]}}]}, {
             PlotLabel -> "TopView", ImageSize -> 800, AspectRatio -> 
              Automatic}], Optica`Optica`Intensity -> Dynamic[
             ListPlot3D[
              
              Apply[$CellContext`rayfunction213150201411393217506022, \
{$CellContext`ff$$, $CellContext`xs$$}], {
              PlotLabel -> Optica`Optica`Intensity, 
               DataRange -> {{-0.5, 0.5}, {-0.5, 0.5}}, Axes -> True, Mesh -> 
               False, ImageSize -> 600, PlotRange -> All, AspectRatio -> 
               Automatic}], SynchronousUpdating -> True]}, 1], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`ff$$, 100.}, 1., 200, ControlType -> 
         None}, {{$CellContext`xs$$, 110.}, 1, 220, ControlType -> 
         None}, {{$CellContext`minff$$, 1.}, ControlType -> 
         None}, {{$CellContext`maxff$$, 200}, ControlType -> 
         None}, {{$CellContext`minxs$$, 1}, ControlType -> 
         None}, {{$CellContext`maxxs$$, 220}, ControlType -> None}, 
        Style[
         Grid[{{"ff", 
            InputField[
             Dynamic[$CellContext`minff$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159313150201411393217589757; $CellContext`ff$$, \
($CellContext`ff$$ = #)& ], {
              Dynamic[$CellContext`minff$$], 
              Dynamic[$CellContext`maxff$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxff$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable159313150201411393217589757; $CellContext`ff$$, \
($CellContext`ff$$ = #)& ]}}]], {{$CellContext`minff$$, 1.}, ControlType -> 
         None}, {{$CellContext`maxff$$, 200}, ControlType -> 
         None}, {{$CellContext`minff$$, 1.}, ControlType -> 
         None}, {{$CellContext`maxff$$, 200}, ControlType -> 
         None}, {{$CellContext`minxs$$, 1}, ControlType -> 
         None}, {{$CellContext`maxxs$$, 220}, ControlType -> 
         None}, {{$CellContext`minff$$, 1.}, ControlType -> 
         None}, {{$CellContext`maxff$$, 200}, ControlType -> None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{
               "ff", "xs"}, {$CellContext`ff$$, $CellContext`xs$$}}], 
            Optica`Optica`SymbolicRanges -> Map[ToExpression[
                Part[#, 1]] -> {
                Part[#, 2], 
                Part[#, 3]}& , 
              Select[
               
               Transpose[{{
                 "ff", "xs"}, {$CellContext`minff$$, $CellContext`minxs$$}, \
{$CellContext`maxff$$, $CellContext`maxxs$$}}], NumberQ[
                Part[#, 2]]& ]]}; 
         Optica`Optica`$OpticalSystemScript = 
          "{GridOfRays[{40, 40}, NumberOfRays -> 100], \
Move[PlanoConvexLens[{ff, 100}, 50, 10], 10.], CustomGrid[Move[Screen[10], \
{xs, 110.}, SymbolicValues -> {xs -> 110}], griddata, 1, GridFunction -> \
((griddata[[#2,#1]] = griddata[[#2,#1]] + Intensity/100.; 1.) & ), \
EmbedGridData -> True, ReportedFunction -> griddata, SymbolicValues -> {xs -> \
110}], Move[Screen[50], 125.]}"; Print[
           InputForm[
            StringJoin["{SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "ff", "xs"}, {$CellContext`ff$$, $CellContext`xs$$}}]], 
             ", SymbolicRanges -> ", 
             ToString[
              Map[StringJoin[
                Part[#, 1], "->", 
                ToString[{
                  Part[#, 2], 
                  Part[#, 3]}, InputForm]]& , 
               Select[
                
                Transpose[{{
                  "ff", "xs"}, {$CellContext`minff$$, $CellContext`minxs$$}, \
{$CellContext`maxff$$, $CellContext`maxxs$$}}], NumberQ[
                 Part[#, 2]]& ]]], "}"]]], ImageSize -> 
         Automatic], \
{{$CellContext`staticpolygons1213150201411393214964820$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
            "]]}}, 
         ControlType -> 
         None}, {{$CellContext`staticpolygons1313150201411393214965833$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZigAKHeAcIw/IAjB8WCgRXTeD81atAwADOZwQz
NOH8NWB5BTh/A5gvcADV/A97YPwVEHkHVL4CnP/nPwhooMkbwPkhEPfB+f/A
6i0cUO2zhPPD0NSvRjMP6h84fw2aezaguRfqHxs0/xxA5SPCA+ofNHlEeIag
hTfUP2jhZ3kAADp5fqU=
            "]]}}, ControlType -> None}}, 
      "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1, 2}, SynchronousInitialization -> False, 
        SynchronousUpdating -> False, 
        BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{861., {337., 342.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`raytracefunction113150201411393214967381 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`ff$$, 
            Blank[Real]}, {$CellContext`xs$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`rsx$ = 1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`propagatedrays$ = CompressedData["
1:eJzVmL1KA0EUhVcL0SKQIoIsChqCWX8wiV7BzoH4AFErmxSClYW26awiWNto
paWVLyA4tS8QGwsh9iG9YNa5RjluyGnvwHL2fPvD4bC7zM7S8dnByWQURYXB
Vo5wiP+HMnlvN/s8/vhdXHkrTb3reUfu9iYdD8PrusXDq3hi1H3G3T+MfPPT
/dXf6wQ8nxvJfrPeyn3UPMet9hapCng+N5K9QTvb1xXPcau9TasKeD43kkE5
nUZzzXPcam95VQHP50Zy2Y9fTpOy57jV3gqqAp7PjWTl8f6p3S96jlvtbU5V
wPO5kaRvY7214Dlutbd5VQHP50bymtaTm/Uct9rboqqA53Mj2fl+sGY8x632
VlQV8HxuJBfpdKPTe+a41d5KqgKez43kPPRDcqu9LasKeD43kmp4Hx3HrfaW
qAp4PjcS/f47jlvtbVVVwPO5keh8w3Hcam/rqgKez40kCfNbx3GrvW2oCng+
N5J2+J9yHLfaW1VVwPO5kXTD/7vjuNXeaqoCns+NRNeLHMet9rapKuD53Ega
YX3Scdxqb1uqAp7Pnc2H66BjuNXeZITyuX/2vgDRbVHH
             
             "]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -10. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - ((14921604 $CellContext`ff$$)/
                    28766183) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + (
                    2 $CellContext`rx$) ((14921604 $CellContext`ff$$)/
                    28766183); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    625., Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[((-14921604) $CellContext`ff$$)/
                    
                    28766183 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + Sqrt[(222654265932816 $CellContext`ff$$^2)/
                    827493284389489 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ff$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    625., Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[((-14921604) $CellContext`ff$$)/
                    28766183 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + Sqrt[(222654265932816 $CellContext`ff$$^2)/
                    827493284389489 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ff$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 120333.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -20. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$104}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 625.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$104 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$104), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$104, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$104}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 120334.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -10. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    120333.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`ff$$] $CellContext`ray2$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`ff$$] $CellContext`ray3$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`ff$$] $CellContext`ray2$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 1. $CellContext`ray3$^2)^0.5, 
                    1., 0.}, {(Sign[$CellContext`ff$$] $CellContext`ray3$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 1. $CellContext`ray3$^2)^0.5, 
                    0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -20. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    120334.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 
                    0}; $CellContext`activeregion$ = -1.; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[
                    Abs[$CellContext`alternateindex$ - $CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
              False; $CellContext`reportedrayspresent$ = 
              False; $CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`reporteddummyrayspresent$ = 
              False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
                
                Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                   Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                   Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                   Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                    Re[$CellContext`xs$$]; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                   Chop[$CellContext`rx$]; $CellContext`ry$ = 
                   Chop[$CellContext`ry$]; $CellContext`rz$ = 
                   Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                   False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                 If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                    True; ($CellContext`intersections$ = Block[{Compile`$105}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 25.], {
                    
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$105 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$105), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$105, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$105}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 120383.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                   If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    120383.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ + 
                    Re[$CellContext`xs$$]; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`xs$$], 0., 
                    0.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`deflecteddummyrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                    "]])& , $CellContext`propagatedrays$]]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]; If[
               
               And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); (
             If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
              False; $CellContext`reportedrayspresent$ = 
              False; $CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`reporteddummyrayspresent$ = 
              
              False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
                
                Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                   Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                   Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                   Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -125. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                   Chop[$CellContext`rx$]; $CellContext`ry$ = 
                   Chop[$CellContext`ry$]; $CellContext`rz$ = 
                   Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                   False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                 If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                    True; ($CellContext`intersections$ = Block[{Compile`$106}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 625.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$106 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$106), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$106, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$106}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 120415.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                   If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 1., 
                    120415.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    125. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    125., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`deflecteddummyrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                    "]])& , $CellContext`propagatedrays$]]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]; If[
               
               And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); (
             If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
           Map[{
              Part[#, 1], 
              Part[#, 2], 
              Part[#, 3], 
              Part[#, 4], 
              Part[#, 5], 
              
              Part[#, 6]}& , $CellContext`reportedrays$]], \
$CellContext`compileoptionsetting$]]; \
$CellContext`rayfunction213150201411393217506022 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`ff$$, 
            Blank[Real]}, {$CellContext`xs$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`gcx$, $CellContext`gcy$, \
$CellContext`gcz$, $CellContext`gdimx$, $CellContext`gdimy$, \
$CellContext`gdimz$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`gintercepts$, \
$CellContext`gmaxlength$, $CellContext`gmm$, $CellContext`gnn$, \
$CellContext`goo$, $CellContext`griddata$, $CellContext`grr$, \
$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$, \
$CellContext`grtx$, $CellContext`grty$, $CellContext`grtz$, \
$CellContext`gspacex$, $CellContext`gspacey$, $CellContext`gspacez$, \
$CellContext`gu$, $CellContext`gv$, $CellContext`gw$, $CellContext`gxave$, \
$CellContext`gyave$, $CellContext`gzave$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`rsx$ = 1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`griddata$ = CompressedData["
1:eJztwzENACAQBLALTrDwUpBAwoz/jeVFMLRJ577rjCTVAQAAAAAAAAAAAAAA
AAAAAAAAAPjDA0ZfAhA=
             "]; $CellContext`gintercepts$ = {{
             1.}}; $CellContext`gspacex$ = 1.; $CellContext`gspacey$ = 
            1.; $CellContext`gspacez$ = 1.; $CellContext`gxave$ = 
            1.; $CellContext`gyave$ = 1.; $CellContext`gzave$ = 
            1.; $CellContext`grsx$ = 1.; $CellContext`grsy$ = 
            1.; $CellContext`grsz$ = 1.; $CellContext`grtx$ = 
            1.; $CellContext`grty$ = 1.; $CellContext`grtz$ = 
            1.; $CellContext`gcx$ = 1.; $CellContext`gcy$ = 
            1.; $CellContext`gcz$ = 1.; $CellContext`gdimx$ = 
            1.; $CellContext`gdimy$ = 1.; $CellContext`gdimz$ = 
            1.; $CellContext`gu$ = 1.; $CellContext`gv$ = 
            1.; $CellContext`gw$ = 1.; $CellContext`gnn$ = 
            1; $CellContext`gmm$ = 1; $CellContext`goo$ = 
            1; $CellContext`grr$ = 1.; $CellContext`gmaxlength$ = 
            1.; $CellContext`propagatedrays$ = CompressedData["
1:eJzU3X+Mnfl5HfYbYeMQKqsOBNZhBNYZs6xCK6wykimZkUj59SytMDItT2RK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             "]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$} = Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -10. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - ((14921604 $CellContext`ff$$)/
                    28766183) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + (
                    2 $CellContext`rx$) ((14921604 $CellContext`ff$$)/
                    28766183); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    625., Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[((-14921604) $CellContext`ff$$)/
                    28766183 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + Sqrt[(222654265932816 $CellContext`ff$$^2)/
                    827493284389489 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ff$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    625., Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[((-14921604) $CellContext`ff$$)/
                    28766183 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + Sqrt[(222654265932816 $CellContext`ff$$^2)/
                    827493284389489 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ff$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 120231.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -20. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$102}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 625.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$102 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$102), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$102, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$102}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 120232.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -10. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    120231.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`ff$$] $CellContext`ray2$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`ff$$] $CellContext`ray3$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`ff$$] $CellContext`ray2$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 1. $CellContext`ray3$^2)^0.5, 
                    1., 0.}, {(Sign[$CellContext`ff$$] $CellContext`ray3$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 1. $CellContext`ray3$^2)^0.5, 
                    0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -20. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    120232.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 
                    0}; $CellContext`activeregion$ = -1.; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGBgAmJGIFZngIEP9gNHN0SY5J89SJx6uHv346AH0B/0podm
uAEAvnFifw==
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]); $CellContext`inrays$ = \
$CellContext`deflectedlocalrays$; $CellContext`propagate$ = \
$CellContext`generationnumber$ < $CellContext`generationlimit$]; \
$CellContext`propagatedrays$ = If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`deflectedrayspresent$ = 
              False; $CellContext`deflectedlocalrays$ = 
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                  Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                  Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                  Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                   Re[$CellContext`xs$$]; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                  Chop[$CellContext`rx$]; $CellContext`ry$ = 
                  Chop[$CellContext`ry$]; $CellContext`rz$ = 
                  Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                  False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                   True; ($CellContext`intersections$ = Block[{Compile`$80}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 25.], {
                    
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$80 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$80), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$80, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$80}]}, {{-1., 0., 0.}}]]; 
                   AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 18628.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                   Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                   If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                  If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    18628.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ + 
                    Re[$CellContext`xs$$]; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`xs$$], 0., 
                    0.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`newdeflectedrays$ = \
{$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot = $CellContext`surfacerotationmatrix$; \
{$CellContext`gdimz$, $CellContext`gdimy$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    2]; $CellContext`gspacey$ = (
                    0.5 - -0.5)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    0.5 - -0.5)/$CellContext`gdimz$; $CellContext`gyave$ = \
(-0.5 + 0.5)/2; $CellContext`gzave$ = (-0.5 + 0.5)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    
                    Join[{{($CellContext`ray2$ - -0.5)/$CellContext`gspacey$ + 
                    1., ($CellContext`ray3$ - -0.5)/$CellContext`gspacez$ + 
                    1., $CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$, 0., 0.}}, {{
                    0., 0., 0., $CellContext`gyave$, $CellContext`gzave$, 0., 
                    0.}}], And[
                    Part[#, 4] > -0.5, Part[#, 4] < 0.5, Part[#, 5] > -0.5, 
                    Part[#, 5] < 0.5]& ], {{-1., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Part[$CellContext`gintercepts$, 1, 1] > 
                    0., $CellContext`gintercepts$ = {
                    First[$CellContext`gintercepts$]}; $CellContext`gnn$ = 
                    Floor[
                    Part[$CellContext`gintercepts$, 1, 1]]; $CellContext`gmm$ = 
                    Floor[
                    Part[$CellContext`gintercepts$, 1, 2]]; $CellContext`grr$ = 
                    Part[$CellContext`gintercepts$, 1, 3]; ((
                    Part[$CellContext`griddata$, #2, #] = 
                    Part[$CellContext`griddata$, #2, #] + \
$CellContext`intensity$/100.; 
                    1.)& )[$CellContext`gnn$, $CellContext`gmm$, \
$CellContext`grr$, 
                    Part[$CellContext`gintercepts$, 1, 4], 
                    Part[$CellContext`gintercepts$, 1, 5], 0., 0., 0., 0., 
                    0.]; 1., $CellContext`gintercepts$ = {{0., 0., 0., 0., 0.,
                     0., 0.}}; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); 
                    First[$CellContext`allcreatedrays$], {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}], $CellContext`deflecteddummyrayspresent$ = 
                   True; CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                   "]])& , $CellContext`propagatedrays$]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$; $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`reportedrayspresent$ = 
              False; $CellContext`reporteddummyrayspresent$ = 
              False; $CellContext`reportedlocalrays$ = 
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                  Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                  Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                  Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -125. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                  Chop[$CellContext`rx$]; $CellContext`ry$ = 
                  Chop[$CellContext`ry$]; $CellContext`rz$ = 
                  Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                  False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, ($CellContext`intersections$ = 
                    Block[{Compile`$103}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 625.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$103 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$103), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$103, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$103}]}, {{-1., 0., 0.}}]]; 
                   AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 120283.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                   Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                   If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                  If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 1., 
                    120283.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    
                    125. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); 
                    AddTo[$CellContext`intersectionnumber$, 
                    1.]; $CellContext`intersectionspresent$ = 
                    True; $CellContext`reportedrayspresent$ = 
                    True; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, $CellContext`reporteddummyrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]], $CellContext`reporteddummyrayspresent$ = 
                   True; CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                   "]])& , $CellContext`propagatedrays$]; \
$CellContext`deflectedrayspresent$ = $CellContext`reportedrayspresent$; \
$CellContext`deflecteddummyrayspresent$ = \
$CellContext`reporteddummyrayspresent$; If[
               
               And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]; $CellContext`deflectedlocalrays$ = \
$CellContext`reportedlocalrays$); (
             If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 
               2], $CellContext`reportedrays$]; $CellContext`griddata$], \
$CellContext`compileoptionsetting$]]; \
$CellContext`polygons1113150201411393214963637 = 
       Compile[{$CellContext`ff}, {{
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-625. + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -25.}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-434.0277777777779 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -20.833333333333336`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-277.7777777777778 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -16.666666666666668`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-156.25000000000006` + 0.2690707829696608 $CellContext`ff^2])
             Sign[$CellContext`ff], -12.500000000000002`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-69.44444444444449 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -8.333333333333336}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-17.36111111111115 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -4.166666666666671}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-1.262177448353619*^-29 + 
              0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -3.552713678800501*^-15}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-17.361111111111093` + 0.2690707829696608 $CellContext`ff^2])
             Sign[$CellContext`ff], 4.166666666666664}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-69.44444444444437 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], 8.333333333333329}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-156.24999999999983` + 0.2690707829696608 $CellContext`ff^2])
             Sign[$CellContext`ff], 12.499999999999993`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-277.7777777777775 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], 16.666666666666657`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-434.0277777777776 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], 20.83333333333333}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-624.9999999999997 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], 24.999999999999993`}, {20., 25.}, {20., 
          20.833333333333336`}, {20., 16.666666666666668`}, {20., 
          12.500000000000002`}, {20., 8.333333333333336}, {20., 
          4.166666666666671}, {20., 3.552713678800501*^-15}, {
          20., -4.166666666666664}, {20., -8.333333333333329}, {
          20., -12.499999999999993`}, {20., -16.666666666666657`}, {
          20., -20.83333333333333}, {20., -24.999999999999993`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-625. + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -25.}}]); Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.598613521387292*^9, 3.5986135807318277`*^9}, {
   3.598613651975059*^9, 3.5986136535255823`*^9}, {3.598613689452389*^9, 
   3.598613743029552*^9}, {3.598615941320236*^9, 3.598615946528864*^9}, 
   3.598615988963644*^9, {3.598623176289255*^9, 3.598623177202759*^9}, {
   3.598623372566593*^9, 3.598623373246192*^9}, 3.598623423838861*^9, {
   3.614736835921071*^9, 3.6147368462176237`*^9}, 3.614738898022361*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ManipulateSystem[{Move[GridOfRays[{40,40},NumberOfRays->100,MonteCarlo->\
Stratified],0,0],Move[PlanoConvexLens[{ff,100},50,10],10],Move[gridscreen,{xs,\
110}],Move[Screen[50],125]}, 
{DynamicFrame[PlotType->TopView,OpticalSystem->{Move[LineOfRays[40,\
NumberOfRays->20],0,0],Move[PlanoConvexLens[{ff,100},50,10],10],Move[Screen[\
10],{xs,110}],Move[Screen[50],125]}], 
DynamicFrame[PlotType->ListDensityPlot,PlotLabel-> Intensity]}]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5973817082977037`*^9, 3.597381714399399*^9}, {
   3.597383106405095*^9, 3.5973831474192677`*^9}, {3.5973836057244673`*^9, 
   3.597383611171139*^9}, {3.597384353174958*^9, 3.5973843587883472`*^9}, {
   3.5973853817400723`*^9, 3.597385386187841*^9}, 3.597411474398016*^9, {
   3.597411504605047*^9, 3.597411537769678*^9}, {3.597426155137835*^9, 
   3.5974261569207373`*^9}, {3.597426459577071*^9, 3.597426460063609*^9}, {
   3.5974358681185837`*^9, 3.597435870789466*^9}, {3.597435925261199*^9, 
   3.59743595638137*^9}, 3.597444782252898*^9, {3.5974448412040577`*^9, 
   3.597444869236726*^9}, {3.597449469078992*^9, 3.59744946960637*^9}, 
   3.597449731186005*^9, {3.597449823684758*^9, 3.597449848715803*^9}, {
   3.597454592425885*^9, 3.597454593152026*^9}, {3.5974588089722567`*^9, 
   3.59745881154707*^9}, {3.5974590022953053`*^9, 3.59745901914935*^9}, 
   3.597459874232761*^9, 3.597547821366404*^9, {3.597632608343173*^9, 
   3.597632653789155*^9}, {3.597632956064898*^9, 3.597632964391678*^9}, {
   3.5976330417364407`*^9, 3.597633062841584*^9}, {3.597633207643664*^9, 
   3.597633273296908*^9}, {3.597934993772254*^9, 3.59793499742791*^9}, {
   3.597935035712966*^9, 3.597935063963784*^9}, {3.597938433212634*^9, 
   3.5979384354434013`*^9}, {3.597943775910635*^9, 3.597943777821829*^9}, {
   3.597956666532222*^9, 3.5979567093366413`*^9}, 3.5980317722125072`*^9, {
   3.598064060021538*^9, 3.598064087026854*^9}, {3.598064213281942*^9, 
   3.598064241535131*^9}, {3.598200205978129*^9, 3.598200216191757*^9}, {
   3.598200252578405*^9, 3.598200280542292*^9}, {3.598200361862123*^9, 
   3.598200363538107*^9}, {3.5982009897691507`*^9, 3.598200993935952*^9}, {
   3.598201137236236*^9, 3.598201158707644*^9}, {3.59820246112914*^9, 
   3.598202481846354*^9}, {3.598233161345736*^9, 3.5982331951113443`*^9}, {
   3.59823426574898*^9, 3.598234286577612*^9}, {3.598234316769774*^9, 
   3.598234337259926*^9}, {3.598234626979321*^9, 3.59823463915486*^9}, {
   3.5982346701678877`*^9, 3.598234709118672*^9}, {3.598234740818186*^9, 
   3.598234840053815*^9}, {3.5982348930592127`*^9, 3.598234895115028*^9}, {
   3.5982353164638147`*^9, 3.5982353516695766`*^9}, {3.59823630800804*^9, 
   3.59823630969383*^9}, {3.5982364010844193`*^9, 3.598236402026805*^9}, {
   3.598236934781481*^9, 3.598236941211789*^9}, {3.598238921703396*^9, 
   3.5982389346124487`*^9}, {3.5982391200337763`*^9, 3.598239124154553*^9}, {
   3.598239217836976*^9, 3.5982392249155483`*^9}, {3.5982394446290703`*^9, 
   3.598239445940723*^9}, {3.598280999160664*^9, 3.598281159130096*^9}, {
   3.598281317499378*^9, 3.598281334832835*^9}, 3.598287973584145*^9, {
   3.598293191842476*^9, 3.598293230736383*^9}, {3.5982946814027977`*^9, 
   3.598294684356538*^9}, {3.598294729385804*^9, 3.5982947600192127`*^9}, {
   3.598310196029866*^9, 3.598310196204924*^9}, {3.59831121944151*^9, 
   3.5983112243342657`*^9}, {3.5983113155490503`*^9, 3.598311318546649*^9}, {
   3.598311383751254*^9, 3.598311387280938*^9}, {3.598362130386321*^9, 
   3.598362136975369*^9}, 3.598472124043518*^9, {3.598472154809353*^9, 
   3.5984721734231873`*^9}, 3.598472239549612*^9, {3.598472370589409*^9, 
   3.598472405187937*^9}, 3.598473431918316*^9, {3.598489254967058*^9, 
   3.5984892797235622`*^9}, {3.598489334654168*^9, 3.598489339724307*^9}, {
   3.598490376740888*^9, 3.598490408074595*^9}, {3.5984905482038107`*^9, 
   3.598490550690796*^9}, {3.598490608759013*^9, 3.5984906204969387`*^9}, {
   3.598490859350644*^9, 3.598490862172333*^9}, {3.598490999858392*^9, 
   3.5984910065930243`*^9}, {3.5984917992190943`*^9, 3.598491813450012*^9}, {
   3.598491912149733*^9, 3.598491929964335*^9}, {3.5985232995815763`*^9, 
   3.598523311490386*^9}, {3.5985233534277067`*^9, 3.5985233848529663`*^9}, {
   3.598523423349094*^9, 3.598523431414445*^9}, {3.598528935685931*^9, 
   3.598528961564802*^9}, {3.598529021033514*^9, 3.598529054696096*^9}, {
   3.5985291717044783`*^9, 3.598529237960127*^9}, {3.598529442044526*^9, 
   3.598529446835479*^9}, 3.598529510196568*^9, {3.5985295734861307`*^9, 
   3.59852963448055*^9}, {3.598529763966462*^9, 3.598529778223288*^9}, 
   3.59852988095361*^9, {3.5986134200846663`*^9, 3.598613527800748*^9}, {
   3.5986158073442707`*^9, 3.598615856908063*^9}, {3.598616021222122*^9, 
   3.598616069970199*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`ff$$ = 100., $CellContext`maxff$$ = 
    200, $CellContext`maxxs$$ = 220, $CellContext`minff$$ = 
    1., $CellContext`minxs$$ = 
    1, $CellContext`staticpolygons1213150201411393434567306$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
      
      "]]}, $CellContext`staticpolygons1313150201411393434568267$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZigAKHeAcIw/IAjB8WCgRXTeD81atAwADOZwQz
NOH8NWB5BTh/A5gvcADV/A97YPwVEHkHVL4CnP/nPwhooMkbwPkhEPfB+f/A
6i0cUO2zhPPD0NSvRjMP6h84fw2aezaguRfqHxs0/xxA5SPCA+ofNHlEeIag
hTfUP2jhZ3kAADp5fqU=
      "]]}, $CellContext`xs$$ = 110.49589473006634`, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`ff$$], 100.}, 1., 200}, {{
       Hold[$CellContext`xs$$], 110.}, 1, 220}, {{
       Hold[$CellContext`minff$$], 1.}}, {{
       Hold[$CellContext`maxff$$], 200}}, {{
       Hold[$CellContext`minxs$$], 1}}, {{
       Hold[$CellContext`maxxs$$], 220}}, {
      Hold[
       Style[
        Grid[{{"ff", 
           InputField[
            Dynamic[$CellContext`minff$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159313150201411393437198819; $CellContext`ff$$, \
($CellContext`ff$$ = #)& ], {
             Dynamic[$CellContext`minff$$], 
             Dynamic[$CellContext`maxff$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxff$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable159313150201411393437198819; $CellContext`ff$$, \
($CellContext`ff$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minff$$], 1.}}, {{
       Hold[$CellContext`maxff$$], 200}}, {{
       Hold[$CellContext`minff$$], 1.}}, {{
       Hold[$CellContext`maxff$$], 200}}, {{
       Hold[$CellContext`minxs$$], 1}}, {{
       Hold[$CellContext`maxxs$$], 220}}, {{
       Hold[$CellContext`minff$$], 1.}}, {{
       Hold[$CellContext`maxff$$], 200}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{
              "ff", "xs"}, {$CellContext`ff$$, $CellContext`xs$$}}], 
           Optica`Optica`SymbolicRanges -> Map[ToExpression[
               Part[#, 1]] -> {
               Part[#, 2], 
               Part[#, 3]}& , 
             Select[
              
              Transpose[{{
                "ff", "xs"}, {$CellContext`minff$$, $CellContext`minxs$$}, \
{$CellContext`maxff$$, $CellContext`maxxs$$}}], NumberQ[
               Part[#, 2]]& ]]}; 
        Optica`Optica`$OpticalSystemScript = 
         "{GridOfRays[{40, 40}, NumberOfRays -> 100, MonteCarlo -> \
Stratified], Move[PlanoConvexLens[{ff, 100}, 50, 10], 10.], \
CustomGrid[Move[Screen[10], {xs, 110.}, SymbolicValues -> {xs -> 110}], \
griddata, 1, GridFunction -> ((griddata[[#2,#1]] = griddata[[#2,#1]] + \
Intensity/100.; 1.) & ), EmbedGridData -> True, ReportedFunction -> griddata, \
SymbolicValues -> {xs -> 110}], Move[Screen[50], 125.]}"; Print[
          InputForm[
           StringJoin["{SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "ff", "xs"}, {$CellContext`ff$$, $CellContext`xs$$}}]], 
            ", SymbolicRanges -> ", 
            ToString[
             Map[StringJoin[
               Part[#, 1], "->", 
               ToString[{
                 Part[#, 2], 
                 Part[#, 3]}, InputForm]]& , 
              Select[
               
               Transpose[{{
                 "ff", "xs"}, {$CellContext`minff$$, $CellContext`minxs$$}, \
{$CellContext`maxff$$, $CellContext`maxxs$$}}], NumberQ[
                Part[#, 2]]& ]]], "}"]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`staticpolygons1213150201411393434567306$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
         "]]}}}, {{
       Hold[$CellContext`staticpolygons1313150201411393434568267$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZigAKHeAcIw/IAjB8WCgRXTeD81atAwADOZwQz
NOH8NWB5BTh/A5gvcADV/A97YPwVEHkHVL4CnP/nPwhooMkbwPkhEPfB+f/A
6i0cUO2zhPPD0NSvRjMP6h84fw2aezaguRfqHxs0/xxA5SPCA+ofNHlEeIag
hTfUP2jhZ3kAADp5fqU=
         "]]}}}}, Typeset`size$$ = {
    816., {329.125, 334.875}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`ff$303544$$ = 
    0, $CellContext`xs$303545$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`ff$$ = 100., $CellContext`maxff$$ = 
        200, $CellContext`maxxs$$ = 220, $CellContext`minff$$ = 
        1., $CellContext`minxs$$ = 
        1, $CellContext`staticpolygons1213150201411393434567306$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
           
           "]]}, $CellContext`staticpolygons1313150201411393434568267$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZigAKHeAcIw/IAjB8WCgRXTeD81atAwADOZwQz
NOH8NWB5BTh/A5gvcADV/A97YPwVEHkHVL4CnP/nPwhooMkbwPkhEPfB+f/A
6i0cUO2zhPPD0NSvRjMP6h84fw2aezaguRfqHxs0/xxA5SPCA+ofNHlEeIag
hTfUP2jhZ3kAADp5fqU=
           "]]}, $CellContext`xs$$ = 110.}, 
      "ControllerVariables" :> {
        Hold[$CellContext`ff$$, $CellContext`ff$303544$$, 0], 
        Hold[$CellContext`xs$$, $CellContext`xs$303545$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         TabView[{"TopView" -> Show[{
              Graphics[{{
                 Opacity[0.8], {
                  AbsoluteThickness[1], 
                  AbsolutePointSize[1], 
                  EdgeForm[], 
                  RGBColor[0.4, 0.6, 0.8], 
                  Polygon[
                   Dynamic[
                    (Map[
                    Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], {{1, 27}}]& )[
                    $CellContext`polygons1113150201411393434566250[$\
CellContext`ff$$]]]]}, 
                 
                 GeometricTransformation[$CellContext`\
staticpolygons1213150201411393434567306$$, 
                  Dynamic[
                  BesselJ[
                    1., 3.]; {{{1, 0}, {0, 
                    1}}, {$CellContext`xs$$, 
                    0}}]], $CellContext`\
staticpolygons1313150201411393434568267$$, 
                 Opacity[1], 
                 RGBColor[
                 0.038747429704798886`, 0.9161617552424038, 
                  0.039847212269181365`], 
                 AbsoluteThickness[Medium], 
                 Line[
                  Dynamic[
                   Refresh[
                    Map[{
                    Part[#, {1, 2}], 
                    Part[#, {4, 5}]}& , 
                    Select[
                    $CellContext`raytracefunction113150201411393434569740[$\
CellContext`ff$$, $CellContext`xs$$], And[
                    Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]], 
                    TrackedSymbols :> {$CellContext`ff$$, $CellContext`xs$$}],
                    SynchronousUpdating -> False]], 
                 Tooltip[
                  Locator[
                   Dynamic[
                   BesselJ[
                    1., 3.]; {$CellContext`xs$$, 0}, ($CellContext`xs$$ = Chop[
                    Part[#, 1]])& ], 
                   Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["xs = ", 
                    ToString[$CellContext`xs$$]]]]}}]}, {
             PlotLabel -> "TopView", ImageSize -> 800, AspectRatio -> 
              Automatic}], Optica`Optica`Intensity -> Dynamic[
             ListDensityPlot[
              
              Apply[$CellContext`rayfunction213150201411393437109774, \
{$CellContext`ff$$, $CellContext`xs$$}], {
              PlotLabel -> Optica`Optica`Intensity, 
               DataRange -> {{-0.5, 0.5}, {-0.5, 0.5}}, Frame -> True, Axes -> 
               True, Mesh -> False, ImageSize -> 600, PlotRange -> All, 
               AspectRatio -> Automatic, 
               ColorFunction -> (Hue[0.65 - # 0.65, 1, # 0.9 + 0.1]& )}], 
             SynchronousUpdating -> True]}, 1], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`ff$$, 100.}, 1., 200, ControlType -> 
         None}, {{$CellContext`xs$$, 110.}, 1, 220, ControlType -> 
         None}, {{$CellContext`minff$$, 1.}, ControlType -> 
         None}, {{$CellContext`maxff$$, 200}, ControlType -> 
         None}, {{$CellContext`minxs$$, 1}, ControlType -> 
         None}, {{$CellContext`maxxs$$, 220}, ControlType -> None}, 
        Style[
         Grid[{{"ff", 
            InputField[
             Dynamic[$CellContext`minff$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159313150201411393437198819; $CellContext`ff$$, \
($CellContext`ff$$ = #)& ], {
              Dynamic[$CellContext`minff$$], 
              Dynamic[$CellContext`maxff$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxff$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable159313150201411393437198819; $CellContext`ff$$, \
($CellContext`ff$$ = #)& ]}}]], {{$CellContext`minff$$, 1.}, ControlType -> 
         None}, {{$CellContext`maxff$$, 200}, ControlType -> 
         None}, {{$CellContext`minff$$, 1.}, ControlType -> 
         None}, {{$CellContext`maxff$$, 200}, ControlType -> 
         None}, {{$CellContext`minxs$$, 1}, ControlType -> 
         None}, {{$CellContext`maxxs$$, 220}, ControlType -> 
         None}, {{$CellContext`minff$$, 1.}, ControlType -> 
         None}, {{$CellContext`maxff$$, 200}, ControlType -> None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{
               "ff", "xs"}, {$CellContext`ff$$, $CellContext`xs$$}}], 
            Optica`Optica`SymbolicRanges -> Map[ToExpression[
                Part[#, 1]] -> {
                Part[#, 2], 
                Part[#, 3]}& , 
              Select[
               
               Transpose[{{
                 "ff", "xs"}, {$CellContext`minff$$, $CellContext`minxs$$}, \
{$CellContext`maxff$$, $CellContext`maxxs$$}}], NumberQ[
                Part[#, 2]]& ]]}; 
         Optica`Optica`$OpticalSystemScript = 
          "{GridOfRays[{40, 40}, NumberOfRays -> 100, MonteCarlo -> \
Stratified], Move[PlanoConvexLens[{ff, 100}, 50, 10], 10.], \
CustomGrid[Move[Screen[10], {xs, 110.}, SymbolicValues -> {xs -> 110}], \
griddata, 1, GridFunction -> ((griddata[[#2,#1]] = griddata[[#2,#1]] + \
Intensity/100.; 1.) & ), EmbedGridData -> True, ReportedFunction -> griddata, \
SymbolicValues -> {xs -> 110}], Move[Screen[50], 125.]}"; Print[
           InputForm[
            StringJoin["{SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "ff", "xs"}, {$CellContext`ff$$, $CellContext`xs$$}}]], 
             ", SymbolicRanges -> ", 
             ToString[
              Map[StringJoin[
                Part[#, 1], "->", 
                ToString[{
                  Part[#, 2], 
                  Part[#, 3]}, InputForm]]& , 
               Select[
                
                Transpose[{{
                  "ff", "xs"}, {$CellContext`minff$$, $CellContext`minxs$$}, \
{$CellContext`maxff$$, $CellContext`maxxs$$}}], NumberQ[
                 Part[#, 2]]& ]]], "}"]]], ImageSize -> 
         Automatic], \
{{$CellContext`staticpolygons1213150201411393434567306$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
            "]]}}, 
         ControlType -> 
         None}, {{$CellContext`staticpolygons1313150201411393434568267$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZigAKHeAcIw/IAjB8WCgRXTeD81atAwADOZwQz
NOH8NWB5BTh/A5gvcADV/A97YPwVEHkHVL4CnP/nPwhooMkbwPkhEPfB+f/A
6i0cUO2zhPPD0NSvRjMP6h84fw2aezaguRfqHxs0/xxA5SPCA+ofNHlEeIag
hTfUP2jhZ3kAADp5fqU=
            "]]}}, ControlType -> None}}, 
      "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1, 2}, SynchronousInitialization -> False, 
        SynchronousUpdating -> False, 
        BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{861., {390., 395.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`raytracefunction113150201411393434569740 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`ff$$, 
            Blank[Real]}, {$CellContext`xs$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`rsx$ = 1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`propagatedrays$ = CompressedData["
1:eJzVmD9LQnEYhW8NUYMQYRBSUCJpf0gtg7besA9gNbU4BE0NtboFgUFzS001
NvUFgn5zX8CWhsB28RPk7b3H4s3wNL4X4nSe9HJ8SLnehaPT/ePRKIrSvZ98
ZI9K+IUG8s724Mfxf7/LFN9yY+/J4w7l9iY+HvrPa2cPrjIjf51n2Pn1kIup
nZ/5/byKDD7P/1/XXr3aSH2UA8e9eotEA97Q+d2W7PbsbF4XA8e9ehsXTXhD
53db0pPTqtVXAse9epsUTXhD53dbctnNvJwU8oHjXr2lRRPe0Pndliw93j81
u9nAca/eZkQT3tD53ZbE78ZqYy5w3Ku3WdGEN3R+tyWvsZ7UdOC4V2/zoglv
6PxuS7a+/rEmAse9esuKJryh87stOY8vN1qdZ4579ZYTTXhD53dbcqZ+SO7V
26Jowhs6v9uSkr4fheNevRVEE97Q+d2WJJ//wnGv3pZFE97Q+d2WJNcbwnGv
3lZFE97Q+d2WFPT6Vjju1duaaMIbOr/bkqZ+nxKOe/VWEk14Q+d3W9LW7+/C
ca/eyqIJb+j8bkuS+0XCca/e1kUT3tD53ZbU9P6kcNyrtw3RhDd0fvdg3r8P
OoR79YbXYZPfjd8+AXYCOn8=
             "]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -10. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - ((14921604 $CellContext`ff$$)/
                    28766183) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + (
                    2 $CellContext`rx$) ((14921604 $CellContext`ff$$)/
                    28766183); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    625., Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[((-14921604) $CellContext`ff$$)/
                    28766183 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + Sqrt[(222654265932816 $CellContext`ff$$^2)/
                    827493284389489 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ff$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    625., Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[((-14921604) $CellContext`ff$$)/
                    28766183 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + Sqrt[(222654265932816 $CellContext`ff$$^2)/
                    827493284389489 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ff$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 303356.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -20. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$140}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 625.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$140 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$140), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$140, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$140}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 303357.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -10. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    303356.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`ff$$] $CellContext`ray2$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`ff$$] $CellContext`ray3$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`ff$$] $CellContext`ray2$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 1. $CellContext`ray3$^2)^0.5, 
                    1., 0.}, {(Sign[$CellContext`ff$$] $CellContext`ray3$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 1. $CellContext`ray3$^2)^0.5, 
                    0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -20. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    303357.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 
                    0}; $CellContext`activeregion$ = -1.; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
              False; $CellContext`reportedrayspresent$ = 
              False; $CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`reporteddummyrayspresent$ = 
              False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
                
                Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                   Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                   Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                   Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                    Re[$CellContext`xs$$]; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                   Chop[$CellContext`rx$]; $CellContext`ry$ = 
                   Chop[$CellContext`ry$]; $CellContext`rz$ = 
                   Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                   False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                 If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                    True; ($CellContext`intersections$ = Block[{Compile`$141}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 25.], {
                    
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$141 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$141), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$141, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$141}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 303406.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                   If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    303406.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ + 
                    Re[$CellContext`xs$$]; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`xs$$], 0., 
                    0.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`deflecteddummyrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                    "]])& , $CellContext`propagatedrays$]]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]; If[
               
               And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); (
             If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
              False; $CellContext`reportedrayspresent$ = 
              False; $CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`reporteddummyrayspresent$ = 
              False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
                
                Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                   Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                   Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                   Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -125. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                   Chop[$CellContext`rx$]; $CellContext`ry$ = 
                   Chop[$CellContext`ry$]; $CellContext`rz$ = 
                   Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                   False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                 If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                    True; ($CellContext`intersections$ = Block[{Compile`$142}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 625.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$142 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$142), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$142, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$142}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 303438.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                   If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 1., 
                    303438.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    125. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    125., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`deflecteddummyrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                    "]])& , $CellContext`propagatedrays$]]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]; If[
               
               And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); (
             If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
           Map[{
              Part[#, 1], 
              Part[#, 2], 
              Part[#, 3], 
              Part[#, 4], 
              Part[#, 5], 
              
              Part[#, 6]}& , $CellContext`reportedrays$]], \
$CellContext`compileoptionsetting$]]; \
$CellContext`rayfunction213150201411393437109774 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`ff$$, 
            Blank[Real]}, {$CellContext`xs$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`gcx$, $CellContext`gcy$, \
$CellContext`gcz$, $CellContext`gdimx$, $CellContext`gdimy$, \
$CellContext`gdimz$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`gintercepts$, \
$CellContext`gmaxlength$, $CellContext`gmm$, $CellContext`gnn$, \
$CellContext`goo$, $CellContext`griddata$, $CellContext`grr$, \
$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$, \
$CellContext`grtx$, $CellContext`grty$, $CellContext`grtz$, \
$CellContext`gspacex$, $CellContext`gspacey$, $CellContext`gspacez$, \
$CellContext`gu$, $CellContext`gv$, $CellContext`gw$, $CellContext`gxave$, \
$CellContext`gyave$, $CellContext`gzave$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`rsx$ = 1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`griddata$ = CompressedData["
1:eJztwzENACAQBLALTrDwUpBAwoz/jeVFMLRJ577rjCTVAQAAAAAAAAAAAAAA
AAAAAAAAAPjDA0ZfAhA=
             "]; $CellContext`gintercepts$ = {{
             1.}}; $CellContext`gspacex$ = 1.; $CellContext`gspacey$ = 
            1.; $CellContext`gspacez$ = 1.; $CellContext`gxave$ = 
            1.; $CellContext`gyave$ = 1.; $CellContext`gzave$ = 
            1.; $CellContext`grsx$ = 1.; $CellContext`grsy$ = 
            1.; $CellContext`grsz$ = 1.; $CellContext`grtx$ = 
            1.; $CellContext`grty$ = 1.; $CellContext`grtz$ = 
            1.; $CellContext`gcx$ = 1.; $CellContext`gcy$ = 
            1.; $CellContext`gcz$ = 1.; $CellContext`gdimx$ = 
            1.; $CellContext`gdimy$ = 1.; $CellContext`gdimz$ = 
            1.; $CellContext`gu$ = 1.; $CellContext`gv$ = 
            1.; $CellContext`gw$ = 1.; $CellContext`gnn$ = 
            1; $CellContext`gmm$ = 1; $CellContext`goo$ = 
            1; $CellContext`grr$ = 1.; $CellContext`gmaxlength$ = 
            1.; $CellContext`propagatedrays$ = CompressedData["
1:eJzU3WdUVM+2LvwWDARBlCCiSBMl0wQVFaVAUcwoKogJMGFGxazYYg4oZswY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             "]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$} = Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -10. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - ((14921604 $CellContext`ff$$)/
                    28766183) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + (
                    2 $CellContext`rx$) ((14921604 $CellContext`ff$$)/
                    28766183); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    625., Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[((-14921604) $CellContext`ff$$)/
                    28766183 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + Sqrt[(222654265932816 $CellContext`ff$$^2)/
                    827493284389489 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ff$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    625., Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[((-14921604) $CellContext`ff$$)/
                    28766183 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + Sqrt[(222654265932816 $CellContext`ff$$^2)/
                    827493284389489 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ff$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 303254.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -20. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$137}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 625.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$137 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$137), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$137, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$137}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 303255.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -10. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    303254.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`ff$$] $CellContext`ray2$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`ff$$] $CellContext`ray3$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`ff$$] $CellContext`ray2$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 1. $CellContext`ray3$^2)^0.5, 
                    1., 0.}, {(Sign[$CellContext`ff$$] $CellContext`ray3$)/(
                    0.2690707829696608 $CellContext`ff$$^2 - 
                    1. $CellContext`ray2$^2 - 1. $CellContext`ray3$^2)^0.5, 
                    0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -20. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    303255.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 
                    0}; $CellContext`activeregion$ = -1.; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGBgAmJGIFZngIEP9gNHN0SY5J89SJx6uHv346AH0B/0podm
uAEAvnFifw==
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]); $CellContext`inrays$ = \
$CellContext`deflectedlocalrays$; $CellContext`propagate$ = \
$CellContext`generationnumber$ < $CellContext`generationlimit$]; \
$CellContext`propagatedrays$ = If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`deflectedrayspresent$ = 
              False; $CellContext`deflectedlocalrays$ = 
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                  Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                  Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                  Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                   Re[$CellContext`xs$$]; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                  Chop[$CellContext`rx$]; $CellContext`ry$ = 
                  Chop[$CellContext`ry$]; $CellContext`rz$ = 
                  Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                  False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                   True; ($CellContext`intersections$ = Block[{Compile`$80}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 25.], {
                    
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$80 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$80), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$80, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$80}]}, {{-1., 0., 0.}}]]; 
                   AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 18628.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                   Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                   If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                  If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    18628.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ + 
                    Re[$CellContext`xs$$]; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`xs$$], 0., 
                    0.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`newdeflectedrays$ = \
{$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot = $CellContext`surfacerotationmatrix$; \
{$CellContext`gdimz$, $CellContext`gdimy$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    2]; $CellContext`gspacey$ = (
                    0.5 - -0.5)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    0.5 - -0.5)/$CellContext`gdimz$; $CellContext`gyave$ = \
(-0.5 + 0.5)/2; $CellContext`gzave$ = (-0.5 + 0.5)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    
                    Join[{{($CellContext`ray2$ - -0.5)/$CellContext`gspacey$ + 
                    1., ($CellContext`ray3$ - -0.5)/$CellContext`gspacez$ + 
                    1., $CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$, 0., 0.}}, {{
                    0., 0., 0., $CellContext`gyave$, $CellContext`gzave$, 0., 
                    0.}}], And[
                    Part[#, 4] > -0.5, Part[#, 4] < 0.5, Part[#, 5] > -0.5, 
                    Part[#, 5] < 0.5]& ], {{-1., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Part[$CellContext`gintercepts$, 1, 1] > 
                    0., $CellContext`gintercepts$ = {
                    First[$CellContext`gintercepts$]}; $CellContext`gnn$ = 
                    Floor[
                    Part[$CellContext`gintercepts$, 1, 1]]; $CellContext`gmm$ = 
                    Floor[
                    Part[$CellContext`gintercepts$, 1, 2]]; $CellContext`grr$ = 
                    Part[$CellContext`gintercepts$, 1, 3]; ((
                    Part[$CellContext`griddata$, #2, #] = 
                    Part[$CellContext`griddata$, #2, #] + \
$CellContext`intensity$/100.; 
                    1.)& )[$CellContext`gnn$, $CellContext`gmm$, \
$CellContext`grr$, 
                    Part[$CellContext`gintercepts$, 1, 4], 
                    Part[$CellContext`gintercepts$, 1, 5], 0., 0., 0., 0., 
                    0.]; 1., $CellContext`gintercepts$ = {{0., 0., 0., 0., 0.,
                     0., 0.}}; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); 
                    First[$CellContext`allcreatedrays$], {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}], $CellContext`deflecteddummyrayspresent$ = 
                   True; CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                   "]])& , $CellContext`propagatedrays$]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$; $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`reportedrayspresent$ = 
              False; $CellContext`reporteddummyrayspresent$ = 
              False; $CellContext`reportedlocalrays$ = 
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                  Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                  Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                  Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -125. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                  Chop[$CellContext`rx$]; $CellContext`ry$ = 
                  Chop[$CellContext`ry$]; $CellContext`rz$ = 
                  Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                  False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, ($CellContext`intersections$ = 
                    Block[{Compile`$139}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 625.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$139 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$139), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$139, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$139}]}, {{-1., 0., 0.}}]]; 
                   AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 303306.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                   Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                   If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                  If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 1., 
                    303306.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    125. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); 
                    AddTo[$CellContext`intersectionnumber$, 
                    1.]; $CellContext`intersectionspresent$ = 
                    True; $CellContext`reportedrayspresent$ = 
                    True; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, $CellContext`reporteddummyrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]], $CellContext`reporteddummyrayspresent$ = 
                   True; CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                   "]])& , $CellContext`propagatedrays$]; \
$CellContext`deflectedrayspresent$ = $CellContext`reportedrayspresent$; \
$CellContext`deflecteddummyrayspresent$ = \
$CellContext`reporteddummyrayspresent$; If[
               
               And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]; $CellContext`deflectedlocalrays$ = \
$CellContext`reportedlocalrays$); (
             If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 
               2], $CellContext`reportedrays$]; $CellContext`griddata$], \
$CellContext`compileoptionsetting$]]; \
$CellContext`polygons1113150201411393434566250 = 
       Compile[{$CellContext`ff}, {{
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-625. + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -25.}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-434.0277777777779 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -20.833333333333336`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-277.7777777777778 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -16.666666666666668`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-156.25000000000006` + 0.2690707829696608 $CellContext`ff^2])
             Sign[$CellContext`ff], -12.500000000000002`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-69.44444444444449 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -8.333333333333336}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-17.36111111111115 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -4.166666666666671}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-1.262177448353619*^-29 + 
              0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -3.552713678800501*^-15}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-17.361111111111093` + 0.2690707829696608 $CellContext`ff^2])
             Sign[$CellContext`ff], 4.166666666666664}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-69.44444444444437 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], 8.333333333333329}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-156.24999999999983` + 0.2690707829696608 $CellContext`ff^2])
             Sign[$CellContext`ff], 12.499999999999993`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-277.7777777777775 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], 16.666666666666657`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-434.0277777777776 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], 20.83333333333333}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-624.9999999999997 + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], 24.999999999999993`}, {20., 25.}, {20., 
          20.833333333333336`}, {20., 16.666666666666668`}, {20., 
          12.500000000000002`}, {20., 8.333333333333336}, {20., 
          4.166666666666671}, {20., 3.552713678800501*^-15}, {
          20., -4.166666666666664}, {20., -8.333333333333329}, {
          20., -12.499999999999993`}, {20., -16.666666666666657`}, {
          20., -20.83333333333333}, {20., -24.999999999999993`}, {
          10. + 0.5187203321344371 $CellContext`ff - (1. 
            Sqrt[-625. + 0.2690707829696608 $CellContext`ff^2]) 
           Sign[$CellContext`ff], -25.}}]); Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.598616080862525*^9, 3.598616114229175*^9}, {
   3.598623165326015*^9, 3.5986231663894377`*^9}, 3.598623425876796*^9, {
   3.614736816570672*^9, 3.614736855147787*^9}, 3.614738893942116*^9}]
}, Open  ]]
},
WindowSize->{1434, 1057},
WindowMargins->{{-54, Automatic}, {Automatic, 491}},
ShowSelection->True,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3598601901-9407342"->{
  Cell[521, 18, 1260, 18, 161, "Print",
   CellTags->"Info3598601901-9407342"]},
 "Info3598601906-9407342"->{
  Cell[1916, 44, 1532, 21, 181, "Print",
   CellTags->"Info3598601906-9407342"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3598601901-9407342", 1374229, 22852},
 {"Info3598601906-9407342", 1374339, 22855}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[422, 15, 96, 1, 29, "Input"],
Cell[521, 18, 1260, 18, 161, "Print",
 CellTags->"Info3598601901-9407342"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1818, 41, 95, 1, 29, "Input"],
Cell[1916, 44, 1532, 21, 181, "Print",
 CellTags->"Info3598601906-9407342"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3485, 70, 2877, 41, 44, "Input"],
Cell[6365, 113, 4280, 76, 110, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10682, 194, 3957, 57, 74, "Input"],
Cell[14642, 253, 294409, 4933, 608, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[309088, 5191, 3444, 48, 44, "Input"],
Cell[312535, 5241, 1225, 30, 77, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[313797, 5276, 4716, 67, 59, "Input"],
Cell[318516, 5345, 423790, 7044, 696, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[742343, 12394, 4796, 68, 89, "Input"],
Cell[747142, 12464, 626726, 10373, 802, "Output"]
}, Open  ]]
}
]
*)

