(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    861347,      14715]
NotebookOptionsPosition[    860633,      14687]
NotebookOutlinePosition[    860991,      14703]
CellTagsIndexPosition[    860948,      14700]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Double Gauss Lens", "Title"],
 "\n\n\n  ",
 StyleBox["The Double-Gauss lens is a highly  utilized photographic lenses.\n\
It  consists of two Gauss lenses back to back.\nIn its most basic design,  it \
therefore consists of two positive meniscus lenses on the outside\nwith two \
negative meniscus lenses on the inside.  This system  reduces the optical \
aberrations.\n\n", "Subsection"],
 "\"CompoundLens[curvatures, surfaceboundaries, surfaceseparations, \\\n\
opticalmediumlist, label, options] refers to a lens assembly that consists of \
\\\nspherical and aspherical refracting surfaces. \"\n\n The below design is \
from page 76 of the textbook \"Lens Design\" by Milton Laikin\n"
}], "Input",
 CellChangeTimes->{{3.4305797917645073`*^9, 3.430579917343402*^9}, {
   3.4305799500716867`*^9, 3.430580108757103*^9}, {3.430580559684781*^9, 
   3.430580631932955*^9}, {3.430580778890602*^9, 3.430580782722087*^9}, {
   3.43497159174955*^9, 3.4349715997934103`*^9}, {3.434971639741975*^9, 
   3.434971640341683*^9}, {3.434971683124538*^9, 3.434971707779543*^9}, {
   3.440432583527807*^9, 3.440432865853856*^9}, {3.440432968773971*^9, 
   3.440433065095312*^9}, 3.538140452335019*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DrawSystem", "[", 
  RowBox[{
   RowBox[{"{", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"LineOfRays", "[", 
        RowBox[{".9", ",", " ", 
         RowBox[{"NumberOfRays", " ", "\[Rule]", " ", "5"}], ",", "  ", 
         RowBox[{"WaveLength", " ", "\[Rule]", " ", ".7"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", 
         RowBox[{"{", 
          RowBox[{"lighty", ",", "0"}], "}"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"LightAngle", ",", " ", "0"}], "}"}]}], " ", "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"LineOfRays", "[", 
        RowBox[{".9", ",", " ", 
         RowBox[{"NumberOfRays", " ", "\[Rule]", " ", "5"}], ",", " ", 
         RowBox[{"WaveLength", " ", "\[Rule]", " ", ".4"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1.0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"LightAngle2", ",", " ", 
         RowBox[{"-", "5"}]}], "}"}]}], " ", "]"}], ",", " ", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"CompoundLens", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"3.3077", ",", " ", "13.8223", ",", " ", "1.9625", ",", " ", 
           RowBox[{"-", "22.1426"}], ",", " ", "1.2787", ",", " ", 
           "\[Infinity]", ",", " ", 
           RowBox[{"-", "1.7291"}], ",", " ", "2.7243", ",", " ", 
           RowBox[{"-", "2.2955"}], ",", " ", "6.5730", ",", " ", 
           RowBox[{"-", "8.8951"}]}], "}"}], ",", " ", "\[IndentingNewLine]", 
         
         RowBox[{"{", 
          RowBox[{
          "3.20", ",", " ", "3.20", ",", " ", "2.56", ",", " ", "2.56", ",", 
           " ", "1.50", ",", " ", "1.26", ",", " ", "1.60", ",", " ", "2.36", 
           ",", " ", "2.36", ",", " ", "3.0", ",", " ", "3.0"}], "}"}], ",", 
         " ", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
          ".420", ",", " ", ".023", ",", " ", ".605", ",", " ", ".283", ",", 
           " ", ".380", ",", " ", ".491", ",", " ", ".201", ",", " ", ".672", 
           ",", " ", ".286", ",", " ", ".394"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
          "SK16", ",", " ", "IntrinsicMedium", ",", " ", "SK16", ",", " ", 
           "LF5", ",", " ", "IntrinsicMedium", ",", "IntrinsicMedium", ",", 
           "\[IndentingNewLine]", "LF5", ",", " ", "SK4", ",", " ", 
           "IntrinsicMedium", ",", " ", "SK16"}], "}"}]}], "]"}], ",", " ", 
       "2"}], "]"}], ",", " ", 
     RowBox[{"Move", "[", " ", 
      RowBox[{
       RowBox[{"Screen", "[", "5", "]"}], ",", 
       RowBox[{"6.538", "+", " ", "2.0"}]}], "]"}]}], " ", "}"}], ",", " ", 
   RowBox[{"Axes", " ", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{"PlotType", " ", "\[Rule]", " ", "TopView"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.430582136705831*^9, 3.430582279306122*^9}, {
  3.430582347518166*^9, 3.430582378170793*^9}, {3.4305824846967363`*^9, 
  3.4305825034000196`*^9}, {3.430582705068893*^9, 3.43058273365773*^9}, {
  3.430582770366117*^9, 3.430582774450427*^9}, {3.440432412492483*^9, 
  3.440432490227394*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.4127251659124918`, -1.6}, {2.5129162814931867`, -1.6}, {
      2.461218782903055, -1.0666666666666669`}, {
      2.1767094998192316`, -1.0666666666666669`}, {
      2.4127251659124918`, -1.6}}], 
     PolygonBox[{{2.1767094998192316`, -1.0666666666666669`}, {
      2.461218782903055, -1.0666666666666669`}, {
      2.430293163716014, -0.5333333333333337}, {
      2.0432804734140633`, -0.5333333333333334}, {
      2.1767094998192316`, -1.0666666666666669`}}], 
     PolygonBox[{{2.0432804734140633`, -0.5333333333333334}, {
      2.430293163716014, -0.5333333333333337}, {
      2.42, -4.440892098500626*^-16}, {2.0000000000000004`, 0.}, {
      2.0432804734140633`, -0.5333333333333334}}], 
     PolygonBox[{{2.0000000000000004`, 0.}, {2.42, 0.}, {2.430293163716014, 
      0.5333333333333332}, {2.0432804734140633`, 0.5333333333333332}, {
      2.0000000000000004`, 0.}}], 
     PolygonBox[{{2.0432804734140633`, 0.5333333333333332}, {
      2.430293163716014, 0.5333333333333332}, {2.461218782903055, 
      1.0666666666666664`}, {2.1767094998192316`, 1.0666666666666664`}, {
      2.0432804734140633`, 0.5333333333333332}}], 
     PolygonBox[{{2.1767094998192316`, 1.0666666666666664`}, {
      2.461218782903055, 1.0666666666666664`}, {2.5129162814931867`, 
      1.5999999999999999`}, {2.4127251659124913`, 1.5999999999999996`}, {
      2.1767094998192316`, 1.0666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4127251659124918`, -1.6}, {
       2.1767094998192316`, -1.0666666666666669`}, {
       2.0432804734140633`, -0.5333333333333334}, {2.0000000000000004`, 0.}, {
       2.0432804734140633`, 0.5333333333333332}, {2.1767094998192316`, 
       1.0666666666666664`}, {2.4127251659124918`, 1.6}, {2.5129162814931867`,
        1.6}, {2.461218782903055, 1.0666666666666669`}, {2.430293163716014, 
       0.5333333333333334}, {2.42, 0.}, {
       2.430293163716014, -0.5333333333333332}, {
       2.461218782903055, -1.0666666666666664`}, {
       2.5129162814931867`, -1.6}, {2.4127251659124918`, -1.6}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{2.4127251659124918`, 0.}, {2.5129162814931867`, 
        1.9594348786357652`*^-16}, {2.461218782903055, 
        1.6328623988631378`*^-16}, {2.1767094998192316`, 
        3.265724797726275*^-17}, {2.4127251659124918`, 0.}}], 
       PolygonBox[{{2.1767094998192316`, 3.265724797726275*^-17}, {
        2.461218782903055, 1.6328623988631378`*^-16}, {2.430293163716014, 
        1.3062899190905103`*^-16}, {2.0432804734140633`, 
        6.53144959545255*^-17}, {2.1767094998192316`, 
        3.265724797726275*^-17}}], 
       PolygonBox[{{2.0432804734140633`, 6.53144959545255*^-17}, {
        2.430293163716014, 1.3062899190905103`*^-16}, {2.42, 
        9.797174393178829*^-17}, {2.0000000000000004`, 
        9.797174393178826*^-17}, {2.0432804734140633`, 
        6.53144959545255*^-17}}], 
       PolygonBox[{{2.0000000000000004`, 9.797174393178826*^-17}, {2.42, 
        9.797174393178826*^-17}, {2.430293163716014, 
        6.531449595452552*^-17}, {2.0432804734140633`, 
        1.30628991909051*^-16}, {2.0000000000000004`, 
        9.797174393178826*^-17}}], 
       PolygonBox[{{2.0432804734140633`, 1.30628991909051*^-16}, {
        2.430293163716014, 6.531449595452552*^-17}, {2.461218782903055, 
        3.2657247977262764`*^-17}, {2.1767094998192316`, 
        1.6328623988631375`*^-16}, {2.0432804734140633`, 
        1.30628991909051*^-16}}], 
       PolygonBox[{{2.1767094998192316`, 1.6328623988631375`*^-16}, {
        2.461218782903055, 3.2657247977262764`*^-17}, {2.5129162814931867`, 
        1.6315572881362695`*^-32}, {2.4127251659124913`, 
        1.959434878635765*^-16}, {2.1767094998192316`, 
        1.6328623988631375`*^-16}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{2.4127251659124918`, 0.}, {2.1767094998192316`, 0.}, {
         2.0432804734140633`, 0.}, {2.0000000000000004`, 0.}, {
         2.0432804734140633`, 0.}, {2.1767094998192316`, 0.}, {
         2.4127251659124918`, 0.}, {2.5129162814931867`, 0.}, {
         2.461218782903055, 0.}, {2.430293163716014, 0.}, {2.42, 0.}, {
         2.430293163716014, 0.}, {2.461218782903055, 0.}, {
         2.5129162814931867`, 0.}, {2.4127251659124918`, 0.}}], 
        {GrayLevel[0.5], EdgeForm[None], 
         PolygonBox[{{2.9178823575931885`, -1.28}, {
          3.0109724820688584`, -1.28}, {
          3.031550975310239, -0.8533333333333333}, {
          2.6382341817875212`, -0.8533333333333334}, {
          2.9178823575931885`, -1.28}}], 
         PolygonBox[{{2.6382341817875212`, -0.8533333333333334}, {
          3.031550975310239, -0.8533333333333333}, {
          3.043888889613843, -0.42666666666666697`}, {
          2.489942168569282, -0.42666666666666675`}, {
          2.6382341817875212`, -0.8533333333333334}}], 
         PolygonBox[{{2.489942168569282, -0.42666666666666675`}, {
          3.043888889613843, -0.42666666666666697`}, {
          3.0479999999999983`, -2.220446049250313*^-16}, {2.4429999999999996`,
           0.}, {2.489942168569282, -0.42666666666666675`}}], 
         PolygonBox[{{2.4429999999999996`, 0.}, {3.0479999999999983`, 0.}, {
          3.043888889613843, 0.4266666666666665}, {2.4899421685692817`, 
          0.4266666666666665}, {2.4429999999999996`, 0.}}], 
         PolygonBox[{{2.4899421685692817`, 0.4266666666666665}, {
          3.043888889613843, 0.4266666666666665}, {3.031550975310239, 
          0.8533333333333333}, {2.6382341817875212`, 0.8533333333333333}, {
          2.4899421685692817`, 0.4266666666666665}}], 
         PolygonBox[{{2.6382341817875212`, 0.8533333333333333}, {
          3.031550975310239, 0.8533333333333332}, {3.0109724820688584`, 
          1.2799999999999998`}, {2.917882357593188, 1.2799999999999996`}, {
          2.6382341817875212`, 0.8533333333333333}}], 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          LineBox[{{2.9178823575931885`, -1.28}, {
           2.6382341817875212`, -0.8533333333333334}, {
           2.489942168569282, -0.42666666666666675`}, {
           2.4429999999999996`, -2.220446049250313*^-16}, {
           2.4899421685692817`, 0.4266666666666665}, {2.6382341817875212`, 
           0.8533333333333333}, {2.917882357593188, 1.2799999999999996`}, {
           3.0109724820688584`, 1.28}, {3.031550975310239, 
           0.8533333333333334}, {3.043888889613843, 0.42666666666666675`}, {
           3.0479999999999983`, 2.220446049250313*^-16}, {
           3.043888889613843, -0.4266666666666665}, {
           3.031550975310239, -0.8533333333333333}, {
           3.0109724820688584`, -1.2799999999999996`}, {
           2.9178823575931885`, -1.28}}], 
          {GrayLevel[0.5], EdgeForm[None], 
           PolygonBox[{{2.9178823575931885`, 0.}, {3.0109724820688584`, 
            1.567547902908612*^-16}, {3.031550975310239, 
            1.30628991909051*^-16}, {2.6382341817875212`, 
            2.61257983818102*^-17}, {2.9178823575931885`, 0.}}], 
           PolygonBox[{{2.6382341817875212`, 2.61257983818102*^-17}, {
            3.031550975310239, 1.30628991909051*^-16}, {3.043888889613843, 
            1.0450319352724083`*^-16}, {2.489942168569282, 
            5.22515967636204*^-17}, {2.6382341817875212`, 
            2.61257983818102*^-17}}], 
           PolygonBox[{{2.489942168569282, 5.22515967636204*^-17}, {
            3.043888889613843, 1.0450319352724083`*^-16}, {
            3.0479999999999983`, 7.837739514543062*^-17}, {
            2.4429999999999996`, 7.83773951454306*^-17}, {2.489942168569282, 
            5.22515967636204*^-17}}], 
           PolygonBox[{{2.4429999999999996`, 7.83773951454306*^-17}, {
            3.0479999999999983`, 7.83773951454306*^-17}, {3.043888889613843, 
            5.2251596763620415`*^-17}, {2.4899421685692817`, 
            1.045031935272408*^-16}, {2.4429999999999996`, 
            7.83773951454306*^-17}}], 
           PolygonBox[{{2.4899421685692817`, 1.045031935272408*^-16}, {
            3.043888889613843, 5.2251596763620415`*^-17}, {3.031550975310239, 
            2.612579838181021*^-17}, {2.6382341817875212`, 
            1.30628991909051*^-16}, {2.4899421685692817`, 
            1.045031935272408*^-16}}], 
           PolygonBox[{{2.6382341817875212`, 1.30628991909051*^-16}, {
            3.031550975310239, 2.6125798381810214`*^-17}, {
            3.0109724820688584`, 1.3052458305090153`*^-32}, {
            2.917882357593188, 1.5675479029086118`*^-16}, {
            2.6382341817875212`, 1.30628991909051*^-16}}], 
           {GrayLevel[0], AbsoluteThickness[0.5], 
            LineBox[{{2.9178823575931885`, 0.}, {2.6382341817875212`, 0.}, {
             2.489942168569282, 0.}, {2.4429999999999996`, 0.}, {
             2.4899421685692817`, 0.}, {2.6382341817875212`, 0.}, {
             2.917882357593188, 0.}, {3.0109724820688584`, 0.}, {
             3.031550975310239, 0.}, {3.043888889613843, 0.}, {
             3.0479999999999983`, 0.}, {3.043888889613843, 0.}, {
             3.031550975310239, 0.}, {3.0109724820688584`, 0.}, {
             2.9178823575931885`, 0.}}], 
            {GrayLevel[0.5], EdgeForm[None], 
             PolygonBox[{{3.0109724820688584`, -1.28}, {
              3.574048663883448, -0.75}, {3.4328084629414652`, -0.5}, {
              3.031550975310239, -0.8533333333333334}, {
              3.0109724820688584`, -1.28}}], 
             PolygonBox[{{3.031550975310239, -0.8533333333333334}, {
              3.4328084629414652`, -0.5}, {3.3556769978186205`, -0.25}, {
              3.043888889613843, -0.42666666666666675`}, {
              3.031550975310239, -0.8533333333333334}}], 
             PolygonBox[{{3.043888889613843, -0.42666666666666675`}, {
              3.3556769978186205`, -0.25}, {
              3.3310000000000004`, -2.220446049250313*^-16}, {
              3.0479999999999983`, 0.}, {
              3.043888889613843, -0.42666666666666675`}}], 
             PolygonBox[{{3.0479999999999983`, 0.}, {3.3310000000000004`, 
              0.}, {3.3556769978186205`, 0.25}, {3.043888889613843, 
              0.4266666666666665}, {3.0479999999999983`, 0.}}], 
             PolygonBox[{{3.043888889613843, 0.4266666666666665}, {
              3.3556769978186205`, 0.25}, {3.4328084629414652`, 
              0.49999999999999994`}, {3.031550975310239, 
              0.8533333333333333}, {3.043888889613843, 0.4266666666666665}}], 
             PolygonBox[{{3.031550975310239, 0.8533333333333333}, {
              3.4328084629414652`, 0.4999999999999999}, {3.574048663883448, 
              0.7499999999999999}, {3.0109724820688584`, 
              1.2799999999999996`}, {3.031550975310239, 0.8533333333333333}}], 
             {GrayLevel[0], AbsoluteThickness[0.5], 
              LineBox[{{3.0109724820688584`, -1.28}, {
               3.031550975310239, -0.8533333333333334}, {
               3.043888889613843, -0.42666666666666675`}, {
               3.0479999999999983`, -2.220446049250313*^-16}, {
               3.043888889613843, 0.4266666666666665}, {3.031550975310239, 
               0.8533333333333333}, {3.0109724820688584`, 
               1.2799999999999996`}, {3.574048663883448, 0.75}, {
               3.4328084629414652`, 0.5}, {3.3556769978186205`, 0.25}, {
               3.3310000000000004`, 0.}, {3.3556769978186205`, -0.25}, {
               3.4328084629414652`, -0.5}, {3.574048663883448, -0.75}, {
               3.0109724820688584`, -1.28}}], 
              {GrayLevel[0.5], EdgeForm[None], 
               PolygonBox[{{3.0109724820688584`, 0.}, {3.574048663883448, 
                9.184850993605148*^-17}, {3.4328084629414652`, 
                7.654042494670958*^-17}, {3.031550975310239, 
                2.61257983818102*^-17}, {3.0109724820688584`, 0.}}], 
               PolygonBox[{{3.031550975310239, 2.61257983818102*^-17}, {
                3.4328084629414652`, 7.654042494670958*^-17}, {
                3.3556769978186205`, 6.123233995736766*^-17}, {
                3.043888889613843, 5.22515967636204*^-17}, {3.031550975310239,
                 2.61257983818102*^-17}}], 
               PolygonBox[{{3.043888889613843, 5.22515967636204*^-17}, {
                3.3556769978186205`, 6.123233995736766*^-17}, {
                3.3310000000000004`, 4.592425496802576*^-17}, {
                3.0479999999999983`, 7.83773951454306*^-17}, {
                3.043888889613843, 5.22515967636204*^-17}}], 
               PolygonBox[{{3.0479999999999983`, 7.83773951454306*^-17}, {
                3.3310000000000004`, 4.592425496802574*^-17}, {
                3.3556769978186205`, 3.061616997868383*^-17}, {
                3.043888889613843, 1.045031935272408*^-16}, {
                3.0479999999999983`, 7.83773951454306*^-17}}], 
               PolygonBox[{{3.043888889613843, 1.045031935272408*^-16}, {
                3.3556769978186205`, 3.061616997868383*^-17}, {
                3.4328084629414652`, 1.5308084989341918`*^-17}, {
                3.031550975310239, 1.30628991909051*^-16}, {3.043888889613843,
                 1.045031935272408*^-16}}], 
               PolygonBox[{{3.031550975310239, 1.30628991909051*^-16}, {
                3.4328084629414652`, 1.530808498934192*^-17}, {
                3.574048663883448, 7.647924788138762*^-33}, {
                3.0109724820688584`, 1.5675479029086118`*^-16}, {
                3.031550975310239, 1.30628991909051*^-16}}], 
               {GrayLevel[0], AbsoluteThickness[0.5], 
                LineBox[{{3.0109724820688584`, 0.}, {3.031550975310239, 0.}, {
                 3.043888889613843, 0.}, {3.0479999999999983`, 0.}, {
                 3.043888889613843, 0.}, {3.031550975310239, 0.}, {
                 3.0109724820688584`, 0.}, {3.574048663883448, 0.}, {
                 3.4328084629414652`, 0.}, {3.3556769978186205`, 0.}, {
                 3.3310000000000004`, 0.}, {3.3556769978186205`, 0.}, {
                 3.4328084629414652`, 0.}, {3.574048663883448, 0.}, {
                 3.0109724820688584`, 0.}}], 
                {GrayLevel[0.5], EdgeForm[None], 
                 PolygonBox[{{4.005801435187534, -0.8}, {
                  4.671814204887351, -1.18}, {
                  4.519050386647099, -0.7866666666666666}, {
                  4.117692499239815, -0.5333333333333334}, {
                  4.005801435187534, -0.8}}], 
                 PolygonBox[{{4.117692499239815, -0.5333333333333334}, {
                  4.519050386647099, -0.7866666666666666}, {
                  4.431544191532013, -0.39333333333333353`}, {
                  4.181313210815489, -0.2666666666666667}, {
                  4.117692499239815, -0.5333333333333334}}], 
                 PolygonBox[{{4.181313210815489, -0.2666666666666667}, {
                  4.431544191532013, -0.39333333333333353`}, {
                  4.4030000000000005`, -2.220446049250313*^-16}, {4.202, 
                  0.}, {4.181313210815489, -0.2666666666666667}}], 
                 PolygonBox[{{4.202, 0.}, {4.4030000000000005`, 0.}, {
                  4.431544191532013, 0.3933333333333332}, {4.181313210815489, 
                  0.2666666666666666}, {4.202, 0.}}], 
                 PolygonBox[{{4.181313210815489, 0.2666666666666666}, {
                  4.431544191532013, 0.3933333333333332}, {4.519050386647099, 
                  0.7866666666666665}, {4.117692499239815, 
                  0.5333333333333332}, {4.181313210815489, 
                  0.2666666666666666}}], 
                 PolygonBox[{{4.117692499239815, 0.5333333333333332}, {
                  4.519050386647099, 0.7866666666666664}, {4.671814204887351, 
                  1.1799999999999997`}, {4.005801435187534, 
                  0.7999999999999998}, {4.117692499239815, 
                  0.5333333333333332}}], 
                 {GrayLevel[0], AbsoluteThickness[0.5], 
                  LineBox[{{4.005801435187534, -0.8}, {
                   4.117692499239815, -0.5333333333333334}, {
                   4.181313210815489, -0.2666666666666667}, {4.202, 0.}, {
                   4.181313210815489, 0.2666666666666666}, {4.117692499239815,
                    0.5333333333333332}, {4.005801435187534, 0.8}, {
                   4.671814204887351, 1.18}, {4.519050386647099, 
                   0.7866666666666666}, {4.431544191532013, 
                   0.3933333333333333}, {4.4030000000000005`, 0.}, {
                   4.431544191532013, -0.3933333333333333}, {
                   4.519050386647099, -0.7866666666666666}, {
                   4.671814204887351, -1.18}, {4.005801435187534, -0.8}}], 
                  {GrayLevel[0.5], EdgeForm[None], 
                   PolygonBox[{{4.005801435187534, 0.}, {4.671814204887351, 
                    1.4450832229938768`*^-16}, {4.519050386647099, 
                    1.2042360191615639`*^-16}, {4.117692499239815, 
                    1.6328623988631376`*^-17}, {4.005801435187534, 0.}}], 
                   PolygonBox[{{4.117692499239815, 
                    1.6328623988631376`*^-17}, {4.519050386647099, 
                    1.2042360191615639`*^-16}, {4.431544191532013, 
                    9.633888153292513*^-17}, {4.181313210815489, 
                    3.265724797726275*^-17}, {4.117692499239815, 
                    1.6328623988631376`*^-17}}], 
                   PolygonBox[{{4.181313210815489, 3.265724797726275*^-17}, {
                    4.431544191532013, 9.633888153292513*^-17}, {
                    4.4030000000000005`, 7.225416114969385*^-17}, {4.202, 
                    4.898587196589413*^-17}, {4.181313210815489, 
                    3.265724797726275*^-17}}], 
                   PolygonBox[{{4.202, 4.898587196589413*^-17}, {
                    4.4030000000000005`, 7.225416114969384*^-17}, {
                    4.431544191532013, 4.8169440766462566`*^-17}, {
                    4.181313210815489, 6.53144959545255*^-17}, {4.202, 
                    4.898587196589413*^-17}}], 
                   PolygonBox[{{4.181313210815489, 6.53144959545255*^-17}, {
                    4.431544191532013, 4.8169440766462566`*^-17}, {
                    4.519050386647099, 2.4084720383231286`*^-17}, {
                    4.117692499239815, 8.164311994315688*^-17}, {
                    4.181313210815489, 6.53144959545255*^-17}}], 
                   PolygonBox[{{4.117692499239815, 8.164311994315688*^-17}, {
                    4.519050386647099, 2.408472038323129*^-17}, {
                    4.671814204887351, 1.2032735000004987`*^-32}, {
                    4.005801435187534, 9.797174393178825*^-17}, {
                    4.117692499239815, 8.164311994315688*^-17}}], 
                   {GrayLevel[0], AbsoluteThickness[0.5], 
                    LineBox[{{4.005801435187534, 0.}, {4.117692499239815, 
                    0.}, {4.181313210815489, 0.}, {4.202, 0.}, {
                    4.181313210815489, 0.}, {4.117692499239815, 0.}, {
                    4.005801435187534, 0.}, {4.671814204887351, 0.}, {
                    4.519050386647099, 0.}, {4.431544191532013, 0.}, {
                    4.4030000000000005`, 0.}, {4.431544191532013, 0.}, {
                    4.519050386647099, 0.}, {4.671814204887351, 0.}, {
                    4.005801435187534, 0.}}], 
                    {GrayLevel[0.5], EdgeForm[None], 
                    PolygonBox[{{4.671814204887351, -1.18}, {
                    4.748489652080478, -1.18}, {
                    4.9359961872341795`, -0.7866666666666666}, {
                    4.519050386647099, -0.7866666666666666}, {
                    4.671814204887351, -1.18}}], 
                    PolygonBox[{{4.519050386647099, -0.7866666666666666}, {
                    4.9359961872341795`, -0.7866666666666666}, {
                    5.041050162806231, -0.39333333333333353`}, {
                    4.431544191532013, -0.3933333333333333}, {
                    4.519050386647099, -0.7866666666666666}}], 
                    PolygonBox[{{4.431544191532013, -0.3933333333333333}, {
                    5.041050162806231, -0.39333333333333353`}, {
                    5.075, -2.220446049250313*^-16}, {4.4030000000000005`, 
                    0.}, {4.431544191532013, -0.3933333333333333}}], 
                    PolygonBox[{{4.4030000000000005`, 0.}, {5.075, 0.}, {
                    5.041050162806231, 0.3933333333333332}, {
                    4.431544191532013, 0.3933333333333333}, {
                    4.4030000000000005`, 0.}}], 
                    PolygonBox[{{4.431544191532013, 0.3933333333333333}, {
                    5.041050162806231, 0.3933333333333332}, {
                    4.9359961872341795`, 0.7866666666666665}, {
                    4.519050386647099, 0.7866666666666664}, {
                    4.431544191532013, 0.3933333333333333}}], 
                    PolygonBox[{{4.519050386647099, 0.7866666666666664}, {
                    4.9359961872341795`, 0.7866666666666664}, {
                    4.748489652080478, 1.1799999999999997`}, {
                    4.67181420488735, 1.1799999999999995`}, {
                    4.519050386647099, 0.7866666666666664}}], 
                    {GrayLevel[0], AbsoluteThickness[0.5], 
                    LineBox[{{4.671814204887351, -1.18}, {
                    4.519050386647099, -0.7866666666666666}, {
                    4.431544191532013, -0.3933333333333333}, {
                    4.4030000000000005`, 0.}, {4.431544191532013, 
                    0.3933333333333333}, {4.519050386647099, 
                    0.7866666666666666}, {4.671814204887351, 1.18}, {
                    4.748489652080478, 1.18}, {4.9359961872341795`, 
                    0.7866666666666666}, {5.041050162806231, 
                    0.3933333333333333}, {5.075, 0.}, {
                    5.041050162806231, -0.3933333333333333}, {
                    4.9359961872341795`, -0.7866666666666666}, {
                    4.748489652080478, -1.18}, {4.671814204887351, -1.18}}], 
                    {GrayLevel[0.5], EdgeForm[None], 
                    PolygonBox[{{4.671814204887351, 0.}, {4.748489652080478, 
                    1.4450832229938768`*^-16}, {4.9359961872341795`, 
                    1.2042360191615639`*^-16}, {4.519050386647099, 
                    2.408472038323128*^-17}, {4.671814204887351, 0.}}], 
                    PolygonBox[{{4.519050386647099, 2.408472038323128*^-17}, {
                    4.9359961872341795`, 1.2042360191615639`*^-16}, {
                    5.041050162806231, 9.633888153292513*^-17}, {
                    4.431544191532013, 4.816944076646256*^-17}, {
                    4.519050386647099, 2.408472038323128*^-17}}], 
                    PolygonBox[{{4.431544191532013, 4.816944076646256*^-17}, {
                    5.041050162806231, 9.633888153292513*^-17}, {5.075, 
                    7.225416114969385*^-17}, {4.4030000000000005`, 
                    7.225416114969384*^-17}, {4.431544191532013, 
                    4.816944076646256*^-17}}], 
                    PolygonBox[{{4.4030000000000005`, 
                    7.225416114969384*^-17}, {5.075, 
                    7.225416114969384*^-17}, {5.041050162806231, 
                    4.8169440766462566`*^-17}, {4.431544191532013, 
                    9.633888153292512*^-17}, {4.4030000000000005`, 
                    7.225416114969384*^-17}}], 
                    PolygonBox[{{4.431544191532013, 9.633888153292512*^-17}, {
                    5.041050162806231, 4.8169440766462566`*^-17}, {
                    4.9359961872341795`, 2.4084720383231286`*^-17}, {
                    4.519050386647099, 1.2042360191615639`*^-16}, {
                    4.431544191532013, 9.633888153292512*^-17}}], 
                    PolygonBox[{{4.519050386647099, 
                    1.2042360191615639`*^-16}, {4.9359961872341795`, 
                    2.408472038323129*^-17}, {4.748489652080478, 
                    1.2032735000004987`*^-32}, {4.67181420488735, 
                    1.4450832229938765`*^-16}, {4.519050386647099, 
                    1.2042360191615639`*^-16}}], 
                    {GrayLevel[0], AbsoluteThickness[0.5], 
                    LineBox[{{4.671814204887351, 0.}, {4.519050386647099, 
                    0.}, {4.431544191532013, 0.}, {4.4030000000000005`, 0.}, {
                    4.431544191532013, 0.}, {4.519050386647099, 0.}, {
                    4.671814204887351, 0.}, {4.748489652080478, 0.}, {
                    4.9359961872341795`, 0.}, {5.041050162806231, 0.}, {5.075,
                     0.}, {5.041050162806231, 0.}, {4.9359961872341795`, 
                    0.}, {4.748489652080478, 0.}, {4.671814204887351, 0.}}], 
                    {GrayLevel[0.5], EdgeForm[None], 
                    PolygonBox[{{5.534443062211261, -1.5}, {
                    5.627613727648733, -1.5}, {5.698610540005257, -1.}, {
                    5.437514103763482, -1.}, {5.534443062211261, -1.5}}], 
                    PolygonBox[{{5.437514103763482, -1.}, {
                    5.698610540005257, -1.}, {5.7409362013674965`, -0.5}, {
                    5.380044781965627, -0.5}, {5.437514103763482, -1.}}], 
                    PolygonBox[{{5.380044781965627, -0.5}, {
                    5.7409362013674965`, -0.5}, {
                    5.755000000000001, -4.440892098500626*^-16}, {
                    5.361000000000001, 0.}, {5.380044781965627, -0.5}}], 
                    PolygonBox[{{5.361000000000001, 0.}, {5.755000000000001, 
                    0.}, {5.7409362013674965`, 0.5}, {5.380044781965627, 
                    0.5}, {5.361000000000001, 0.}}], 
                    PolygonBox[{{5.380044781965627, 0.5}, {
                    5.7409362013674965`, 0.5}, {5.698610540005257, 
                    0.9999999999999999}, {5.437514103763482, 1.}, {
                    5.380044781965627, 0.5}}], 
                    PolygonBox[{{5.437514103763482, 1.}, {5.698610540005257, 
                    0.9999999999999998}, {5.627613727648733, 
                    1.4999999999999998`}, {5.534443062211261, 
                    1.4999999999999996`}, {5.437514103763482, 1.}}], 
                    {GrayLevel[0], AbsoluteThickness[0.5], 
                    LineBox[{{5.534443062211261, -1.5}, {
                    5.437514103763482, -1.}, {5.380044781965627, -0.5}, {
                    5.361000000000001, 0.}, {5.380044781965627, 0.5}, {
                    5.437514103763482, 1.}, {5.534443062211261, 1.5}, {
                    5.627613727648733, 1.5}, {5.698610540005257, 1.}, {
                    5.7409362013674965`, 0.5}, {5.755000000000001, 0.}, {
                    5.7409362013674965`, -0.5}, {5.698610540005257, -1.}, {
                    5.627613727648733, -1.5}, {5.534443062211261, -1.5}}], 
                    {GrayLevel[0.5], EdgeForm[None], 
                    PolygonBox[{{5.534443062211261, 0.}, {5.627613727648733, 
                    1.8369701987210297`*^-16}, {5.698610540005257, 
                    1.5308084989341916`*^-16}, {5.437514103763482, 
                    3.061616997868383*^-17}, {5.534443062211261, 0.}}], 
                    PolygonBox[{{5.437514103763482, 3.061616997868383*^-17}, {
                    5.698610540005257, 1.5308084989341916`*^-16}, {
                    5.7409362013674965`, 1.2246467991473532`*^-16}, {
                    5.380044781965627, 6.123233995736766*^-17}, {
                    5.437514103763482, 3.061616997868383*^-17}}], 
                    PolygonBox[{{5.380044781965627, 6.123233995736766*^-17}, {
                    5.7409362013674965`, 1.2246467991473532`*^-16}, {
                    5.755000000000001, 9.184850993605152*^-17}, {
                    5.361000000000001, 9.184850993605148*^-17}, {
                    5.380044781965627, 6.123233995736766*^-17}}], 
                    PolygonBox[{{5.361000000000001, 9.184850993605148*^-17}, {
                    5.755000000000001, 9.184850993605148*^-17}, {
                    5.7409362013674965`, 6.123233995736766*^-17}, {
                    5.380044781965627, 1.2246467991473532`*^-16}, {
                    5.361000000000001, 9.184850993605148*^-17}}], 
                    PolygonBox[{{5.380044781965627, 
                    1.2246467991473532`*^-16}, {5.7409362013674965`, 
                    6.123233995736766*^-17}, {5.698610540005257, 
                    3.0616169978683836`*^-17}, {5.437514103763482, 
                    1.5308084989341916`*^-16}, {5.380044781965627, 
                    1.2246467991473532`*^-16}}], 
                    PolygonBox[{{5.437514103763482, 
                    1.5308084989341916`*^-16}, {5.698610540005257, 
                    3.061616997868384*^-17}, {5.627613727648733, 
                    1.5295849576277525`*^-32}, {5.534443062211261, 
                    1.8369701987210294`*^-16}, {5.437514103763482, 
                    1.5308084989341916`*^-16}}], 
                    {GrayLevel[0], AbsoluteThickness[0.5], 
                    LineBox[{{5.534443062211261, 0.}, {5.437514103763482, 
                    0.}, {5.380044781965627, 0.}, {5.361000000000001, 0.}, {
                    5.380044781965627, 0.}, {5.437514103763482, 0.}, {
                    5.534443062211261, 0.}, {5.627613727648733, 0.}, {
                    5.698610540005257, 0.}, {5.7409362013674965`, 0.}, {
                    5.755000000000001, 0.}, {5.7409362013674965`, 0.}, {
                    5.698610540005257, 0.}, {5.627613727648733, 0.}, {
                    5.534443062211261, 0.}}]}}}}}}}}}}}}}}}}}}}}}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4127251659124918`, 1.6}, {2.5129162814931867`, 1.6}, {
       2.5129162814931867`, 1.5454813220625094`}, {2.4127251659124918`, 
       1.5454813220625094`}, {2.4127251659124918`, 1.6}}], 
      LineBox[{{2.4127251659124918`, 1.5454813220625094`}, {
       2.5129162814931867`, 1.5454813220625094`}, {2.512916281493185, 
       1.385640646055102}, {2.4127251659124918`, 1.385640646055102}, {
       2.4127251659124918`, 1.5454813220625094`}}], 
      LineBox[{{2.4127251659124918`, 1.385640646055102}, {2.512916281493185, 
       1.385640646055102}, {2.5129162814931867`, 1.1313708498984762`}, {
       2.4127251659124918`, 1.1313708498984762`}, {2.4127251659124918`, 
       1.385640646055102}}], 
      LineBox[{{2.4127251659124918`, 1.1313708498984762`}, {
       2.5129162814931867`, 1.1313708498984762`}, {2.512916281493185, 
       0.8000000000000003}, {2.4127251659124918`, 0.8000000000000003}, {
       2.4127251659124918`, 1.1313708498984762`}}], 
      LineBox[{{2.4127251659124918`, 0.8000000000000003}, {2.512916281493185, 
       0.8000000000000003}, {2.5129162814931867`, 0.41411047216403357`}, {
       2.4127251659124918`, 0.41411047216403357`}, {2.4127251659124918`, 
       0.8000000000000003}}], 
      LineBox[{{2.4127251659124918`, 0.41411047216403357`}, {
       2.5129162814931867`, 0.41411047216403357`}, {2.5129162814931867`, 
       4.5324311181183835`*^-16}, {2.4127251659124918`, 
       4.5324311181183835`*^-16}, {2.4127251659124918`, 
       0.41411047216403357`}}], 
      LineBox[{{2.4127251659124918`, 9.797174393178826*^-17}, {
       2.5129162814931867`, 9.797174393178826*^-17}, {
       2.5129162814931867`, -0.414110472164033}, {
       2.4127251659124918`, -0.414110472164033}, {2.4127251659124918`, 
       9.797174393178826*^-17}}], 
      LineBox[{{2.4127251659124918`, -0.414110472164033}, {
       2.5129162814931867`, -0.414110472164033}, {
       2.512916281493185, -0.7999999999999997}, {
       2.4127251659124918`, -0.7999999999999997}, {
       2.4127251659124918`, -0.414110472164033}}], 
      LineBox[{{2.4127251659124918`, -0.7999999999999997}, {
       2.512916281493185, -0.7999999999999997}, {
       2.5129162814931867`, -1.131370849898476}, {
       2.4127251659124918`, -1.131370849898476}, {
       2.4127251659124918`, -0.7999999999999997}}], 
      LineBox[{{2.4127251659124918`, -1.131370849898476}, {
       2.5129162814931867`, -1.131370849898476}, {
       2.512916281493185, -1.385640646055102}, {
       2.4127251659124918`, -1.385640646055102}, {
       2.4127251659124918`, -1.131370849898476}}], 
      LineBox[{{2.4127251659124918`, -1.3856406460551016`}, {
       2.5129162814931867`, -1.3856406460551016`}, {
       2.5129162814931867`, -1.5454813220625092`}, {
       2.4127251659124918`, -1.5454813220625092`}, {
       2.4127251659124918`, -1.3856406460551016`}}], 
      LineBox[{{2.4127251659124918`, -1.5454813220625092`}, {
       2.5129162814931867`, -1.5454813220625092`}, {
       2.5129162814931867`, -1.6}, {2.4127251659124918`, -1.6}, {
       2.4127251659124918`, -1.5454813220625092`}}], 
      LineBox[{{2.4127251659124918`, -1.6}, {2.5129162814931867`, -1.6}, {
       2.5129162814931867`, -1.5454813220625094`}, {
       2.4127251659124918`, -1.5454813220625094`}, {
       2.4127251659124918`, -1.6}}], 
      LineBox[{{2.4127251659124918`, -1.5454813220625097`}, {
       2.5129162814931867`, -1.5454813220625097`}, {
       2.512916281493185, -1.3856406460551023`}, {
       2.4127251659124918`, -1.3856406460551023`}, {
       2.4127251659124918`, -1.5454813220625097`}}], 
      LineBox[{{2.4127251659124918`, -1.3856406460551023`}, {
       2.512916281493185, -1.3856406460551023`}, {
       2.5129162814931867`, -1.1313708498984762`}, {
       2.4127251659124918`, -1.1313708498984762`}, {
       2.4127251659124918`, -1.3856406460551023`}}], 
      LineBox[{{2.4127251659124918`, -1.1313708498984767`}, {
       2.5129162814931867`, -1.1313708498984767`}, {
       2.5129162814931867`, -0.8000000000000007}, {
       2.4127251659124913`, -0.8000000000000007}, {
       2.4127251659124918`, -1.1313708498984767`}}], 
      LineBox[{{2.4127251659124913`, -0.8000000000000007}, {
       2.5129162814931867`, -0.8000000000000007}, {
       2.5129162814931867`, -0.41411047216403435`}, {
       2.4127251659124918`, -0.41411047216403435`}, {
       2.4127251659124913`, -0.8000000000000007}}], 
      LineBox[{{2.4127251659124918`, -0.41411047216403435`}, {
       2.5129162814931867`, -0.41411047216403435`}, {
       2.5129162814931867`, -1.7150007033155652`*^-15}, {
       2.4127251659124918`, -1.7150007033155652`*^-15}, {
       2.4127251659124918`, -0.41411047216403435`}}], 
      LineBox[{{2.4127251659124918`, -2.9391523179536476`*^-16}, {
       2.5129162814931867`, -2.9391523179536476`*^-16}, {2.5129162814931867`, 
       0.4141104721640325}, {2.4127251659124918`, 0.4141104721640325}, {
       2.4127251659124918`, -2.9391523179536476`*^-16}}], 
      LineBox[{{2.4127251659124918`, 0.4141104721640325}, {
       2.5129162814931867`, 0.4141104721640325}, {2.5129162814931867`, 
       0.7999999999999989}, {2.4127251659124918`, 0.7999999999999989}, {
       2.4127251659124918`, 0.4141104721640325}}], 
      LineBox[{{2.4127251659124918`, 0.7999999999999989}, {
       2.5129162814931867`, 0.7999999999999989}, {2.5129162814931867`, 
       1.1313708498984747`}, {2.4127251659124918`, 1.1313708498984747`}, {
       2.4127251659124918`, 0.7999999999999989}}], 
      LineBox[{{2.4127251659124918`, 1.131370849898476}, {2.5129162814931867`,
        1.131370849898476}, {2.5129162814931867`, 1.3856406460551014`}, {
       2.4127251659124913`, 1.3856406460551014`}, {2.4127251659124918`, 
       1.131370849898476}}], 
      LineBox[{{2.4127251659124913`, 1.3856406460551014`}, {
       2.5129162814931867`, 1.3856406460551014`}, {2.5129162814931867`, 
       1.545481322062509}, {2.4127251659124918`, 1.545481322062509}, {
       2.4127251659124913`, 1.3856406460551014`}}], 
      LineBox[{{2.4127251659124918`, 1.545481322062509}, {2.5129162814931867`,
        1.545481322062509}, {2.5129162814931867`, 1.6}, {2.4127251659124918`, 
       1.6}, {2.4127251659124918`, 1.545481322062509}}], {}, {}, {}}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9178823575931885`, 1.28}, {3.0109724820688584`, 1.28}, {
       3.0109724820688584`, 1.2363850576500075`}, {2.9178823575931885`, 
       1.2363850576500075`}, {2.9178823575931885`, 1.28}}], 
      LineBox[{{2.9178823575931885`, 1.2363850576500075`}, {
       3.0109724820688584`, 1.2363850576500075`}, {3.0109724820688584`, 
       1.1085125168440815`}, {2.9178823575931885`, 1.1085125168440815`}, {
       2.9178823575931885`, 1.2363850576500075`}}], 
      LineBox[{{2.9178823575931885`, 1.1085125168440815`}, {
       3.0109724820688584`, 1.1085125168440815`}, {3.0109724820688584`, 
       0.905096679918781}, {2.9178823575931885`, 0.905096679918781}, {
       2.9178823575931885`, 1.1085125168440815`}}], 
      LineBox[{{2.9178823575931885`, 0.905096679918781}, {3.0109724820688584`,
        0.905096679918781}, {3.0109724820688584`, 0.6400000000000001}, {
       2.9178823575931885`, 0.6400000000000001}, {2.9178823575931885`, 
       0.905096679918781}}], 
      LineBox[{{2.9178823575931885`, 0.6400000000000001}, {
       3.0109724820688584`, 0.6400000000000001}, {3.0109724820688584`, 
       0.3312883777312268}, {2.9178823575931885`, 0.3312883777312268}, {
       2.9178823575931885`, 0.6400000000000001}}], 
      LineBox[{{2.9178823575931885`, 0.3312883777312268}, {
       3.0109724820688584`, 0.3312883777312268}, {3.0109724820688584`, 
       3.625944894494707*^-16}, {2.9178823575931885`, 
       3.625944894494707*^-16}, {2.9178823575931885`, 0.3312883777312268}}], 
      LineBox[{{2.9178823575931885`, 7.83773951454306*^-17}, {
       3.0109724820688584`, 7.83773951454306*^-17}, {
       3.0109724820688584`, -0.33128837773122644`}, {
       2.9178823575931885`, -0.33128837773122644`}, {2.9178823575931885`, 
       7.83773951454306*^-17}}], 
      LineBox[{{2.9178823575931885`, -0.33128837773122644`}, {
       3.0109724820688584`, -0.33128837773122644`}, {
       3.0109724820688584`, -0.6399999999999997}, {
       2.9178823575931885`, -0.6399999999999997}, {
       2.9178823575931885`, -0.33128837773122644`}}], 
      LineBox[{{2.9178823575931885`, -0.6399999999999997}, {
       3.0109724820688584`, -0.6399999999999997}, {
       3.0109724820688584`, -0.9050966799187807}, {
       2.9178823575931885`, -0.9050966799187807}, {
       2.9178823575931885`, -0.6399999999999997}}], 
      LineBox[{{2.9178823575931885`, -0.9050966799187807}, {
       3.0109724820688584`, -0.9050966799187807}, {
       3.0109724820688584`, -1.1085125168440815`}, {
       2.9178823575931885`, -1.1085125168440815`}, {
       2.9178823575931885`, -0.9050966799187807}}], 
      LineBox[{{2.9178823575931885`, -1.1085125168440813`}, {
       3.0109724820688584`, -1.1085125168440813`}, {
       3.0109724820688584`, -1.2363850576500073`}, {
       2.9178823575931885`, -1.2363850576500073`}, {
       2.9178823575931885`, -1.1085125168440813`}}], 
      LineBox[{{2.9178823575931885`, -1.2363850576500073`}, {
       3.0109724820688584`, -1.2363850576500073`}, {
       3.0109724820688584`, -1.28}, {2.9178823575931885`, -1.28}, {
       2.9178823575931885`, -1.2363850576500073`}}], 
      LineBox[{{2.9178823575931885`, -1.28}, {3.0109724820688584`, -1.28}, {
       3.0109724820688584`, -1.2363850576500075`}, {
       2.9178823575931885`, -1.2363850576500075`}, {
       2.9178823575931885`, -1.28}}], 
      LineBox[{{2.9178823575931885`, -1.2363850576500075`}, {
       3.0109724820688584`, -1.2363850576500075`}, {
       3.0109724820688584`, -1.1085125168440817`}, {
       2.9178823575931885`, -1.1085125168440817`}, {
       2.9178823575931885`, -1.2363850576500075`}}], 
      LineBox[{{2.9178823575931885`, -1.1085125168440817`}, {
       3.0109724820688584`, -1.1085125168440817`}, {
       3.0109724820688584`, -0.9050966799187811}, {
       2.9178823575931885`, -0.9050966799187811}, {
       2.9178823575931885`, -1.1085125168440817`}}], 
      LineBox[{{2.9178823575931885`, -0.9050966799187813}, {
       3.0109724820688584`, -0.9050966799187813}, {
       3.0109724820688584`, -0.6400000000000006}, {
       2.9178823575931885`, -0.6400000000000006}, {
       2.9178823575931885`, -0.9050966799187813}}], 
      LineBox[{{2.9178823575931885`, -0.6400000000000006}, {
       3.0109724820688584`, -0.6400000000000006}, {
       3.0109724820688584`, -0.3312883777312275}, {
       2.9178823575931885`, -0.3312883777312275}, {
       2.9178823575931885`, -0.6400000000000006}}], 
      LineBox[{{2.9178823575931885`, -0.3312883777312275}, {
       3.0109724820688584`, -0.3312883777312275}, {
       3.0109724820688584`, -1.372000562652452*^-15}, {
       2.9178823575931885`, -1.372000562652452*^-15}, {
       2.9178823575931885`, -0.3312883777312275}}], 
      LineBox[{{2.9178823575931885`, -2.351321854362918*^-16}, {
       3.0109724820688584`, -2.351321854362918*^-16}, {3.0109724820688584`, 
       0.331288377731226}, {2.9178823575931885`, 0.331288377731226}, {
       2.9178823575931885`, -2.351321854362918*^-16}}], 
      LineBox[{{2.9178823575931885`, 0.331288377731226}, {3.0109724820688584`,
        0.331288377731226}, {3.0109724820688584`, 0.6399999999999991}, {
       2.9178823575931885`, 0.6399999999999991}, {2.9178823575931885`, 
       0.331288377731226}}], 
      LineBox[{{2.9178823575931885`, 0.6399999999999991}, {
       3.0109724820688584`, 0.6399999999999991}, {3.0109724820688584`, 
       0.9050966799187797}, {2.9178823575931885`, 0.9050966799187797}, {
       2.9178823575931885`, 0.6399999999999991}}], 
      LineBox[{{2.9178823575931885`, 0.9050966799187807}, {
       3.0109724820688584`, 0.9050966799187807}, {3.0109724820688584`, 
       1.1085125168440813`}, {2.9178823575931885`, 1.1085125168440813`}, {
       2.9178823575931885`, 0.9050966799187807}}], 
      LineBox[{{2.9178823575931885`, 1.1085125168440813`}, {
       3.0109724820688584`, 1.1085125168440813`}, {3.0109724820688584`, 
       1.2363850576500073`}, {2.9178823575931885`, 1.2363850576500073`}, {
       2.9178823575931885`, 1.1085125168440813`}}], 
      LineBox[{{2.9178823575931885`, 1.2363850576500073`}, {
       3.0109724820688584`, 1.2363850576500073`}, {3.0109724820688584`, 
       1.28}, {2.9178823575931885`, 1.28}, {2.9178823575931885`, 
       1.2363850576500073`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0109724820688584`, 1.28}, {3.574048663883448, 0.75}, {
       3.574048663883448, 0.7244443697168013}, {3.0109724820688584`, 
       1.2363850576500075`}, {3.0109724820688584`, 1.28}}], 
      LineBox[{{3.0109724820688584`, 1.2363850576500075`}, {3.574048663883448,
        0.7244443697168013}, {3.574048663883448, 0.649519052838329}, {
       3.0109724820688584`, 1.1085125168440815`}, {3.0109724820688584`, 
       1.2363850576500075`}}], 
      LineBox[{{3.0109724820688584`, 1.1085125168440815`}, {3.574048663883448,
        0.649519052838329}, {3.574048663883448, 0.5303300858899107}, {
       3.0109724820688584`, 0.905096679918781}, {3.0109724820688584`, 
       1.1085125168440815`}}], 
      LineBox[{{3.0109724820688584`, 0.905096679918781}, {3.574048663883448, 
       0.5303300858899107}, {3.574048663883448, 0.3750000000000001}, {
       3.0109724820688584`, 0.6400000000000001}, {3.0109724820688584`, 
       0.905096679918781}}], 
      LineBox[{{3.0109724820688584`, 0.6400000000000001}, {3.574048663883448, 
       0.3750000000000001}, {3.574048663883448, 0.19411428382689072`}, {
       3.0109724820688584`, 0.3312883777312268}, {3.0109724820688584`, 
       0.6400000000000001}}], 
      LineBox[{{3.0109724820688584`, 0.3312883777312268}, {3.574048663883448, 
       0.19411428382689072`}, {3.574048663883448, 2.1245770866179924`*^-16}, {
       3.0109724820688584`, 3.625944894494707*^-16}, {3.0109724820688584`, 
       0.3312883777312268}}], 
      LineBox[{{3.0109724820688584`, 7.83773951454306*^-17}, {
       3.574048663883448, 4.592425496802574*^-17}, {
       3.574048663883448, -0.19411428382689047`}, {
       3.0109724820688584`, -0.33128837773122644`}, {3.0109724820688584`, 
       7.83773951454306*^-17}}], 
      LineBox[{{3.0109724820688584`, -0.33128837773122644`}, {
       3.574048663883448, -0.19411428382689047`}, {
       3.574048663883448, -0.37499999999999983`}, {
       3.0109724820688584`, -0.6399999999999997}, {
       3.0109724820688584`, -0.33128837773122644`}}], 
      LineBox[{{3.0109724820688584`, -0.6399999999999997}, {
       3.574048663883448, -0.37499999999999983`}, {
       3.574048663883448, -0.5303300858899106}, {
       3.0109724820688584`, -0.9050966799187807}, {
       3.0109724820688584`, -0.6399999999999997}}], 
      LineBox[{{3.0109724820688584`, -0.9050966799187807}, {
       3.574048663883448, -0.5303300858899106}, {
       3.574048663883448, -0.649519052838329}, {
       3.0109724820688584`, -1.1085125168440815`}, {
       3.0109724820688584`, -0.9050966799187807}}], 
      LineBox[{{3.0109724820688584`, -1.1085125168440813`}, {
       3.574048663883448, -0.6495190528383289}, {
       3.574048663883448, -0.7244443697168012}, {
       3.0109724820688584`, -1.2363850576500073`}, {
       3.0109724820688584`, -1.1085125168440813`}}], 
      LineBox[{{3.0109724820688584`, -1.2363850576500073`}, {
       3.574048663883448, -0.7244443697168012}, {3.574048663883448, -0.75}, {
       3.0109724820688584`, -1.28}, {
       3.0109724820688584`, -1.2363850576500073`}}], 
      LineBox[{{3.0109724820688584`, -1.28}, {3.574048663883448, -0.75}, {
       3.574048663883448, -0.7244443697168013}, {
       3.0109724820688584`, -1.2363850576500075`}, {
       3.0109724820688584`, -1.28}}], 
      LineBox[{{3.0109724820688584`, -1.2363850576500075`}, {
       3.574048663883448, -0.7244443697168013}, {
       3.574048663883448, -0.6495190528383291}, {
       3.0109724820688584`, -1.1085125168440817`}, {
       3.0109724820688584`, -1.2363850576500075`}}], 
      LineBox[{{3.0109724820688584`, -1.1085125168440817`}, {
       3.574048663883448, -0.6495190528383291}, {
       3.574048663883448, -0.5303300858899107}, {
       3.0109724820688584`, -0.9050966799187811}, {
       3.0109724820688584`, -1.1085125168440817`}}], 
      LineBox[{{3.0109724820688584`, -0.9050966799187813}, {
       3.574048663883448, -0.5303300858899109}, {
       3.574048663883448, -0.37500000000000033`}, {
       3.0109724820688584`, -0.6400000000000006}, {
       3.0109724820688584`, -0.9050966799187813}}], 
      LineBox[{{3.0109724820688584`, -0.6400000000000006}, {
       3.574048663883448, -0.37500000000000033`}, {
       3.574048663883448, -0.1941142838268911}, {
       3.0109724820688584`, -0.3312883777312275}, {
       3.0109724820688584`, -0.6400000000000006}}], 
      LineBox[{{3.0109724820688584`, -0.3312883777312275}, {
       3.574048663883448, -0.1941142838268911}, {
       3.574048663883448, -8.039065796791712*^-16}, {
       3.0109724820688584`, -1.372000562652452*^-15}, {
       3.0109724820688584`, -0.3312883777312275}}], 
      LineBox[{{3.0109724820688584`, -2.351321854362918*^-16}, {
       3.574048663883448, -1.3777276490407724`*^-16}, {3.574048663883448, 
       0.19411428382689022`}, {3.0109724820688584`, 0.331288377731226}, {
       3.0109724820688584`, -2.351321854362918*^-16}}], 
      LineBox[{{3.0109724820688584`, 0.331288377731226}, {3.574048663883448, 
       0.19411428382689022`}, {3.574048663883448, 0.37499999999999944`}, {
       3.0109724820688584`, 0.6399999999999991}, {3.0109724820688584`, 
       0.331288377731226}}], 
      LineBox[{{3.0109724820688584`, 0.6399999999999991}, {3.574048663883448, 
       0.37499999999999944`}, {3.574048663883448, 0.53033008588991}, {
       3.0109724820688584`, 0.9050966799187797}, {3.0109724820688584`, 
       0.6399999999999991}}], 
      LineBox[{{3.0109724820688584`, 0.9050966799187807}, {3.574048663883448, 
       0.5303300858899106}, {3.574048663883448, 0.6495190528383288}, {
       3.0109724820688584`, 1.1085125168440813`}, {3.0109724820688584`, 
       0.9050966799187807}}], 
      LineBox[{{3.0109724820688584`, 1.1085125168440813`}, {3.574048663883448,
        0.6495190528383288}, {3.574048663883448, 0.724444369716801}, {
       3.0109724820688584`, 1.2363850576500073`}, {3.0109724820688584`, 
       1.1085125168440813`}}], 
      LineBox[{{3.0109724820688584`, 1.2363850576500073`}, {3.574048663883448,
        0.724444369716801}, {3.574048663883448, 0.75}, {3.0109724820688584`, 
       1.28}, {3.0109724820688584`, 1.2363850576500073`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{3.711, 0.63}, {3.711, 0.6825}, {3.711, 
        0.659244376442289}, {3.711, 0.6085332705621129}, {3.711, 0.63}}], 
       PolygonBox[{{3.711, 0.6085332705621129}, {3.711, 0.659244376442289}, {
        3.711, 0.5910623380828793}, {3.711, 0.5455960043841963}, {3.711, 
        0.6085332705621129}}], 
       PolygonBox[{{3.711, 0.5455960043841963}, {3.711, 0.5910623380828793}, {
        3.711, 0.48260037815981865`}, {3.711, 0.4454772721475249}, {3.711, 
        0.5455960043841963}}], 
       PolygonBox[{{3.711, 0.4454772721475249}, {3.711, 
        0.48260037815981865`}, {3.711, 0.34125}, {3.711, 0.315}, {3.711, 
        0.4454772721475249}}], 
       PolygonBox[{{3.711, 0.315}, {3.711, 0.34125}, {3.711, 
        0.17664399828247038`}, {3.711, 0.16305599841458804`}, {3.711, 
        0.315}}], 
       PolygonBox[{{3.711, 0.16305599841458804`}, {3.711, 
        0.17664399828247038`}, {3.711, 0.}, {3.711, 0.}, {3.711, 
        0.16305599841458804`}}], 
       PolygonBox[{{3.711, 0.}, {3.711, 0.}, {3.711, -0.17664399828247038`}, {
        3.711, -0.16305599841458804`}, {3.711, 0.}}], 
       PolygonBox[{{3.711, -0.16305599841458804`}, {
        3.711, -0.17664399828247038`}, {3.711, -0.34125}, {3.711, -0.315}, {
        3.711, -0.16305599841458804`}}], 
       PolygonBox[{{3.711, -0.315}, {3.711, -0.34125}, {
        3.711, -0.48260037815981865`}, {3.711, -0.4454772721475249}, {
        3.711, -0.315}}], 
       PolygonBox[{{3.711, -0.4454772721475249}, {
        3.711, -0.48260037815981865`}, {3.711, -0.5910623380828793}, {
        3.711, -0.5455960043841963}, {3.711, -0.4454772721475249}}], 
       PolygonBox[{{3.711, -0.5455960043841963}, {
        3.711, -0.5910623380828793}, {3.711, -0.659244376442289}, {
        3.711, -0.6085332705621129}, {3.711, -0.5455960043841963}}], 
       PolygonBox[{{3.711, -0.6085332705621129}, {
        3.711, -0.659244376442289}, {3.711, -0.6825}, {3.711, -0.63}, {
        3.711, -0.6085332705621129}}], 
       PolygonBox[{{3.711, -0.63}, {3.711, -0.6825}, {
        3.711, -0.659244376442289}, {3.711, -0.6085332705621129}, {
        3.711, -0.63}}], 
       PolygonBox[{{3.711, -0.6085332705621129}, {
        3.711, -0.659244376442289}, {3.711, -0.5910623380828793}, {
        3.711, -0.5455960043841963}, {3.711, -0.6085332705621129}}], 
       PolygonBox[{{3.711, -0.5455960043841963}, {
        3.711, -0.5910623380828793}, {3.711, -0.48260037815981865`}, {
        3.711, -0.4454772721475249}, {3.711, -0.5455960043841963}}], 
       PolygonBox[{{3.711, -0.4454772721475249}, {
        3.711, -0.48260037815981865`}, {3.711, -0.34125}, {3.711, -0.315}, {
        3.711, -0.4454772721475249}}], 
       PolygonBox[{{3.711, -0.315}, {3.711, -0.34125}, {
        3.711, -0.17664399828247038`}, {3.711, -0.16305599841458804`}, {
        3.711, -0.315}}], 
       PolygonBox[{{3.711, -0.16305599841458804`}, {
        3.711, -0.17664399828247038`}, {3.711, 0.}, {3.711, 0.}, {
        3.711, -0.16305599841458804`}}], 
       PolygonBox[{{3.711, 0.}, {3.711, 0.}, {3.711, 0.17664399828247038`}, {
        3.711, 0.16305599841458804`}, {3.711, 0.}}], 
       PolygonBox[{{3.711, 0.16305599841458804`}, {3.711, 
        0.17664399828247038`}, {3.711, 0.34125}, {3.711, 0.315}, {3.711, 
        0.16305599841458804`}}], 
       PolygonBox[{{3.711, 0.315}, {3.711, 0.34125}, {3.711, 
        0.48260037815981865`}, {3.711, 0.4454772721475249}, {3.711, 0.315}}], 
       PolygonBox[{{3.711, 0.4454772721475249}, {3.711, 
        0.48260037815981865`}, {3.711, 0.5910623380828793}, {3.711, 
        0.5455960043841963}, {3.711, 0.4454772721475249}}], 
       PolygonBox[{{3.711, 0.5455960043841963}, {3.711, 0.5910623380828793}, {
        3.711, 0.659244376442289}, {3.711, 0.6085332705621129}, {3.711, 
        0.5455960043841963}}], 
       PolygonBox[{{3.711, 0.6085332705621129}, {3.711, 0.659244376442289}, {
        3.711, 0.6825}, {3.711, 0.63}, {3.711, 0.6085332705621129}}], 
       PolygonBox[{{3.711, 0.6825}, {3.711, 0.735}, {3.711, 
        0.7099554823224651}, {3.711, 0.659244376442289}, {3.711, 0.6825}}], 
       PolygonBox[{{3.711, 0.659244376442289}, {3.711, 0.7099554823224651}, {
        3.711, 0.6365286717815624}, {3.711, 0.5910623380828793}, {3.711, 
        0.659244376442289}}], 
       PolygonBox[{{3.711, 0.5910623380828793}, {3.711, 0.6365286717815624}, {
        3.711, 0.5197234841721123}, {3.711, 0.48260037815981865`}, {3.711, 
        0.5910623380828793}}], 
       PolygonBox[{{3.711, 0.48260037815981865`}, {3.711, 
        0.5197234841721123}, {3.711, 0.3675}, {3.711, 0.34125}, {3.711, 
        0.48260037815981865`}}], 
       PolygonBox[{{3.711, 0.34125}, {3.711, 0.3675}, {3.711, 
        0.19023199815035272`}, {3.711, 0.17664399828247038`}, {3.711, 
        0.34125}}], 
       PolygonBox[{{3.711, 0.17664399828247038`}, {3.711, 
        0.19023199815035272`}, {3.711, 0.}, {3.711, 0.}, {3.711, 
        0.17664399828247038`}}], 
       PolygonBox[{{3.711, 0.}, {3.711, 0.}, {3.711, -0.19023199815035272`}, {
        3.711, -0.17664399828247038`}, {3.711, 0.}}], 
       PolygonBox[{{3.711, -0.17664399828247038`}, {
        3.711, -0.19023199815035272`}, {3.711, -0.3675}, {3.711, -0.34125}, {
        3.711, -0.17664399828247038`}}], 
       PolygonBox[{{3.711, -0.34125}, {3.711, -0.3675}, {
        3.711, -0.5197234841721123}, {3.711, -0.48260037815981865`}, {
        3.711, -0.34125}}], 
       PolygonBox[{{3.711, -0.48260037815981865`}, {
        3.711, -0.5197234841721123}, {3.711, -0.6365286717815624}, {
        3.711, -0.5910623380828793}, {3.711, -0.48260037815981865`}}], 
       PolygonBox[{{3.711, -0.5910623380828793}, {
        3.711, -0.6365286717815624}, {3.711, -0.7099554823224651}, {
        3.711, -0.659244376442289}, {3.711, -0.5910623380828793}}], 
       PolygonBox[{{3.711, -0.659244376442289}, {
        3.711, -0.7099554823224651}, {3.711, -0.735}, {3.711, -0.6825}, {
        3.711, -0.659244376442289}}], 
       PolygonBox[{{3.711, -0.6825}, {3.711, -0.735}, {
        3.711, -0.7099554823224651}, {3.711, -0.659244376442289}, {
        3.711, -0.6825}}], 
       PolygonBox[{{3.711, -0.659244376442289}, {
        3.711, -0.7099554823224651}, {3.711, -0.6365286717815624}, {
        3.711, -0.5910623380828793}, {3.711, -0.659244376442289}}], 
       PolygonBox[{{3.711, -0.5910623380828793}, {
        3.711, -0.6365286717815624}, {3.711, -0.5197234841721123}, {
        3.711, -0.48260037815981865`}, {3.711, -0.5910623380828793}}], 
       PolygonBox[{{3.711, -0.48260037815981865`}, {
        3.711, -0.5197234841721123}, {3.711, -0.3675}, {3.711, -0.34125}, {
        3.711, -0.48260037815981865`}}], 
       PolygonBox[{{3.711, -0.34125}, {3.711, -0.3675}, {
        3.711, -0.19023199815035272`}, {3.711, -0.17664399828247038`}, {
        3.711, -0.34125}}], 
       PolygonBox[{{3.711, -0.17664399828247038`}, {
        3.711, -0.19023199815035272`}, {3.711, 0.}, {3.711, 0.}, {
        3.711, -0.17664399828247038`}}], 
       PolygonBox[{{3.711, 0.}, {3.711, 0.}, {3.711, 0.19023199815035272`}, {
        3.711, 0.17664399828247038`}, {3.711, 0.}}], 
       PolygonBox[{{3.711, 0.17664399828247038`}, {3.711, 
        0.19023199815035272`}, {3.711, 0.3675}, {3.711, 0.34125}, {3.711, 
        0.17664399828247038`}}], 
       PolygonBox[{{3.711, 0.34125}, {3.711, 0.3675}, {3.711, 
        0.5197234841721123}, {3.711, 0.48260037815981865`}, {3.711, 
        0.34125}}], 
       PolygonBox[{{3.711, 0.48260037815981865`}, {3.711, 
        0.5197234841721123}, {3.711, 0.6365286717815624}, {3.711, 
        0.5910623380828793}, {3.711, 0.48260037815981865`}}], 
       PolygonBox[{{3.711, 0.5910623380828793}, {3.711, 0.6365286717815624}, {
        3.711, 0.7099554823224651}, {3.711, 0.659244376442289}, {3.711, 
        0.5910623380828793}}], 
       PolygonBox[{{3.711, 0.659244376442289}, {3.711, 0.7099554823224651}, {
        3.711, 0.735}, {3.711, 0.6825}, {3.711, 0.659244376442289}}], 
       PolygonBox[{{3.711, 0.735}, {3.711, 0.7875}, {3.711, 
        0.7606665882026411}, {3.711, 0.7099554823224651}, {3.711, 0.735}}], 
       PolygonBox[{{3.711, 0.7099554823224651}, {3.711, 0.7606665882026411}, {
        3.711, 0.6819950054802454}, {3.711, 0.6365286717815624}, {3.711, 
        0.7099554823224651}}], 
       PolygonBox[{{3.711, 0.6365286717815624}, {3.711, 0.6819950054802454}, {
        3.711, 0.5568465901844061}, {3.711, 0.5197234841721123}, {3.711, 
        0.6365286717815624}}], 
       PolygonBox[{{3.711, 0.5197234841721123}, {3.711, 0.5568465901844061}, {
        3.711, 0.39375}, {3.711, 0.3675}, {3.711, 0.5197234841721123}}], 
       PolygonBox[{{3.711, 0.3675}, {3.711, 0.39375}, {3.711, 
        0.20381999801823503`}, {3.711, 0.19023199815035272`}, {3.711, 
        0.3675}}], 
       PolygonBox[{{3.711, 0.19023199815035272`}, {3.711, 
        0.20381999801823503`}, {3.711, 0.}, {3.711, 0.}, {3.711, 
        0.19023199815035272`}}], 
       PolygonBox[{{3.711, 0.}, {3.711, 0.}, {3.711, -0.20381999801823503`}, {
        3.711, -0.19023199815035272`}, {3.711, 0.}}], 
       PolygonBox[{{3.711, -0.19023199815035272`}, {
        3.711, -0.20381999801823503`}, {3.711, -0.39375}, {3.711, -0.3675}, {
        3.711, -0.19023199815035272`}}], 
       PolygonBox[{{3.711, -0.3675}, {3.711, -0.39375}, {
        3.711, -0.5568465901844061}, {3.711, -0.5197234841721123}, {
        3.711, -0.3675}}], 
       PolygonBox[{{3.711, -0.5197234841721123}, {
        3.711, -0.5568465901844061}, {3.711, -0.6819950054802454}, {
        3.711, -0.6365286717815624}, {3.711, -0.5197234841721123}}], 
       PolygonBox[{{3.711, -0.6365286717815624}, {
        3.711, -0.6819950054802454}, {3.711, -0.7606665882026411}, {
        3.711, -0.7099554823224651}, {3.711, -0.6365286717815624}}], 
       PolygonBox[{{3.711, -0.7099554823224651}, {
        3.711, -0.7606665882026411}, {3.711, -0.7875}, {3.711, -0.735}, {
        3.711, -0.7099554823224651}}], 
       PolygonBox[{{3.711, -0.735}, {3.711, -0.7875}, {
        3.711, -0.7606665882026411}, {3.711, -0.7099554823224651}, {
        3.711, -0.735}}], 
       PolygonBox[{{3.711, -0.7099554823224651}, {
        3.711, -0.7606665882026411}, {3.711, -0.6819950054802454}, {
        3.711, -0.6365286717815624}, {3.711, -0.7099554823224651}}], 
       PolygonBox[{{3.711, -0.6365286717815624}, {
        3.711, -0.6819950054802454}, {3.711, -0.5568465901844061}, {
        3.711, -0.5197234841721123}, {3.711, -0.6365286717815624}}], 
       PolygonBox[{{3.711, -0.5197234841721123}, {
        3.711, -0.5568465901844061}, {3.711, -0.39375}, {3.711, -0.3675}, {
        3.711, -0.5197234841721123}}], 
       PolygonBox[{{3.711, -0.3675}, {3.711, -0.39375}, {
        3.711, -0.20381999801823503`}, {3.711, -0.19023199815035272`}, {
        3.711, -0.3675}}], 
       PolygonBox[{{3.711, -0.19023199815035272`}, {
        3.711, -0.20381999801823503`}, {3.711, 0.}, {3.711, 0.}, {
        3.711, -0.19023199815035272`}}], 
       PolygonBox[{{3.711, 0.}, {3.711, 0.}, {3.711, 0.20381999801823503`}, {
        3.711, 0.19023199815035272`}, {3.711, 0.}}], 
       PolygonBox[{{3.711, 0.19023199815035272`}, {3.711, 
        0.20381999801823503`}, {3.711, 0.39375}, {3.711, 0.3675}, {3.711, 
        0.19023199815035272`}}], 
       PolygonBox[{{3.711, 0.3675}, {3.711, 0.39375}, {3.711, 
        0.5568465901844061}, {3.711, 0.5197234841721123}, {3.711, 0.3675}}], 
       PolygonBox[{{3.711, 0.5197234841721123}, {3.711, 0.5568465901844061}, {
        3.711, 0.6819950054802454}, {3.711, 0.6365286717815624}, {3.711, 
        0.5197234841721123}}], 
       PolygonBox[{{3.711, 0.6365286717815624}, {3.711, 0.6819950054802454}, {
        3.711, 0.7606665882026411}, {3.711, 0.7099554823224651}, {3.711, 
        0.6365286717815624}}], 
       PolygonBox[{{3.711, 0.7099554823224651}, {3.711, 0.7606665882026411}, {
        3.711, 0.7875}, {3.711, 0.735}, {3.711, 0.7099554823224651}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/Xjp7CMKG3gdNGP6D33VeGIP4zt//nRYqvIxnD9V
sPRAa+lDOP8Ux36pzU134HwtsP4rcH7tbt9bLPePwPkPjsqZ3bNps4HxyyDy
+2F8NYh+OP8kxHw4fzLEfjjfCeK+/Wjuh/Nd0OSnouk/h2a+Hpr9HWjuyxCZ
vmLZ2gV7YPw8NP8povn/JFr4TEYLPye08IWFPwAh79OF
         "]], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/Xjp7CMKG3gdjMHgpT2ML7LhfUli+As4/1foJIPn
l57C+XWp2z+sv/gQzjcF678J58doPRQ4JnYKzo8oX3ZY9Ey3DYwfDJHfD+Mb
QPTD+bUQ8+H8HxD74XxhiPv2o7l/P5r796O5H85vQDPfEs3+LDT3Nd7cEyRw
c8keGN8TzX+aaP6vRQuf72jhJ4QWvrDwBwDlfso/
         "]], {}, {}, {}}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{4.005801435187534, 0.8}, {4.671814204887351, 1.18}, {
         4.671814204887351, 1.1397924750211006`}, {4.005801435187534, 
         0.7727406610312547}, {4.005801435187534, 0.8}}], 
        LineBox[{{4.005801435187534, 0.7727406610312547}, {4.671814204887351, 
         1.1397924750211006`}, {4.671814204887351, 1.0219099764656376`}, {
         4.005801435187534, 0.692820323027551}, {4.005801435187534, 
         0.7727406610312547}}], 
        LineBox[{{4.005801435187534, 0.692820323027551}, {4.671814204887351, 
         1.0219099764656376`}, {4.671814204887351, 0.8343860018001261}, {
         4.005801435187534, 0.5656854249492381}, {4.005801435187534, 
         0.692820323027551}}], 
        LineBox[{{4.005801435187534, 0.5656854249492381}, {4.671814204887351, 
         0.8343860018001261}, {4.671814204887351, 0.5900000000000001}, {
         4.005801435187534, 0.40000000000000013`}, {4.005801435187534, 
         0.5656854249492381}}], 
        LineBox[{{4.005801435187534, 0.40000000000000013`}, {
         4.671814204887351, 0.5900000000000001}, {4.671814204887351, 
         0.3054064732209747}, {4.005801435187534, 0.20705523608201679`}, {
         4.005801435187534, 0.40000000000000013`}}], 
        LineBox[{{4.005801435187534, 0.20705523608201679`}, {
         4.671814204887351, 0.3054064732209747}, {4.671814204887351, 
         3.342667949612308*^-16}, {4.005801435187534, 
         2.2662155590591917`*^-16}, {4.005801435187534, 
         0.20705523608201679`}}], 
        LineBox[{{4.005801435187534, 4.898587196589413*^-17}, {
         4.671814204887351, 7.225416114969384*^-17}, {
         4.671814204887351, -0.3054064732209743}, {
         4.005801435187534, -0.2070552360820165}, {4.005801435187534, 
         4.898587196589413*^-17}}], 
        LineBox[{{4.005801435187534, -0.2070552360820165}, {
         4.671814204887351, -0.3054064732209743}, {
         4.671814204887351, -0.5899999999999997}, {
         4.005801435187534, -0.39999999999999986`}, {
         4.005801435187534, -0.2070552360820165}}], 
        LineBox[{{4.005801435187534, -0.39999999999999986`}, {
         4.671814204887351, -0.5899999999999997}, {
         4.671814204887351, -0.834386001800126}, {
         4.005801435187534, -0.565685424949238}, {
         4.005801435187534, -0.39999999999999986`}}], 
        LineBox[{{4.005801435187534, -0.565685424949238}, {
         4.671814204887351, -0.834386001800126}, {
         4.671814204887351, -1.0219099764656376`}, {
         4.005801435187534, -0.692820323027551}, {
         4.005801435187534, -0.565685424949238}}], 
        LineBox[{{4.005801435187534, -0.6928203230275508}, {
         4.671814204887351, -1.0219099764656374`}, {
         4.671814204887351, -1.1397924750211004`}, {
         4.005801435187534, -0.7727406610312546}, {
         4.005801435187534, -0.6928203230275508}}], 
        LineBox[{{4.005801435187534, -0.7727406610312546}, {
         4.671814204887351, -1.1397924750211004`}, {
         4.671814204887351, -1.18}, {4.005801435187534, -0.8}, {
         4.005801435187534, -0.7727406610312546}}], 
        LineBox[{{4.005801435187534, -0.8}, {4.671814204887351, -1.18}, {
         4.671814204887351, -1.1397924750211006`}, {
         4.005801435187534, -0.7727406610312547}, {4.005801435187534, -0.8}}],
         LineBox[{{4.005801435187534, -0.7727406610312548}, {
         4.671814204887351, -1.1397924750211006`}, {
         4.671814204887351, -1.0219099764656379`}, {
         4.005801435187534, -0.6928203230275511}, {
         4.005801435187534, -0.7727406610312548}}], 
        LineBox[{{4.005801435187534, -0.6928203230275511}, {
         4.671814204887351, -1.0219099764656379`}, {
         4.671814204887351, -0.8343860018001262}, {
         4.005801435187534, -0.5656854249492381}, {
         4.005801435187534, -0.6928203230275511}}], 
        LineBox[{{4.005801435187534, -0.5656854249492383}, {
         4.671814204887351, -0.8343860018001265}, {
         4.671814204887351, -0.5900000000000005}, {
         4.005801435187534, -0.40000000000000036`}, {
         4.005801435187534, -0.5656854249492383}}], 
        LineBox[{{4.005801435187534, -0.40000000000000036`}, {
         4.671814204887351, -0.5900000000000005}, {
         4.671814204887351, -0.3054064732209753}, {
         4.005801435187534, -0.20705523608201717`}, {
         4.005801435187534, -0.40000000000000036`}}], 
        LineBox[{{4.005801435187534, -0.20705523608201717`}, {
         4.671814204887351, -0.3054064732209753}, {
         4.671814204887351, -1.2648130186952292`*^-15}, {
         4.005801435187534, -8.575003516577826*^-16}, {
         4.005801435187534, -0.20705523608201717`}}], 
        LineBox[{{4.005801435187534, -1.4695761589768238`*^-16}, {
         4.671814204887351, -2.1676248344908148`*^-16}, {4.671814204887351, 
         0.3054064732209739}, {4.005801435187534, 0.20705523608201626`}, {
         4.005801435187534, -1.4695761589768238`*^-16}}], 
        LineBox[{{4.005801435187534, 0.20705523608201626`}, {
         4.671814204887351, 0.3054064732209739}, {4.671814204887351, 
         0.5899999999999991}, {4.005801435187534, 0.39999999999999947`}, {
         4.005801435187534, 0.20705523608201626`}}], 
        LineBox[{{4.005801435187534, 0.39999999999999947`}, {
         4.671814204887351, 0.5899999999999991}, {4.671814204887351, 
         0.834386001800125}, {4.005801435187534, 0.5656854249492373}, {
         4.005801435187534, 0.39999999999999947`}}], 
        LineBox[{{4.005801435187534, 0.565685424949238}, {4.671814204887351, 
         0.834386001800126}, {4.671814204887351, 1.0219099764656372`}, {
         4.005801435187534, 0.6928203230275507}, {4.005801435187534, 
         0.565685424949238}}], 
        LineBox[{{4.005801435187534, 0.6928203230275507}, {4.671814204887351, 
         1.0219099764656372`}, {4.671814204887351, 1.1397924750211004`}, {
         4.005801435187534, 0.7727406610312545}, {4.005801435187534, 
         0.6928203230275507}}], 
        LineBox[{{4.005801435187534, 0.7727406610312545}, {4.671814204887351, 
         1.1397924750211004`}, {4.671814204887351, 1.18}, {4.005801435187534, 
         0.8}, {4.005801435187534, 0.7727406610312545}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{4.671814204887351, 1.18}, {4.748489652080478, 1.18}, {
         4.748489652080478, 1.1397924750211006`}, {4.671814204887351, 
         1.1397924750211006`}, {4.671814204887351, 1.18}}], 
        LineBox[{{4.671814204887351, 1.1397924750211006`}, {4.748489652080478,
          1.1397924750211006`}, {4.748489652080478, 1.0219099764656376`}, {
         4.671814204887351, 1.0219099764656376`}, {4.671814204887351, 
         1.1397924750211006`}}], 
        LineBox[{{4.671814204887351, 1.0219099764656376`}, {4.748489652080478,
          1.0219099764656376`}, {4.748489652080478, 0.8343860018001261}, {
         4.671814204887351, 0.8343860018001261}, {4.671814204887351, 
         1.0219099764656376`}}], 
        LineBox[{{4.671814204887351, 0.8343860018001261}, {4.748489652080478, 
         0.8343860018001261}, {4.748489652080478, 0.5900000000000001}, {
         4.671814204887351, 0.5900000000000001}, {4.671814204887351, 
         0.8343860018001261}}], 
        LineBox[{{4.671814204887351, 0.5900000000000001}, {4.748489652080478, 
         0.5900000000000001}, {4.748489652080478, 0.3054064732209747}, {
         4.671814204887351, 0.3054064732209747}, {4.671814204887351, 
         0.5900000000000001}}], 
        LineBox[{{4.671814204887351, 0.3054064732209747}, {4.748489652080478, 
         0.3054064732209747}, {4.748489652080478, 3.342667949612308*^-16}, {
         4.671814204887351, 3.342667949612308*^-16}, {4.671814204887351, 
         0.3054064732209747}}], 
        LineBox[{{4.671814204887351, 7.225416114969384*^-17}, {
         4.748489652080478, 7.225416114969384*^-17}, {
         4.748489652080478, -0.3054064732209743}, {
         4.671814204887351, -0.3054064732209743}, {4.671814204887351, 
         7.225416114969384*^-17}}], 
        LineBox[{{4.671814204887351, -0.3054064732209743}, {
         4.748489652080478, -0.3054064732209743}, {
         4.748489652080478, -0.5899999999999997}, {
         4.671814204887351, -0.5899999999999997}, {
         4.671814204887351, -0.3054064732209743}}], 
        LineBox[{{4.671814204887351, -0.5899999999999997}, {
         4.748489652080478, -0.5899999999999997}, {
         4.748489652080478, -0.834386001800126}, {
         4.671814204887351, -0.834386001800126}, {
         4.671814204887351, -0.5899999999999997}}], 
        LineBox[{{4.671814204887351, -0.834386001800126}, {
         4.748489652080478, -0.834386001800126}, {
         4.748489652080478, -1.0219099764656376`}, {
         4.671814204887351, -1.0219099764656376`}, {
         4.671814204887351, -0.834386001800126}}], 
        LineBox[{{4.671814204887351, -1.0219099764656374`}, {
         4.748489652080478, -1.0219099764656374`}, {
         4.748489652080478, -1.1397924750211004`}, {
         4.671814204887351, -1.1397924750211004`}, {
         4.671814204887351, -1.0219099764656374`}}], 
        LineBox[{{4.671814204887351, -1.1397924750211004`}, {
         4.748489652080478, -1.1397924750211004`}, {
         4.748489652080478, -1.18}, {4.671814204887351, -1.18}, {
         4.671814204887351, -1.1397924750211004`}}], 
        LineBox[{{4.671814204887351, -1.18}, {4.748489652080478, -1.18}, {
         4.748489652080478, -1.1397924750211006`}, {
         4.671814204887351, -1.1397924750211006`}, {
         4.671814204887351, -1.18}}], 
        LineBox[{{4.671814204887351, -1.1397924750211006`}, {
         4.748489652080478, -1.1397924750211006`}, {
         4.748489652080478, -1.0219099764656379`}, {
         4.671814204887351, -1.0219099764656379`}, {
         4.671814204887351, -1.1397924750211006`}}], 
        LineBox[{{4.671814204887351, -1.0219099764656379`}, {
         4.748489652080478, -1.0219099764656379`}, {
         4.748489652080478, -0.8343860018001262}, {
         4.671814204887351, -0.8343860018001262}, {
         4.671814204887351, -1.0219099764656379`}}], 
        LineBox[{{4.671814204887351, -0.8343860018001265}, {
         4.748489652080478, -0.8343860018001265}, {
         4.748489652080478, -0.5900000000000005}, {
         4.671814204887351, -0.5900000000000005}, {
         4.671814204887351, -0.8343860018001265}}], 
        LineBox[{{4.671814204887351, -0.5900000000000005}, {
         4.748489652080478, -0.5900000000000005}, {
         4.748489652080478, -0.3054064732209753}, {
         4.671814204887351, -0.3054064732209753}, {
         4.671814204887351, -0.5900000000000005}}], 
        LineBox[{{4.671814204887351, -0.3054064732209753}, {
         4.748489652080478, -0.3054064732209753}, {
         4.748489652080478, -1.2648130186952292`*^-15}, {
         4.671814204887351, -1.2648130186952292`*^-15}, {
         4.671814204887351, -0.3054064732209753}}], 
        LineBox[{{4.671814204887351, -2.1676248344908148`*^-16}, {
         4.748489652080478, -2.1676248344908148`*^-16}, {4.748489652080478, 
         0.3054064732209739}, {4.671814204887351, 0.3054064732209739}, {
         4.671814204887351, -2.1676248344908148`*^-16}}], 
        LineBox[{{4.671814204887351, 0.3054064732209739}, {4.748489652080478, 
         0.3054064732209739}, {4.748489652080478, 0.5899999999999991}, {
         4.671814204887351, 0.5899999999999991}, {4.671814204887351, 
         0.3054064732209739}}], 
        LineBox[{{4.671814204887351, 0.5899999999999991}, {4.748489652080478, 
         0.5899999999999991}, {4.748489652080478, 0.834386001800125}, {
         4.671814204887351, 0.834386001800125}, {4.671814204887351, 
         0.5899999999999991}}], 
        LineBox[{{4.671814204887351, 0.834386001800126}, {4.748489652080478, 
         0.834386001800126}, {4.748489652080478, 1.0219099764656372`}, {
         4.671814204887351, 1.0219099764656372`}, {4.671814204887351, 
         0.834386001800126}}], 
        LineBox[{{4.671814204887351, 1.0219099764656372`}, {4.748489652080478,
          1.0219099764656372`}, {4.748489652080478, 1.1397924750211004`}, {
         4.671814204887351, 1.1397924750211004`}, {4.671814204887351, 
         1.0219099764656372`}}], 
        LineBox[{{4.671814204887351, 1.1397924750211004`}, {4.748489652080478,
          1.1397924750211004`}, {4.748489652080478, 1.18}, {4.671814204887351,
          1.18}, {4.671814204887351, 1.1397924750211004`}}], {}, {}}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{5.534443062211261, 1.5}, {5.627613727648733, 1.5}, {
         5.627613727648731, 1.4488887394336025`}, {5.534443062211261, 
         1.4488887394336025`}, {5.534443062211261, 1.5}}], 
        LineBox[{{5.534443062211261, 1.4488887394336025`}, {5.627613727648731,
          1.4488887394336025`}, {5.627613727648733, 1.299038105676658}, {
         5.534443062211261, 1.299038105676658}, {5.534443062211261, 
         1.4488887394336025`}}], 
        LineBox[{{5.534443062211261, 1.299038105676658}, {5.627613727648733, 
         1.299038105676658}, {5.627613727648733, 1.0606601717798214`}, {
         5.534443062211261, 1.0606601717798214`}, {5.534443062211261, 
         1.299038105676658}}], 
        LineBox[{{5.534443062211261, 1.0606601717798214`}, {5.627613727648733,
          1.0606601717798214`}, {5.627613727648733, 0.7500000000000002}, {
         5.534443062211261, 0.7500000000000002}, {5.534443062211261, 
         1.0606601717798214`}}], 
        LineBox[{{5.534443062211261, 0.7500000000000002}, {5.627613727648733, 
         0.7500000000000002}, {5.627613727648733, 0.38822856765378144`}, {
         5.534443062211261, 0.38822856765378144`}, {5.534443062211261, 
         0.7500000000000002}}], 
        LineBox[{{5.534443062211261, 0.38822856765378144`}, {
         5.627613727648733, 0.38822856765378144`}, {5.627613727648733, 
         4.2491541732359847`*^-16}, {5.534443062211261, 
         4.2491541732359847`*^-16}, {5.534443062211261, 
         0.38822856765378144`}}], 
        LineBox[{{5.534443062211261, 9.184850993605148*^-17}, {
         5.627613727648733, 9.184850993605148*^-17}, {
         5.627613727648733, -0.38822856765378094`}, {
         5.534443062211261, -0.38822856765378094`}, {5.534443062211261, 
         9.184850993605148*^-17}}], 
        LineBox[{{5.534443062211261, -0.38822856765378094`}, {
         5.627613727648733, -0.38822856765378094`}, {
         5.627613727648733, -0.7499999999999997}, {
         5.534443062211261, -0.7499999999999997}, {
         5.534443062211261, -0.38822856765378094`}}], 
        LineBox[{{5.534443062211261, -0.7499999999999997}, {
         5.627613727648733, -0.7499999999999997}, {
         5.627613727648733, -1.0606601717798212`}, {
         5.534443062211261, -1.0606601717798212`}, {
         5.534443062211261, -0.7499999999999997}}], 
        LineBox[{{5.534443062211261, -1.0606601717798212`}, {
         5.627613727648733, -1.0606601717798212`}, {
         5.627613727648733, -1.299038105676658}, {
         5.534443062211261, -1.299038105676658}, {
         5.534443062211261, -1.0606601717798212`}}], 
        LineBox[{{5.534443062211261, -1.2990381056766578`}, {
         5.627613727648733, -1.2990381056766578`}, {
         5.627613727648733, -1.4488887394336023`}, {
         5.534443062211261, -1.4488887394336023`}, {
         5.534443062211261, -1.2990381056766578`}}], 
        LineBox[{{5.534443062211261, -1.4488887394336023`}, {
         5.627613727648733, -1.4488887394336023`}, {
         5.627613727648733, -1.5}, {5.534443062211261, -1.5}, {
         5.534443062211261, -1.4488887394336023`}}], 
        LineBox[{{5.534443062211261, -1.5}, {5.627613727648733, -1.5}, {
         5.627613727648731, -1.4488887394336025`}, {
         5.534443062211261, -1.4488887394336025`}, {
         5.534443062211261, -1.5}}], 
        LineBox[{{5.534443062211261, -1.4488887394336025`}, {
         5.627613727648733, -1.4488887394336025`}, {
         5.627613727648733, -1.2990381056766582`}, {
         5.534443062211261, -1.2990381056766582`}, {
         5.534443062211261, -1.4488887394336025`}}], 
        LineBox[{{5.534443062211261, -1.2990381056766582`}, {
         5.627613727648733, -1.2990381056766582`}, {
         5.627613727648733, -1.0606601717798214`}, {
         5.534443062211261, -1.0606601717798214`}, {
         5.534443062211261, -1.2990381056766582`}}], 
        LineBox[{{5.534443062211261, -1.0606601717798219`}, {
         5.627613727648733, -1.0606601717798219`}, {
         5.627613727648733, -0.7500000000000007}, {
         5.534443062211261, -0.7500000000000007}, {
         5.534443062211261, -1.0606601717798219`}}], 
        LineBox[{{5.534443062211261, -0.7500000000000007}, {
         5.627613727648733, -0.7500000000000007}, {
         5.627613727648733, -0.3882285676537822}, {
         5.534443062211261, -0.3882285676537822}, {
         5.534443062211261, -0.7500000000000007}}], 
        LineBox[{{5.534443062211261, -0.3882285676537822}, {5.627613727648733,
          -0.3882285676537822}, {
         5.627613727648733, -1.6078131593583423`*^-15}, {
         5.534443062211261, -1.6078131593583423`*^-15}, {
         5.534443062211261, -0.3882285676537822}}], 
        LineBox[{{5.534443062211261, -2.755455298081545*^-16}, {
         5.627613727648733, -2.755455298081545*^-16}, {5.627613727648733, 
         0.38822856765378044`}, {5.534443062211261, 0.38822856765378044`}, {
         5.534443062211261, -2.755455298081545*^-16}}], 
        LineBox[{{5.534443062211261, 0.38822856765378044`}, {
         5.627613727648733, 0.38822856765378044`}, {5.627613727648733, 
         0.7499999999999989}, {5.534443062211261, 0.7499999999999989}, {
         5.534443062211261, 0.38822856765378044`}}], 
        LineBox[{{5.534443062211261, 0.7499999999999989}, {5.627613727648733, 
         0.7499999999999989}, {5.627613727648733, 1.06066017177982}, {
         5.534443062211261, 1.06066017177982}, {5.534443062211261, 
         0.7499999999999989}}], 
        LineBox[{{5.534443062211261, 1.0606601717798212`}, {5.627613727648733,
          1.0606601717798212`}, {5.627613727648733, 1.2990381056766576`}, {
         5.534443062211261, 1.2990381056766576`}, {5.534443062211261, 
         1.0606601717798212`}}], 
        LineBox[{{5.534443062211261, 1.2990381056766576`}, {5.627613727648733,
          1.2990381056766576`}, {5.627613727648733, 1.448888739433602}, {
         5.534443062211261, 1.448888739433602}, {5.534443062211261, 
         1.2990381056766576`}}], 
        LineBox[{{5.534443062211261, 1.448888739433602}, {5.627613727648733, 
         1.448888739433602}, {5.627613727648733, 1.5}, {5.534443062211261, 
         1.5}, {5.534443062211261, 1.448888739433602}}]}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.538, -2.5}, {8.538, -1.6666666666666667`}, {
       8.538, -0.8333333333333335}, {8.538, 0.}, {8.538, 0.833333333333333}, {
       8.538, 1.666666666666666}, {8.538, 2.5}, {8.538, 2.5}, {8.538, 
       1.6666666666666667`}, {8.538, 0.8333333333333335}, {8.538, 0.}, {
       8.538, -0.833333333333333}, {8.538, -1.666666666666666}, {
       8.538, -2.5}, {8.538, -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.538, 0.}, {8.538, 0.}, {8.538, 0.}, {8.538, 0.}, {8.538, 
       0.}, {8.538, 0.}, {8.538, 0.}, {8.538, 0.}, {8.538, 0.}, {8.538, 0.}, {
       8.538, 0.}, {8.538, 0.}, {8.538, 0.}, {8.538, 0.}, {8.538, 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/asua0+JsKIDAxiwOMD4ueW9Pl2BzHD+a33zizxB
jHD+AS55hmMef+xhfEaw/i9wvuWJ74ZztzyB8zmLb+5fz7/MBsY3gsjvh/H/
/QeBz3D+foj5cP4riP0HYPwciPsOoLkfzs9Dk3+Dpv8ImvmsEPfD+S5o7nMT
e3z+cPeBPTC+Fpr/fkDcb4/mfjj/JVr45aCFLyz8ASA9rxE=
      "]]}, 
    {RGBColor[0.8888048816904333, 0.001443572353399647, 0.007022832322456984],
      AbsoluteThickness[0.5], 
     LineBox[{{{0., -0.45}, {2.030753358688915, -0.45}}, {{0., -0.225}, {
      2.0076614714370375`, -0.225}}, {{0., 0.}, {1.9999999999999996`, 0.}}, {{
      0., 0.22500000000000003`}, {2.0076614714370375`, 
      0.22500000000000003`}}, {{0., 0.45}, {2.030753358688915, 0.45}}}]}, 
    {RGBColor[
     0.0014301774013306678`, 0.03162733424853975, 0.9365489651388929], 
     AbsoluteThickness[0.5], 
     LineBox[{{{-0.03922008423644618, 0.5517123858587145}, {2.020925426954475,
       0.3714730084156893}}, {{-0.01961004211822309, 0.7758561929293573}, {
      2.053855089058077, 0.594451499735138}}, {{0., 1.}, {2.102251832922853, 
      0.8160767967426555}}, {{0.01961004211822309, 1.2241438070706427`}, {
      2.1665321018886994`, 1.036312465367}}, {{0.03922008423644618, 
      1.4482876141412855`}, {2.2473724047807813`, 1.2550993187551938`}}}]}, 
    {RGBColor[0.8888048816904333, 0.001443572353399647, 0.007022832322456984],
      AbsoluteThickness[0.5], 
     LineBox[{{{2.030753358688915, -0.45}, {
      2.4266694551392973`, -0.42933662540247447`}}, {{
      2.0076614714370375`, -0.225}, {
      2.4216606348673566`, -0.2142541223546788}}, {{1.9999999999999996`, 
      0.}, {2.4199999999999995`, 0.}}, {{2.0076614714370375`, 
      0.22500000000000003`}, {2.4216606348673566`, 0.21425412235467883`}}, {{
      2.030753358688915, 0.45}, {2.4266694551392973`, 
      0.42933662540247447`}}}]}, 
    {RGBColor[
     0.0014301774013306678`, 0.03162733424853975, 0.9365489651388929], 
     AbsoluteThickness[0.5], 
     LineBox[{{{2.020925426954475, 0.3714730084156893}, {2.4239927124057212`, 
      0.3322062546352712}}, {{2.053855089058077, 0.594451499735138}, {
      2.430850353319696, 0.5475727780071975}}, {{2.102251832922853, 
      0.8160767967426555}, {2.441165247496458, 0.7646285590003742}}, {{
      2.1665321018886994`, 1.036312465367}, {2.4550938563496874`, 
      0.9843393939546863}}, {{2.2473724047807813`, 1.2550993187551938`}, {
      2.4728723322107617`, 1.2078240730835792`}}}]}, 
    {RGBColor[0.8888048816904333, 0.001443572353399647, 0.007022832322456984],
      AbsoluteThickness[0.5], 
     LineBox[{{{2.4266694551392973`, -0.42933662540247447`}, {
      2.4896230690395877`, -0.42523150802088017`}}, {{
      2.4216606348673566`, -0.2142541223546788}, {
      2.4546136202566955`, -0.21318673348044515`}}, {{2.4199999999999995`, 
      0.}, {2.443, 0.}}, {{2.4216606348673566`, 0.21425412235467883`}, {
      2.4546136202566955`, 0.21318673348044517`}}, {{2.4266694551392973`, 
      0.42933662540247447`}, {2.4896230690395877`, 
      0.42523150802088017`}}}]}, 
    {RGBColor[
     0.0014301774013306678`, 0.03162733424853975, 0.9365489651388929], 
     AbsoluteThickness[0.5], 
     LineBox[{{{2.4239927124057212`, 0.3322062546352712}, {
      2.4701839573492395`, 0.32551200447694756`}}, {{2.430850353319696, 
      0.5475727780071975}, {2.516537013988154, 0.5321889584322574}}, {{
      2.441165247496458, 0.7646285590003742}, {2.5852819133117384`, 
      0.7336295842541545}}, {{2.4550938563496874`, 0.9843393939546863}, {
      2.676543545553418, 0.9285019270995101}}, {{2.4728723322107617`, 
      1.2078240730835792`}, {2.790679086563181, 1.1152397354502201`}}}]}, 
    {RGBColor[0.8888048816904333, 0.001443572353399647, 0.007022832322456984],
      AbsoluteThickness[0.5], 
     LineBox[{{{2.4896230690395877`, -0.42523150802088017`}, {
      3.0451357316846606`, -0.35614111131061166`}}, {{
      2.4546136202566955`, -0.21318673348044515`}, {
      3.047295184029783, -0.17667036944166994`}}, {{2.443, 0.}, {
      3.0480000000000005`, 0.}}, {{2.4546136202566955`, 
      0.21318673348044517`}, {3.047295184029783, 0.17667036944166997`}}, {{
      2.4896230690395877`, 0.42523150802088017`}, {3.0451357316846606`, 
      0.35614111131061166`}}}]}, 
    {RGBColor[
     0.0014301774013306678`, 0.03162733424853975, 0.9365489651388929], 
     AbsoluteThickness[0.5], 
     LineBox[{{{2.4701839573492395`, 0.32551200447694756`}, {
      3.0467343962850797`, 0.2367401780079721}}, {{2.516537013988154, 
      0.5321889584322574}, {3.044078277238814, 0.4167240056851709}}, {{
      2.5852819133117384`, 0.7336295842541545}, {3.0397748025899287`, 
      0.6034789627419146}}, {{2.676543545553418, 0.9285019270995101}, {
      3.033516923134714, 0.8007347851062525}}, {{2.790679086563181, 
      1.1152397354502201`}, {3.0248018863944512`, 1.0133089105349926`}}}]}, 
    {RGBColor[0.8888048816904333, 0.001443572353399647, 0.007022832322456984],
      AbsoluteThickness[0.5], 
     LineBox[{{{3.0451357316846606`, -0.35614111131061166`}, {
      3.3702808218657982`, -0.3145056293186821}}, {{
      3.047295184029783, -0.17667036944166994`}, {
      3.3408063273079978`, -0.15805865177901937`}}, {{3.0480000000000005`, 
      0.}, {3.331, 0.}}, {{3.047295184029783, 0.17667036944166997`}, {
      3.3408063273079978`, 0.1580586517790194}}, {{3.0451357316846606`, 
      0.35614111131061166`}, {3.3702808218657982`, 0.3145056293186821}}}]}, 
    {RGBColor[
     0.0014301774013306678`, 0.03162733424853975, 0.9365489651388929], 
     AbsoluteThickness[0.5], 
     LineBox[{{{3.0467343962850797`, 0.2367401780079721}, {
      3.3451691312292895`, 0.1898298499340711}}, {{3.044078277238814, 
      0.4167240056851709}, {3.377620032869276, 0.342129572815847}}, {{
      3.0397748025899287`, 0.6034789627419146}, {3.428458858864194, 
      0.4896356364565179}}, {{3.033516923134714, 0.8007347851062525}, {
      3.497373686220475, 0.6307169425928358}}, {{3.0248018863944512`, 
      1.0133089105349926`}, {3.711, 0.7068764831606622}}}]}, 
    {RGBColor[0.8888048816904333, 0.001443572353399647, 0.007022832322456984],
      AbsoluteThickness[0.5], 
     LineBox[{{{3.3702808218657982`, -0.3145056293186821}, {
      3.711, -0.2950540297301716}}, {{
      3.3408063273079978`, -0.15805865177901937`}, {
      3.711, -0.14753880557730537`}}, {{3.331, 0.}, {3.711, 0.}}, {{
      3.3408063273079978`, 0.1580586517790194}, {3.711, 
      0.1475388055773054}}, {{3.3702808218657982`, 0.3145056293186821}, {
      3.711, 0.2950540297301716}}}]}, 
    {RGBColor[
     0.0014301774013306678`, 0.03162733424853975, 0.9365489651388929], 
     AbsoluteThickness[0.5], 
     LineBox[{{{3.3451691312292895`, 0.1898298499340711}, {3.711, 
      0.13075190971158795`}}, {{3.377620032869276, 0.342129572815847}, {3.711,
       0.2783303400359059}}, {{3.428458858864194, 0.4896356364565179}, {3.711,
       0.4268216748504863}}, {{3.497373686220475, 0.6307169425928358}, {3.711,
       0.5762940251884607}}}]}, 
    {RGBColor[0.8888048816904333, 0.001443572353399647, 0.007022832322456984],
      AbsoluteThickness[0.5], 
     LineBox[{{{3.711, -0.2950540297301716}, {
      4.181070373756456, -0.26821779251334377`}}, {{
      3.711, -0.14753880557730537`}, {
      4.196820603911042, -0.13373317244045788`}}, {{3.711, 0.}, {4.202, 
      0.}}, {{3.711, 0.1475388055773054}, {4.196820603911042, 
      0.1337331724404579}}, {{3.711, 0.2950540297301716}, {4.181070373756456, 
      0.26821779251334377`}}}]}, 
    {RGBColor[
     0.0014301774013306678`, 0.03162733424853975, 0.9365489651388929], 
     AbsoluteThickness[0.5], 
     LineBox[{{{3.711, 0.13075190971158795`}, {4.2012303579164625`, 
      0.051584725494589784`}}, {{3.711, 0.2783303400359059}, {
      4.191935077603378, 0.1862933492348794}}, {{3.711, 0.4268216748504863}, {
      4.17127888176907, 0.3244934266835662}}, {{3.711, 0.5762940251884607}, {
      4.137566822289205, 0.4676229044535335}}}]}, 
    {RGBColor[0.8888048816904333, 0.001443572353399647, 0.007022832322456984],
      AbsoluteThickness[0.5], 
     LineBox[{{{4.181070373756456, -0.26821779251334377`}, {
      4.4167357126513025`, -0.27322469535136135`}}, {{
      4.196820603911042, -0.13373317244045788`}, {
      4.4063912494353845`, -0.13588988594042126`}}, {{4.202, 0.}, {
      4.4030000000000005`, 0.}}, {{4.196820603911042, 0.1337331724404579}, {
      4.4063912494353845`, 0.13588988594042128`}}, {{4.181070373756456, 
      0.26821779251334377`}, {4.4167357126513025`, 
      0.27322469535136135`}}}]}, 
    {RGBColor[
     0.0014301774013306678`, 0.03162733424853975, 0.9365489651388929], 
     AbsoluteThickness[0.5], 
     LineBox[{{{4.2012303579164625`, 0.051584725494589784`}, {
      4.403209524673778, 0.03378716082999034}}, {{4.191935077603378, 
      0.1862933492348794}, {4.408309418445189, 0.17000208062322109`}}, {{
      4.17127888176907, 0.3244934266835662}, {4.420629267984201, 
      0.30942533582280574`}}, {{4.137566822289205, 0.4676229044535335}, {
      4.441227116127898, 0.4547779156104748}}}]}, 
    {RGBColor[0.8888048816904333, 0.001443572353399647, 0.007022832322456984],
      AbsoluteThickness[0.5], 
     LineBox[{{{4.4167357126513025`, -0.27322469535136135`}, {
      5.057209730657558, -0.2852343472793484}}, {{
      4.4063912494353845`, -0.13588988594042126`}, {
      5.070609348560703, -0.1419091362025445}}, {{4.4030000000000005`, 0.}, {
      5.075, 0.}}, {{4.4063912494353845`, 0.13588988594042128`}, {
      5.070609348560703, 0.14190913620254453`}}, {{4.4167357126513025`, 
      0.27322469535136135`}, {5.057209730657558, 0.2852343472793484}}}]}, 
    {RGBColor[
     0.0014301774013306678`, 0.03162733424853975, 0.9365489651388929], 
     AbsoluteThickness[0.5], 
     LineBox[{{{4.403209524673778, 0.03378716082999034}, {
      5.074867487162185, -0.02466472944831228}}, {{4.408309418445189, 
      0.17000208062322109`}, {5.071852702768046, 0.12016378868874944`}}, {{
      4.420629267984201, 0.30942533582280574`}, {5.059023458738829, 
      0.27035726559382184`}}, {{4.441227116127898, 0.4547779156104748}, {
      5.034631517546891, 0.42860481631295}}}]}, 
    {RGBColor[0.8888048816904333, 0.001443572353399647, 0.007022832322456984],
      AbsoluteThickness[0.5], 
     LineBox[{{{5.057209730657558, -0.2852343472793484}, {
      5.366587940942547, -0.2709757305493151}}, {{
      5.070609348560703, -0.1419091362025445}, {
      5.362390087569146, -0.13517454952960534`}}, {{5.075, 0.}, {
      5.361000000000001, 0.}}, {{5.070609348560703, 0.14190913620254453`}, {
      5.362390087569146, 0.13517454952960536`}}, {{5.057209730657558, 
      0.2852343472793484}, {5.366587940942547, 0.2709757305493151}}}]}, 
    {RGBColor[
     0.0014301774013306678`, 0.03162733424853975, 0.9365489651388929], 
     AbsoluteThickness[0.5], 
     LineBox[{{{5.074867487162185, -0.02466472944831228}, {
      5.36130738158566, -0.06356684545930281}}, {{5.071852702768046, 
      0.12016378868874944`}, {5.361422769864097, 0.07454900334046304}}, {{
      5.059023458738829, 0.27035726559382184`}, {5.364542155881909, 
      0.21576059500121955`}}, {{5.034631517546891, 0.42860481631295}, {
      5.3709595599854625`, 0.36170316937202235`}}}]}, 
    {RGBColor[0.8888048816904333, 0.001443572353399647, 0.007022832322456984],
      AbsoluteThickness[0.5], 
     LineBox[{{{5.366587940942547, -0.2709757305493151}, {
      5.751374216779747, -0.25394933026293387`}}, {{
      5.362390087569146, -0.13517454952960534`}, {
      5.754100339375468, -0.12650823314442264`}}, {{5.361000000000001, 0.}, {
      5.755000000000001, 0.}}, {{5.362390087569146, 0.13517454952960536`}, {
      5.754100339375468, 0.12650823314442267`}}, {{5.366587940942547, 
      0.2709757305493151}, {5.751374216779747, 0.25394933026293387`}}}]}, 
    {RGBColor[
     0.0014301774013306678`, 0.03162733424853975, 0.9365489651388929], 
     AbsoluteThickness[0.5], 
     LineBox[{{{5.36130738158566, -0.06356684545930281}, {
      5.754498286184699, -0.09447400383304144}}, {{5.361422769864097, 
      0.07454900334046304}, {5.75493025866072, 0.035223678260768526`}}, {{
      5.364542155881909, 0.21576059500121955`}, {5.7534009677416655`, 
      0.16865511192398697`}}, {{5.3709595599854625`, 0.36170316937202235`}, {
      5.749669617922754, 0.30789633037364084`}}}]}, 
    {RGBColor[0.8888048816904333, 0.001443572353399647, 0.007022832322456984],
      AbsoluteThickness[0.5], 
     LineBox[{{{5.751374216779747, -0.25394933026293387`}, {
      8.538, -0.00482570821822792}}, {{
      5.754100339375468, -0.12650823314442264`}, {
      8.538, -0.002536701385561807}}, {{5.755000000000001, 0.}, {8.538, 
      0.}}, {{5.754100339375468, 0.12650823314442267`}, {8.538, 
      0.0025367013855618764`}}, {{5.751374216779747, 0.25394933026293387`}, {
      8.538, 0.00482570821822792}}}]}, 
    {RGBColor[
     0.0014301774013306678`, 0.03162733424853975, 0.9365489651388929], 
     AbsoluteThickness[0.5], 
     LineBox[{{{5.754498286184699, -0.09447400383304144}, {
      8.538, -0.43537612077404114`}}, {{5.75493025866072, 
      0.035223678260768526`}, {8.538, -0.43163984142371103`}}, {{
      5.7534009677416655`, 0.16865511192398697`}, {
      8.538, -0.42732606096465653`}}, {{5.749669617922754, 
      0.30789633037364084`}, {8.538, -0.421538312603967}}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxdlHdQU1kYRyNJMEMQgiZgWZBIWQVHii6o7Hg/QWYBE3oRZVdFUBHFAIus
IFIsuBSBBduoRJojiBVBEdwrEJAVKYHQy0oTRKWM2ABxo9n3nMmdefPmzLnn
ze+vx/U+6OyrQKFQAqXP17dixOjl6Q0UqH329XThlRp24tuqBD/Ds1++HUT5
/xC+TuaRXI+mfazedhhQoOeosNisqhXpNt5J3RxAAceQWn1M70e3nt/d6yem
wH0NrjpfcwQ1irZWq7jNgRvU1TtL08YRs0THO31qDuinTNL72ZOIteZ5vtiP
CrYMaxcI68SJ2rsvJW2nQsakdduN/TV4W1L5u+VeVCD2ET5T5uV7pLA6wc7d
hwr27TX0HstmZNEUe31nEBWyWfe33D/RiywZJjnRsVS40FDv0BI6jMxVDyBG
NhXm++q7FkaOIfv1LLvAaun3g5rckMtbZKQzFIlHqHDen2k+a9aJsxLWhypn
USE5T2u8wLYG6ylGn7GK/76P8CkyL9+jp56RdWPlVJgQ+fONmyXIix60vIdL
g6M2f+jcmduLRl9m21y7SQPe5w944PAQsqlKzU3yo8NDO99826I3yMQr9bSD
iyKcdhtLp7dNoLsl25YKvBjgUxmiTqtpwf6ueryuHQw4wTt0eNnlKvw5d6KR
780g9xH+pMzL92izboRN0XYGQMXCxCh+HbLJWldkvZUBxqofV1y83oE+XckM
DnFiwPDlRZoFDv1It976RPYmBjhneJ5OF75EkvhW1xpTBrAHQvccMxtHJl8y
nrq9V4LkdZy1XdoSbH5oPO9jsRKcadCav8lChNvrPrj05yiR+wh/Vuble5SI
UxjD5Uow+yjTdAuvGvkOdV79lc6EOqukg8GDzShOMa0l/AAT9nh5Fxq7/4tq
crkqwikmSGhGvOZVA6g/56JI+/Y8eJhiFFCS/oJkR6Eqz6CvERNMM9+/JrGv
nGRiH8F0mZfvSY4ZUj4eVvqY5EH2jIpBg5jkSYsbnUynTpJPqvUZUAL7UK+F
+rF9xSyAnyrehRmIscewjkf8PyygShRWGGqVYQXDWPX2Oha5h/A0mZfvUWHH
A1dV6f0jPRMrHP3yEFWZnhEnYsFAnFlvSNsTtLFqVcmuWywQdLcuiBJJ0L0Z
A6eeBBaMWG5PP/WmG0VdtRKV5qkB9zwOOHZEjCMa1efqXVGDfueZ6RafMjyi
b8LIv6RG7iH8gMzL98gv68d3fdL7gnVpnxN4GUgUbtG9JFMNfsi3arhSXon0
Rt0FxTfV4Om+sNfC2iZUHROrJK5Qg0ovoYS9pBvlY4bxmfVsENxyTP5lYyN+
KDAU823YYLUyUpNtUI6//ad4bHIP4TfJvHyPKtOorDzpfefDOz8VbryAd8+3
LEu1ZcP4YFrLvIq/0YVXVjmCn9ngdyoi6RRfjDwW1QYe0mHD1bUbBi0DOpFh
k7XEO5QDv9FWncvzEOPltMW71IM5EHfukf1ufhlO2D80nRvIIfcQPl7m5Xs0
1jGaNCW9z43fdnfE+jZ2946pXxjEgeC3m0uyOQWoYvH7P+1COPCkI2ceM70G
PVqc29gVzgHN2SZlPf1WdD1ae8PeORoQFc2+cw8asJCt1WtK0wB+G3XK3+Qx
PvnK6YEWXYPcQ3h7mZfvUfKa56YXpV40XS0KMnqAhc0qAmVp/zrG83gLIxNd
esGOD6dqwDVdBWHE2UrUwj3ok/tFHaBtR/1f95rQ1NF9pb8v4AJlWZbRUlEw
JvhxV4FR+xMfkok9BO/o/uble5KRiFm3uruT7NOMs4tmhN9ZdFZ3r4Pndy6y
yZWET3Xg/wDoPRil
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"L\"\>", {3.8775, -1.8095101539675547`}, {0., 0.}], 
    InsetBox["\<\"S\"\>", {8.538, -2.7095101539675546`}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.430582283733951*^9, 3.430582353586522*^9, 
  3.430582384222579*^9, 3.430582509585021*^9, 3.4305827397792788`*^9, 
  3.4305827806090107`*^9, 3.440432256101449*^9, 3.440432498592052*^9, 
  3.538110436278921*^9, 3.538140466896082*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"DrawSystem", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"LineOfRays", "[", 
           RowBox[{"0.9`", ",", 
            RowBox[{"NumberOfRays", "\[Rule]", "5"}], ",", 
            RowBox[{"WaveLength", "\[Rule]", "0.7`"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"lighty", ",", "0"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"LightAngle", ",", "0.`"}], "}"}], ",", 
          RowBox[{"SymbolicValues", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"LightAngle", "\[Rule]", "0"}], ",", 
             RowBox[{"lighty", "\[Rule]", "0"}]}], "}"}]}]}], "]"}], ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"LineOfRays", "[", 
           RowBox[{"0.9`", ",", 
            RowBox[{"NumberOfRays", "\[Rule]", "5"}], ",", 
            RowBox[{"WaveLength", "\[Rule]", "0.4`"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"LightAngle2", ",", 
            RowBox[{"-", "4.999999999999999`"}]}], "}"}], ",", 
          RowBox[{"SymbolicValues", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"LightAngle2", "\[Rule]", 
             RowBox[{"-", "5"}]}], "}"}]}]}], "]"}], ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"CompoundLens", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.3077`", ",", "13.8223`", ",", "1.9625`", ",", 
              RowBox[{"-", "22.1426`"}], ",", "1.2787`", ",", "\[Infinity]", 
              ",", 
              RowBox[{"-", "1.7291`"}], ",", "2.7243`", ",", 
              RowBox[{"-", "2.2955`"}], ",", "6.573`", ",", 
              RowBox[{"-", "8.8951`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.2`", ",", "3.2`", ",", "2.56`", ",", "2.56`", ",", "1.5`", 
              ",", "1.26`", ",", "1.6`", ",", "2.36`", ",", "2.36`", ",", 
              "3.`", ",", "3.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.42`", ",", "0.023`", ",", "0.605`", ",", "0.283`", ",", 
              "0.38`", ",", "0.491`", ",", "0.201`", ",", "0.672`", ",", 
              "0.286`", ",", "0.394`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "SK16", ",", "IntrinsicMedium", ",", "SK16", ",", "LF5", ",", 
              "IntrinsicMedium", ",", "IntrinsicMedium", ",", "LF5", ",", 
              "SK4", ",", "IntrinsicMedium", ",", "SK16"}], "}"}]}], "]"}], 
          ",", "2.`"}], "]"}], ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", "5", "]"}], ",", "8.538`"}], "]"}]}], "}"}], 
      ",", 
      RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
      RowBox[{"SymbolicValues", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"LightAngle", "\[Rule]", "0"}], ",", 
         RowBox[{"lighty", "\[Rule]", "0"}], ",", 
         RowBox[{"LightAngle2", "\[Rule]", 
          RowBox[{"-", "5"}]}]}], "}"}]}], ",", 
      RowBox[{"UpdateNumericParameters", "\[Rule]", "False"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Print",
 CellChangeTimes->{3.430582283733951*^9, 3.430582353586522*^9, 
  3.430582384222579*^9, 3.430582509585021*^9, 3.4305827397792788`*^9, 
  3.4305827806090107`*^9, 3.440432256101449*^9, 3.440432498592052*^9, 
  3.538110436278921*^9, 3.538140467024836*^9}]
}, Open  ]],

Cell[BoxData["\<\"-113 ray/surface intersections-\"\>"], "Output",
 CellChangeTimes->{
  3.4305822114883204`*^9, {3.4305822682736397`*^9, 3.430582283852632*^9}, 
   3.430582353710688*^9, 3.430582384336733*^9, 3.430582509736877*^9, 
   3.4305827398870277`*^9, 3.4305827806975594`*^9, 3.440432256114151*^9, 
   3.440432498650783*^9, 3.538110437200534*^9, 3.53814046702802*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.430668077533517*^9, 3.430668079209752*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "some", " ", "variables", " ", "on", " ", "the", " ", "first", " ", "lense",
    " ", "elemnt", " ", "are", " ", "selected", " ", "as", " ", "dynamic"}], 
  "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.440433161706609*^9, 3.4404331745491962`*^9}, {
  3.4404336580349617`*^9, 3.440433663084805*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ManipulateSystem", "[", 
   RowBox[{
    RowBox[{"{", " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"LineOfRays", "[", 
         RowBox[{".9", ",", " ", 
          RowBox[{"NumberOfRays", " ", "\[Rule]", " ", "5"}], ",", "  ", 
          RowBox[{"WaveLength", " ", "\[Rule]", " ", ".7"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", 
          RowBox[{"{", 
           RowBox[{"lighty", ",", "0"}], "}"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"LightAngle", ",", " ", "0"}], "}"}]}], " ", "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"LineOfRays", "[", 
         RowBox[{".9", ",", " ", 
          RowBox[{"NumberOfRays", " ", "\[Rule]", " ", "5"}], ",", " ", 
          RowBox[{"WaveLength", " ", "\[Rule]", " ", ".4"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.0"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"LightAngle2", ",", " ", 
          RowBox[{"-", "5"}]}], "}"}]}], " ", "]"}], ",", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"CompoundLens", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rr1", ",", " ", "3.3077"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"rr2", ",", " ", "13.8223"}], "}"}], ",", " ", "1.9625", 
            ",", " ", 
            RowBox[{"-", "22.1426"}], ",", " ", "1.2787", ",", " ", 
            "\[Infinity]", ",", " ", 
            RowBox[{"{", 
             RowBox[{"rr6", ",", 
              RowBox[{"-", "1.7291"}]}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"rr7", ",", "2.7243"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"rr8", ",", 
              RowBox[{"-", "2.2955"}]}], "}"}], ",", " ", "6.5730", ",", "  ", 
            RowBox[{"-", "8.8951"}]}], "}"}], ",", " ", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "3.20", ",", " ", "3.20", ",", " ", "2.56", ",", " ", "2.56", ",", 
            " ", "1.50", ",", "1.26", ",", " ", "1.60", ",", " ", "2.36", ",",
             " ", "2.36", ",", " ", "3.0", ",", " ", "3.0"}], "}"}], ",", " ",
           "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           ".420", ",", ".023", ",", " ", ".605", ",", " ", ".283", ",", " ", 
            ".380", ",", " ", ".491", ",", " ", ".201", ",", " ", ".672", ",",
             " ", ".286", ",", "  ", ".394"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "SK16", ",", " ", "IntrinsicMedium", ",", " ", "SK16", ",", " ", 
            "LF5", ",", " ", "IntrinsicMedium", ",", "IntrinsicMedium", ",", 
            "\[IndentingNewLine]", "LF5", ",", " ", "SK4", ",", " ", 
            "IntrinsicMedium", ",", " ", "SK16"}], "}"}]}], "]"}], ",", " ", 
        "2"}], "]"}], ",", " ", 
      RowBox[{"Move", "[", " ", 
       RowBox[{
        RowBox[{"Screen", "[", "5", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"sx1", ",", " ", 
          RowBox[{"6.538", "+", " ", "2.0"}]}], "}"}]}], "]"}]}], " ", "}"}], 
    ",", " ", 
    RowBox[{"Axes", " ", "\[Rule]", " ", "True"}], ",", "  ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{"rr1", " ", ",", " ", "3.3077"}], "}"}], ",", "  ", "2.5", ",",
       " ", "4.5"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{"rr2", ",", " ", "13.8223"}], "}"}], ",", "  ", "13.0", ",", 
      "15.0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{"rr6", ",", " ", 
        RowBox[{"-", "1.7291"}]}], "}"}], ",", "  ", 
      RowBox[{"-", "2.0"}], ",", " ", 
      RowBox[{"-", "1.5"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{"rr7", ",", " ", "2.7243"}], "}"}], ",", "  ", "2.5", ",", " ",
       "3.0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{"rr8", ",", " ", 
        RowBox[{"-", "2.2955"}]}], "}"}], ",", "  ", 
      RowBox[{"-", "2.0"}], ",", 
      RowBox[{"-", "2.8"}]}], "}"}], ",", " ", 
    RowBox[{"PlotType", " ", "\[Rule]", " ", "TopView"}]}], "]"}], 
  " "}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQAGIQfaLs5bOq/peO54wUXoHoL773voJor/MR30F0Qngo
UzWQ9vEoYgfRmy/u5wPRU84U8oPoqAXHJUH04/hNUiA6KyZME0TzfTbSAtE/
DvWbbJj+0jE9f50piD4xZ5s/iPY6JhYAovmuB4eCaDaWlAgQXSmy+IfUopeO
Ut4ff4HooF5GdWkg7a0vpwWiFZ7c1wXRJ6a9BtNJk7aagugs472WIPqWF58d
iM7XbfYA0UeiF0WAaNcnF6NB9J3GFRkgOox5XhaI3vb1exGInuLSXw6id6yt
rwfRHL3tjSA6p/veNBD95r7eEjA948ImEP1o3u2jIPpHPvspED0nNhBMX7tn
9RBEOzakPQXRz9Ii34PogmXyH8Du2crzC0Q7Lcz5C6IBo9XFzw==
  "]],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`lastLightAngle$$ = 
    0., $CellContext`lastLightAngle2$$ = -5., \
$CellContext`lastlocposLightAngle$$ = {0.21345000000000003`, 
    0.}, $CellContext`lastlocposLightAngle2$$ = {0.2126377583076831, 
    0.9813966067105123}, $CellContext`laststartposLightAngle$$ = {
    0, 0.}, $CellContext`laststartposLightAngle2$$ = {0, 
    1}, $CellContext`LightAngle$$ = 
    0., $CellContext`LightAngle2$$ = -5., $CellContext`lighty$$ = 
    0., $CellContext`maxLightAngle$$ = 180., $CellContext`maxLightAngle2$$ = 
    175., $CellContext`maxlighty$$ = 10, $CellContext`maxrr1$$ = 
    4.5, $CellContext`maxrr2$$ = 
    15., $CellContext`maxrr6$$ = -1.5, $CellContext`maxrr7$$ = 
    3., $CellContext`maxrr8$$ = -2.8, $CellContext`maxsx1$$ = 
    17, $CellContext`minLightAngle$$ = -180., $CellContext`minLightAngle2$$ = \
-185., $CellContext`minlighty$$ = -10, $CellContext`minrr1$$ = 
    2.5, $CellContext`minrr2$$ = 
    13., $CellContext`minrr6$$ = -2., $CellContext`minrr7$$ = 
    2.5, $CellContext`minrr8$$ = -2., $CellContext`minsx1$$ = 
    0.085, $CellContext`oldwavelengths121142012213105118381628$$ = \
CompressedData["
1:eJxTTMoPSmVkYGDIAOJZM0Hgpv0oPbB0Ghg8G6WHGA0ABrCqEA==
    
    "], $CellContext`radiusLightAngle$$ = 
    0.21345000000000003`, $CellContext`radiusLightAngle2$$ = 
    0.21345000000000003`, $CellContext`raycolormodel$$ = RGBColor[
     Abs[(-0.3183098861837907) 
       ArcTan[63.75 - 0.25 Abs[-500. + 2. Mod[100. + 500. #, 500.]]] + 
      0.3183098861837907 
       ArcTan[43. - 0.1 Abs[-500. + 2. Mod[100. + 500. #, 500.]]]], 
     Abs[0.3183098861837907 
       ArcTan[60. - 0.2 Abs[-500. + 2. Mod[100. + 500. #, 500.]]] - 
      0.3183098861837907 
      ArcTan[18. - 0.1 Abs[-500. + 2. Mod[100. + 500. #, 500.]]]], 
     Abs[(-0.3183098861837907) 
       ArcTan[10. - 0.2 Abs[-500. + 2. Mod[100. + 500. #, 500.]]] + 
      0.3183098861837907 
       ArcTan[22.5 - 0.125 
         Abs[-500. + 
           2. Mod[100. + 500. #, 500.]]]]]& , $CellContext`raycolors$$ = {
     RGBColor[
     0.0014301774013306678`, 0.03162733424853975, 0.9365489651388929], 
     RGBColor[
     0.8888048816904333, 0.001443572353399647, 
      0.007022832322456984]}, $CellContext`rayresults$$ = {{
    1.}}, $CellContext`rr1$$ = 3.3077, $CellContext`rr2$$ = 
    13.8223, $CellContext`rr6$$ = -1.7291, $CellContext`rr7$$ = 
    2.7243, $CellContext`rr8$$ = -2.2955, \
$CellContext`staticpolygons1221142012213105118353036$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAcsB2Cs1atAgAGN/2s/qvovcP4asPwrOH8D
mH8LTT0CrIDI26PyX8H5//6DwGc0+V9w/iqI+xzQ3I+TvxpN/Wo086D+gfPX
oLlnA5p7cfhnPyofER5Q/6DJI8JzFVp4Q92PwQcAOh1pDw==
      
      "]]}, $CellContext`sx1$$ = 8.538, $CellContext`unionwavelengths$$ = {
    1.}, $CellContext`wavelengthpositions$$ = {1, 50, 
    105}, $CellContext`wavelengths$$ = {1.}, $CellContext`xLightAngle$$ = 
    0.21345000000000003`, $CellContext`xLightAngle2$$ = 
    0.2126377583076831, $CellContext`xoffLightAngle$$ = 
    0.21345000000000003`, $CellContext`xoffLightAngle2$$ = 
    0.2126377583076831, $CellContext`yLightAngle$$ = 
    0., $CellContext`yLightAngle2$$ = 
    0.9813966067105123, $CellContext`yoffLightAngle$$ = 
    0., $CellContext`yoffLightAngle2$$ = 0.018603393289487638`, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`rr1$$], 3.3077}, 2.5, 4.5}, {{
       Hold[$CellContext`rr2$$], 13.8223}, 13., 15.}, {{
       Hold[$CellContext`rr6$$], -1.7291}, -2., -1.5}, {{
       Hold[$CellContext`rr7$$], 2.7243}, 2.5, 3.}, {{
       Hold[$CellContext`rr8$$], -2.2955}, -2., -2.8}, {{
       Hold[$CellContext`LightAngle$$], 0.}, -180., 180.}, {{
       Hold[$CellContext`LightAngle2$$], -5.}, -185., 175.}, {{
       Hold[$CellContext`lighty$$], 0.}, -10, 10}, {{
       Hold[$CellContext`sx1$$], 8.538}, 0.085, 17}, {
      Hold[
       Style[
        Grid[{{"rr1", 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159321142012213105120181650; $CellContext`rr1$$, \
($CellContext`rr1$$ = #)& ], {2.5, 4.5}], 
           
           Dynamic[$CellContext`\
nonexistantvariable159321142012213105120181650; $CellContext`rr1$$, \
($CellContext`rr1$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style[
        Grid[{{"rr2", 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159321142012213105120181915; $CellContext`rr2$$, \
($CellContext`rr2$$ = #)& ], {13., 15.}], 
           
           Dynamic[$CellContext`\
nonexistantvariable159321142012213105120181915; $CellContext`rr2$$, \
($CellContext`rr2$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style[
        Grid[{{"rr6", 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159321142012213105120182077; $CellContext`rr6$$, \
($CellContext`rr6$$ = #)& ], {-2., -1.5}], 
           
           Dynamic[$CellContext`\
nonexistantvariable159321142012213105120182077; $CellContext`rr6$$, \
($CellContext`rr6$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style[
        Grid[{{"rr7", 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159321142012213105120182236; $CellContext`rr7$$, \
($CellContext`rr7$$ = #)& ], {2.5, 3.}], 
           
           Dynamic[$CellContext`\
nonexistantvariable159321142012213105120182236; $CellContext`rr7$$, \
($CellContext`rr7$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style[
        Grid[{{"rr8", 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159321142012213105120182395; $CellContext`rr8$$, \
($CellContext`rr8$$ = #)& ], {-2., -2.8}], 
           
           Dynamic[$CellContext`\
nonexistantvariable159321142012213105120182395; $CellContext`rr8$$, \
($CellContext`rr8$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minLightAngle$$], -180.}}, {{
       Hold[$CellContext`maxLightAngle$$], 180.}}, {{
       Hold[$CellContext`minLightAngle2$$], -185.}}, {{
       Hold[$CellContext`maxLightAngle2$$], 175.}}, {{
       Hold[$CellContext`minlighty$$], -10}}, {{
       Hold[$CellContext`maxlighty$$], 10}}, {{
       Hold[$CellContext`minsx1$$], 0.085}}, {{
       Hold[$CellContext`maxsx1$$], 17}}, {{
       Hold[$CellContext`minrr1$$], 2.5}}, {{
       Hold[$CellContext`maxrr1$$], 4.5}}, {{
       Hold[$CellContext`minrr2$$], 13.}}, {{
       Hold[$CellContext`maxrr2$$], 15.}}, {{
       Hold[$CellContext`minrr6$$], -2.}}, {{
       Hold[$CellContext`maxrr6$$], -1.5}}, {{
       Hold[$CellContext`minrr7$$], 2.5}}, {{
       Hold[$CellContext`maxrr7$$], 3.}}, {{
       Hold[$CellContext`minrr8$$], -2.}}, {{
       Hold[$CellContext`maxrr8$$], -2.8}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{
              "LightAngle", "LightAngle2", "lighty", "rr1", "rr2", "rr6", 
               "rr7", "rr8", 
               "sx1"}, {$CellContext`LightAngle$$, \
$CellContext`LightAngle2$$, $CellContext`lighty$$, $CellContext`rr1$$, \
$CellContext`rr2$$, $CellContext`rr6$$, $CellContext`rr7$$, \
$CellContext`rr8$$, $CellContext`sx1$$}}], 
           Optica`Optica`SymbolicRanges -> {$CellContext`rr1$$ -> {2.5, 
              4.5}, $CellContext`rr2$$ -> {13., 
              15.}, $CellContext`rr6$$ -> {-2., -1.5}, $CellContext`rr7$$ -> {
              2.5, 3.}, $CellContext`rr8$$ -> {-2., -2.8}, \
$CellContext`LightAngle$$ -> {-180., 
              180.}, $CellContext`LightAngle2$$ -> {-185., 
              175.}, $CellContext`lighty$$ -> {-10, 
              10}, $CellContext`sx1$$ -> {0.085, 17}}}; 
        Optica`Optica`$OpticalSystemScript = 
         "{Move[LineOfRays[0.9, NumberOfRays -> 5, WaveLength -> 0.7], {0, \
{lighty, 0}}, {LightAngle, 0.}, SymbolicValues -> {LightAngle -> 0, lighty -> \
0}], Move[LineOfRays[0.9, NumberOfRays -> 5, WaveLength -> 0.4], {0, 1.}, \
{LightAngle2, -4.999999999999999}, SymbolicValues -> {LightAngle2 -> -5}], \
Move[CompoundLens[{{rr1, 3.3077}, {rr2, 13.8223}, 1.9625, -22.1426, 1.2787, \
Infinity, {rr6, -1.7291}, {rr7, 2.7243}, {rr8, -2.2955}, 6.573, -8.8951}, \
{3.2, 3.2, 2.56, 2.56, 1.5, 1.26, 1.6, 2.36, 2.36, 3., 3.}, {0.42, 0.023, \
0.605, 0.283, 0.38, 0.491, 0.201, 0.672, 0.286, 0.394}, {SK16, \
IntrinsicMedium, SK16, LF5, IntrinsicMedium, IntrinsicMedium, LF5, SK4, \
IntrinsicMedium, SK16}], 2.], Move[Screen[5], {sx1, 8.538}, SymbolicValues -> \
{sx1 -> 8.538}]}"; Print[
          InputForm[
           StringJoin["SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "LightAngle", "LightAngle2", "lighty", "rr1", "rr2", "rr6", 
                "rr7", "rr8", 
                "sx1"}, {$CellContext`LightAngle$$, \
$CellContext`LightAngle2$$, $CellContext`lighty$$, $CellContext`rr1$$, \
$CellContext`rr2$$, $CellContext`rr6$$, $CellContext`rr7$$, \
$CellContext`rr8$$, $CellContext`sx1$$}}]]]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`xLightAngle$$], 0.21345000000000003`}}, {{
       Hold[$CellContext`yLightAngle$$], 0.}}, {{
       Hold[$CellContext`radiusLightAngle$$], 0.21345000000000003`}}, {{
       Hold[$CellContext`xoffLightAngle$$], 0.21345000000000003`}}, {{
       Hold[$CellContext`yoffLightAngle$$], 0.}}, {{
       Hold[$CellContext`laststartposLightAngle$$], {0, 0.}}}, {{
       Hold[$CellContext`lastlocposLightAngle$$], {0.21345000000000003`, 
       0.}}}, {{
       Hold[$CellContext`lastLightAngle$$], 0}}, {{
       Hold[$CellContext`xLightAngle2$$], 0.2126377583076831}}, {{
       Hold[$CellContext`yLightAngle2$$], 1.0186033932894876`}}, {{
       Hold[$CellContext`radiusLightAngle2$$], 0.21345000000000003`}}, {{
       Hold[$CellContext`xoffLightAngle2$$], 0.2126377583076831}}, {{
       Hold[$CellContext`yoffLightAngle2$$], 0.018603393289487638`}}, {{
       Hold[$CellContext`laststartposLightAngle2$$], {0, 1}}}, {{
       Hold[$CellContext`lastlocposLightAngle2$$], {0.2126377583076831, 
       1.0186033932894876`}}}, {{
       Hold[$CellContext`lastLightAngle2$$], 0}}, {{
       Hold[$CellContext`rayresults$$], {{1.}}}}, {{
       Hold[$CellContext`oldwavelengths121142012213105118381628$$], {1.}}}, {{
      
       Hold[$CellContext`wavelengths$$], {1.}}}, {{
       Hold[$CellContext`unionwavelengths$$], {1.}}}, {{
       Hold[$CellContext`wavelengthpositions$$], {1.}}}, {{
       Hold[$CellContext`raycolors$$], {{1., 1., 1.}}}}, {{
       Hold[$CellContext`raycolormodel$$], RGBColor[
        Abs[(-0.3183098861837907) 
          ArcTan[63.75 - 0.25 Abs[-500. + 2. Mod[100. + 500. #, 500.]]] + 
         0.3183098861837907 
          ArcTan[43. - 0.1 Abs[-500. + 2. Mod[100. + 500. #, 500.]]]], 
        Abs[
        0.3183098861837907 
          ArcTan[60. - 0.2 Abs[-500. + 2. Mod[100. + 500. #, 500.]]] - 
         0.3183098861837907 
         ArcTan[18. - 0.1 Abs[-500. + 2. Mod[100. + 500. #, 500.]]]], 
        Abs[(-0.3183098861837907) 
          ArcTan[10. - 0.2 Abs[-500. + 2. Mod[100. + 500. #, 500.]]] + 
         0.3183098861837907 
          ArcTan[22.5 - 0.125 
            Abs[-500. + 2. Mod[100. + 500. #, 500.]]]]]& }}, {{
       Hold[$CellContext`staticpolygons1221142012213105118353036$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAcsB2Cs1atAgAGN/2s/qvovcP4asPwrOH8D
mH8LTT0CrIDI26PyX8H5//6DwGc0+V9w/iqI+xzQ3I+TvxpN/Wo086D+gfPX
oLlnA5p7cfhnPyofER5Q/6DJI8JzFVp4Q92PwQcAOh1pDw==
         "]]}}}}, 
    Typeset`size$$ = {815., {261.34375, 266.65625}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`rr1$28531$$ = 0, $CellContext`rr2$28532$$ = 
    0, $CellContext`rr6$28533$$ = 0, $CellContext`rr7$28534$$ = 
    0, $CellContext`rr8$28535$$ = 0, $CellContext`LightAngle$28536$$ = 
    0, $CellContext`LightAngle2$28537$$ = 0, $CellContext`lighty$28538$$ = 
    0, $CellContext`sx1$28539$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`lastLightAngle$$ = 
        0, $CellContext`lastLightAngle2$$ = 
        0, $CellContext`lastlocposLightAngle$$ = {0.21345000000000003`, 
         0.}, $CellContext`lastlocposLightAngle2$$ = {0.2126377583076831, 
         1.0186033932894876`}, $CellContext`laststartposLightAngle$$ = {
         0, 0.}, $CellContext`laststartposLightAngle2$$ = {0, 
         1}, $CellContext`LightAngle$$ = 
        0., $CellContext`LightAngle2$$ = -5., $CellContext`lighty$$ = 
        0., $CellContext`maxLightAngle$$ = 
        180., $CellContext`maxLightAngle2$$ = 175., $CellContext`maxlighty$$ = 
        10, $CellContext`maxrr1$$ = 4.5, $CellContext`maxrr2$$ = 
        15., $CellContext`maxrr6$$ = -1.5, $CellContext`maxrr7$$ = 
        3., $CellContext`maxrr8$$ = -2.8, $CellContext`maxsx1$$ = 
        17, $CellContext`minLightAngle$$ = -180., \
$CellContext`minLightAngle2$$ = -185., $CellContext`minlighty$$ = -10, \
$CellContext`minrr1$$ = 2.5, $CellContext`minrr2$$ = 
        13., $CellContext`minrr6$$ = -2., $CellContext`minrr7$$ = 
        2.5, $CellContext`minrr8$$ = -2., $CellContext`minsx1$$ = 
        0.085, $CellContext`oldwavelengths121142012213105118381628$$ = {
         1.}, $CellContext`radiusLightAngle$$ = 
        0.21345000000000003`, $CellContext`radiusLightAngle2$$ = 
        0.21345000000000003`, $CellContext`raycolormodel$$ = RGBColor[
          
          Abs[(-0.3183098861837907) 
            ArcTan[63.75 - 0.25 Abs[-500. + 2. Mod[100. + 500. #, 500.]]] + 
           0.3183098861837907 
            ArcTan[43. - 0.1 Abs[-500. + 2. Mod[100. + 500. #, 500.]]]], 
          Abs[
          0.3183098861837907 
            ArcTan[60. - 0.2 Abs[-500. + 2. Mod[100. + 500. #, 500.]]] - 
           0.3183098861837907 
           ArcTan[18. - 0.1 Abs[-500. + 2. Mod[100. + 500. #, 500.]]]], 
          Abs[(-0.3183098861837907) 
            ArcTan[10. - 0.2 Abs[-500. + 2. Mod[100. + 500. #, 500.]]] + 
           0.3183098861837907 
            ArcTan[22.5 - 0.125 
              Abs[-500. + 
                2. Mod[100. + 500. #, 
                   500.]]]]]& , $CellContext`raycolors$$ = {{1., 1., 
         1.}}, $CellContext`rayresults$$ = {{1.}}, $CellContext`rr1$$ = 
        3.3077, $CellContext`rr2$$ = 
        13.8223, $CellContext`rr6$$ = -1.7291, $CellContext`rr7$$ = 
        2.7243, $CellContext`rr8$$ = -2.2955, \
$CellContext`staticpolygons1221142012213105118353036$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAcsB2Cs1atAgAGN/2s/qvovcP4asPwrOH8D
mH8LTT0CrIDI26PyX8H5//6DwGc0+V9w/iqI+xzQ3I+TvxpN/Wo086D+gfPX
oLlnA5p7cfhnPyofER5Q/6DJI8JzFVp4Q92PwQcAOh1pDw==
           
           "]]}, $CellContext`sx1$$ = 
        8.538, $CellContext`unionwavelengths$$ = {
         1.}, $CellContext`wavelengthpositions$$ = {
         1.}, $CellContext`wavelengths$$ = {1.}, $CellContext`xLightAngle$$ = 
        0.21345000000000003`, $CellContext`xLightAngle2$$ = 
        0.2126377583076831, $CellContext`xoffLightAngle$$ = 
        0.21345000000000003`, $CellContext`xoffLightAngle2$$ = 
        0.2126377583076831, $CellContext`yLightAngle$$ = 
        0., $CellContext`yLightAngle2$$ = 
        1.0186033932894876`, $CellContext`yoffLightAngle$$ = 
        0., $CellContext`yoffLightAngle2$$ = 0.018603393289487638`}, 
      "ControllerVariables" :> {
        Hold[$CellContext`rr1$$, $CellContext`rr1$28531$$, 0], 
        Hold[$CellContext`rr2$$, $CellContext`rr2$28532$$, 0], 
        Hold[$CellContext`rr6$$, $CellContext`rr6$28533$$, 0], 
        Hold[$CellContext`rr7$$, $CellContext`rr7$28534$$, 0], 
        Hold[$CellContext`rr8$$, $CellContext`rr8$28535$$, 0], 
        Hold[$CellContext`LightAngle$$, $CellContext`LightAngle$28536$$, 0], 
        Hold[$CellContext`LightAngle2$$, $CellContext`LightAngle2$28537$$, 0], 
        Hold[$CellContext`lighty$$, $CellContext`lighty$28538$$, 0], 
        Hold[$CellContext`sx1$$, $CellContext`sx1$28539$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         OpenerView[{"TopView", 
           Show[{
             Graphics[{{
                Opacity[0.8], {
                 AbsoluteThickness[1], 
                 AbsolutePointSize[1], 
                 EdgeForm[], 
                 RGBColor[0.4, 0.6, 0.8], 
                 Polygon[
                  Dynamic[
                   (Map[
                    Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], CompressedData["
1:eJwt1mWQEFQUgNEFFlhq6c6lu7u7uzuWriUlpBsJCQkJCenulJCQkJCQbiQk
JCQkBDwM/jhz/79v7twXEtqtdlj4gICA9eECAj5PIyAikYhKNGISi3jEJzFJ
SEFK0pCWjGQiG9nJTR4KUJCiFKMUpSlPBapQlZrUoh71aUwTWtCSNrSlI50I
oxu96E0/+jOIwQxnBGMYywQmMoWpzGAmc5jLAhayhKWsZBXrPr8Pm9nCDnay
h70c4CBHOMoJTnKGs1zgIle5xi1uc4/7POIxz3jOK17zjvd8CvgSJpCIRCEq
wcQkLvFIRGKSk4LUpCEDGclKNnKRm/wUoAhFKUkpylGeylShBjWpSz0a0Zjm
tKA1behAR7oSRk960Zd+DGQQwxjOaMYwnglMZgrTmcFs5jCfBSxmCStYyVrW
sYnNbGcHu9nDfg5wmCMc5wSnOcN5LnCFq9zkFne5x0Me8ZRnvOQVb3nHRz4R
weIEEkQUYhBMHOKSkEQkIzkhpCY9GchCVnKSi3zkpzBFKEFJylKOSlSmOjWo
Q10a0ohmNCeU1rSnA13oSg960oe+DGAgQxnGKEYzjvFMYjLTmM4sZjOP+Sxi
MctZwRrWspFNbGM7u9jNPvZziMMc4zinOM05znOZK9zgJne4ywMe8oSnvOAl
b3jLBz4SPoI2RCaI6MQgNnFIQEKSkoxUhJCO9GQmCznISV7yUYjCFKcEZShL
RSpRjerUpg4NaEhTmtGKUNrRns50oTs9+Io+fM0AhjCUkYziG8bxLZP4jml8
zyx+YB4/sohlLGc1a9jARrayjZ/Yxc/s4xcO8SvH+I1T/M45LnGZ69zgD+7w
Jw/4iyf8zQv+4Q3/8oFwgdoQichEIzqxiE18EpCEpKQkFWlJRyYyk50c5CEv
BSlEMYpTmjJUoCJVqUYtalOfBjShKS1pRVva0YnOdKM7vfmK/nzNYIYwgpGM
5Rsm8i1T+Y6ZfM9cfmAhP7KUZaxiNevZwBa2spOf2MvPHOQXjvIrJ/mNs/zO
RS5xjevc5g/u8yeP+Yvn/M1r/uE9/wZ+OfzhiEgkohKNmMQiHvFJTBJSkJI0
pCUjmchGdnKThwIUpCjFKEVpylOBKlSlJrWoR30a04QWtKQNbelIJ8LoRi96
04/+DGIwwxnBGMYygYlMYSozmMkc5rKAhSxhKStZxTrWs5kt7GAne9jLAQ5y
hKOc4CRnOMsFLnKVa9ziNve4zyMe84znvOI173jPp/8/ZIFEJApRCSYmcYlH
IhKTnBSkJg0ZyEhWspGL3OSnAEUoSklKUY7yVKYKNahJXerRiMY0pwWtaUMH
OtKVMHrSi770YyCDGMZwRjOG8UxgMlOYzgxmM4f5LGAxS1jBStayjk1sZjs7
2M0e9nOAwxzhOCc4zRnOc4ErXOUmt7jLPR7yiKc84yWveMs7PvKJCJG1IYgo
xCCYOMQlIYlIRnJCSE16MpCFrOQkF/nIT2GKUIKSlKUclahMdWpQh7o0pBHN
aE4orWlPB7rQlR70pA99GcBAhjKMUYxmHOOZxGSmMZ1ZzGYe81nEYpazgjWs
ZSOb2MZ2drGbfeznEIc5xnFOcZpznOcyV7jBTe5wlwc85AlPecFL3vCWD3wk
fJA2RCaI6MQgNnFIQEKSkoxUhJCO9GQmCznISV7yUYjCFKcEZShLRSpRjerU
pg4NaEhTmtGKUNrRns50oTv/AewuscM=
                    "]]& )[
                    $CellContext`polygons1121142012213105118342190[$\
CellContext`rr1$$, $CellContext`rr2$$, $CellContext`rr6$$, \
$CellContext`rr7$$, $CellContext`rr8$$]]]], 
                 GrayLevel[0], 
                 AbsoluteThickness[0.5], 
                 Line[
                  Dynamic[
                   (Map[
                    Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], CompressedData["
1:eJwV1G1MCAgcx/FwypQTU3ayk53sZFd2OLKTnWc33OQmN7nJTW7icCPzMGXi
PMzDlHmYmDJlHqbMw8SRiSlTpkyMTJmYMjIxud3Hi89+7/5vvtu/9+yFCX+1
DQgIiGkTEPB5TUAEPfmBIUwhgfks4B82kEseF/mXe9TQzFu+dKwz/YhmNGOY
wM9M5hem8ivT+Y2Z/M5s/mAufzKfBSzmb9JYxkpWkcEa1rGeTWxmG9vJZid7
2Mt+DpDHIQo4wnFOUMQpznKOC1ykhCtc4zrl3KSS21Rzl/s8oJbH1POU57yg
iVc085b3fOAT/33uIUg7guhACJ3oQlfC6U4EPYmkN1H0JZr+xDKAQQwmjmHE
M4JRjGY8E5jEZBKYSiLTSWImycwmhbmkMp9FLGYpaaxgJelkkMk6NrKJrWwj
i2x2s4cc9pNLHvkUcIzjFFLEGc5SzAUuU0Ip1yijnAoqqaKaGu7ziFrqqKeB
5zTSxBuaaeE9rXyiTTttCCSIYEIIpQthhNODCHoRSR+i6Ec0McQykEEMJY7h
xDOSUYxjPBOZxBQSmEYiM0hiFsnMIYV5pLKQRSxhKctZwWrSWUsmG9jIFray
gyx2sZt95HCQXA6Tz1GOcZJCTnOG8xRzictcpZQblHGLCu5QxT1qeMgjnlDH
Mxp4SSOvecM7WvhIKwFfaEN7AulIMJ0JpRthjGEsaSxjJavIYA3rWM8mNrON
7WSzkz3sZT8HyOMQBRzhOCco4hRnOccFLlLCFa5xnXJuUsltqrnLfR5Qy2Pq
ecpzXtDEK5p5y3s+8In/aNve/yCIDoTQiS50JZzuRNCTSHoTRV+i6U8sAxjE
YOIYRjwjGMVoxjOBSUwmgakkMp0kZpLMbFKYSyrzWcRilpLGClaSTgaZrGMj
m9jKNrLIZjd7yGE/ueSRTwHHOE4hRZzhLMVc4DIllHKNMsqpoJIqqqnhPo+o
pY56GnhOI028oZkW3tPKJ9oEakMgQQQTQihdCCOcHkTQi0j6EEU/ookhloEM
YihxDCeekYxiHOOZyCSmkMA0EplBErNIZg4pzCOVhSxiCUtZzgpWk85aMtnA
RrawlR1ksYvd7COHg+RymHyOcoyTFHKaM5ynmEtc5iql3KCMW1RwhyruUcND
HvGEOp7RwEsaec0b3tHCR1oJCNKG9gTSkWA6E0o3wviKHnxNL76hD9/Sj++I
4XsGMoSh/MhwfmIkY/kfopU8Mg==
                    "]]& )[
                    $CellContext`lines1121142012213105118345376[$CellContext`\
rr1$$, $CellContext`rr2$$, $CellContext`rr6$$, $CellContext`rr7$$, \
$CellContext`rr8$$]]]]}, 
                
                GeometricTransformation[$CellContext`\
staticpolygons1221142012213105118353036$$, 
                 Dynamic[
                 BesselJ[
                   1., 3.]; {{{1, 0}, {0, 1}}, {$CellContext`sx1$$, 0}}]], 
                Opacity[1], 
                AbsoluteThickness[Medium], 
                Dynamic[
                 Refresh[
                  
                  Module[{$CellContext`rayresults$, \
$CellContext`wavelengths$, $CellContext`unionwavelengths$}, \
$CellContext`rayresults$ = Sort[
                    Select[
                    $CellContext`raytracefunction121142012213105118381495[$\
CellContext`LightAngle$$, $CellContext`LightAngle2$$, $CellContext`lighty$$, \
$CellContext`rr1$$, $CellContext`rr2$$, $CellContext`rr6$$, \
$CellContext`rr7$$, $CellContext`rr8$$, $CellContext`sx1$$], And[
                    Length[#] == 7, 
                    Part[#, 
                    2] > -9.87654321*^8]& ]]; $CellContext`wavelengths$ = 
                    First[
                    Transpose[$CellContext`rayresults$]]; 
                   If[$CellContext`oldwavelengths121142012213105118381628$$ =!= \
$CellContext`wavelengths$, $CellContext`unionwavelengths$ = 
                    Union[$CellContext`wavelengths$]; \
$CellContext`wavelengthpositions$$ = Map[Part[
                    Position[$CellContext`wavelengths$, #], 1, 
                    
                    1]& , $CellContext`unionwavelengths$]; \
$CellContext`wavelengthpositions$$ = 
                    Join[$CellContext`wavelengthpositions$$, {
                    Length[$CellContext`wavelengths$] + 
                    1}]; $CellContext`raycolors$$ = 
                    Map[$CellContext`raycolormodel$$, \
$CellContext`unionwavelengths$]; 
                    Null]; $CellContext`\
oldwavelengths121142012213105118381628$$ = $CellContext`wavelengths$; \
$CellContext`rayresults$ = Map[{
                    Part[#, {2, 3}], 
                    Part[#, {5, 6}]}& , $CellContext`rayresults$]; Table[{
                    Part[$CellContext`raycolors$$, $CellContext`nn], 
                    Line[
                    Take[$CellContext`rayresults$, {
                    Part[$CellContext`wavelengthpositions$$, $CellContext`nn],
                     Part[$CellContext`wavelengthpositions$$, $CellContext`nn + 
                    1] - 1}]]}, {$CellContext`nn, 1, 
                    Length[$CellContext`wavelengthpositions$$] - 1}]], 
                  TrackedSymbols :> {$CellContext`LightAngle$$, \
$CellContext`LightAngle2$$, $CellContext`lighty$$, $CellContext`rr1$$, \
$CellContext`rr2$$, $CellContext`rr6$$, $CellContext`rr7$$, \
$CellContext`rr8$$, $CellContext`sx1$$}], SynchronousUpdating -> False], 
                Arrowheads[Large], 
                Thickness[Large], 
                Dashing[{Small, Small}], 
                RGBColor[1, 1, 0], 
                Arrow[
                 Dynamic[If[
                    
                    Or[$CellContext`laststartposLightAngle$$ != {
                    0, $CellContext`lighty$$}, $CellContext`lastLightAngle$$ =!= \
$CellContext`LightAngle$$], $CellContext`laststartposLightAngle$$ = {
                    0, $CellContext`lighty$$}; $CellContext`lastLightAngle$$ = \
$CellContext`LightAngle$$; {$CellContext`xLightAngle$$, \
$CellContext`yLightAngle$$} = $CellContext`laststartposLightAngle$$ + \
$CellContext`radiusLightAngle$$ {
                    Cos[$CellContext`LightAngle$$ Degree], 
                    
                    Sin[$CellContext`LightAngle$$ 
                    Degree]}]; {$CellContext`laststartposLightAngle$$, \
{$CellContext`xLightAngle$$, $CellContext`yLightAngle$$}}, \
({$CellContext`laststartposLightAngle$$, {$CellContext`xLightAngle$$, \
$CellContext`yLightAngle$$}} = #)& ]], 
                Tooltip[
                 Locator[
                  Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`xLightAngle$$, \
$CellContext`yLightAngle$$} != $CellContext`lastlocposLightAngle$$, \
$CellContext`lastLightAngle$$ != $CellContext`LightAngle$$], \
$CellContext`lastlocposLightAngle$$ = {$CellContext`xLightAngle$$, \
$CellContext`yLightAngle$$}; $CellContext`lastLightAngle$$ = \
$CellContext`LightAngle$$; {$CellContext`xLightAngle$$, \
$CellContext`yLightAngle$$} = $CellContext`laststartposLightAngle$$ + \
$CellContext`radiusLightAngle$$ {
                    Cos[$CellContext`LightAngle$$ Degree], 
                    
                    Sin[$CellContext`LightAngle$$ 
                    Degree]}]; {$CellContext`xLightAngle$$, \
$CellContext`yLightAngle$$}), ({$CellContext`xLightAngle$$, \
$CellContext`yLightAngle$$} = #; $CellContext`xoffLightAngle$$ = \
$CellContext`xLightAngle$$ + 
                    0; $CellContext`yoffLightAngle$$ = \
$CellContext`yLightAngle$$ - $CellContext`lighty$$; \
$CellContext`radiusLightAngle$$ = 
                    Sqrt[$CellContext`xoffLightAngle$$^2 + \
$CellContext`yoffLightAngle$$^2]; $CellContext`LightAngle$$ = 
                    Chop[ArcTan[$CellContext`xoffLightAngle$$, \
$CellContext`yoffLightAngle$$]/
                    Degree]; {$CellContext`xLightAngle$$, \
$CellContext`yLightAngle$$})& ], 
                  Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                 Dynamic[
                  StringJoin["LightAngle = ", 
                   ToString[$CellContext`LightAngle$$]]]], 
                Arrowheads[Large], 
                Thickness[Large], 
                Dashing[{Small, Small}], 
                RGBColor[1, 1, 0], 
                Arrow[
                 Dynamic[
                 
                 If[$CellContext`lastLightAngle2$$ =!= \
$CellContext`LightAngle2$$, $CellContext`lastLightAngle2$$ = \
$CellContext`LightAngle2$$; {$CellContext`xLightAngle2$$, \
$CellContext`yLightAngle2$$} = $CellContext`laststartposLightAngle2$$ + \
$CellContext`radiusLightAngle2$$ {
                    Cos[$CellContext`LightAngle2$$ Degree], 
                    
                    Sin[$CellContext`LightAngle2$$ 
                    Degree]}]; {$CellContext`laststartposLightAngle2$$, \
{$CellContext`xLightAngle2$$, $CellContext`yLightAngle2$$}}, \
({$CellContext`laststartposLightAngle2$$, {$CellContext`xLightAngle2$$, \
$CellContext`yLightAngle2$$}} = #)& ]], 
                Tooltip[
                 Locator[
                  Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`xLightAngle2$$, \
$CellContext`yLightAngle2$$} != $CellContext`lastlocposLightAngle2$$, \
$CellContext`lastLightAngle2$$ != $CellContext`LightAngle2$$], \
$CellContext`lastlocposLightAngle2$$ = {$CellContext`xLightAngle2$$, \
$CellContext`yLightAngle2$$}; $CellContext`lastLightAngle2$$ = \
$CellContext`LightAngle2$$; {$CellContext`xLightAngle2$$, \
$CellContext`yLightAngle2$$} = $CellContext`laststartposLightAngle2$$ + \
$CellContext`radiusLightAngle2$$ {
                    Cos[$CellContext`LightAngle2$$ Degree], 
                    
                    Sin[$CellContext`LightAngle2$$ 
                    Degree]}]; {$CellContext`xLightAngle2$$, \
$CellContext`yLightAngle2$$}), ({$CellContext`xLightAngle2$$, \
$CellContext`yLightAngle2$$} = #; $CellContext`xoffLightAngle2$$ = \
$CellContext`xLightAngle2$$ + 
                    0; $CellContext`yoffLightAngle2$$ = \
$CellContext`yLightAngle2$$ - 1; $CellContext`radiusLightAngle2$$ = 
                    Sqrt[$CellContext`xoffLightAngle2$$^2 + \
$CellContext`yoffLightAngle2$$^2]; $CellContext`LightAngle2$$ = 
                    Chop[ArcTan[$CellContext`xoffLightAngle2$$, \
$CellContext`yoffLightAngle2$$]/
                    Degree]; {$CellContext`xLightAngle2$$, \
$CellContext`yLightAngle2$$})& ], 
                  Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                 Dynamic[
                  StringJoin["LightAngle2 = ", 
                   ToString[$CellContext`LightAngle2$$]]]], 
                Tooltip[
                 Locator[
                  Dynamic[
                  BesselJ[1., 3.]; {
                    0, $CellContext`lighty$$}, ($CellContext`lighty$$ = Chop[
                    Part[#, 2]])& ], 
                  Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                 Dynamic[
                  StringJoin["lighty = ", 
                   ToString[$CellContext`lighty$$]]]], 
                Tooltip[
                 Locator[
                  Dynamic[
                  BesselJ[
                    1., 3.]; {$CellContext`sx1$$, 0}, ($CellContext`sx1$$ = 
                   Chop[
                    Part[#, 1]])& ], 
                  Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                 Dynamic[
                  StringJoin["sx1 = ", 
                   ToString[$CellContext`sx1$$]]]]}}]}, {
            PlotLabel -> "TopView", Axes -> True, ImageSize -> 800, 
             AspectRatio -> Automatic}]}, True], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`rr1$$, 3.3077}, 2.5, 4.5, 
         ControlType -> None}, {{$CellContext`rr2$$, 13.8223}, 13., 15., 
         ControlType -> None}, {{$CellContext`rr6$$, -1.7291}, -2., -1.5, 
         ControlType -> None}, {{$CellContext`rr7$$, 2.7243}, 2.5, 3., 
         ControlType -> None}, {{$CellContext`rr8$$, -2.2955}, -2., -2.8, 
         ControlType -> None}, {{$CellContext`LightAngle$$, 0.}, -180., 180., 
         ControlType -> None}, {{$CellContext`LightAngle2$$, -5.}, -185., 
         175., ControlType -> None}, {{$CellContext`lighty$$, 0.}, -10, 10, 
         ControlType -> None}, {{$CellContext`sx1$$, 8.538}, 0.085, 17, 
         ControlType -> None}, 
        Style[
         Grid[{{"rr1", 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159321142012213105120181650; $CellContext`rr1$$, \
($CellContext`rr1$$ = #)& ], {2.5, 4.5}], 
            
            Dynamic[$CellContext`\
nonexistantvariable159321142012213105120181650; $CellContext`rr1$$, \
($CellContext`rr1$$ = #)& ]}}]], 
        Style[
         Grid[{{"rr2", 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159321142012213105120181915; $CellContext`rr2$$, \
($CellContext`rr2$$ = #)& ], {13., 15.}], 
            
            Dynamic[$CellContext`\
nonexistantvariable159321142012213105120181915; $CellContext`rr2$$, \
($CellContext`rr2$$ = #)& ]}}]], 
        Style[
         Grid[{{"rr6", 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159321142012213105120182077; $CellContext`rr6$$, \
($CellContext`rr6$$ = #)& ], {-2., -1.5}], 
            
            Dynamic[$CellContext`\
nonexistantvariable159321142012213105120182077; $CellContext`rr6$$, \
($CellContext`rr6$$ = #)& ]}}]], 
        Style[
         Grid[{{"rr7", 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159321142012213105120182236; $CellContext`rr7$$, \
($CellContext`rr7$$ = #)& ], {2.5, 3.}], 
            
            Dynamic[$CellContext`\
nonexistantvariable159321142012213105120182236; $CellContext`rr7$$, \
($CellContext`rr7$$ = #)& ]}}]], 
        Style[
         Grid[{{"rr8", 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159321142012213105120182395; $CellContext`rr8$$, \
($CellContext`rr8$$ = #)& ], {-2., -2.8}], 
            
            Dynamic[$CellContext`\
nonexistantvariable159321142012213105120182395; $CellContext`rr8$$, \
($CellContext`rr8$$ = #)& ]}}]], {{$CellContext`minLightAngle$$, -180.}, 
         ControlType -> None}, {{$CellContext`maxLightAngle$$, 180.}, 
         ControlType -> None}, {{$CellContext`minLightAngle2$$, -185.}, 
         ControlType -> None}, {{$CellContext`maxLightAngle2$$, 175.}, 
         ControlType -> None}, {{$CellContext`minlighty$$, -10}, ControlType -> 
         None}, {{$CellContext`maxlighty$$, 10}, ControlType -> 
         None}, {{$CellContext`minsx1$$, 0.085}, ControlType -> 
         None}, {{$CellContext`maxsx1$$, 17}, ControlType -> 
         None}, {{$CellContext`minrr1$$, 2.5}, ControlType -> 
         None}, {{$CellContext`maxrr1$$, 4.5}, ControlType -> 
         None}, {{$CellContext`minrr2$$, 13.}, ControlType -> 
         None}, {{$CellContext`maxrr2$$, 15.}, ControlType -> 
         None}, {{$CellContext`minrr6$$, -2.}, ControlType -> 
         None}, {{$CellContext`maxrr6$$, -1.5}, ControlType -> 
         None}, {{$CellContext`minrr7$$, 2.5}, ControlType -> 
         None}, {{$CellContext`maxrr7$$, 3.}, ControlType -> 
         None}, {{$CellContext`minrr8$$, -2.}, ControlType -> 
         None}, {{$CellContext`maxrr8$$, -2.8}, ControlType -> None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{
               "LightAngle", "LightAngle2", "lighty", "rr1", "rr2", "rr6", 
                "rr7", "rr8", 
                "sx1"}, {$CellContext`LightAngle$$, \
$CellContext`LightAngle2$$, $CellContext`lighty$$, $CellContext`rr1$$, \
$CellContext`rr2$$, $CellContext`rr6$$, $CellContext`rr7$$, \
$CellContext`rr8$$, $CellContext`sx1$$}}], 
            Optica`Optica`SymbolicRanges -> {$CellContext`rr1$$ -> {2.5, 
               4.5}, $CellContext`rr2$$ -> {13., 
               15.}, $CellContext`rr6$$ -> {-2., -1.5}, $CellContext`rr7$$ -> \
{2.5, 3.}, $CellContext`rr8$$ -> {-2., -2.8}, $CellContext`LightAngle$$ -> \
{-180., 180.}, $CellContext`LightAngle2$$ -> {-185., 
               175.}, $CellContext`lighty$$ -> {-10, 
               10}, $CellContext`sx1$$ -> {0.085, 17}}}; 
         Optica`Optica`$OpticalSystemScript = 
          "{Move[LineOfRays[0.9, NumberOfRays -> 5, WaveLength -> 0.7], {0, \
{lighty, 0}}, {LightAngle, 0.}, SymbolicValues -> {LightAngle -> 0, lighty -> \
0}], Move[LineOfRays[0.9, NumberOfRays -> 5, WaveLength -> 0.4], {0, 1.}, \
{LightAngle2, -4.999999999999999}, SymbolicValues -> {LightAngle2 -> -5}], \
Move[CompoundLens[{{rr1, 3.3077}, {rr2, 13.8223}, 1.9625, -22.1426, 1.2787, \
Infinity, {rr6, -1.7291}, {rr7, 2.7243}, {rr8, -2.2955}, 6.573, -8.8951}, \
{3.2, 3.2, 2.56, 2.56, 1.5, 1.26, 1.6, 2.36, 2.36, 3., 3.}, {0.42, 0.023, \
0.605, 0.283, 0.38, 0.491, 0.201, 0.672, 0.286, 0.394}, {SK16, \
IntrinsicMedium, SK16, LF5, IntrinsicMedium, IntrinsicMedium, LF5, SK4, \
IntrinsicMedium, SK16}], 2.], Move[Screen[5], {sx1, 8.538}, SymbolicValues -> \
{sx1 -> 8.538}]}"; Print[
           InputForm[
            StringJoin["SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "LightAngle", "LightAngle2", "lighty", "rr1", "rr2", "rr6", 
                 "rr7", "rr8", 
                 "sx1"}, {$CellContext`LightAngle$$, \
$CellContext`LightAngle2$$, $CellContext`lighty$$, $CellContext`rr1$$, \
$CellContext`rr2$$, $CellContext`rr6$$, $CellContext`rr7$$, \
$CellContext`rr8$$, $CellContext`sx1$$}}]]]]], ImageSize -> 
         Automatic], {{$CellContext`xLightAngle$$, 0.21345000000000003`}, 
         ControlType -> None}, {{$CellContext`yLightAngle$$, 0.}, ControlType -> 
         None}, {{$CellContext`radiusLightAngle$$, 0.21345000000000003`}, 
         ControlType -> 
         None}, {{$CellContext`xoffLightAngle$$, 0.21345000000000003`}, 
         ControlType -> None}, {{$CellContext`yoffLightAngle$$, 0.}, 
         ControlType -> 
         None}, {{$CellContext`laststartposLightAngle$$, {0, 0.}}, 
         ControlType -> 
         None}, {{$CellContext`lastlocposLightAngle$$, {0.21345000000000003`, 
          0.}}, ControlType -> None}, {{$CellContext`lastLightAngle$$, 0}, 
         ControlType -> 
         None}, {{$CellContext`xLightAngle2$$, 0.2126377583076831}, 
         ControlType -> 
         None}, {{$CellContext`yLightAngle2$$, 1.0186033932894876`}, 
         ControlType -> 
         None}, {{$CellContext`radiusLightAngle2$$, 0.21345000000000003`}, 
         ControlType -> 
         None}, {{$CellContext`xoffLightAngle2$$, 0.2126377583076831}, 
         ControlType -> 
         None}, {{$CellContext`yoffLightAngle2$$, 0.018603393289487638`}, 
         ControlType -> 
         None}, {{$CellContext`laststartposLightAngle2$$, {0, 1}}, 
         ControlType -> 
         None}, {{$CellContext`lastlocposLightAngle2$$, {0.2126377583076831, 
          1.0186033932894876`}}, ControlType -> 
         None}, {{$CellContext`lastLightAngle2$$, 0}, ControlType -> 
         None}, {{$CellContext`rayresults$$, {{1.}}}, ControlType -> 
         None}, {{$CellContext`oldwavelengths121142012213105118381628$$, {
          1.}}, ControlType -> None}, {{$CellContext`wavelengths$$, {1.}}, 
         ControlType -> None}, {{$CellContext`unionwavelengths$$, {1.}}, 
         ControlType -> None}, {{$CellContext`wavelengthpositions$$, {1.}}, 
         ControlType -> None}, {{$CellContext`raycolors$$, {{1., 1., 1.}}}, 
         ControlType -> None}, {{$CellContext`raycolormodel$$, RGBColor[
           
           Abs[(-0.3183098861837907) 
             ArcTan[63.75 - 0.25 Abs[-500. + 2. Mod[100. + 500. #, 500.]]] + 
            0.3183098861837907 
             ArcTan[43. - 0.1 Abs[-500. + 2. Mod[100. + 500. #, 500.]]]], 
           Abs[
           0.3183098861837907 
             ArcTan[60. - 0.2 Abs[-500. + 2. Mod[100. + 500. #, 500.]]] - 
            0.3183098861837907 
            ArcTan[18. - 0.1 Abs[-500. + 2. Mod[100. + 500. #, 500.]]]], 
           
           Abs[(-0.3183098861837907) 
             ArcTan[10. - 0.2 Abs[-500. + 2. Mod[100. + 500. #, 500.]]] + 
            0.3183098861837907 
             ArcTan[22.5 - 0.125 
               Abs[-500. + 2. Mod[100. + 500. #, 500.]]]]]& }, ControlType -> 
         None}, {{$CellContext`staticpolygons1221142012213105118353036$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAcsB2Cs1atAgAGN/2s/qvovcP4asPwrOH8D
mH8LTT0CrIDI26PyX8H5//6DwGc0+V9w/iqI+xzQ3I+TvxpN/Wo086D+gfPX
oLlnA5p7cfhnPyofER5Q/6DJI8JzFVp4Q92PwQcAOh1pDw==
            "]]}}, 
         ControlType -> None}}, 
      "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1, 2, 3, 4, 5, 6, 7, 8, 9}, 
        SynchronousInitialization -> False, SynchronousUpdating -> False, 
        BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{858., {378., 384.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`raytracefunction121142012213105118381495 = 
       Compile[{{$CellContext`LightAngle$$, 
           Blank[Real]}, {$CellContext`LightAngle2$$, 
           Blank[Real]}, {$CellContext`lighty$$, 
           Blank[Real]}, {$CellContext`rr1$$, 
           Blank[Real]}, {$CellContext`rr2$$, 
           Blank[Real]}, {$CellContext`rr6$$, 
           Blank[Real]}, {$CellContext`rr7$$, 
           Blank[Real]}, {$CellContext`rr8$$, 
           Blank[Real]}, {$CellContext`sx1$$, 
           Blank[Real]}}, 
         Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
           Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`activeregion$ = 
           1.; $CellContext`allcreatedamplitudes$ = {{
             0. + 0. I, 0. + 0. I, 0. + 
              0. I}}; $CellContext`allcreatedrays$ = {{
            1.}}; $CellContext`allowzeroraylength$ = 
           True; $CellContext`alternateindex$ = 
           1.; $CellContext`amplitude$ = {
            1. + 0. I, 0. + 0. I, 0. + 0. I}; $CellContext`axismagnitude$ = 
           1.; $CellContext`axismatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}; $CellContext`clonedata$ = {{
            1.}}; $CellContext`clonegenerationnumber$ = 
           1.; $CellContext`cloneinput$ = {1.}; $CellContext`clonenumber$ = 
           1; $CellContext`cloneposition$ = {0., 0., 
            0.}; $CellContext`clonereportedrays$ = {{
            1.}}; $CellContext`clonerotation$ = {{
            1.}}; $CellContext`clonescale$ = 
           1.; $CellContext`clonescalevector$ = {
            1.}; $CellContext`clonesorthistogram$ = {
            1}; $CellContext`clonetraceinput$ = {{
            1.}}; $CellContext`clonetraceoutput$ = {{
            1.}}; $CellContext`closestdistances$ = {
            1.}; $CellContext`closestposition$ = 
           0; $CellContext`closestpositions$ = {
            0}; $CellContext`closestraylength$ = 
           1.; $CellContext`completedray$ = {
            1.}; $CellContext`componentnumber$ = -1.; $CellContext`cosangle$ = 
           1.; $CellContext`crossmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}; $CellContext`deflecteddummyrayspresent$ = 
           False; $CellContext`deflectedlocalrays$ = {{
            1.}}; $CellContext`deflectedrays$ = {{
            1.}}; $CellContext`deflectedrayspresent$ = 
           False; $CellContext`dummymatrix$ = {{
            1.}}; $CellContext`dummymatrixlist$ = {{{
            1.}}}; $CellContext`dummyvector$ = {1.}; $CellContext`frontid$ = 
           1.; $CellContext`generationlimit$ = 
           200.; $CellContext`generationnumber$ = 
           1.; $CellContext`holeintersections$ = {{-1., 0., 
            0.}}; $CellContext`holeQ$ = 
           False; $CellContext`holeQlist$ = {0}; $CellContext`hor$ = 
           1. + 0. I; $CellContext`index$ = 1.; $CellContext`index1$ = 
           1.; $CellContext`index2$ = 
           1.; $CellContext`inrays$ = {{1.}}; $CellContext`intensity$ = 
           1.; $CellContext`intensityscale$ = 
           1.; $CellContext`intersectionnumber$ = 
           1.; $CellContext`intersections$ = {{-1., 0., 
            0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
            0.}}}; $CellContext`intersectionspresent$ = 
           False; $CellContext`localdummyoutrayspresent$ = 
           False; $CellContext`localoutrays$ = {{
            1.}}; $CellContext`localoutrayspresent$ = 
           False; $CellContext`magnitude$ = 
           1.; $CellContext`maxclonegenerationnumber$ = 
           1.; $CellContext`maximumposition$ = 
           1; $CellContext`minimumraylength$ = 
           0.0001; $CellContext`minresonateraylength$ = 1.; $CellContext`n12$ = 
           1.; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newdeflectedrays$ = {{1.}}; $CellContext`newdistance$ = 
           1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`nonintersectingrays$ = {{
            1.}}; $CellContext`normalizedpolarization$ = {1., 
            1.}; $CellContext`oldgenerationnumber$ = 
           1.; $CellContext`opticallength$ = 
           1.; $CellContext`originalray$ = {
            1.}; $CellContext`originalraytilt$ = {
            1.}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 1., 
            0.}, {0., 0., 1.}}; $CellContext`originalsurfnorm$ = {{
            1.}}; $CellContext`outrays$ = {{
            1.}}; $CellContext`parallelamplitude$ = 
           1. + 0. I; $CellContext`PAxis$ = {1., 0., 
            0.}; $CellContext`perpendicularamplitude$ = 
           1. + 0. I; $CellContext`phaseshift$ = 0.; $CellContext`pol1$ = 
           1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
           1.; $CellContext`previoustilt$ = {1., 0., 
            0.}; $CellContext`propagate$ = 
           True; $CellContext`propagatedrays$ = {{1.}}; $CellContext`r1$ = 
           1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 1.; $CellContext`r4$ = 
           1.; $CellContext`r5$ = 1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
           1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
           1.; $CellContext`ray1$ = 1.; $CellContext`ray2$ = 
           1.; $CellContext`ray3$ = 1.; $CellContext`LocRayL$ = 
           1.; $CellContext`rayslot$ = 1.; $CellContext`raysreported$ = 
           False; $CellContext`raytiltx$ = 1.; $CellContext`raytiltz$ = 
           1.; $CellContext`reporteddummyrayspresent$ = 
           False; $CellContext`reportedlocalrays$ = {{
            1.}}; $CellContext`reportedrays$ = {{
            1.}}; $CellContext`reportedrayspresent$ = 
           False; $CellContext`resonateintersections$ = {{-1., 0., 
            0.}}; $CellContext`resonatenumber$ = 
           0; $CellContext`resonateraylength$ = 1.; $CellContext`rex$ = 
           1.; $CellContext`rey$ = 1.; $CellContext`rez$ = 
           1.; $CellContext`rsx$ = 1.; $CellContext`LocRSx$ = 
           1.; $CellContext`rsy$ = 1.; $CellContext`LocRSy$ = 
           1.; $CellContext`rsz$ = 1.; $CellContext`LocRSz$ = 1.; 
          Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
           1.; $CellContext`LocRTz$ = 1.; $CellContext`rx$ = 
           1.; $CellContext`rxhlp$ = 1.; $CellContext`ry$ = 
           1.; $CellContext`ryhlp$ = 1.; $CellContext`rz$ = 
           1.; $CellContext`rzhlp$ = 1.; $CellContext`LocSCx$ = 
           1.; $CellContext`LocSCy$ = 1.; $CellContext`sid$ = 
           1.; $CellContext`sinangle$ = 1.; $CellContext`sno1$ = 
           1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
           1.; $CellContext`sno4$ = 
           1.; $CellContext`surfaceid$ = -1.; $CellContext`surfacenumber$ = \
-1.; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}; $CellContext`surfacetranslationvector$ = {0., 0., 
            0.}; $CellContext`surfnorm$ = {{1.}}; $CellContext`symr1$ = 
           1.; $CellContext`symr2$ = 1.; $CellContext`symr3$ = 
           1.; $CellContext`symr4$ = 1.; $CellContext`symr5$ = 
           1.; $CellContext`symr6$ = 1.; $CellContext`symr7$ = 
           1.; $CellContext`symr8$ = 1.; $CellContext`symr9$ = 
           1.; $CellContext`tempclonedata$ = {{
            1.}}; $CellContext`terminatedeflection$ = 
           False; $CellContext`thresholdintensity$ = 
           1.; $CellContext`tiltmagnitude$ = 
           1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}}; $CellContext`LocTV1$ = 1.; $CellContext`LocTV10$ = 
           1.; $CellContext`LocTV2$ = 1.; $CellContext`LocTV3$ = 
           1.; $CellContext`LocTV4$ = 1.; $CellContext`LocTV5$ = 
           1.; $CellContext`LocTV6$ = 1.; $CellContext`LocTV7$ = 
           1.; $CellContext`LocTV8$ = 1.; $CellContext`LocTV9$ = 
           1.; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
            0.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`ver$ = 0. + 0. I; $CellContext`wavelength$ = 
           1.; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`xunit$ = 
           1.; $CellContext`YAxis$ = {1., 0., 0.}; $CellContext`yunit$ = 
           1.; $CellContext`ZAxis$ = {1., 0., 0.}; $CellContext`zunit$ = 
           1.; $CellContext`propagatedrays$ = 
           Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                 Cos[Degree $CellContext`LightAngle$$], 
                 Sin[Degree $CellContext`LightAngle$$], 0, -
                 Sin[Degree $CellContext`LightAngle$$], 
                 Cos[Degree $CellContext`LightAngle$$], 0, 0, 0, 1}]; 
             Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ \
$CellContext`symr7$, $CellContext`lighty$$ + $CellContext`rsx$ \
$CellContext`symr2$ + $CellContext`rsy$ $CellContext`symr5$ + \
$CellContext`rsz$ $CellContext`symr8$, $CellContext`rsx$ $CellContext`symr3$ + \
$CellContext`rsy$ $CellContext`symr6$ + $CellContext`rsz$ \
$CellContext`symr9$}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$} = {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rex$ $CellContext`symr1$ + \
$CellContext`rey$ $CellContext`symr4$ + $CellContext`rez$ \
$CellContext`symr7$, $CellContext`lighty$$ + $CellContext`rex$ \
$CellContext`symr2$ + $CellContext`rey$ $CellContext`symr5$ + \
$CellContext`rez$ $CellContext`symr8$, $CellContext`rex$ $CellContext`symr3$ + \
$CellContext`rey$ $CellContext`symr6$ + $CellContext`rez$ \
$CellContext`symr9$}; {$CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$} = {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`r1$ $CellContext`symr1$ + \
$CellContext`r2$ $CellContext`symr4$ + $CellContext`r3$ $CellContext`symr7$, \
$CellContext`r1$ $CellContext`symr2$ + $CellContext`r2$ $CellContext`symr5$ + \
$CellContext`r3$ $CellContext`symr8$, $CellContext`r1$ $CellContext`symr3$ + \
$CellContext`r2$ $CellContext`symr6$ + $CellContext`r3$ $CellContext`symr9$}; \
{$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$} = \
{$CellContext`r4$ $CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + \
$CellContext`r6$ $CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + \
$CellContext`r5$ $CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, \
$CellContext`r4$ $CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + \
$CellContext`r6$ $CellContext`symr9$}; {$CellContext`LocTV7$, \
$CellContext`LocTV8$, $CellContext`LocTV9$} = {$CellContext`r7$ \
$CellContext`symr1$ + $CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ \
$CellContext`symr7$, $CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ \
$CellContext`symr5$ + $CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ \
$CellContext`symr3$ + $CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ \
$CellContext`symr9$}; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
{{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}, \
{$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$}, \
{$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$}}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJxTTMoPSmViYGBgBWJ1BgQ4ewYE7uxnQAPYxT/Yo6sjVT4NDJ5B1UU6zJoJ
Aifh+iwz2cQlGHGZQ8h8CGhwue2ATCP0iaDxiXc3uggkfM7gCDd08aEabgxQ
WgSNT7y7ibGXfP2DNdw4oLQIGp94d6OLnIOkKyLFh2q4CUBpETQ+8e5GF4GW
Y0SKD9VwE8FBE+9uGAsADwilNA==
               
               "]], {$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                 Cos[Degree $CellContext`LightAngle2$$], 
                 Sin[Degree $CellContext`LightAngle2$$], 0, -
                 Sin[Degree $CellContext`LightAngle2$$], 
                 Cos[Degree $CellContext`LightAngle2$$], 0, 0, 0, 1}]; 
             Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$,
                   1 + $CellContext`rsx$ $CellContext`symr2$ + \
$CellContext`rsy$ $CellContext`symr5$ + $CellContext`rsz$ \
$CellContext`symr8$, $CellContext`rsx$ $CellContext`symr3$ + \
$CellContext`rsy$ $CellContext`symr6$ + $CellContext`rsz$ \
$CellContext`symr9$}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$} = {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rex$ $CellContext`symr1$ + \
$CellContext`rey$ $CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$,
                   1 + $CellContext`rex$ $CellContext`symr2$ + \
$CellContext`rey$ $CellContext`symr5$ + $CellContext`rez$ \
$CellContext`symr8$, $CellContext`rex$ $CellContext`symr3$ + \
$CellContext`rey$ $CellContext`symr6$ + $CellContext`rez$ \
$CellContext`symr9$}; {$CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$} = {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`r1$ $CellContext`symr1$ + \
$CellContext`r2$ $CellContext`symr4$ + $CellContext`r3$ $CellContext`symr7$, \
$CellContext`r1$ $CellContext`symr2$ + $CellContext`r2$ $CellContext`symr5$ + \
$CellContext`r3$ $CellContext`symr8$, $CellContext`r1$ $CellContext`symr3$ + \
$CellContext`r2$ $CellContext`symr6$ + $CellContext`r3$ $CellContext`symr9$}; \
{$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$} = \
{$CellContext`r4$ $CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + \
$CellContext`r6$ $CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + \
$CellContext`r5$ $CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, \
$CellContext`r4$ $CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + \
$CellContext`r6$ $CellContext`symr9$}; {$CellContext`LocTV7$, \
$CellContext`LocTV8$, $CellContext`LocTV9$} = {$CellContext`r7$ \
$CellContext`symr1$ + $CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ \
$CellContext`symr7$, $CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ \
$CellContext`symr5$ + $CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ \
$CellContext`symr3$ + $CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ \
$CellContext`symr9$}; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
{{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}, \
{$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$}, \
{$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$}}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJxTTMoPSmViYGBgBWJ1BgQ4ewYE7uxnQAPYxT/Yo6sjVX7WTBC4CVUX6QDh
n4Tre8qdoC/PiMscQuZDgdttBxQark8EjU+8u9FFIOFzBke4oYsP1XBjgNIi
aHzi3U2UvWTrH6zhxgGlRdD4xLsbXeQcJF0RKT5Uw00ASoug8Yl3N7oItBwj
UnyohpsIDpp4d8NYAINHqek=
               "]]]; $CellContext`propagatedrays$ = 
           Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
              1.; $CellContext`frontid$ = 
              1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
           200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
           0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

             "]; $CellContext`deflectedrayspresent$ = 
            True; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = True; While[
             And[$CellContext`deflectedrayspresent$, $CellContext`propagate$],
              AddTo[$CellContext`generationnumber$, 
               1.]; ($CellContext`deflecteddummyrayspresent$ = 
               False; $CellContext`deflectedrayspresent$ = 
               False; $CellContext`reportedrayspresent$ = 
               False; $CellContext`reporteddummyrayspresent$ = 
               True; $CellContext`localdummyoutrayspresent$ = 
               False; $CellContext`localoutrayspresent$ = 
               False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
               Map[Flatten[#, 1]& , 
                 Transpose[
                  
                  Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -2. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`rr1$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`rr1$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    2.5600000000000005`, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`rr1$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`rr1$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`rr1$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    2.5600000000000005`, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`rr1$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`rr1$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`rr1$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 28328.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -2.42 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`rr2$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`rr2$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    2.5600000000000005`, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`rr2$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`rr2$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`rr2$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    2.5600000000000005`, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`rr2$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`rr2$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`rr2$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 28329.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -2.443 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$2439, Compile`$2473, Compile`$2474}, 
                    
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - 1.9625 $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 2 $CellContext`rx$ 1.9625; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = (
                    Compile`$2439 = Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3; {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - 
                    Compile`$2439 $CellContext`yunit$, $CellContext`rz$ - 
                    Compile`$2439 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    1.6384, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-1.9625 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[3.8514062499999997` - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = (Compile`$2473 = -Optica`Optica`TempVar2; 
                    Compile`$2474 = Compile`$2473 + Optica`Optica`TempVar3; {
                    Compile`$2474, $CellContext`ry$ + 
                    Compile`$2474 $CellContext`yunit$, $CellContext`rz$ + 
                    Compile`$2474 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    1.6384, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-1.9625 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[3.8514062499999997` - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 28351.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -3.048 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$2441, Compile`$2476, Compile`$2477}, 
                    
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - (-22.1426) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 2 $CellContext`rx$ (-22.1426); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = (
                    Compile`$2441 = Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3; {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - 
                    Compile`$2441 $CellContext`yunit$, $CellContext`rz$ - 
                    Compile`$2441 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    1.6384, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[22.1426 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ - 
                    Sqrt[490.2947347600001 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = (Compile`$2476 = -Optica`Optica`TempVar2; 
                    Compile`$2477 = Compile`$2476 + Optica`Optica`TempVar3; {
                    Compile`$2477, $CellContext`ry$ + 
                    Compile`$2477 $CellContext`yunit$, $CellContext`rz$ + 
                    Compile`$2477 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    1.6384, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[22.1426 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ - 
                    Sqrt[490.2947347600001 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 28352.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -3.331 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$2454, Compile`$2479, Compile`$2480}, 
                    
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - 1.2787 $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 2 $CellContext`rx$ 1.2787; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = (
                    Compile`$2454 = Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3; {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - 
                    Compile`$2454 $CellContext`yunit$, $CellContext`rz$ - 
                    Compile`$2454 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.5625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-1.2787 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[1.6350736899999998` - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = (Compile`$2479 = -Optica`Optica`TempVar2; 
                    Compile`$2480 = Compile`$2479 + Optica`Optica`TempVar3; {
                    Compile`$2480, $CellContext`ry$ + 
                    Compile`$2480 $CellContext`yunit$, $CellContext`rz$ + 
                    Compile`$2480 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.5625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-1.2787 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[1.6350736899999998` - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 28353.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -3.711 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2242}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 
                    0.62015625], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2242 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2242), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2242, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2242}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 28150.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; $CellContext`intersections$ = Union[
                    Map[
                    If[Part[#, 2]^2 + Part[#, 3]^2 <= 
                    0.39690000000000003`, $CellContext`holeQ$ = True; {-1., 
                    0., 0.}, #]& , $CellContext`unfilteredintersections$]]; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -4.202 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`rr6$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`rr6$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.6400000000000001, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`rr6$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`rr6$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`rr6$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.6400000000000001, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`rr6$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`rr6$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`rr6$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 28375.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
-4.4030000000000005` + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`rr7$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`rr7$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    1.3923999999999999`, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`rr7$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`rr7$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`rr7$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    1.3923999999999999`, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`rr7$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`rr7$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`rr7$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 28376.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5.075 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`rr8$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`rr8$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    1.3923999999999999`, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`rr8$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`rr8$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`rr8$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    1.3923999999999999`, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`rr8$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`rr8$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`rr8$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 28377.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
-5.361000000000001 + $CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$2478, Compile`$2655, Compile`$2656}, 
                    
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - 6.573 $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 2 $CellContext`rx$ 6.573; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = (
                    Compile`$2478 = Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3; {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - 
                    Compile`$2478 $CellContext`yunit$, $CellContext`rz$ - 
                    Compile`$2478 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    2.25, Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-6.573 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[43.20432900000001 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = (Compile`$2655 = -Optica`Optica`TempVar2; 
                    Compile`$2656 = Compile`$2655 + Optica`Optica`TempVar3; {
                    Compile`$2656, $CellContext`ry$ + 
                    Compile`$2656 $CellContext`yunit$, $CellContext`rz$ + 
                    Compile`$2656 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    2.25, Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-6.573 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[43.20432900000001 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 28396.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
-5.755000000000001 + $CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$2483, Compile`$2658, Compile`$2660}, 
                    
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - (-8.8951) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 2 $CellContext`rx$ (-8.8951); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = (
                    Compile`$2483 = Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3; {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - 
                    Compile`$2483 $CellContext`yunit$, $CellContext`rz$ - 
                    Compile`$2483 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    2.25, Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[8.8951 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ - 
                    Sqrt[79.12280400999998 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = (Compile`$2658 = -Optica`Optica`TempVar2; 
                    Compile`$2660 = Compile`$2658 + Optica`Optica`TempVar3; {
                    Compile`$2660, $CellContext`ry$ + 
                    Compile`$2660 $CellContext`yunit$, $CellContext`rz$ + 
                    Compile`$2660 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    2.25, Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[8.8951 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ - 
                    Sqrt[79.12280400999998 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 28397.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -2. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    28328.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 1., 
                    28328.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    2. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`rr1$$] \
$CellContext`ray2$)/($CellContext`rr1$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`rr1$$] \
$CellContext`ray3$)/($CellContext`rr1$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`rr1$$] \
$CellContext`ray2$)/($CellContext`rr1$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`rr1$$] \
$CellContext`ray3$)/($CellContext`rr1$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    2., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    92.7508526)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 92.7508526)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    92.7508526)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[
                    1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -2.42 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    28329.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 2., 
                    28329.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    2.42 + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`rr2$$] \
$CellContext`ray2$)/($CellContext`rr2$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`rr2$$] \
$CellContext`ray3$)/($CellContext`rr2$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`rr2$$] \
$CellContext`ray2$)/($CellContext`rr2$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`rr2$$] \
$CellContext`ray3$)/($CellContext`rr2$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    2.42, 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    92.7508526)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 92.7508526)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    92.7508526)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[
                    1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -2.443 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    28351.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 3., 
                    28351.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    2.443 + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -($CellContext`ray2$/(
                    3.8514062499999997` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1))), -($CellContext`ray3$/(
                    3.8514062499999997` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)))}, {$CellContext`ray2$/(
                    3.8514062499999997` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 1., 
                    0.}, {$CellContext`ray3$/(
                    3.8514062499999997` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    2.443, 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    92.7508526)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 92.7508526)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    92.7508526)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[
                    1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -3.048 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    28352.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 4., 
                    28352.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    3.048 + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -(-$CellContext`ray2$/(
                    490.2947347600001 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1))), -(-$CellContext`ray3$/(
                    490.2947347600001 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)))}, {-$CellContext`ray2$/(
                    490.2947347600001 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 1., 
                    0.}, {-$CellContext`ray3$/(
                    490.2947347600001 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    3.048, 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.280356279999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0092985442) + (
                    0.163505973 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0449135769) + (
                    0.8939301119999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    110.493685)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 92.7508526)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    92.7508526)]], $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    92.7508526)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.280356279999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0092985442) + (
                    0.163505973 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0449135769) + (
                    0.8939301119999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 110.493685)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.280356279999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0092985442) + (
                    0.163505973 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0449135769) + (
                    0.8939301119999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    110.493685)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[
                    1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -3.331 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    28353.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 5., 
                    28353.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    3.331 + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -($CellContext`ray2$/(
                    1.6350736899999998` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1))), -($CellContext`ray3$/(
                    1.6350736899999998` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)))}, {$CellContext`ray2$/(
                    1.6350736899999998` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 1., 
                    0.}, {$CellContext`ray3$/(
                    1.6350736899999998` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    3.331, 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.280356279999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0092985442) + (
                    0.163505973 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0449135769) + (
                    0.8939301119999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    110.493685)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.280356279999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0092985442) + (
                    0.163505973 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0449135769) + (
                    0.8939301119999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 110.493685)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.280356279999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0092985442) + (
                    0.163505973 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0449135769) + (
                    0.8939301119999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    110.493685)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[
                    1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -3.711 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    28150.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 6., 
                    28150.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    3.711 + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    3.711, 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    7, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -4.202 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 7., 
                    
                    28375.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 7., 
                    28375.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    4.202 + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`rr6$$] \
$CellContext`ray2$)/($CellContext`rr6$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`rr6$$] \
$CellContext`ray3$)/($CellContext`rr6$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`rr6$$] \
$CellContext`ray2$)/($CellContext`rr6$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`rr6$$] \
$CellContext`ray3$)/($CellContext`rr6$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    4.202, 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.280356279999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0092985442) + (
                    0.163505973 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0449135769) + (
                    0.8939301119999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    110.493685)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.280356279999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0092985442) + (0.163505973 $CellContext`wavelength$^2)/(
                    $CellContext`wavelength$^2 - 
                    0.0449135769) + (
                    0.8939301119999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 110.493685)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.280356279999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0092985442) + (
                    0.163505973 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0449135769) + (
                    0.8939301119999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    110.493685)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[
                    1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    8, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
-4.4030000000000005` + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 8., 
                    28376.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 8., 
                    28376.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    4.4030000000000005` + $CellContext`rxhlp$; \
$CellContext`rey$ = $CellContext`ryhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`rr7$$] \
$CellContext`ray2$)/($CellContext`rr7$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`rr7$$] \
$CellContext`ray3$)/($CellContext`rr7$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`rr7$$] \
$CellContext`ray2$)/($CellContext`rr7$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`rr7$$] \
$CellContext`ray3$)/($CellContext`rr7$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    4.4030000000000005`, 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.393888339999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007691473599999999) + (
                    0.1645107209999998 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02719462269999999) + (
                    0.963522479 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    99.2757639)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.280356279999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0092985442) + (
                    0.163505973 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0449135769) + (
                    
                    0.8939301119999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 110.493685)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.280356279999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0092985442) + (
                    0.163505973 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0449135769) + (
                    0.8939301119999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    110.493685)]], $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.280356279999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0092985442) + (
                    0.163505973 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0449135769) + (
                    0.8939301119999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    110.493685)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.393888339999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007691473599999999) + (
                    0.1645107209999998 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02719462269999999) + (
                    0.963522479 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 99.2757639)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.393888339999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007691473599999999) + (
                    0.1645107209999998 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02719462269999999) + (
                    0.963522479 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    99.2757639)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[
                    1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    9, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5.075 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 9., 
                    28377.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 9., 
                    28377.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5.075 + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`rr8$$] \
$CellContext`ray2$)/($CellContext`rr8$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`rr8$$] \
$CellContext`ray3$)/($CellContext`rr8$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`rr8$$] \
$CellContext`ray2$)/($CellContext`rr8$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`rr8$$] \
$CellContext`ray3$)/($CellContext`rr8$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    5.075, 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.393888339999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007691473599999999) + (
                    0.1645107209999998 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02719462269999999) + (
                    0.963522479 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    99.2757639)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.393888339999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007691473599999999) + (
                    0.1645107209999998 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02719462269999999) + (
                    0.963522479 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 99.2757639)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.393888339999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007691473599999999) + (
                    0.1645107209999998 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02719462269999999) + (
                    0.963522479 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    99.2757639)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[
                    1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    10, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
-5.361000000000001 + $CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 10., 
                    28396.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 10., 
                    28396.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5.361000000000001 + $CellContext`rxhlp$; \
$CellContext`rey$ = $CellContext`ryhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -($CellContext`ray2$/(
                    43.20432900000001 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1))), -($CellContext`ray3$/(
                    43.20432900000001 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)))}, {$CellContext`ray2$/(
                    
                    43.20432900000001 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 1., 
                    0.}, {$CellContext`ray3$/(
                    43.20432900000001 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    5.361000000000001, 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    92.7508526)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 92.7508526)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    92.7508526)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[
                    1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    11, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
-5.755000000000001 + $CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 11., 
                    28397.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 11., 
                    28397.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5.755000000000001 + $CellContext`rxhlp$; \
$CellContext`rey$ = $CellContext`ryhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -(-$CellContext`ray2$/(
                    79.12280400999998 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1))), -(-$CellContext`ray3$/(
                    79.12280400999998 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)))}, {-$CellContext`ray2$/(
                    79.12280400999998 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 1., 
                    0.}, {-$CellContext`ray3$/(
                    79.12280400999998 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    5.755000000000001, 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    92.7508526)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 92.7508526)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.34317774 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.007046873399999999) + (
                    0.2411443989999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02290049999999999) + (
                    0.994317969 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    92.7508526)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[
                    1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                
                And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                 1., 1.]; 
              If[$CellContext`localoutrayspresent$, 
                If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                   Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 1.,
                   1.]; $CellContext`outrays$ = 
                 Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1., 
                1.]; If[
                
                And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                 Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                1., 1.]); 
             If[$CellContext`reportedrayspresent$, $CellContext`raysreported$ = 
                True; $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
            If[Length[$CellContext`outrays$] > 1, 
              Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
             
             And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
              Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); (
           AddTo[$CellContext`generationnumber$, 
             1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
               0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
             False; $CellContext`reportedrayspresent$ = 
             False; $CellContext`deflecteddummyrayspresent$ = 
             False; $CellContext`reporteddummyrayspresent$ = 
             False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
               
               Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                  Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                  Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                  Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                   Re[$CellContext`sx1$$]; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                  Chop[$CellContext`rx$]; $CellContext`ry$ = 
                  Chop[$CellContext`ry$]; $CellContext`rz$ = 
                  Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                  False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                   True; ($CellContext`intersections$ = Block[{Compile`$2418}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 6.25], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2418 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2418), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2418, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2418}]}, {{-1., 0., 0.}}]]; 
                   AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 28453.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                   Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                   If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                  If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    28453.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 1., 
                    28453.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ + 
                    Re[$CellContext`sx1$$]; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`sx1$$], 0., 
                    0.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                   True; $CellContext`deflecteddummyrayspresent$ = 
                   True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                   "]])& , $CellContext`propagatedrays$]]; If[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
               Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
              1., 1.]; If[
              
              And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
               Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
              1., 1.]); (
            If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
               Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                 
                 "], $CellContext`reportedlocalrays$]; 1., 
              1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); 
          If[Length[$CellContext`reportedrays$] > 
            2, $CellContext`reportedrays$ = 
            Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
          Map[{
             Part[#, 16], 
             Part[#, 1], 
             Part[#, 2], 
             Part[#, 3], 
             Part[#, 4], 
             Part[#, 5], 
             Part[#, 6]}& , $CellContext`reportedrays$]], {
         CompilationTarget -> "MVM", RuntimeAttributes -> {Listable}, 
          Parallelization -> False, 
          RuntimeOptions -> {}}]; \
$CellContext`polygons1121142012213105118342190 = 
       Compile[{$CellContext`rr1, $CellContext`rr2, $CellContext`rr6, \
$CellContext`rr7, $CellContext`rr8}, {{
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.6}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.6}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.3333333333333335`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.3333333333333335`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.6}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.3333333333333335`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.3333333333333335`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.1377777777777773` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.0666666666666664`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777782` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.0666666666666669`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.3333333333333335`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777782` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.0666666666666669`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.1377777777777782` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.0666666666666669`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.6400000000000005 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.8000000000000003}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.8}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777782` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.0666666666666669`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.8}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.6400000000000005 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.8000000000000003}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.5333333333333332}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.5333333333333334}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.8}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.5333333333333334}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.2844444444444448 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.5333333333333337}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.26666666666666683`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.26666666666666683`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.5333333333333334}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.26666666666666683`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.26666666666666683`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-3.839385043614356*^-32 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-4.930380657631324*^-32 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -2.220446049250313*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.26666666666666683`}, {
          2. + $CellContext`rr1 - 1. Sqrt[0. + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-3.839385043614356*^-32 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.07111111111111108 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.2666666666666666}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.26666666666666683`}, {
          2. + $CellContext`rr1 - 1. Sqrt[0. + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.07111111111111096 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.2666666666666664}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.07111111111111096 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.2666666666666664}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.28444444444444406` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.533333333333333}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.5333333333333332}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.07111111111111096 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.2666666666666664}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.5333333333333332}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.5333333333333332}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.6399999999999997 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.7999999999999998}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6400000000000005 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.8000000000000003}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.5333333333333332}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6400000000000005 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.8000000000000003}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.8}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.1377777777777778` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.0666666666666667`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777782` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.0666666666666669`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6400000000000005 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.8000000000000003}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777773` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.0666666666666664`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.1377777777777773` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.0666666666666664`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.777777777777777 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.333333333333333}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.3333333333333335`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777773` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.0666666666666664`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.3333333333333335`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.7777777777777777` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.3333333333333333`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5599999999999996` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.5999999999999999`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.6}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.3333333333333335`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.9594348786357652`*^-16}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.7961486387494515`*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.6328623988631376`*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.6328623988631376`*^-17}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.7961486387494515`*^-16}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.1377777777777773` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.6328623988631375`*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777782` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 3.265724797726275*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.6328623988631376`*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777782` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 3.265724797726275*^-17}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.1377777777777782` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.6328623988631378`*^-16}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.6400000000000005 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.469576158976824*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 4.898587196589413*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777782` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 3.265724797726275*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 4.898587196589413*^-17}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.6400000000000005 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.469576158976824*^-16}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.30628991909051*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 6.53144959545255*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 4.898587196589413*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 6.53144959545255*^-17}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.2844444444444448 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.3062899190905103`*^-16}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.1430036792041966`*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 8.164311994315688*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 6.53144959545255*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 8.164311994315688*^-17}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.1430036792041966`*^-16}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-9.59846260903589*^-33 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 9.797174393178826*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-5.890226918534913*^-32 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 9.797174393178825*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 8.164311994315688*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-9.59846260903589*^-33 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 9.797174393178826*^-17}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-9.59846260903589*^-33 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 9.797174393178826*^-17}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.07111111111111108 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 8.164311994315689*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.1430036792041966`*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-9.59846260903589*^-33 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 9.797174393178826*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.07111111111111096 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.143003679204196*^-16}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.07111111111111096 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 8.16431199431569*^-17}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.28444444444444406` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 6.531449595452553*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.30628991909051*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.07111111111111096 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.143003679204196*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.30628991909051*^-16}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 6.531449595452552*^-17}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.6399999999999997 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 4.898587196589414*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6400000000000005 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.469576158976824*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.30628991909051*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6400000000000005 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.469576158976824*^-16}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 4.898587196589413*^-17}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.1377777777777778` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 3.265724797726276*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777782` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.6328623988631378`*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6400000000000005 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.469576158976824*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777773` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.6328623988631375`*^-16}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.1377777777777773` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 3.2657247977262764`*^-17}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.777777777777777 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.6328623988631394`*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.7961486387494515`*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777773` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.6328623988631375`*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.7961486387494515`*^-16}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.7777777777777777` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.6328623988631382`*^-17}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5599999999999996` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 8.157786440681347*^-33}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.9594348786357652`*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.7961486387494515`*^-16}, {
          2.9178823575931885`, -1.28}, {3.0109724820688584`, -1.28}, {
          3.022293022805492, -1.0666666666666667`}, {
          2.7581905353813383`, -1.0666666666666667`}, {
          2.9178823575931885`, -1.28}, {
          2.7581905353813383`, -1.0666666666666667`}, {
          3.022293022805492, -1.0666666666666667`}, {
          3.031550975310239, -0.8533333333333333}, {
          2.6382341817875212`, -0.8533333333333334}, {
          2.7581905353813383`, -1.0666666666666667`}, {
          2.6382341817875212`, -0.8533333333333334}, {
          3.031550975310239, -0.8533333333333333}, {
          3.0387489278057522`, -0.6399999999999999}, {
          2.550289432436307, -0.64}, {
          2.6382341817875212`, -0.8533333333333334}, {
          2.550289432436307, -0.64}, {
          3.0387489278057522`, -0.6399999999999999}, {
          3.043888889613843, -0.4266666666666665}, {
          2.489942168569282, -0.42666666666666675`}, {
          2.550289432436307, -0.64}, {
          2.489942168569282, -0.42666666666666675`}, {
          3.043888889613843, -0.42666666666666697`}, {
          3.046972293965233, -0.21333333333333337`}, {
          2.4546296458019334`, -0.21333333333333337`}, {
          2.489942168569282, -0.42666666666666675`}, {
          2.4546296458019334`, -0.21333333333333337`}, {
          3.046972293965233, -0.21333333333333337`}, {3.0479999999999983`, 
          0.}, {2.4429999999999996`, -2.220446049250313*^-16}, {
          2.4546296458019334`, -0.21333333333333337`}, {2.4429999999999996`, 
          0.}, {3.0479999999999983`, 0.}, {3.046972293965233, 
          0.21333333333333337`}, {2.4546296458019334`, 
          0.21333333333333337`}, {2.4429999999999996`, 0.}, {
          2.4546296458019334`, 0.21333333333333315`}, {3.046972293965233, 
          0.21333333333333315`}, {3.043888889613843, 0.4266666666666664}, {
          2.4899421685692817`, 0.4266666666666665}, {2.4546296458019334`, 
          0.21333333333333315`}, {2.4899421685692817`, 0.4266666666666665}, {
          3.043888889613843, 0.4266666666666665}, {3.0387489278057522`, 
          0.6399999999999999}, {2.5502894324363066`, 0.6399999999999999}, {
          2.4899421685692817`, 0.4266666666666665}, {2.5502894324363066`, 
          0.6399999999999999}, {3.0387489278057522`, 0.64}, {
          3.031550975310239, 0.8533333333333333}, {2.6382341817875212`, 
          0.8533333333333333}, {2.5502894324363066`, 0.6399999999999999}, {
          2.6382341817875212`, 0.8533333333333333}, {3.031550975310239, 
          0.8533333333333332}, {3.022293022805492, 1.0666666666666664`}, {
          2.7581905353813383`, 1.0666666666666667`}, {2.6382341817875212`, 
          0.8533333333333333}, {2.7581905353813383`, 1.0666666666666667`}, {
          3.022293022805492, 1.0666666666666667`}, {3.0109724820688584`, 
          1.28}, {2.9178823575931885`, 1.28}, {2.7581905353813383`, 
          1.0666666666666667`}, {2.9178823575931885`, 0.}, {
          3.0109724820688584`, 1.567547902908612*^-16}, {3.022293022805492, 
          1.4369189109995612`*^-16}, {2.7581905353813383`, 
          1.30628991909051*^-17}, {2.9178823575931885`, 0.}, {
          2.7581905353813383`, 1.30628991909051*^-17}, {3.022293022805492, 
          1.4369189109995612`*^-16}, {3.031550975310239, 
          1.30628991909051*^-16}, {2.6382341817875212`, 
          2.61257983818102*^-17}, {2.7581905353813383`, 
          1.30628991909051*^-17}, {2.6382341817875212`, 
          2.61257983818102*^-17}, {3.031550975310239, 
          1.30628991909051*^-16}, {3.0387489278057522`, 
          1.175660927181459*^-16}, {2.550289432436307, 
          3.91886975727153*^-17}, {2.6382341817875212`, 
          2.61257983818102*^-17}, {2.550289432436307, 
          3.91886975727153*^-17}, {3.0387489278057522`, 
          1.175660927181459*^-16}, {3.043888889613843, 
          1.045031935272408*^-16}, {2.489942168569282, 
          5.22515967636204*^-17}, {2.550289432436307, 
          3.91886975727153*^-17}, {2.489942168569282, 
          5.22515967636204*^-17}, {3.043888889613843, 
          1.0450319352724083`*^-16}, {3.046972293965233, 
          9.14402943363357*^-17}, {2.4546296458019334`, 
          6.53144959545255*^-17}, {2.489942168569282, 
          5.22515967636204*^-17}, {2.4546296458019334`, 
          6.53144959545255*^-17}, {3.046972293965233, 
          9.14402943363357*^-17}, {3.0479999999999983`, 
          7.83773951454306*^-17}, {2.4429999999999996`, 
          7.837739514543059*^-17}, {2.4546296458019334`, 
          6.53144959545255*^-17}, {2.4429999999999996`, 
          7.83773951454306*^-17}, {3.0479999999999983`, 
          7.83773951454306*^-17}, {3.046972293965233, 
          6.53144959545255*^-17}, {2.4546296458019334`, 
          9.14402943363357*^-17}, {2.4429999999999996`, 
          7.83773951454306*^-17}, {2.4546296458019334`, 
          9.144029433633569*^-17}, {3.046972293965233, 
          6.531449595452552*^-17}, {3.043888889613843, 
          5.225159676362042*^-17}, {2.4899421685692817`, 
          1.045031935272408*^-16}, {2.4546296458019334`, 
          9.144029433633569*^-17}, {2.4899421685692817`, 
          1.045031935272408*^-16}, {3.043888889613843, 
          5.2251596763620415`*^-17}, {3.0387489278057522`, 
          3.918869757271531*^-17}, {2.5502894324363066`, 
          1.175660927181459*^-16}, {2.4899421685692817`, 
          1.045031935272408*^-16}, {2.5502894324363066`, 
          1.175660927181459*^-16}, {3.0387489278057522`, 
          3.91886975727153*^-17}, {3.031550975310239, 
          2.6125798381810208`*^-17}, {2.6382341817875212`, 
          1.30628991909051*^-16}, {2.5502894324363066`, 
          1.175660927181459*^-16}, {2.6382341817875212`, 
          1.30628991909051*^-16}, {3.031550975310239, 
          2.6125798381810214`*^-17}, {3.022293022805492, 
          1.3062899190905113`*^-17}, {2.7581905353813383`, 
          1.4369189109995612`*^-16}, {2.6382341817875212`, 
          1.30628991909051*^-16}, {2.7581905353813383`, 
          1.4369189109995612`*^-16}, {3.022293022805492, 
          1.3062899190905107`*^-17}, {3.0109724820688584`, 
          6.526229152545076*^-33}, {2.9178823575931885`, 
          1.567547902908612*^-16}, {2.7581905353813383`, 
          1.4369189109995612`*^-16}, {3.0109724820688584`, -1.28}, {
          3.574048663883448, -0.75}, {3.494151395052641, -0.625}, {
          3.022293022805492, -1.0666666666666667`}, {
          3.0109724820688584`, -1.28}, {
          3.022293022805492, -1.0666666666666667`}, {
          3.494151395052641, -0.625}, {3.4328084629414652`, -0.5}, {
          3.031550975310239, -0.8533333333333334}, {
          3.022293022805492, -1.0666666666666667`}, {
          3.031550975310239, -0.8533333333333334}, {
          3.4328084629414652`, -0.5}, {3.3872235421489707`, -0.375}, {
          3.0387489278057522`, -0.64}, {
          3.031550975310239, -0.8533333333333334}, {
          3.0387489278057522`, -0.64}, {3.3872235421489707`, -0.375}, {
          3.3556769978186205`, -0.25}, {
          3.043888889613843, -0.42666666666666675`}, {
          3.0387489278057522`, -0.64}, {
          3.043888889613843, -0.42666666666666675`}, {
          3.3556769978186205`, -0.25}, {3.337124387315237, -0.125}, {
          3.046972293965233, -0.21333333333333337`}, {
          3.043888889613843, -0.42666666666666675`}, {
          3.046972293965233, -0.21333333333333337`}, {
          3.337124387315237, -0.125}, {3.3310000000000004`, 0.}, {
          3.0479999999999983`, -2.220446049250313*^-16}, {
          3.046972293965233, -0.21333333333333337`}, {3.0479999999999983`, 
          0.}, {3.3310000000000004`, 0.}, {3.337124387315237, 0.125}, {
          3.046972293965233, 0.21333333333333337`}, {3.0479999999999983`, 
          0.}, {3.046972293965233, 0.21333333333333315`}, {3.337124387315237, 
          0.12499999999999989`}, {3.3556769978186205`, 0.2499999999999999}, {
          3.043888889613843, 0.4266666666666665}, {3.046972293965233, 
          0.21333333333333315`}, {3.043888889613843, 0.4266666666666665}, {
          3.3556769978186205`, 0.25}, {3.3872235421489707`, 
          0.3749999999999999}, {3.0387489278057522`, 0.6399999999999999}, {
          3.043888889613843, 0.4266666666666665}, {3.0387489278057522`, 
          0.6399999999999999}, {3.3872235421489707`, 0.375}, {
          3.4328084629414652`, 0.5}, {3.031550975310239, 
          0.8533333333333333}, {3.0387489278057522`, 0.6399999999999999}, {
          3.031550975310239, 0.8533333333333333}, {3.4328084629414652`, 
          0.4999999999999999}, {3.494151395052641, 0.6249999999999999}, {
          3.022293022805492, 1.0666666666666667`}, {3.031550975310239, 
          0.8533333333333333}, {3.022293022805492, 1.0666666666666667`}, {
          3.494151395052641, 0.625}, {3.574048663883448, 
          0.7499999999999999}, {3.0109724820688584`, 1.28}, {
          3.022293022805492, 1.0666666666666667`}, {3.0109724820688584`, 
          0.}, {3.574048663883448, 9.184850993605148*^-17}, {
          3.494151395052641, 8.419446744138054*^-17}, {3.022293022805492, 
          1.30628991909051*^-17}, {3.0109724820688584`, 0.}, {
          3.022293022805492, 1.30628991909051*^-17}, {3.494151395052641, 
          8.419446744138054*^-17}, {3.4328084629414652`, 
          7.654042494670958*^-17}, {3.031550975310239, 
          2.61257983818102*^-17}, {3.022293022805492, 
          1.30628991909051*^-17}, {3.031550975310239, 
          2.61257983818102*^-17}, {3.4328084629414652`, 
          7.654042494670958*^-17}, {3.3872235421489707`, 
          6.888638245203862*^-17}, {3.0387489278057522`, 
          3.91886975727153*^-17}, {3.031550975310239, 
          2.61257983818102*^-17}, {3.0387489278057522`, 
          3.91886975727153*^-17}, {3.3872235421489707`, 
          6.888638245203862*^-17}, {3.3556769978186205`, 
          6.123233995736766*^-17}, {3.043888889613843, 
          5.22515967636204*^-17}, {3.0387489278057522`, 
          3.91886975727153*^-17}, {3.043888889613843, 
          5.22515967636204*^-17}, {3.3556769978186205`, 
          6.123233995736766*^-17}, {3.337124387315237, 
          5.35782974626967*^-17}, {3.046972293965233, 
          6.53144959545255*^-17}, {3.043888889613843, 
          5.22515967636204*^-17}, {3.046972293965233, 
          6.53144959545255*^-17}, {3.337124387315237, 
          5.35782974626967*^-17}, {3.3310000000000004`, 
          4.592425496802574*^-17}, {3.0479999999999983`, 
          7.837739514543059*^-17}, {3.046972293965233, 
          6.53144959545255*^-17}, {3.0479999999999983`, 
          7.83773951454306*^-17}, {3.3310000000000004`, 
          4.592425496802574*^-17}, {3.337124387315237, 
          3.827021247335479*^-17}, {3.046972293965233, 
          9.14402943363357*^-17}, {3.0479999999999983`, 
          7.83773951454306*^-17}, {3.046972293965233, 
          9.144029433633569*^-17}, {3.337124387315237, 
          3.8270212473354795`*^-17}, {3.3556769978186205`, 
          3.0616169978683836`*^-17}, {3.043888889613843, 
          1.045031935272408*^-16}, {3.046972293965233, 
          9.144029433633569*^-17}, {3.043888889613843, 
          1.045031935272408*^-16}, {3.3556769978186205`, 
          3.061616997868383*^-17}, {3.3872235421489707`, 
          2.296212748401288*^-17}, {3.0387489278057522`, 
          1.175660927181459*^-16}, {3.043888889613843, 
          1.045031935272408*^-16}, {3.0387489278057522`, 
          1.175660927181459*^-16}, {3.3872235421489707`, 
          2.296212748401287*^-17}, {3.4328084629414652`, 
          1.5308084989341915`*^-17}, {3.031550975310239, 
          1.30628991909051*^-16}, {3.0387489278057522`, 
          1.175660927181459*^-16}, {3.031550975310239, 
          1.30628991909051*^-16}, {3.4328084629414652`, 
          1.530808498934192*^-17}, {3.494151395052641, 
          7.654042494670964*^-18}, {3.022293022805492, 
          1.4369189109995612`*^-16}, {3.031550975310239, 
          1.30628991909051*^-16}, {3.022293022805492, 
          1.4369189109995612`*^-16}, {3.494151395052641, 
          7.65404249467096*^-18}, {3.574048663883448, 
          3.823962394069381*^-33}, {3.0109724820688584`, 
          1.567547902908612*^-16}, {3.022293022805492, 
          1.4369189109995612`*^-16}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.8}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9833333333333332}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444453` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.6666666666666667}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.8}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444453` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.6666666666666667}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9833333333333332}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.618844444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.7866666666666664}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.5333333333333334}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444453` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.6666666666666667}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.5333333333333334}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.7866666666666666}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.5900000000000001}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.16000000000000003` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.4}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.5333333333333334}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.16000000000000003` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.4}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.5900000000000001}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3933333333333333}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111114 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.2666666666666667}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.16000000000000003` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.4}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111114 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.2666666666666667}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.15471111111111127` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.39333333333333353`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.19666666666666677`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.0177777777777778 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.13333333333333341`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111114 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.2666666666666667}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.0177777777777778 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.13333333333333341`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.19666666666666677`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-2.0882655213783707`*^-32 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-1.232595164407831*^-32 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -1.1102230246251565`*^-16}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.0177777777777778 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.13333333333333341`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[0. + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-2.0882655213783707`*^-32 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.038677777777777776` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.19666666666666666`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.0177777777777778 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.13333333333333341`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[0. + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.01777777777777774 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.1333333333333332}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.038677777777777686` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.19666666666666643`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111109 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.3933333333333331}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111108 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.2666666666666666}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.01777777777777774 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.1333333333333332}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111108 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.2666666666666666}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.154711111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.3933333333333332}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.34809999999999985` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.5899999999999999}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.16000000000000011` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.40000000000000013`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111108 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.2666666666666666}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.16000000000000011` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.40000000000000013`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.59}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7866666666666666}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.5333333333333334}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.16000000000000011` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.40000000000000013`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.5333333333333332}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.618844444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7866666666666664}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444439 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9833333333333331}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444453` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.6666666666666667}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.5333333333333332}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444453` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.6666666666666667}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9833333333333332}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.18}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.8}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444453` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.6666666666666667}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.4450832229938768`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.3246596210777202`*^-16}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444453` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 8.164311994315688*^-18}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444453` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 8.164311994315688*^-18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.3246596210777202`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.618844444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.2042360191615639`*^-16}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 1.6328623988631376`*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444453` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 8.164311994315688*^-18}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 1.6328623988631376`*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.2042360191615639`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0838124172454077`*^-16}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.16000000000000003` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 2.4492935982947065`*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 1.6328623988631376`*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.16000000000000003` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 2.4492935982947065`*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0838124172454077`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 9.633888153292512*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111114 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 3.265724797726275*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.16000000000000003` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 2.4492935982947065`*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111114 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 3.265724797726275*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.15471111111111127` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 9.633888153292513*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 8.429652134130949*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.0177777777777778 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 4.082155997157844*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111114 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 3.265724797726275*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.0177777777777778 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 4.082155997157844*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 8.429652134130949*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-5.220663803445927*^-33 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 7.225416114969384*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-1.4725567296337283`*^-32 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 4.8985871965894125`*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.0177777777777778 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 4.082155997157844*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-2.3996156522589726`*^-33 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 4.898587196589413*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-5.220663803445927*^-33 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 7.225416114969384*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.038677777777777776` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 6.021180095807819*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.0177777777777778 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 5.715018396020983*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-2.3996156522589726`*^-33 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 4.898587196589413*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.01777777777777774 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 5.71501839602098*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.038677777777777686` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 6.02118009580782*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111109 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 4.816944076646257*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111108 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 6.53144959545255*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.01777777777777774 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 5.71501839602098*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111108 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 6.53144959545255*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.154711111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 4.8169440766462566`*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.34809999999999985` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 3.6127080574846926`*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.16000000000000011` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 7.34788079488412*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111108 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 6.53144959545255*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.16000000000000011` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 7.34788079488412*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 3.612708057484692*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 2.4084720383231283`*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 8.164311994315689*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.16000000000000011` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 7.34788079488412*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 8.164311994315688*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.618844444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 2.408472038323129*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444439 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.204236019161565*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444453` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 8.980743193747258*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 8.164311994315688*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444453` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 8.980743193747258*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.2042360191615645`*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 6.016367500002493*^-33}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 9.797174393178826*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444453` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 8.980743193747258*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.18}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.18}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.9833333333333332}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9833333333333333}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9833333333333333}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.9833333333333332}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.618844444444444 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.7866666666666664}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.7866666666666666}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9833333333333333}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.7866666666666666}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.7866666666666666}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.5900000000000001}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.59}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.7866666666666666}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.59}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.5900000000000001}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.3933333333333333}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3933333333333333}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.59}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3933333333333333}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.15471111111111127` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.39333333333333353`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.19666666666666677`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.19666666666666677`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3933333333333333}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.19666666666666677`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.19666666666666677`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-2.0882655213783707`*^-32 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-4.930380657631324*^-32 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -2.220446049250313*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.19666666666666677`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[0. + $CellContext`rr7^2] Sign[$CellContext`rr7], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-2.0882655213783707`*^-32 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.038677777777777776` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.19666666666666666`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.19666666666666677`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[0. + $CellContext`rr7^2] Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777773 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.19666666666666655`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.038677777777777686` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.19666666666666643`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.1547111111111109 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.3933333333333331}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.3933333333333333}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777773 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.19666666666666655`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.3933333333333333}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.154711111111111 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.3933333333333332}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.34809999999999985` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.5899999999999999}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.5900000000000001}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.3933333333333333}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.5900000000000001}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.59}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.7866666666666666}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7866666666666666}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.5900000000000001}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.618844444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7866666666666664}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.618844444444444 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.7866666666666664}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.9669444444444439 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.9833333333333331}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9833333333333332}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.618844444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7866666666666664}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9833333333333332}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.9833333333333332}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9833333333333332}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.4450832229938768`*^-16}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.3246596210777202`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.204236019161564*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.204236019161564*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.3246596210777202`*^-16}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.618844444444444 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.2042360191615639`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 2.408472038323128*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.204236019161564*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 2.408472038323128*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.2042360191615639`*^-16}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.0838124172454077`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 3.612708057484692*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 2.408472038323128*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 3.612708057484692*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.0838124172454077`*^-16}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 9.633888153292512*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 4.816944076646256*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 3.612708057484692*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 4.816944076646256*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.15471111111111127` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 9.633888153292513*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 8.429652134130949*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 6.021180095807819*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 4.816944076646256*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 6.021180095807819*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 8.429652134130949*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-5.220663803445927*^-33 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 7.225416114969384*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-5.452447037975916*^-32 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 7.225416114969383*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 6.021180095807819*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-5.220663803445927*^-33 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 7.225416114969384*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-5.220663803445927*^-33 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 7.225416114969384*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.038677777777777776` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 6.021180095807819*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777782 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 8.429652134130949*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-5.220663803445927*^-33 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 7.225416114969384*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777773 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 8.429652134130947*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.038677777777777686` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 6.02118009580782*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.1547111111111109 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 4.816944076646257*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 9.633888153292512*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777773 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 8.429652134130947*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 9.633888153292512*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.154711111111111 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 4.8169440766462566`*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.34809999999999985` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 3.6127080574846926`*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0838124172454077`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 9.633888153292512*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0838124172454077`*^-16}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 3.612708057484692*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 2.4084720383231283`*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.2042360191615639`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0838124172454077`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.618844444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.2042360191615639`*^-16}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.618844444444444 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 2.408472038323129*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.9669444444444439 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.204236019161565*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.3246596210777202`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.618844444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.2042360191615639`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.3246596210777202`*^-16}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.2042360191615645`*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 6.016367500002493*^-33}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.4450832229938768`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.3246596210777202`*^-16}, {
          5.534443062211261, -1.5}, {5.627613727648733, -1.5}, {
          5.66673280243244, -1.25}, {5.480951960507346, -1.25}, {
          5.534443062211261, -1.5}, {5.480951960507346, -1.25}, {
          5.66673280243244, -1.25}, {5.698610540005257, -1.}, {
          5.437514103763482, -1.}, {5.480951960507346, -1.25}, {
          5.437514103763482, -1.}, {5.698610540005257, -1.}, {
          5.723325072171594, -0.75}, {5.403928867156194, -0.75}, {
          5.437514103763482, -1.}, {5.403928867156194, -0.75}, {
          5.723325072171594, -0.75}, {5.7409362013674965`, -0.5}, {
          5.380044781965627, -0.5}, {5.403928867156194, -0.75}, {
          5.380044781965627, -0.5}, {5.7409362013674965`, -0.5}, {
          5.751486135780276, -0.25}, {5.365756018538898, -0.25}, {
          5.380044781965627, -0.5}, {5.365756018538898, -0.25}, {
          5.751486135780276, -0.25}, {5.755000000000001, 0.}, {
          5.361000000000001, -2.220446049250313*^-16}, {
          5.365756018538898, -0.25}, {5.361000000000001, 0.}, {
          5.755000000000001, 0.}, {5.751486135780276, 0.25}, {
          5.365756018538898, 0.25}, {5.361000000000001, 0.}, {
          5.365756018538898, 0.24999999999999978`}, {5.751486135780276, 
          0.24999999999999978`}, {5.7409362013674965`, 0.4999999999999998}, {
          5.380044781965627, 0.5}, {5.365756018538898, 
          0.24999999999999978`}, {5.380044781965627, 0.5}, {
          5.7409362013674965`, 0.5}, {5.723325072171594, 
          0.7499999999999998}, {5.403928867156194, 0.75}, {5.380044781965627, 
          0.5}, {5.403928867156194, 0.75}, {5.723325072171594, 0.75}, {
          5.698610540005257, 1.}, {5.437514103763482, 1.}, {5.403928867156194,
           0.75}, {5.437514103763482, 1.}, {5.698610540005257, 
          0.9999999999999998}, {5.66673280243244, 1.2499999999999998`}, {
          5.480951960507346, 1.25}, {5.437514103763482, 1.}, {
          5.480951960507346, 1.25}, {5.66673280243244, 1.25}, {
          5.627613727648733, 1.4999999999999998`}, {5.534443062211261, 1.5}, {
          5.480951960507346, 1.25}, {5.534443062211261, 0.}, {
          5.627613727648733, 1.8369701987210297`*^-16}, {5.66673280243244, 
          1.6838893488276108`*^-16}, {5.480951960507346, 
          1.5308084989341915`*^-17}, {5.534443062211261, 0.}, {
          5.480951960507346, 1.5308084989341915`*^-17}, {5.66673280243244, 
          1.6838893488276108`*^-16}, {5.698610540005257, 
          1.5308084989341916`*^-16}, {5.437514103763482, 
          3.061616997868383*^-17}, {5.480951960507346, 
          1.5308084989341915`*^-17}, {5.437514103763482, 
          3.061616997868383*^-17}, {5.698610540005257, 
          1.5308084989341916`*^-16}, {5.723325072171594, 
          1.3777276490407724`*^-16}, {5.403928867156194, 
          4.592425496802574*^-17}, {5.437514103763482, 
          3.061616997868383*^-17}, {5.403928867156194, 
          4.592425496802574*^-17}, {5.723325072171594, 
          1.3777276490407724`*^-16}, {5.7409362013674965`, 
          1.2246467991473532`*^-16}, {5.380044781965627, 
          6.123233995736766*^-17}, {5.403928867156194, 
          4.592425496802574*^-17}, {5.380044781965627, 
          6.123233995736766*^-17}, {5.7409362013674965`, 
          1.2246467991473532`*^-16}, {5.751486135780276, 
          1.071565949253934*^-16}, {5.365756018538898, 
          7.654042494670958*^-17}, {5.380044781965627, 
          6.123233995736766*^-17}, {5.365756018538898, 
          7.654042494670958*^-17}, {5.751486135780276, 
          1.071565949253934*^-16}, {5.755000000000001, 
          9.184850993605148*^-17}, {5.361000000000001, 
          9.184850993605147*^-17}, {5.365756018538898, 
          7.654042494670958*^-17}, {5.361000000000001, 
          9.184850993605148*^-17}, {5.755000000000001, 
          9.184850993605148*^-17}, {5.751486135780276, 
          7.654042494670958*^-17}, {5.365756018538898, 
          1.071565949253934*^-16}, {5.361000000000001, 
          9.184850993605148*^-17}, {5.365756018538898, 
          1.0715659492539339`*^-16}, {5.751486135780276, 
          7.654042494670959*^-17}, {5.7409362013674965`, 
          6.123233995736767*^-17}, {5.380044781965627, 
          1.2246467991473532`*^-16}, {5.365756018538898, 
          1.0715659492539339`*^-16}, {5.380044781965627, 
          1.2246467991473532`*^-16}, {5.7409362013674965`, 
          6.123233995736766*^-17}, {5.723325072171594, 
          4.592425496802576*^-17}, {5.403928867156194, 
          1.3777276490407724`*^-16}, {5.380044781965627, 
          1.2246467991473532`*^-16}, {5.403928867156194, 
          1.3777276490407724`*^-16}, {5.723325072171594, 
          4.592425496802574*^-17}, {5.698610540005257, 
          3.061616997868383*^-17}, {5.437514103763482, 
          1.5308084989341916`*^-16}, {5.403928867156194, 
          1.3777276490407724`*^-16}, {5.437514103763482, 
          1.5308084989341916`*^-16}, {5.698610540005257, 
          3.061616997868384*^-17}, {5.66673280243244, 
          1.5308084989341927`*^-17}, {5.480951960507346, 
          1.6838893488276108`*^-16}, {5.437514103763482, 
          1.5308084989341916`*^-16}, {5.480951960507346, 
          1.6838893488276108`*^-16}, {5.66673280243244, 
          1.530808498934192*^-17}, {5.627613727648733, 
          7.647924788138762*^-33}, {5.534443062211261, 
          1.8369701987210297`*^-16}, {5.480951960507346, 
          1.6838893488276108`*^-16}, {3.711, 0.63}, {3.711, 0.65625}, {3.711, 
          0.6506356902765631}, {3.711, 0.6246102626655006}, {3.711, 0.63}, {
          3.711, 0.6246102626655006}, {3.711, 0.6506356902765631}, {3.711, 
          0.633888823502201}, {3.711, 0.6085332705621129}, {3.711, 
          0.6246102626655006}, {3.711, 0.6085332705621129}, {3.711, 
          0.633888823502201}, {3.711, 0.6062959432105319}, {3.711, 
          0.5820441054821106}, {3.711, 0.6085332705621129}, {3.711, 
          0.5820441054821106}, {3.711, 0.6062959432105319}, {3.711, 
          0.5683291712335378}, {3.711, 0.5455960043841963}, {3.711, 
          0.5820441054821106}, {3.711, 0.5455960043841963}, {3.711, 
          0.5683291712335378}, {3.711, 0.5206381295661231}, {3.711, 
          0.49981260438347813`}, {3.711, 0.5455960043841963}, {3.711, 
          0.49981260438347813`}, {3.711, 0.5206381295661231}, {3.711, 
          0.4640388251536718}, {3.711, 0.4454772721475249}, {3.711, 
          0.49981260438347813`}, {3.711, 0.4454772721475249}, {3.711, 
          0.4640388251536718}, {3.711, 0.3994996877869729}, {3.711, 
          0.38351970027549404`}, {3.711, 0.4454772721475249}, {3.711, 
          0.38351970027549404`}, {3.711, 0.3994996877869729}, {3.711, 
          0.328125}, {3.711, 0.315}, {3.711, 0.38351970027549404`}, {3.711, 
          0.315}, {3.711, 0.328125}, {3.711, 0.25113600248959017`}, {3.711, 
          0.24109056239000656`}, {3.711, 0.315}, {3.711, 
          0.24109056239000656`}, {3.711, 0.25113600248959017`}, {3.711, 
          0.1698499983485292}, {3.711, 0.16305599841458804`}, {3.711, 
          0.24109056239000656`}, {3.711, 0.16305599841458804`}, {3.711, 
          0.1698499983485292}, {3.711, 0.08565781364440885}, {3.711, 
          0.08223150109863249}, {3.711, 0.16305599841458804`}, {3.711, 
          0.08223150109863249}, {3.711, 0.08565781364440885}, {3.711, 0.}, {
          3.711, 0.}, {3.711, 0.08223150109863249}, {3.711, 0.}, {3.711, 
          0.}, {3.711, -0.08565781364440885}, {3.711, -0.08223150109863249}, {
          3.711, 0.}, {3.711, -0.08223150109863249}, {
          3.711, -0.08565781364440885}, {3.711, -0.1698499983485292}, {
          3.711, -0.16305599841458804`}, {3.711, -0.08223150109863249}, {
          3.711, -0.16305599841458804`}, {3.711, -0.1698499983485292}, {
          3.711, -0.25113600248959017`}, {3.711, -0.24109056239000656`}, {
          3.711, -0.16305599841458804`}, {3.711, -0.24109056239000656`}, {
          3.711, -0.25113600248959017`}, {3.711, -0.328125}, {
          3.711, -0.315}, {3.711, -0.24109056239000656`}, {3.711, -0.315}, {
          3.711, -0.328125}, {3.711, -0.3994996877869729}, {
          3.711, -0.38351970027549404`}, {3.711, -0.315}, {
          3.711, -0.38351970027549404`}, {3.711, -0.3994996877869729}, {
          3.711, -0.4640388251536718}, {3.711, -0.4454772721475249}, {
          3.711, -0.38351970027549404`}, {3.711, -0.4454772721475249}, {
          3.711, -0.4640388251536718}, {3.711, -0.5206381295661231}, {
          3.711, -0.49981260438347813`}, {3.711, -0.4454772721475249}, {
          3.711, -0.49981260438347813`}, {3.711, -0.5206381295661231}, {
          3.711, -0.5683291712335378}, {3.711, -0.5455960043841963}, {
          3.711, -0.49981260438347813`}, {3.711, -0.5455960043841963}, {
          3.711, -0.5683291712335378}, {3.711, -0.6062959432105319}, {
          3.711, -0.5820441054821106}, {3.711, -0.5455960043841963}, {
          3.711, -0.5820441054821106}, {3.711, -0.6062959432105319}, {
          3.711, -0.633888823502201}, {3.711, -0.6085332705621129}, {
          3.711, -0.5820441054821106}, {3.711, -0.6085332705621129}, {
          3.711, -0.633888823502201}, {3.711, -0.6506356902765631}, {
          3.711, -0.6246102626655006}, {3.711, -0.6085332705621129}, {
          3.711, -0.6246102626655006}, {3.711, -0.6506356902765631}, {
          3.711, -0.65625}, {3.711, -0.63}, {3.711, -0.6246102626655006}, {
          3.711, -0.63}, {3.711, -0.65625}, {3.711, -0.6506356902765631}, {
          3.711, -0.6246102626655006}, {3.711, -0.63}, {
          3.711, -0.6246102626655006}, {3.711, -0.6506356902765631}, {
          3.711, -0.633888823502201}, {3.711, -0.6085332705621129}, {
          3.711, -0.6246102626655006}, {3.711, -0.6085332705621129}, {
          3.711, -0.633888823502201}, {3.711, -0.6062959432105319}, {
          3.711, -0.5820441054821106}, {3.711, -0.6085332705621129}, {
          3.711, -0.5820441054821106}, {3.711, -0.6062959432105319}, {
          3.711, -0.5683291712335378}, {3.711, -0.5455960043841963}, {
          3.711, -0.5820441054821106}, {3.711, -0.5455960043841963}, {
          3.711, -0.5683291712335378}, {3.711, -0.5206381295661231}, {
          3.711, -0.49981260438347813`}, {3.711, -0.5455960043841963}, {
          3.711, -0.49981260438347813`}, {3.711, -0.5206381295661231}, {
          3.711, -0.4640388251536718}, {3.711, -0.4454772721475249}, {
          3.711, -0.49981260438347813`}, {3.711, -0.4454772721475249}, {
          3.711, -0.4640388251536718}, {3.711, -0.3994996877869729}, {
          3.711, -0.38351970027549404`}, {3.711, -0.4454772721475249}, {
          3.711, -0.38351970027549404`}, {3.711, -0.3994996877869729}, {
          3.711, -0.328125}, {3.711, -0.315}, {
          3.711, -0.38351970027549404`}, {3.711, -0.315}, {
          3.711, -0.328125}, {3.711, -0.25113600248959017`}, {
          3.711, -0.24109056239000656`}, {3.711, -0.315}, {
          3.711, -0.24109056239000656`}, {3.711, -0.25113600248959017`}, {
          3.711, -0.1698499983485292}, {3.711, -0.16305599841458804`}, {
          3.711, -0.24109056239000656`}, {3.711, -0.16305599841458804`}, {
          3.711, -0.1698499983485292}, {3.711, -0.08565781364440885}, {
          3.711, -0.08223150109863249}, {3.711, -0.16305599841458804`}, {
          3.711, -0.08223150109863249}, {3.711, -0.08565781364440885}, {3.711,
           0.}, {3.711, 0.}, {3.711, -0.08223150109863249}, {3.711, 0.}, {
          3.711, 0.}, {3.711, 0.08565781364440885}, {3.711, 
          0.08223150109863249}, {3.711, 0.}, {3.711, 0.08223150109863249}, {
          3.711, 0.08565781364440885}, {3.711, 0.1698499983485292}, {3.711, 
          0.16305599841458804`}, {3.711, 0.08223150109863249}, {3.711, 
          0.16305599841458804`}, {3.711, 0.1698499983485292}, {3.711, 
          0.25113600248959017`}, {3.711, 0.24109056239000656`}, {3.711, 
          0.16305599841458804`}, {3.711, 0.24109056239000656`}, {3.711, 
          0.25113600248959017`}, {3.711, 0.328125}, {3.711, 0.315}, {3.711, 
          0.24109056239000656`}, {3.711, 0.315}, {3.711, 0.328125}, {3.711, 
          0.3994996877869729}, {3.711, 0.38351970027549404`}, {3.711, 
          0.315}, {3.711, 0.38351970027549404`}, {3.711, 
          0.3994996877869729}, {3.711, 0.4640388251536718}, {3.711, 
          0.4454772721475249}, {3.711, 0.38351970027549404`}, {3.711, 
          0.4454772721475249}, {3.711, 0.4640388251536718}, {3.711, 
          0.5206381295661231}, {3.711, 0.49981260438347813`}, {3.711, 
          0.4454772721475249}, {3.711, 0.49981260438347813`}, {3.711, 
          0.5206381295661231}, {3.711, 0.5683291712335378}, {3.711, 
          0.5455960043841963}, {3.711, 0.49981260438347813`}, {3.711, 
          0.5455960043841963}, {3.711, 0.5683291712335378}, {3.711, 
          0.6062959432105319}, {3.711, 0.5820441054821106}, {3.711, 
          0.5455960043841963}, {3.711, 0.5820441054821106}, {3.711, 
          0.6062959432105319}, {3.711, 0.633888823502201}, {3.711, 
          0.6085332705621129}, {3.711, 0.5820441054821106}, {3.711, 
          0.6085332705621129}, {3.711, 0.633888823502201}, {3.711, 
          0.6506356902765631}, {3.711, 0.6246102626655006}, {3.711, 
          0.6085332705621129}, {3.711, 0.6246102626655006}, {3.711, 
          0.6506356902765631}, {3.711, 0.65625}, {3.711, 0.63}, {3.711, 
          0.6246102626655006}, {3.711, 0.65625}, {3.711, 0.6825}, {3.711, 
          0.6766611178876256}, {3.711, 0.6506356902765631}, {3.711, 
          0.65625}, {3.711, 0.6506356902765631}, {3.711, 
          0.6766611178876256}, {3.711, 0.659244376442289}, {3.711, 
          0.633888823502201}, {3.711, 0.6506356902765631}, {3.711, 
          0.633888823502201}, {3.711, 0.659244376442289}, {3.711, 
          0.6305477809389531}, {3.711, 0.6062959432105319}, {3.711, 
          0.633888823502201}, {3.711, 0.6062959432105319}, {3.711, 
          0.6305477809389531}, {3.711, 0.5910623380828793}, {3.711, 
          0.5683291712335378}, {3.711, 0.6062959432105319}, {3.711, 
          0.5683291712335378}, {3.711, 0.5910623380828793}, {3.711, 
          0.541463654748768}, {3.711, 0.5206381295661231}, {3.711, 
          0.5683291712335378}, {3.711, 0.5206381295661231}, {3.711, 
          0.541463654748768}, {3.711, 0.48260037815981865`}, {3.711, 
          0.4640388251536718}, {3.711, 0.5206381295661231}, {3.711, 
          0.4640388251536718}, {3.711, 0.48260037815981865`}, {3.711, 
          0.41547967529845187`}, {3.711, 0.3994996877869729}, {3.711, 
          0.4640388251536718}, {3.711, 0.3994996877869729}, {3.711, 
          0.41547967529845187`}, {3.711, 0.34125}, {3.711, 0.328125}, {3.711, 
          0.3994996877869729}, {3.711, 0.328125}, {3.711, 0.34125}, {3.711, 
          0.26118144258917375`}, {3.711, 0.25113600248959017`}, {3.711, 
          0.328125}, {3.711, 0.25113600248959017`}, {3.711, 
          0.26118144258917375`}, {3.711, 0.17664399828247038`}, {3.711, 
          0.1698499983485292}, {3.711, 0.25113600248959017`}, {3.711, 
          0.1698499983485292}, {3.711, 0.17664399828247038`}, {3.711, 
          0.0890841261901852}, {3.711, 0.08565781364440885}, {3.711, 
          0.1698499983485292}, {3.711, 0.08565781364440885}, {3.711, 
          0.0890841261901852}, {3.711, 0.}, {3.711, 0.}, {3.711, 
          0.08565781364440885}, {3.711, 0.}, {3.711, 0.}, {
          3.711, -0.0890841261901852}, {3.711, -0.08565781364440885}, {3.711, 
          0.}, {3.711, -0.08565781364440885}, {3.711, -0.0890841261901852}, {
          3.711, -0.17664399828247038`}, {3.711, -0.1698499983485292}, {
          3.711, -0.08565781364440885}, {3.711, -0.1698499983485292}, {
          3.711, -0.17664399828247038`}, {3.711, -0.26118144258917375`}, {
          3.711, -0.25113600248959017`}, {3.711, -0.1698499983485292}, {
          3.711, -0.25113600248959017`}, {3.711, -0.26118144258917375`}, {
          3.711, -0.34125}, {3.711, -0.328125}, {
          3.711, -0.25113600248959017`}, {3.711, -0.328125}, {
          3.711, -0.34125}, {3.711, -0.41547967529845187`}, {
          3.711, -0.3994996877869729}, {3.711, -0.328125}, {
          3.711, -0.3994996877869729}, {3.711, -0.41547967529845187`}, {
          3.711, -0.48260037815981865`}, {3.711, -0.4640388251536718}, {
          3.711, -0.3994996877869729}, {3.711, -0.4640388251536718}, {
          3.711, -0.48260037815981865`}, {3.711, -0.541463654748768}, {
          3.711, -0.5206381295661231}, {3.711, -0.4640388251536718}, {
          3.711, -0.5206381295661231}, {3.711, -0.541463654748768}, {
          3.711, -0.5910623380828793}, {3.711, -0.5683291712335378}, {
          3.711, -0.5206381295661231}, {3.711, -0.5683291712335378}, {
          3.711, -0.5910623380828793}, {3.711, -0.6305477809389531}, {
          3.711, -0.6062959432105319}, {3.711, -0.5683291712335378}, {
          3.711, -0.6062959432105319}, {3.711, -0.6305477809389531}, {
          3.711, -0.659244376442289}, {3.711, -0.633888823502201}, {
          3.711, -0.6062959432105319}, {3.711, -0.633888823502201}, {
          3.711, -0.659244376442289}, {3.711, -0.6766611178876256}, {
          3.711, -0.6506356902765631}, {3.711, -0.633888823502201}, {
          3.711, -0.6506356902765631}, {3.711, -0.6766611178876256}, {
          3.711, -0.6825}, {3.711, -0.65625}, {3.711, -0.6506356902765631}, {
          3.711, -0.65625}, {3.711, -0.6825}, {3.711, -0.6766611178876256}, {
          3.711, -0.6506356902765631}, {3.711, -0.65625}, {
          3.711, -0.6506356902765631}, {3.711, -0.6766611178876256}, {
          3.711, -0.659244376442289}, {3.711, -0.633888823502201}, {
          3.711, -0.6506356902765631}, {3.711, -0.633888823502201}, {
          3.711, -0.659244376442289}, {3.711, -0.6305477809389531}, {
          3.711, -0.6062959432105319}, {3.711, -0.633888823502201}, {
          3.711, -0.6062959432105319}, {3.711, -0.6305477809389531}, {
          3.711, -0.5910623380828793}, {3.711, -0.5683291712335378}, {
          3.711, -0.6062959432105319}, {3.711, -0.5683291712335378}, {
          3.711, -0.5910623380828793}, {3.711, -0.541463654748768}, {
          3.711, -0.5206381295661231}, {3.711, -0.5683291712335378}, {
          3.711, -0.5206381295661231}, {3.711, -0.541463654748768}, {
          3.711, -0.48260037815981865`}, {3.711, -0.4640388251536718}, {
          3.711, -0.5206381295661231}, {3.711, -0.4640388251536718}, {
          3.711, -0.48260037815981865`}, {3.711, -0.41547967529845187`}, {
          3.711, -0.3994996877869729}, {3.711, -0.4640388251536718}, {
          3.711, -0.3994996877869729}, {3.711, -0.41547967529845187`}, {
          3.711, -0.34125}, {3.711, -0.328125}, {
          3.711, -0.3994996877869729}, {3.711, -0.328125}, {
          3.711, -0.34125}, {3.711, -0.26118144258917375`}, {
          3.711, -0.25113600248959017`}, {3.711, -0.328125}, {
          3.711, -0.25113600248959017`}, {3.711, -0.26118144258917375`}, {
          3.711, -0.17664399828247038`}, {3.711, -0.1698499983485292}, {
          3.711, -0.25113600248959017`}, {3.711, -0.1698499983485292}, {
          3.711, -0.17664399828247038`}, {3.711, -0.0890841261901852}, {
          3.711, -0.08565781364440885}, {3.711, -0.1698499983485292}, {
          3.711, -0.08565781364440885}, {3.711, -0.0890841261901852}, {3.711, 
          0.}, {3.711, 0.}, {3.711, -0.08565781364440885}, {3.711, 0.}, {
          3.711, 0.}, {3.711, 0.0890841261901852}, {3.711, 
          0.08565781364440885}, {3.711, 0.}, {3.711, 0.08565781364440885}, {
          3.711, 0.0890841261901852}, {3.711, 0.17664399828247038`}, {3.711, 
          0.1698499983485292}, {3.711, 0.08565781364440885}, {3.711, 
          0.1698499983485292}, {3.711, 0.17664399828247038`}, {3.711, 
          0.26118144258917375`}, {3.711, 0.25113600248959017`}, {3.711, 
          0.1698499983485292}, {3.711, 0.25113600248959017`}, {3.711, 
          0.26118144258917375`}, {3.711, 0.34125}, {3.711, 0.328125}, {3.711, 
          0.25113600248959017`}, {3.711, 0.328125}, {3.711, 0.34125}, {3.711, 
          0.41547967529845187`}, {3.711, 0.3994996877869729}, {3.711, 
          0.328125}, {3.711, 0.3994996877869729}, {3.711, 
          0.41547967529845187`}, {3.711, 0.48260037815981865`}, {3.711, 
          0.4640388251536718}, {3.711, 0.3994996877869729}, {3.711, 
          0.4640388251536718}, {3.711, 0.48260037815981865`}, {3.711, 
          0.541463654748768}, {3.711, 0.5206381295661231}, {3.711, 
          0.4640388251536718}, {3.711, 0.5206381295661231}, {3.711, 
          0.541463654748768}, {3.711, 0.5910623380828793}, {3.711, 
          0.5683291712335378}, {3.711, 0.5206381295661231}, {3.711, 
          0.5683291712335378}, {3.711, 0.5910623380828793}, {3.711, 
          0.6305477809389531}, {3.711, 0.6062959432105319}, {3.711, 
          0.5683291712335378}, {3.711, 0.6062959432105319}, {3.711, 
          0.6305477809389531}, {3.711, 0.659244376442289}, {3.711, 
          0.633888823502201}, {3.711, 0.6062959432105319}, {3.711, 
          0.633888823502201}, {3.711, 0.659244376442289}, {3.711, 
          0.6766611178876256}, {3.711, 0.6506356902765631}, {3.711, 
          0.633888823502201}, {3.711, 0.6506356902765631}, {3.711, 
          0.6766611178876256}, {3.711, 0.6825}, {3.711, 0.65625}, {3.711, 
          0.6506356902765631}, {3.711, 0.6825}, {3.711, 0.70875}, {3.711, 
          0.7026865454986881}, {3.711, 0.6766611178876256}, {3.711, 0.6825}, {
          3.711, 0.6766611178876256}, {3.711, 0.7026865454986881}, {3.711, 
          0.684599929382377}, {3.711, 0.659244376442289}, {3.711, 
          0.6766611178876256}, {3.711, 0.659244376442289}, {3.711, 
          0.684599929382377}, {3.711, 0.6547996186673745}, {3.711, 
          0.6305477809389531}, {3.711, 0.659244376442289}, {3.711, 
          0.6305477809389531}, {3.711, 0.6547996186673745}, {3.711, 
          0.6137955049322208}, {3.711, 0.5910623380828793}, {3.711, 
          0.6305477809389531}, {3.711, 0.5910623380828793}, {3.711, 
          0.6137955049322208}, {3.711, 0.5622891799314129}, {3.711, 
          0.541463654748768}, {3.711, 0.5910623380828793}, {3.711, 
          0.541463654748768}, {3.711, 0.5622891799314129}, {3.711, 
          0.5011619311659655}, {3.711, 0.48260037815981865`}, {3.711, 
          0.541463654748768}, {3.711, 0.48260037815981865`}, {3.711, 
          0.5011619311659655}, {3.711, 0.43145966280993076`}, {3.711, 
          0.41547967529845187`}, {3.711, 0.48260037815981865`}, {3.711, 
          0.41547967529845187`}, {3.711, 0.43145966280993076`}, {3.711, 
          0.354375}, {3.711, 0.34125}, {3.711, 0.41547967529845187`}, {3.711, 
          0.34125}, {3.711, 0.354375}, {3.711, 0.2712268826887574}, {3.711, 
          0.26118144258917375`}, {3.711, 0.34125}, {3.711, 
          0.26118144258917375`}, {3.711, 0.2712268826887574}, {3.711, 
          0.18343799821641155`}, {3.711, 0.17664399828247038`}, {3.711, 
          0.26118144258917375`}, {3.711, 0.17664399828247038`}, {3.711, 
          0.18343799821641155`}, {3.711, 0.09251043873596154}, {3.711, 
          0.0890841261901852}, {3.711, 0.17664399828247038`}, {3.711, 
          0.0890841261901852}, {3.711, 0.09251043873596154}, {3.711, 0.}, {
          3.711, 0.}, {3.711, 0.0890841261901852}, {3.711, 0.}, {3.711, 0.}, {
          3.711, -0.09251043873596154}, {3.711, -0.0890841261901852}, {3.711, 
          0.}, {3.711, -0.0890841261901852}, {3.711, -0.09251043873596154}, {
          3.711, -0.18343799821641155`}, {3.711, -0.17664399828247038`}, {
          3.711, -0.0890841261901852}, {3.711, -0.17664399828247038`}, {
          3.711, -0.18343799821641155`}, {3.711, -0.2712268826887574}, {
          3.711, -0.26118144258917375`}, {3.711, -0.17664399828247038`}, {
          3.711, -0.26118144258917375`}, {3.711, -0.2712268826887574}, {
          3.711, -0.354375}, {3.711, -0.34125}, {
          3.711, -0.26118144258917375`}, {3.711, -0.34125}, {
          3.711, -0.354375}, {3.711, -0.43145966280993076`}, {
          3.711, -0.41547967529845187`}, {3.711, -0.34125}, {
          3.711, -0.41547967529845187`}, {3.711, -0.43145966280993076`}, {
          3.711, -0.5011619311659655}, {3.711, -0.48260037815981865`}, {
          3.711, -0.41547967529845187`}, {3.711, -0.48260037815981865`}, {
          3.711, -0.5011619311659655}, {3.711, -0.5622891799314129}, {
          3.711, -0.541463654748768}, {3.711, -0.48260037815981865`}, {
          3.711, -0.541463654748768}, {3.711, -0.5622891799314129}, {
          3.711, -0.6137955049322208}, {3.711, -0.5910623380828793}, {
          3.711, -0.541463654748768}, {3.711, -0.5910623380828793}, {
          3.711, -0.6137955049322208}, {3.711, -0.6547996186673745}, {
          3.711, -0.6305477809389531}, {3.711, -0.5910623380828793}, {
          3.711, -0.6305477809389531}, {3.711, -0.6547996186673745}, {
          3.711, -0.684599929382377}, {3.711, -0.659244376442289}, {
          3.711, -0.6305477809389531}, {3.711, -0.659244376442289}, {
          3.711, -0.684599929382377}, {3.711, -0.7026865454986881}, {
          3.711, -0.6766611178876256}, {3.711, -0.659244376442289}, {
          3.711, -0.6766611178876256}, {3.711, -0.7026865454986881}, {
          3.711, -0.70875}, {3.711, -0.6825}, {3.711, -0.6766611178876256}, {
          3.711, -0.6825}, {3.711, -0.70875}, {3.711, -0.7026865454986881}, {
          3.711, -0.6766611178876256}, {3.711, -0.6825}, {
          3.711, -0.6766611178876256}, {3.711, -0.7026865454986881}, {
          3.711, -0.684599929382377}, {3.711, -0.659244376442289}, {
          3.711, -0.6766611178876256}, {3.711, -0.659244376442289}, {
          3.711, -0.684599929382377}, {3.711, -0.6547996186673745}, {
          3.711, -0.6305477809389531}, {3.711, -0.659244376442289}, {
          3.711, -0.6305477809389531}, {3.711, -0.6547996186673745}, {
          3.711, -0.6137955049322208}, {3.711, -0.5910623380828793}, {
          3.711, -0.6305477809389531}, {3.711, -0.5910623380828793}, {
          3.711, -0.6137955049322208}, {3.711, -0.5622891799314129}, {
          3.711, -0.541463654748768}, {3.711, -0.5910623380828793}, {
          3.711, -0.541463654748768}, {3.711, -0.5622891799314129}, {
          3.711, -0.5011619311659655}, {3.711, -0.48260037815981865`}, {
          3.711, -0.541463654748768}, {3.711, -0.48260037815981865`}, {
          3.711, -0.5011619311659655}, {3.711, -0.43145966280993076`}, {
          3.711, -0.41547967529845187`}, {3.711, -0.48260037815981865`}, {
          3.711, -0.41547967529845187`}, {3.711, -0.43145966280993076`}, {
          3.711, -0.354375}, {3.711, -0.34125}, {
          3.711, -0.41547967529845187`}, {3.711, -0.34125}, {
          3.711, -0.354375}, {3.711, -0.2712268826887574}, {
          3.711, -0.26118144258917375`}, {3.711, -0.34125}, {
          3.711, -0.26118144258917375`}, {3.711, -0.2712268826887574}, {
          3.711, -0.18343799821641155`}, {3.711, -0.17664399828247038`}, {
          3.711, -0.26118144258917375`}, {3.711, -0.17664399828247038`}, {
          3.711, -0.18343799821641155`}, {3.711, -0.09251043873596154}, {
          3.711, -0.0890841261901852}, {3.711, -0.17664399828247038`}, {
          3.711, -0.0890841261901852}, {3.711, -0.09251043873596154}, {3.711, 
          0.}, {3.711, 0.}, {3.711, -0.0890841261901852}, {3.711, 0.}, {3.711,
           0.}, {3.711, 0.09251043873596154}, {3.711, 0.0890841261901852}, {
          3.711, 0.}, {3.711, 0.0890841261901852}, {3.711, 
          0.09251043873596154}, {3.711, 0.18343799821641155`}, {3.711, 
          0.17664399828247038`}, {3.711, 0.0890841261901852}, {3.711, 
          0.17664399828247038`}, {3.711, 0.18343799821641155`}, {3.711, 
          0.2712268826887574}, {3.711, 0.26118144258917375`}, {3.711, 
          0.17664399828247038`}, {3.711, 0.26118144258917375`}, {3.711, 
          0.2712268826887574}, {3.711, 0.354375}, {3.711, 0.34125}, {3.711, 
          0.26118144258917375`}, {3.711, 0.34125}, {3.711, 0.354375}, {3.711, 
          0.43145966280993076`}, {3.711, 0.41547967529845187`}, {3.711, 
          0.34125}, {3.711, 0.41547967529845187`}, {3.711, 
          0.43145966280993076`}, {3.711, 0.5011619311659655}, {3.711, 
          0.48260037815981865`}, {3.711, 0.41547967529845187`}, {3.711, 
          0.48260037815981865`}, {3.711, 0.5011619311659655}, {3.711, 
          0.5622891799314129}, {3.711, 0.541463654748768}, {3.711, 
          0.48260037815981865`}, {3.711, 0.541463654748768}, {3.711, 
          0.5622891799314129}, {3.711, 0.6137955049322208}, {3.711, 
          0.5910623380828793}, {3.711, 0.541463654748768}, {3.711, 
          0.5910623380828793}, {3.711, 0.6137955049322208}, {3.711, 
          0.6547996186673745}, {3.711, 0.6305477809389531}, {3.711, 
          0.5910623380828793}, {3.711, 0.6305477809389531}, {3.711, 
          0.6547996186673745}, {3.711, 0.684599929382377}, {3.711, 
          0.659244376442289}, {3.711, 0.6305477809389531}, {3.711, 
          0.659244376442289}, {3.711, 0.684599929382377}, {3.711, 
          0.7026865454986881}, {3.711, 0.6766611178876256}, {3.711, 
          0.659244376442289}, {3.711, 0.6766611178876256}, {3.711, 
          0.7026865454986881}, {3.711, 0.70875}, {3.711, 0.6825}, {3.711, 
          0.6766611178876256}, {3.711, 0.70875}, {3.711, 0.735}, {3.711, 
          0.7287119731097507}, {3.711, 0.7026865454986881}, {3.711, 
          0.70875}, {3.711, 0.7026865454986881}, {3.711, 
          0.7287119731097507}, {3.711, 0.7099554823224651}, {3.711, 
          0.684599929382377}, {3.711, 0.7026865454986881}, {3.711, 
          0.684599929382377}, {3.711, 0.7099554823224651}, {3.711, 
          0.6790514563957957}, {3.711, 0.6547996186673745}, {3.711, 
          0.684599929382377}, {3.711, 0.6547996186673745}, {3.711, 
          0.6790514563957957}, {3.711, 0.6365286717815624}, {3.711, 
          0.6137955049322208}, {3.711, 0.6547996186673745}, {3.711, 
          0.6137955049322208}, {3.711, 0.6365286717815624}, {3.711, 
          0.5831147051140578}, {3.711, 0.5622891799314129}, {3.711, 
          0.6137955049322208}, {3.711, 0.5622891799314129}, {3.711, 
          0.5831147051140578}, {3.711, 0.5197234841721123}, {3.711, 
          0.5011619311659655}, {3.711, 0.5622891799314129}, {3.711, 
          0.5011619311659655}, {3.711, 0.5197234841721123}, {3.711, 
          0.4474396503214097}, {3.711, 0.43145966280993076`}, {3.711, 
          0.5011619311659655}, {3.711, 0.43145966280993076`}, {3.711, 
          0.4474396503214097}, {3.711, 0.3675}, {3.711, 0.354375}, {3.711, 
          0.43145966280993076`}, {3.711, 0.354375}, {3.711, 0.3675}, {3.711, 
          0.28127232278834097`}, {3.711, 0.2712268826887574}, {3.711, 
          0.354375}, {3.711, 0.2712268826887574}, {3.711, 
          0.28127232278834097`}, {3.711, 0.19023199815035272`}, {3.711, 
          0.18343799821641155`}, {3.711, 0.2712268826887574}, {3.711, 
          0.18343799821641155`}, {3.711, 0.19023199815035272`}, {3.711, 
          0.0959367512817379}, {3.711, 0.09251043873596154}, {3.711, 
          0.18343799821641155`}, {3.711, 0.09251043873596154}, {3.711, 
          0.0959367512817379}, {3.711, 0.}, {3.711, 0.}, {3.711, 
          0.09251043873596154}, {3.711, 0.}, {3.711, 0.}, {
          3.711, -0.0959367512817379}, {3.711, -0.09251043873596154}, {3.711, 
          0.}, {3.711, -0.09251043873596154}, {3.711, -0.0959367512817379}, {
          3.711, -0.19023199815035272`}, {3.711, -0.18343799821641155`}, {
          3.711, -0.09251043873596154}, {3.711, -0.18343799821641155`}, {
          3.711, -0.19023199815035272`}, {3.711, -0.28127232278834097`}, {
          3.711, -0.2712268826887574}, {3.711, -0.18343799821641155`}, {
          3.711, -0.2712268826887574}, {3.711, -0.28127232278834097`}, {
          3.711, -0.3675}, {3.711, -0.354375}, {3.711, -0.2712268826887574}, {
          3.711, -0.354375}, {3.711, -0.3675}, {3.711, -0.4474396503214097}, {
          3.711, -0.43145966280993076`}, {3.711, -0.354375}, {
          3.711, -0.43145966280993076`}, {3.711, -0.4474396503214097}, {
          3.711, -0.5197234841721123}, {3.711, -0.5011619311659655}, {
          3.711, -0.43145966280993076`}, {3.711, -0.5011619311659655}, {
          3.711, -0.5197234841721123}, {3.711, -0.5831147051140578}, {
          3.711, -0.5622891799314129}, {3.711, -0.5011619311659655}, {
          3.711, -0.5622891799314129}, {3.711, -0.5831147051140578}, {
          3.711, -0.6365286717815624}, {3.711, -0.6137955049322208}, {
          3.711, -0.5622891799314129}, {3.711, -0.6137955049322208}, {
          3.711, -0.6365286717815624}, {3.711, -0.6790514563957957}, {
          3.711, -0.6547996186673745}, {3.711, -0.6137955049322208}, {
          3.711, -0.6547996186673745}, {3.711, -0.6790514563957957}, {
          3.711, -0.7099554823224651}, {3.711, -0.684599929382377}, {
          3.711, -0.6547996186673745}, {3.711, -0.684599929382377}, {
          3.711, -0.7099554823224651}, {3.711, -0.7287119731097507}, {
          3.711, -0.7026865454986881}, {3.711, -0.684599929382377}, {
          3.711, -0.7026865454986881}, {3.711, -0.7287119731097507}, {
          3.711, -0.735}, {3.711, -0.70875}, {3.711, -0.7026865454986881}, {
          3.711, -0.70875}, {3.711, -0.735}, {3.711, -0.7287119731097507}, {
          3.711, -0.7026865454986881}, {3.711, -0.70875}, {
          3.711, -0.7026865454986881}, {3.711, -0.7287119731097507}, {
          3.711, -0.7099554823224651}, {3.711, -0.684599929382377}, {
          3.711, -0.7026865454986881}, {3.711, -0.684599929382377}, {
          3.711, -0.7099554823224651}, {3.711, -0.6790514563957957}, {
          3.711, -0.6547996186673745}, {3.711, -0.684599929382377}, {
          3.711, -0.6547996186673745}, {3.711, -0.6790514563957957}, {
          3.711, -0.6365286717815624}, {3.711, -0.6137955049322208}, {
          3.711, -0.6547996186673745}, {3.711, -0.6137955049322208}, {
          3.711, -0.6365286717815624}, {3.711, -0.5831147051140578}, {
          3.711, -0.5622891799314129}, {3.711, -0.6137955049322208}, {
          3.711, -0.5622891799314129}, {3.711, -0.5831147051140578}, {
          3.711, -0.5197234841721123}, {3.711, -0.5011619311659655}, {
          3.711, -0.5622891799314129}, {3.711, -0.5011619311659655}, {
          3.711, -0.5197234841721123}, {3.711, -0.4474396503214097}, {
          3.711, -0.43145966280993076`}, {3.711, -0.5011619311659655}, {
          3.711, -0.43145966280993076`}, {3.711, -0.4474396503214097}, {
          3.711, -0.3675}, {3.711, -0.354375}, {
          3.711, -0.43145966280993076`}, {3.711, -0.354375}, {
          3.711, -0.3675}, {3.711, -0.28127232278834097`}, {
          3.711, -0.2712268826887574}, {3.711, -0.354375}, {
          3.711, -0.2712268826887574}, {3.711, -0.28127232278834097`}, {
          3.711, -0.19023199815035272`}, {3.711, -0.18343799821641155`}, {
          3.711, -0.2712268826887574}, {3.711, -0.18343799821641155`}, {
          3.711, -0.19023199815035272`}, {3.711, -0.0959367512817379}, {
          3.711, -0.09251043873596154}, {3.711, -0.18343799821641155`}, {
          3.711, -0.09251043873596154}, {3.711, -0.0959367512817379}, {3.711, 
          0.}, {3.711, 0.}, {3.711, -0.09251043873596154}, {3.711, 0.}, {
          3.711, 0.}, {3.711, 0.0959367512817379}, {3.711, 
          0.09251043873596154}, {3.711, 0.}, {3.711, 0.09251043873596154}, {
          3.711, 0.0959367512817379}, {3.711, 0.19023199815035272`}, {3.711, 
          0.18343799821641155`}, {3.711, 0.09251043873596154}, {3.711, 
          0.18343799821641155`}, {3.711, 0.19023199815035272`}, {3.711, 
          0.28127232278834097`}, {3.711, 0.2712268826887574}, {3.711, 
          0.18343799821641155`}, {3.711, 0.2712268826887574}, {3.711, 
          0.28127232278834097`}, {3.711, 0.3675}, {3.711, 0.354375}, {3.711, 
          0.2712268826887574}, {3.711, 0.354375}, {3.711, 0.3675}, {3.711, 
          0.4474396503214097}, {3.711, 0.43145966280993076`}, {3.711, 
          0.354375}, {3.711, 0.43145966280993076`}, {3.711, 
          0.4474396503214097}, {3.711, 0.5197234841721123}, {3.711, 
          0.5011619311659655}, {3.711, 0.43145966280993076`}, {3.711, 
          0.5011619311659655}, {3.711, 0.5197234841721123}, {3.711, 
          0.5831147051140578}, {3.711, 0.5622891799314129}, {3.711, 
          0.5011619311659655}, {3.711, 0.5622891799314129}, {3.711, 
          0.5831147051140578}, {3.711, 0.6365286717815624}, {3.711, 
          0.6137955049322208}, {3.711, 0.5622891799314129}, {3.711, 
          0.6137955049322208}, {3.711, 0.6365286717815624}, {3.711, 
          0.6790514563957957}, {3.711, 0.6547996186673745}, {3.711, 
          0.6137955049322208}, {3.711, 0.6547996186673745}, {3.711, 
          0.6790514563957957}, {3.711, 0.7099554823224651}, {3.711, 
          0.684599929382377}, {3.711, 0.6547996186673745}, {3.711, 
          0.684599929382377}, {3.711, 0.7099554823224651}, {3.711, 
          0.7287119731097507}, {3.711, 0.7026865454986881}, {3.711, 
          0.684599929382377}, {3.711, 0.7026865454986881}, {3.711, 
          0.7287119731097507}, {3.711, 0.735}, {3.711, 0.70875}, {3.711, 
          0.7026865454986881}, {3.711, 0.735}, {3.711, 0.76125}, {3.711, 
          0.7547374007208132}, {3.711, 0.7287119731097507}, {3.711, 0.735}, {
          3.711, 0.7287119731097507}, {3.711, 0.7547374007208132}, {3.711, 
          0.7353110352625531}, {3.711, 0.7099554823224651}, {3.711, 
          0.7287119731097507}, {3.711, 0.7099554823224651}, {3.711, 
          0.7353110352625531}, {3.711, 0.703303294124217}, {3.711, 
          0.6790514563957957}, {3.711, 0.7099554823224651}, {3.711, 
          0.6790514563957957}, {3.711, 0.703303294124217}, {3.711, 
          0.6592618386309038}, {3.711, 0.6365286717815624}, {3.711, 
          0.6790514563957957}, {3.711, 0.6365286717815624}, {3.711, 
          0.6592618386309038}, {3.711, 0.6039402302967027}, {3.711, 
          0.5831147051140578}, {3.711, 0.6365286717815624}, {3.711, 
          0.5831147051140578}, {3.711, 0.6039402302967027}, {3.711, 
          0.5382850371782593}, {3.711, 0.5197234841721123}, {3.711, 
          0.5831147051140578}, {3.711, 0.5197234841721123}, {3.711, 
          0.5382850371782593}, {3.711, 0.4634196378328886}, {3.711, 
          0.4474396503214097}, {3.711, 0.5197234841721123}, {3.711, 
          0.4474396503214097}, {3.711, 0.4634196378328886}, {3.711, 
          0.380625}, {3.711, 0.3675}, {3.711, 0.4474396503214097}, {3.711, 
          0.3675}, {3.711, 0.380625}, {3.711, 0.2913177628879246}, {3.711, 
          0.28127232278834097`}, {3.711, 0.3675}, {3.711, 
          0.28127232278834097`}, {3.711, 0.2913177628879246}, {3.711, 
          0.19702599808429389`}, {3.711, 0.19023199815035272`}, {3.711, 
          0.28127232278834097`}, {3.711, 0.19023199815035272`}, {3.711, 
          0.19702599808429389`}, {3.711, 0.09936306382751425}, {3.711, 
          0.0959367512817379}, {3.711, 0.19023199815035272`}, {3.711, 
          0.0959367512817379}, {3.711, 0.09936306382751425}, {3.711, 0.}, {
          3.711, 0.}, {3.711, 0.0959367512817379}, {3.711, 0.}, {3.711, 0.}, {
          3.711, -0.09936306382751425}, {3.711, -0.0959367512817379}, {3.711, 
          0.}, {3.711, -0.0959367512817379}, {3.711, -0.09936306382751425}, {
          3.711, -0.19702599808429389`}, {3.711, -0.19023199815035272`}, {
          3.711, -0.0959367512817379}, {3.711, -0.19023199815035272`}, {
          3.711, -0.19702599808429389`}, {3.711, -0.2913177628879246}, {
          3.711, -0.28127232278834097`}, {3.711, -0.19023199815035272`}, {
          3.711, -0.28127232278834097`}, {3.711, -0.2913177628879246}, {
          3.711, -0.380625}, {3.711, -0.3675}, {
          3.711, -0.28127232278834097`}, {3.711, -0.3675}, {
          3.711, -0.380625}, {3.711, -0.4634196378328886}, {
          3.711, -0.4474396503214097}, {3.711, -0.3675}, {
          3.711, -0.4474396503214097}, {3.711, -0.4634196378328886}, {
          3.711, -0.5382850371782593}, {3.711, -0.5197234841721123}, {
          3.711, -0.4474396503214097}, {3.711, -0.5197234841721123}, {
          3.711, -0.5382850371782593}, {3.711, -0.6039402302967027}, {
          3.711, -0.5831147051140578}, {3.711, -0.5197234841721123}, {
          3.711, -0.5831147051140578}, {3.711, -0.6039402302967027}, {
          3.711, -0.6592618386309038}, {3.711, -0.6365286717815624}, {
          3.711, -0.5831147051140578}, {3.711, -0.6365286717815624}, {
          3.711, -0.6592618386309038}, {3.711, -0.703303294124217}, {
          3.711, -0.6790514563957957}, {3.711, -0.6365286717815624}, {
          3.711, -0.6790514563957957}, {3.711, -0.703303294124217}, {
          3.711, -0.7353110352625531}, {3.711, -0.7099554823224651}, {
          3.711, -0.6790514563957957}, {3.711, -0.7099554823224651}, {
          3.711, -0.7353110352625531}, {3.711, -0.7547374007208132}, {
          3.711, -0.7287119731097507}, {3.711, -0.7099554823224651}, {
          3.711, -0.7287119731097507}, {3.711, -0.7547374007208132}, {
          3.711, -0.76125}, {3.711, -0.735}, {3.711, -0.7287119731097507}, {
          3.711, -0.735}, {3.711, -0.76125}, {3.711, -0.7547374007208132}, {
          3.711, -0.7287119731097507}, {3.711, -0.735}, {
          3.711, -0.7287119731097507}, {3.711, -0.7547374007208132}, {
          3.711, -0.7353110352625531}, {3.711, -0.7099554823224651}, {
          3.711, -0.7287119731097507}, {3.711, -0.7099554823224651}, {
          3.711, -0.7353110352625531}, {3.711, -0.703303294124217}, {
          3.711, -0.6790514563957957}, {3.711, -0.7099554823224651}, {
          3.711, -0.6790514563957957}, {3.711, -0.703303294124217}, {
          3.711, -0.6592618386309038}, {3.711, -0.6365286717815624}, {
          3.711, -0.6790514563957957}, {3.711, -0.6365286717815624}, {
          3.711, -0.6592618386309038}, {3.711, -0.6039402302967027}, {
          3.711, -0.5831147051140578}, {3.711, -0.6365286717815624}, {
          3.711, -0.5831147051140578}, {3.711, -0.6039402302967027}, {
          3.711, -0.5382850371782593}, {3.711, -0.5197234841721123}, {
          3.711, -0.5831147051140578}, {3.711, -0.5197234841721123}, {
          3.711, -0.5382850371782593}, {3.711, -0.4634196378328886}, {
          3.711, -0.4474396503214097}, {3.711, -0.5197234841721123}, {
          3.711, -0.4474396503214097}, {3.711, -0.4634196378328886}, {
          3.711, -0.380625}, {3.711, -0.3675}, {3.711, -0.4474396503214097}, {
          3.711, -0.3675}, {3.711, -0.380625}, {3.711, -0.2913177628879246}, {
          3.711, -0.28127232278834097`}, {3.711, -0.3675}, {
          3.711, -0.28127232278834097`}, {3.711, -0.2913177628879246}, {
          3.711, -0.19702599808429389`}, {3.711, -0.19023199815035272`}, {
          3.711, -0.28127232278834097`}, {3.711, -0.19023199815035272`}, {
          3.711, -0.19702599808429389`}, {3.711, -0.09936306382751425}, {
          3.711, -0.0959367512817379}, {3.711, -0.19023199815035272`}, {
          3.711, -0.0959367512817379}, {3.711, -0.09936306382751425}, {3.711, 
          0.}, {3.711, 0.}, {3.711, -0.0959367512817379}, {3.711, 0.}, {3.711,
           0.}, {3.711, 0.09936306382751425}, {3.711, 0.0959367512817379}, {
          3.711, 0.}, {3.711, 0.0959367512817379}, {3.711, 
          0.09936306382751425}, {3.711, 0.19702599808429389`}, {3.711, 
          0.19023199815035272`}, {3.711, 0.0959367512817379}, {3.711, 
          0.19023199815035272`}, {3.711, 0.19702599808429389`}, {3.711, 
          0.2913177628879246}, {3.711, 0.28127232278834097`}, {3.711, 
          0.19023199815035272`}, {3.711, 0.28127232278834097`}, {3.711, 
          0.2913177628879246}, {3.711, 0.380625}, {3.711, 0.3675}, {3.711, 
          0.28127232278834097`}, {3.711, 0.3675}, {3.711, 0.380625}, {3.711, 
          0.4634196378328886}, {3.711, 0.4474396503214097}, {3.711, 0.3675}, {
          3.711, 0.4474396503214097}, {3.711, 0.4634196378328886}, {3.711, 
          0.5382850371782593}, {3.711, 0.5197234841721123}, {3.711, 
          0.4474396503214097}, {3.711, 0.5197234841721123}, {3.711, 
          0.5382850371782593}, {3.711, 0.6039402302967027}, {3.711, 
          0.5831147051140578}, {3.711, 0.5197234841721123}, {3.711, 
          0.5831147051140578}, {3.711, 0.6039402302967027}, {3.711, 
          0.6592618386309038}, {3.711, 0.6365286717815624}, {3.711, 
          0.5831147051140578}, {3.711, 0.6365286717815624}, {3.711, 
          0.6592618386309038}, {3.711, 0.703303294124217}, {3.711, 
          0.6790514563957957}, {3.711, 0.6365286717815624}, {3.711, 
          0.6790514563957957}, {3.711, 0.703303294124217}, {3.711, 
          0.7353110352625531}, {3.711, 0.7099554823224651}, {3.711, 
          0.6790514563957957}, {3.711, 0.7099554823224651}, {3.711, 
          0.7353110352625531}, {3.711, 0.7547374007208132}, {3.711, 
          0.7287119731097507}, {3.711, 0.7099554823224651}, {3.711, 
          0.7287119731097507}, {3.711, 0.7547374007208132}, {3.711, 
          0.76125}, {3.711, 0.735}, {3.711, 0.7287119731097507}, {3.711, 
          0.76125}, {3.711, 0.7875}, {3.711, 0.7807628283318757}, {3.711, 
          0.7547374007208132}, {3.711, 0.76125}, {3.711, 
          0.7547374007208132}, {3.711, 0.7807628283318757}, {3.711, 
          0.7606665882026411}, {3.711, 0.7353110352625531}, {3.711, 
          0.7547374007208132}, {3.711, 0.7353110352625531}, {3.711, 
          0.7606665882026411}, {3.711, 0.7275551318526382}, {3.711, 
          0.703303294124217}, {3.711, 0.7353110352625531}, {3.711, 
          0.703303294124217}, {3.711, 0.7275551318526382}, {3.711, 
          0.6819950054802454}, {3.711, 0.6592618386309038}, {3.711, 
          0.703303294124217}, {3.711, 0.6592618386309038}, {3.711, 
          0.6819950054802454}, {3.711, 0.6247657554793477}, {3.711, 
          0.6039402302967027}, {3.711, 0.6592618386309038}, {3.711, 
          0.6039402302967027}, {3.711, 0.6247657554793477}, {3.711, 
          0.5568465901844061}, {3.711, 0.5382850371782593}, {3.711, 
          0.6039402302967027}, {3.711, 0.5382850371782593}, {3.711, 
          0.5568465901844061}, {3.711, 0.47939962534436753`}, {3.711, 
          0.4634196378328886}, {3.711, 0.5382850371782593}, {3.711, 
          0.4634196378328886}, {3.711, 0.47939962534436753`}, {3.711, 
          0.39375}, {3.711, 0.380625}, {3.711, 0.4634196378328886}, {3.711, 
          0.380625}, {3.711, 0.39375}, {3.711, 0.3013632029875082}, {3.711, 
          0.2913177628879246}, {3.711, 0.380625}, {3.711, 
          0.2913177628879246}, {3.711, 0.3013632029875082}, {3.711, 
          0.20381999801823503`}, {3.711, 0.19702599808429389`}, {3.711, 
          0.2913177628879246}, {3.711, 0.19702599808429389`}, {3.711, 
          0.20381999801823503`}, {3.711, 0.10278937637329061`}, {3.711, 
          0.09936306382751425}, {3.711, 0.19702599808429389`}, {3.711, 
          0.09936306382751425}, {3.711, 0.10278937637329061`}, {3.711, 0.}, {
          3.711, 0.}, {3.711, 0.09936306382751425}, {3.711, 0.}, {3.711, 
          0.}, {3.711, -0.10278937637329061`}, {
          3.711, -0.09936306382751425}, {3.711, 0.}, {
          3.711, -0.09936306382751425}, {3.711, -0.10278937637329061`}, {
          3.711, -0.20381999801823503`}, {3.711, -0.19702599808429389`}, {
          3.711, -0.09936306382751425}, {3.711, -0.19702599808429389`}, {
          3.711, -0.20381999801823503`}, {3.711, -0.3013632029875082}, {
          3.711, -0.2913177628879246}, {3.711, -0.19702599808429389`}, {
          3.711, -0.2913177628879246}, {3.711, -0.3013632029875082}, {
          3.711, -0.39375}, {3.711, -0.380625}, {
          3.711, -0.2913177628879246}, {3.711, -0.380625}, {
          3.711, -0.39375}, {3.711, -0.47939962534436753`}, {
          3.711, -0.4634196378328886}, {3.711, -0.380625}, {
          3.711, -0.4634196378328886}, {3.711, -0.47939962534436753`}, {
          3.711, -0.5568465901844061}, {3.711, -0.5382850371782593}, {
          3.711, -0.4634196378328886}, {3.711, -0.5382850371782593}, {
          3.711, -0.5568465901844061}, {3.711, -0.6247657554793477}, {
          3.711, -0.6039402302967027}, {3.711, -0.5382850371782593}, {
          3.711, -0.6039402302967027}, {3.711, -0.6247657554793477}, {
          3.711, -0.6819950054802454}, {3.711, -0.6592618386309038}, {
          3.711, -0.6039402302967027}, {3.711, -0.6592618386309038}, {
          3.711, -0.6819950054802454}, {3.711, -0.7275551318526382}, {
          3.711, -0.703303294124217}, {3.711, -0.6592618386309038}, {
          3.711, -0.703303294124217}, {3.711, -0.7275551318526382}, {
          3.711, -0.7606665882026411}, {3.711, -0.7353110352625531}, {
          3.711, -0.703303294124217}, {3.711, -0.7353110352625531}, {
          3.711, -0.7606665882026411}, {3.711, -0.7807628283318757}, {
          3.711, -0.7547374007208132}, {3.711, -0.7353110352625531}, {
          3.711, -0.7547374007208132}, {3.711, -0.7807628283318757}, {
          3.711, -0.7875}, {3.711, -0.76125}, {3.711, -0.7547374007208132}, {
          3.711, -0.76125}, {3.711, -0.7875}, {3.711, -0.7807628283318757}, {
          3.711, -0.7547374007208132}, {3.711, -0.76125}, {
          3.711, -0.7547374007208132}, {3.711, -0.7807628283318757}, {
          3.711, -0.7606665882026411}, {3.711, -0.7353110352625531}, {
          3.711, -0.7547374007208132}, {3.711, -0.7353110352625531}, {
          3.711, -0.7606665882026411}, {3.711, -0.7275551318526382}, {
          3.711, -0.703303294124217}, {3.711, -0.7353110352625531}, {
          3.711, -0.703303294124217}, {3.711, -0.7275551318526382}, {
          3.711, -0.6819950054802454}, {3.711, -0.6592618386309038}, {
          3.711, -0.703303294124217}, {3.711, -0.6592618386309038}, {
          3.711, -0.6819950054802454}, {3.711, -0.6247657554793477}, {
          3.711, -0.6039402302967027}, {3.711, -0.6592618386309038}, {
          3.711, -0.6039402302967027}, {3.711, -0.6247657554793477}, {
          3.711, -0.5568465901844061}, {3.711, -0.5382850371782593}, {
          3.711, -0.6039402302967027}, {3.711, -0.5382850371782593}, {
          3.711, -0.5568465901844061}, {3.711, -0.47939962534436753`}, {
          3.711, -0.4634196378328886}, {3.711, -0.5382850371782593}, {
          3.711, -0.4634196378328886}, {3.711, -0.47939962534436753`}, {
          3.711, -0.39375}, {3.711, -0.380625}, {
          3.711, -0.4634196378328886}, {3.711, -0.380625}, {
          3.711, -0.39375}, {3.711, -0.3013632029875082}, {
          3.711, -0.2913177628879246}, {3.711, -0.380625}, {
          3.711, -0.2913177628879246}, {3.711, -0.3013632029875082}, {
          3.711, -0.20381999801823503`}, {3.711, -0.19702599808429389`}, {
          3.711, -0.2913177628879246}, {3.711, -0.19702599808429389`}, {
          3.711, -0.20381999801823503`}, {3.711, -0.10278937637329061`}, {
          3.711, -0.09936306382751425}, {3.711, -0.19702599808429389`}, {
          3.711, -0.09936306382751425}, {3.711, -0.10278937637329061`}, {
          3.711, 0.}, {3.711, 0.}, {3.711, -0.09936306382751425}, {3.711, 
          0.}, {3.711, 0.}, {3.711, 0.10278937637329061`}, {3.711, 
          0.09936306382751425}, {3.711, 0.}, {3.711, 0.09936306382751425}, {
          3.711, 0.10278937637329061`}, {3.711, 0.20381999801823503`}, {3.711,
           0.19702599808429389`}, {3.711, 0.09936306382751425}, {3.711, 
          0.19702599808429389`}, {3.711, 0.20381999801823503`}, {3.711, 
          0.3013632029875082}, {3.711, 0.2913177628879246}, {3.711, 
          0.19702599808429389`}, {3.711, 0.2913177628879246}, {3.711, 
          0.3013632029875082}, {3.711, 0.39375}, {3.711, 0.380625}, {3.711, 
          0.2913177628879246}, {3.711, 0.380625}, {3.711, 0.39375}, {3.711, 
          0.47939962534436753`}, {3.711, 0.4634196378328886}, {3.711, 
          0.380625}, {3.711, 0.4634196378328886}, {3.711, 
          0.47939962534436753`}, {3.711, 0.5568465901844061}, {3.711, 
          0.5382850371782593}, {3.711, 0.4634196378328886}, {3.711, 
          0.5382850371782593}, {3.711, 0.5568465901844061}, {3.711, 
          0.6247657554793477}, {3.711, 0.6039402302967027}, {3.711, 
          0.5382850371782593}, {3.711, 0.6039402302967027}, {3.711, 
          0.6247657554793477}, {3.711, 0.6819950054802454}, {3.711, 
          0.6592618386309038}, {3.711, 0.6039402302967027}, {3.711, 
          0.6592618386309038}, {3.711, 0.6819950054802454}, {3.711, 
          0.7275551318526382}, {3.711, 0.703303294124217}, {3.711, 
          0.6592618386309038}, {3.711, 0.703303294124217}, {3.711, 
          0.7275551318526382}, {3.711, 0.7606665882026411}, {3.711, 
          0.7353110352625531}, {3.711, 0.703303294124217}, {3.711, 
          0.7353110352625531}, {3.711, 0.7606665882026411}, {3.711, 
          0.7807628283318757}, {3.711, 0.7547374007208132}, {3.711, 
          0.7353110352625531}, {3.711, 0.7547374007208132}, {3.711, 
          0.7807628283318757}, {3.711, 0.7875}, {3.711, 0.76125}, {3.711, 
          0.7547374007208132}}]; $CellContext`lines1121142012213105118345376 = 
       Compile[{$CellContext`rr1, $CellContext`rr2, $CellContext`rr6, \
$CellContext`rr7, $CellContext`rr8}, {{
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.6}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.3333333333333335`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777782` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.0666666666666669`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.8}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.5333333333333334}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.26666666666666683`}, {
          2. + $CellContext`rr1 - 1. Sqrt[0. + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.07111111111111108 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.2666666666666666}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.5333333333333332}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6399999999999997 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.7999999999999998}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777773` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.0666666666666664`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.777777777777777 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.333333333333333}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.6}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.6}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.3333333333333335`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.1377777777777782` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.0666666666666669`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.8}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.5333333333333334}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.26666666666666683`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[0. + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.07111111111111108 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.2666666666666666}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.5333333333333332}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.6399999999999997 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.7999999999999998}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.1377777777777773` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.0666666666666664`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.777777777777777 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.333333333333333}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.6}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.6}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777782` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2. + $CellContext`rr1 - 1. Sqrt[0. + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.07111111111111108 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-0.6399999999999997 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.1377777777777773` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-1.777777777777777 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.7777777777777781` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.1377777777777782` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.0711111111111112 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[0. + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.07111111111111108 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-0.6399999999999997 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.1377777777777773` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-1.777777777777777 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.}, {2.9178823575931885`, -1.28}, {
          2.7581905353813383`, -1.0666666666666667`}, {
          2.6382341817875212`, -0.8533333333333334}, {
          2.550289432436307, -0.6400000000000001}, {
          2.489942168569282, -0.42666666666666675`}, {
          2.4546296458019334`, -0.21333333333333337`}, {
          2.4429999999999996`, -2.220446049250313*^-16}, {2.4546296458019334`,
           0.21333333333333315`}, {2.4899421685692817`, 0.4266666666666665}, {
          2.5502894324363066`, 0.6399999999999999}, {2.6382341817875212`, 
          0.8533333333333333}, {2.7581905353813383`, 1.0666666666666667`}, {
          2.917882357593188, 1.2799999999999996`}, {3.0109724820688584`, 
          1.28}, {3.022293022805492, 1.0666666666666667`}, {3.031550975310239,
           0.8533333333333334}, {3.0387489278057522`, 0.6400000000000001}, {
          3.043888889613843, 0.42666666666666675`}, {3.046972293965233, 
          0.21333333333333337`}, {3.0479999999999983`, 
          2.220446049250313*^-16}, {
          3.046972293965233, -0.21333333333333315`}, {
          3.043888889613843, -0.4266666666666665}, {
          3.0387489278057522`, -0.6399999999999999}, {
          3.031550975310239, -0.8533333333333333}, {
          3.022293022805492, -1.0666666666666667`}, {
          3.0109724820688584`, -1.2799999999999996`}, {
          2.9178823575931885`, -1.28}, {2.9178823575931885`, 0.}, {
          2.7581905353813383`, 0.}, {2.6382341817875212`, 0.}, {
          2.550289432436307, 0.}, {2.489942168569282, 0.}, {
          2.4546296458019334`, 0.}, {2.4429999999999996`, 0.}, {
          2.4546296458019334`, 0.}, {2.4899421685692817`, 0.}, {
          2.5502894324363066`, 0.}, {2.6382341817875212`, 0.}, {
          2.7581905353813383`, 0.}, {2.917882357593188, 0.}, {
          3.0109724820688584`, 0.}, {3.022293022805492, 0.}, {
          3.031550975310239, 0.}, {3.0387489278057522`, 0.}, {
          3.043888889613843, 0.}, {3.046972293965233, 0.}, {
          3.0479999999999983`, 0.}, {3.046972293965233, 0.}, {
          3.043888889613843, 0.}, {3.0387489278057522`, 0.}, {
          3.031550975310239, 0.}, {3.022293022805492, 0.}, {
          3.0109724820688584`, 0.}, {2.9178823575931885`, 0.}, {
          3.0109724820688584`, -1.28}, {
          3.022293022805492, -1.0666666666666667`}, {
          3.031550975310239, -0.8533333333333334}, {
          3.0387489278057522`, -0.6400000000000001}, {
          3.043888889613843, -0.42666666666666675`}, {
          3.046972293965233, -0.21333333333333337`}, {
          3.0479999999999983`, -2.220446049250313*^-16}, {3.046972293965233, 
          0.21333333333333315`}, {3.043888889613843, 0.4266666666666665}, {
          3.0387489278057522`, 0.6399999999999999}, {3.031550975310239, 
          0.8533333333333333}, {3.022293022805492, 1.0666666666666667`}, {
          3.0109724820688584`, 1.2799999999999996`}, {3.574048663883448, 
          0.75}, {3.494151395052641, 0.625}, {3.4328084629414652`, 0.5}, {
          3.3872235421489707`, 0.375}, {3.3556769978186205`, 0.25}, {
          3.337124387315237, 0.125}, {3.3310000000000004`, 0.}, {
          3.337124387315237, -0.125}, {3.3556769978186205`, -0.25}, {
          3.3872235421489707`, -0.375}, {3.4328084629414652`, -0.5}, {
          3.494151395052641, -0.625}, {3.574048663883448, -0.75}, {
          3.0109724820688584`, -1.28}, {3.0109724820688584`, 0.}, {
          3.022293022805492, 0.}, {3.031550975310239, 0.}, {
          3.0387489278057522`, 0.}, {3.043888889613843, 0.}, {
          3.046972293965233, 0.}, {3.0479999999999983`, 0.}, {
          3.046972293965233, 0.}, {3.043888889613843, 0.}, {
          3.0387489278057522`, 0.}, {3.031550975310239, 0.}, {
          3.022293022805492, 0.}, {3.0109724820688584`, 0.}, {
          3.574048663883448, 0.}, {3.494151395052641, 0.}, {
          3.4328084629414652`, 0.}, {3.3872235421489707`, 0.}, {
          3.3556769978186205`, 0.}, {3.337124387315237, 0.}, {
          3.3310000000000004`, 0.}, {3.337124387315237, 0.}, {
          3.3556769978186205`, 0.}, {3.3872235421489707`, 0.}, {
          3.4328084629414652`, 0.}, {3.494151395052641, 0.}, {
          3.574048663883448, 0.}, {3.0109724820688584`, 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.8}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444453` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.6666666666666667}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.5333333333333334}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.16000000000000003` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.4}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111114 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.2666666666666667}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.0177777777777778 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.13333333333333341`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[0. + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.01777777777777777 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.1333333333333333}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111108 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.2666666666666666}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.15999999999999992` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.3999999999999999}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.5333333333333332}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444425` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.6666666666666665}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.8}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9833333333333333}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7866666666666666}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.59}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.3933333333333333}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.038677777777777776` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.19666666666666666`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[0. + $CellContext`rr7^2] Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777773 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.19666666666666655`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3933333333333333}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.5900000000000001}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.7866666666666666}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9833333333333332}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.18}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.8}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444453` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444456` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.16000000000000003` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111114 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.0177777777777778 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[0. + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.01777777777777777 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.07111111111111108 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.15999999999999992` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.28444444444444433` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.44444444444444425` + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.038677777777777776` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[0. + $CellContext`rr7^2] Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777773 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9833333333333333}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.7866666666666666}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.59}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3933333333333333}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.038677777777777776` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.19666666666666666`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[0. + $CellContext`rr7^2] Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777773 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.19666666666666655`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.3933333333333333}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.5900000000000001}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7866666666666666}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9833333333333332}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.18}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.18}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.9669444444444444 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.9833333333333333}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.7866666666666666}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.59}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.3933333333333333}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.038677777777777776` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.19666666666666666`}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[0. + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.03867777777777773 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.19666666666666655`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.3933333333333333}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.5900000000000001}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.7866666666666666}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.9833333333333332}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.038677777777777776` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[0. + $CellContext`rr7^2] Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.03867777777777773 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.9669444444444444 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.34809999999999997` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.038677777777777776` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[0. + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.03867777777777773 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.1547111111111111 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.3481000000000001 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.6188444444444444 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-0.9669444444444442 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.}, {5.534443062211261, -1.5}, {
          5.480951960507346, -1.25}, {5.437514103763482, -1.}, {
          5.403928867156194, -0.75}, {5.380044781965627, -0.5}, {
          5.365756018538898, -0.25}, {5.361000000000001, 0.}, {
          5.365756018538898, 0.25}, {5.380044781965627, 0.5}, {
          5.403928867156194, 0.75}, {5.437514103763482, 1.}, {
          5.480951960507346, 1.25}, {5.534443062211261, 1.5}, {
          5.627613727648733, 1.5}, {5.66673280243244, 1.25}, {
          5.698610540005257, 1.}, {5.723325072171594, 0.75}, {
          5.7409362013674965`, 0.5}, {5.751486135780276, 0.25}, {
          5.755000000000001, 0.}, {5.751486135780276, -0.25}, {
          5.7409362013674965`, -0.5}, {5.723325072171594, -0.75}, {
          5.698610540005257, -1.}, {5.66673280243244, -1.25}, {
          5.627613727648733, -1.5}, {5.534443062211261, -1.5}, {
          5.534443062211261, 0.}, {5.480951960507346, 0.}, {5.437514103763482,
           0.}, {5.403928867156194, 0.}, {5.380044781965627, 0.}, {
          5.365756018538898, 0.}, {5.361000000000001, 0.}, {5.365756018538898,
           0.}, {5.380044781965627, 0.}, {5.403928867156194, 0.}, {
          5.437514103763482, 0.}, {5.480951960507346, 0.}, {5.534443062211261,
           0.}, {5.627613727648733, 0.}, {5.66673280243244, 0.}, {
          5.698610540005257, 0.}, {5.723325072171594, 0.}, {
          5.7409362013674965`, 0.}, {5.751486135780276, 0.}, {
          5.755000000000001, 0.}, {5.751486135780276, 0.}, {
          5.7409362013674965`, 0.}, {5.723325072171594, 0.}, {
          5.698610540005257, 0.}, {5.66673280243244, 0.}, {5.627613727648733, 
          0.}, {5.534443062211261, 0.}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.6}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.6}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.5863117781980967`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.5863117781980967`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.6}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.5863117781980967`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.5863117781980967`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.5454813220625094`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.5454813220625094`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.5863117781980967`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.5454813220625094`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.5454813220625094`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.478207252018059}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.478207252018059}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.5454813220625094`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.478207252018059}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.478207252018059}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.385640646055102}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.385640646055102}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.478207252018059}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.385640646055102}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.385640646055102}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5599999999999996` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.2693653444659763`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5599999999999996` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.2693653444659763`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.385640646055102}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5599999999999996` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.2693653444659763`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5599999999999996` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.2693653444659763`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.1313708498984762`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.1313708498984762`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5599999999999996` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.2693653444659763`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.1313708498984762`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.1313708498984762`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.9740182864139533}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.9740182864139533}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.1313708498984762`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.9740182864139533}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.9740182864139533}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.8000000000000003}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.8000000000000003}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.9740182864139533}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.8000000000000003}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.8000000000000003}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.6122934917841438}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.6122934917841438}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.8000000000000003}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.6122934917841438}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.6122934917841438}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.4141104721640332}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.4141104721640332}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.6122934917841438}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.41411047216403357`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.41411047216403357`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.20884190755208276`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.20884190755208276`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.41411047216403357`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.20884190755208276`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.20884190755208276`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 9.797174393178826*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 9.797174393178826*^-17}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.20884190755208276`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 9.797174393178826*^-17}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 9.797174393178826*^-17}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.20884190755208257`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.20884190755208257`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 9.797174393178826*^-17}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.2088419075520822}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.2088419075520822}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.414110472164033}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.414110472164033}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.2088419075520822}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.414110472164033}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.414110472164033}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.6122934917841436}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.6122934917841436}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.414110472164033}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.6122934917841433}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.6122934917841433}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.560000000000001 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.7999999999999997}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.560000000000001 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.7999999999999997}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.6122934917841433}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.560000000000001 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.7999999999999997}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.560000000000001 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.7999999999999997}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.9740182864139526}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.9740182864139526}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.560000000000001 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.7999999999999997}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.9740182864139526}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.9740182864139526}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.1313708498984754`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.1313708498984754`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.9740182864139526}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.131370849898476}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.131370849898476}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.269365344465976}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.269365344465976}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.131370849898476}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.269365344465976}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.269365344465976}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.3856406460551016`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.3856406460551016`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.269365344465976}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.3856406460551016`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.3856406460551016`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.4782072520180585`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.4782072520180585`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.3856406460551016`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.478207252018059}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.478207252018059}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.5454813220625092`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.5454813220625092`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.478207252018059}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.5454813220625092`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.5454813220625092`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.5863117781980967`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.5863117781980967`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.5454813220625092`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.5863117781980967`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.5863117781980967`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.6}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.6}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.5863117781980967`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.6}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.6}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.5863117781980969`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.5863117781980969`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.6}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.5863117781980969`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.5863117781980969`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.5454813220625097`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.5454813220625097`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.5863117781980969`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.5454813220625097`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.5454813220625097`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.4782072520180591`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.4782072520180591`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.5454813220625097`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.4782072520180591`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.4782072520180591`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.3856406460551025`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.3856406460551025`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.4782072520180591`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.560000000000001 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.3856406460551023`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.560000000000001 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.3856406460551023`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.2693653444659767`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.2693653444659767`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.560000000000001 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.3856406460551023`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.2693653444659767`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.2693653444659767`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.1313708498984767`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.1313708498984767`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.2693653444659767`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.1313708498984767`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.1313708498984767`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.9740182864139535}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.9740182864139535}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.1313708498984767`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.9740182864139535}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.9740182864139535}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.8000000000000007}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.8000000000000007}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.9740182864139535}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.8000000000000007}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.8000000000000007}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.6122934917841446}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.6122934917841446}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.8000000000000007}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.6122934917841446}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.6122934917841446}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.41411047216403435`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.41411047216403435`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.6122934917841446}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.41411047216403435`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.41411047216403435`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.20884190755208404`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.20884190755208404`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.41411047216403435`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.20884190755208404`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -0.20884190755208404`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -1.7150007033155652`*^-15}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -1.7150007033155652`*^-15}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -0.20884190755208404`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -2.9391523179536476`*^-16}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], -2.9391523179536476`*^-16}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.20884190755208198`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.20884190755208198`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], -2.9391523179536476`*^-16}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.20884190755208198`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.20884190755208198`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.4141104721640325}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.4141104721640325}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.20884190755208198`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.4141104721640325}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.4141104721640325}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.6122934917841427}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.6122934917841427}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.4141104721640325}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.6122934917841427}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.6122934917841427}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.7999999999999989}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.7999999999999989}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.6122934917841427}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.7999999999999989}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.7999999999999989}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.9740182864139518}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.9740182864139518}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.7999999999999989}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.9740182864139518}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 0.9740182864139518}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5599999999999996` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.1313708498984747`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5599999999999996` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.1313708498984747`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 0.9740182864139518}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.131370849898476}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.131370849898476}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.269365344465976}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.269365344465976}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.131370849898476}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.269365344465976}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.269365344465976}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.3856406460551014`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.3856406460551014`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.269365344465976}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.3856406460551014`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.3856406460551014`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.4782072520180585`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.4782072520180585`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.3856406460551014`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.4782072520180585`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.4782072520180585`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.545481322062509}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.545481322062509}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.4782072520180585`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.545481322062509}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.545481322062509}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.5863117781980964`}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.5863117781980964`}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.545481322062509}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.5863117781980964`}, {
          2.42 + $CellContext`rr2 - 1. Sqrt[-2.56 + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.5863117781980964`}, {
          2.42 + $CellContext`rr2 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr2^2] 
           Sign[$CellContext`rr2], 1.6}, {
          2. + $CellContext`rr1 - 1. 
           Sqrt[-2.5600000000000005` + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.6}, {
          2. + $CellContext`rr1 - 1. Sqrt[-2.56 + $CellContext`rr1^2] 
           Sign[$CellContext`rr1], 1.5863117781980964`}, {2.9178823575931885`,
           1.28}, {3.0109724820688584`, 1.28}, {3.0109724820688584`, 
          1.2690494225584774`}, {2.9178823575931885`, 1.2690494225584774`}, {
          2.9178823575931885`, 1.28}, {2.9178823575931885`, 
          1.2690494225584774`}, {3.0109724820688584`, 1.2690494225584774`}, {
          3.0109724820688584`, 1.2363850576500075`}, {2.9178823575931885`, 
          1.2363850576500075`}, {2.9178823575931885`, 1.2690494225584774`}, {
          2.9178823575931885`, 1.2363850576500075`}, {3.0109724820688584`, 
          1.2363850576500075`}, {3.0109724820688584`, 1.1825658016144471`}, {
          2.9178823575931885`, 1.1825658016144471`}, {2.9178823575931885`, 
          1.2363850576500075`}, {2.9178823575931885`, 1.1825658016144471`}, {
          3.0109724820688584`, 1.1825658016144471`}, {3.0109724820688584`, 
          1.1085125168440815`}, {2.9178823575931885`, 1.1085125168440815`}, {
          2.9178823575931885`, 1.1825658016144471`}, {2.9178823575931885`, 
          1.1085125168440815`}, {3.0109724820688584`, 1.1085125168440815`}, {
          3.0109724820688584`, 1.015492275572781}, {2.9178823575931885`, 
          1.015492275572781}, {2.9178823575931885`, 1.1085125168440815`}, {
          2.9178823575931885`, 1.015492275572781}, {3.0109724820688584`, 
          1.015492275572781}, {3.0109724820688584`, 0.9050966799187811}, {
          2.9178823575931885`, 0.9050966799187811}, {2.9178823575931885`, 
          1.015492275572781}, {2.9178823575931885`, 0.905096679918781}, {
          3.0109724820688584`, 0.905096679918781}, {3.0109724820688584`, 
          0.7792146291311626}, {2.9178823575931885`, 0.7792146291311626}, {
          2.9178823575931885`, 0.905096679918781}, {2.9178823575931885`, 
          0.7792146291311626}, {3.0109724820688584`, 0.7792146291311626}, {
          3.0109724820688584`, 0.6400000000000001}, {2.9178823575931885`, 
          0.6400000000000001}, {2.9178823575931885`, 0.7792146291311626}, {
          2.9178823575931885`, 0.6400000000000001}, {3.0109724820688584`, 
          0.6400000000000001}, {3.0109724820688584`, 0.489834793427315}, {
          2.9178823575931885`, 0.489834793427315}, {2.9178823575931885`, 
          0.6400000000000001}, {2.9178823575931885`, 0.489834793427315}, {
          3.0109724820688584`, 0.489834793427315}, {3.0109724820688584`, 
          0.33128837773122655`}, {2.9178823575931885`, 
          0.33128837773122655`}, {2.9178823575931885`, 0.489834793427315}, {
          2.9178823575931885`, 0.3312883777312268}, {3.0109724820688584`, 
          0.3312883777312268}, {3.0109724820688584`, 0.1670735260416662}, {
          2.9178823575931885`, 0.1670735260416662}, {2.9178823575931885`, 
          0.3312883777312268}, {2.9178823575931885`, 0.1670735260416662}, {
          3.0109724820688584`, 0.1670735260416662}, {3.0109724820688584`, 
          7.83773951454306*^-17}, {2.9178823575931885`, 
          7.83773951454306*^-17}, {2.9178823575931885`, 0.1670735260416662}, {
          2.9178823575931885`, 7.83773951454306*^-17}, {3.0109724820688584`, 
          7.83773951454306*^-17}, {
          3.0109724820688584`, -0.16707352604166606`}, {
          2.9178823575931885`, -0.16707352604166606`}, {2.9178823575931885`, 
          7.83773951454306*^-17}, {
          2.9178823575931885`, -0.16707352604166578`}, {
          3.0109724820688584`, -0.16707352604166578`}, {
          3.0109724820688584`, -0.33128837773122644`}, {
          2.9178823575931885`, -0.33128837773122644`}, {
          2.9178823575931885`, -0.16707352604166578`}, {
          2.9178823575931885`, -0.33128837773122644`}, {
          3.0109724820688584`, -0.33128837773122644`}, {
          3.0109724820688584`, -0.48983479342731484`}, {
          2.9178823575931885`, -0.48983479342731484`}, {
          2.9178823575931885`, -0.33128837773122644`}, {
          2.9178823575931885`, -0.48983479342731456`}, {
          3.0109724820688584`, -0.48983479342731456`}, {
          3.0109724820688584`, -0.6399999999999997}, {
          2.9178823575931885`, -0.6399999999999997}, {
          2.9178823575931885`, -0.48983479342731456`}, {
          2.9178823575931885`, -0.6399999999999997}, {
          3.0109724820688584`, -0.6399999999999997}, {
          3.0109724820688584`, -0.779214629131162}, {
          2.9178823575931885`, -0.779214629131162}, {
          2.9178823575931885`, -0.6399999999999997}, {
          2.9178823575931885`, -0.779214629131162}, {
          3.0109724820688584`, -0.779214629131162}, {
          3.0109724820688584`, -0.9050966799187803}, {
          2.9178823575931885`, -0.9050966799187803}, {
          2.9178823575931885`, -0.779214629131162}, {
          2.9178823575931885`, -0.9050966799187807}, {
          3.0109724820688584`, -0.9050966799187807}, {
          3.0109724820688584`, -1.0154922755727807`}, {
          2.9178823575931885`, -1.0154922755727807`}, {
          2.9178823575931885`, -0.9050966799187807}, {
          2.9178823575931885`, -1.0154922755727807`}, {
          3.0109724820688584`, -1.0154922755727807`}, {
          3.0109724820688584`, -1.1085125168440813`}, {
          2.9178823575931885`, -1.1085125168440813`}, {
          2.9178823575931885`, -1.0154922755727807`}, {
          2.9178823575931885`, -1.1085125168440813`}, {
          3.0109724820688584`, -1.1085125168440813`}, {
          3.0109724820688584`, -1.1825658016144467`}, {
          2.9178823575931885`, -1.1825658016144467`}, {
          2.9178823575931885`, -1.1085125168440813`}, {
          2.9178823575931885`, -1.1825658016144471`}, {
          3.0109724820688584`, -1.1825658016144471`}, {
          3.0109724820688584`, -1.2363850576500073`}, {
          2.9178823575931885`, -1.2363850576500073`}, {
          2.9178823575931885`, -1.1825658016144471`}, {
          2.9178823575931885`, -1.2363850576500073`}, {
          3.0109724820688584`, -1.2363850576500073`}, {
          3.0109724820688584`, -1.2690494225584774`}, {
          2.9178823575931885`, -1.2690494225584774`}, {
          2.9178823575931885`, -1.2363850576500073`}, {
          2.9178823575931885`, -1.2690494225584774`}, {
          3.0109724820688584`, -1.2690494225584774`}, {
          3.0109724820688584`, -1.28}, {2.9178823575931885`, -1.28}, {
          2.9178823575931885`, -1.2690494225584774`}, {
          2.9178823575931885`, -1.28}, {3.0109724820688584`, -1.28}, {
          3.0109724820688584`, -1.2690494225584774`}, {
          2.9178823575931885`, -1.2690494225584774`}, {
          2.9178823575931885`, -1.28}, {
          2.9178823575931885`, -1.2690494225584774`}, {
          3.0109724820688584`, -1.2690494225584774`}, {
          3.0109724820688584`, -1.2363850576500075`}, {
          2.9178823575931885`, -1.2363850576500075`}, {
          2.9178823575931885`, -1.2690494225584774`}, {
          2.9178823575931885`, -1.2363850576500075`}, {
          3.0109724820688584`, -1.2363850576500075`}, {
          3.0109724820688584`, -1.1825658016144474`}, {
          2.9178823575931885`, -1.1825658016144474`}, {
          2.9178823575931885`, -1.2363850576500075`}, {
          2.9178823575931885`, -1.1825658016144474`}, {
          3.0109724820688584`, -1.1825658016144474`}, {
          3.0109724820688584`, -1.108512516844082}, {
          2.9178823575931885`, -1.108512516844082}, {
          2.9178823575931885`, -1.1825658016144474`}, {
          2.9178823575931885`, -1.1085125168440817`}, {
          3.0109724820688584`, -1.1085125168440817`}, {
          3.0109724820688584`, -1.0154922755727813`}, {
          2.9178823575931885`, -1.0154922755727813`}, {
          2.9178823575931885`, -1.1085125168440817`}, {
          2.9178823575931885`, -1.0154922755727813`}, {
          3.0109724820688584`, -1.0154922755727813`}, {
          3.0109724820688584`, -0.9050966799187813}, {
          2.9178823575931885`, -0.9050966799187813}, {
          2.9178823575931885`, -1.0154922755727813`}, {
          2.9178823575931885`, -0.9050966799187813}, {
          3.0109724820688584`, -0.9050966799187813}, {
          3.0109724820688584`, -0.7792146291311628}, {
          2.9178823575931885`, -0.7792146291311628}, {
          2.9178823575931885`, -0.9050966799187813}, {
          2.9178823575931885`, -0.7792146291311628}, {
          3.0109724820688584`, -0.7792146291311628}, {
          3.0109724820688584`, -0.6400000000000006}, {
          2.9178823575931885`, -0.6400000000000006}, {
          2.9178823575931885`, -0.7792146291311628}, {
          2.9178823575931885`, -0.6400000000000006}, {
          3.0109724820688584`, -0.6400000000000006}, {
          3.0109724820688584`, -0.4898347934273156}, {
          2.9178823575931885`, -0.4898347934273156}, {
          2.9178823575931885`, -0.6400000000000006}, {
          2.9178823575931885`, -0.4898347934273156}, {
          3.0109724820688584`, -0.4898347934273156}, {
          3.0109724820688584`, -0.3312883777312275}, {
          2.9178823575931885`, -0.3312883777312275}, {
          2.9178823575931885`, -0.4898347934273156}, {
          2.9178823575931885`, -0.3312883777312275}, {
          3.0109724820688584`, -0.3312883777312275}, {
          3.0109724820688584`, -0.16707352604166723`}, {
          2.9178823575931885`, -0.16707352604166723`}, {
          2.9178823575931885`, -0.3312883777312275}, {
          2.9178823575931885`, -0.16707352604166723`}, {
          3.0109724820688584`, -0.16707352604166723`}, {
          3.0109724820688584`, -1.372000562652452*^-15}, {
          2.9178823575931885`, -1.372000562652452*^-15}, {
          2.9178823575931885`, -0.16707352604166723`}, {
          2.9178823575931885`, -2.351321854362918*^-16}, {
          3.0109724820688584`, -2.351321854362918*^-16}, {3.0109724820688584`,
           0.1670735260416656}, {2.9178823575931885`, 0.1670735260416656}, {
          2.9178823575931885`, -2.351321854362918*^-16}, {2.9178823575931885`,
           0.1670735260416656}, {3.0109724820688584`, 0.1670735260416656}, {
          3.0109724820688584`, 0.331288377731226}, {2.9178823575931885`, 
          0.331288377731226}, {2.9178823575931885`, 0.1670735260416656}, {
          2.9178823575931885`, 0.331288377731226}, {3.0109724820688584`, 
          0.331288377731226}, {3.0109724820688584`, 0.4898347934273142}, {
          2.9178823575931885`, 0.4898347934273142}, {2.9178823575931885`, 
          0.331288377731226}, {2.9178823575931885`, 0.4898347934273142}, {
          3.0109724820688584`, 0.4898347934273142}, {3.0109724820688584`, 
          0.6399999999999991}, {2.9178823575931885`, 0.6399999999999991}, {
          2.9178823575931885`, 0.4898347934273142}, {2.9178823575931885`, 
          0.6399999999999991}, {3.0109724820688584`, 0.6399999999999991}, {
          3.0109724820688584`, 0.7792146291311615}, {2.9178823575931885`, 
          0.7792146291311615}, {2.9178823575931885`, 0.6399999999999991}, {
          2.9178823575931885`, 0.7792146291311615}, {3.0109724820688584`, 
          0.7792146291311615}, {3.0109724820688584`, 0.9050966799187797}, {
          2.9178823575931885`, 0.9050966799187797}, {2.9178823575931885`, 
          0.7792146291311615}, {2.9178823575931885`, 0.9050966799187807}, {
          3.0109724820688584`, 0.9050966799187807}, {3.0109724820688584`, 
          1.0154922755727807`}, {2.9178823575931885`, 1.0154922755727807`}, {
          2.9178823575931885`, 0.9050966799187807}, {2.9178823575931885`, 
          1.0154922755727807`}, {3.0109724820688584`, 1.0154922755727807`}, {
          3.0109724820688584`, 1.1085125168440813`}, {2.9178823575931885`, 
          1.1085125168440813`}, {2.9178823575931885`, 1.0154922755727807`}, {
          2.9178823575931885`, 1.1085125168440813`}, {3.0109724820688584`, 
          1.1085125168440813`}, {3.0109724820688584`, 1.1825658016144467`}, {
          2.9178823575931885`, 1.1825658016144467`}, {2.9178823575931885`, 
          1.1085125168440813`}, {2.9178823575931885`, 1.1825658016144467`}, {
          3.0109724820688584`, 1.1825658016144467`}, {3.0109724820688584`, 
          1.2363850576500073`}, {2.9178823575931885`, 1.2363850576500073`}, {
          2.9178823575931885`, 1.1825658016144467`}, {2.9178823575931885`, 
          1.2363850576500073`}, {3.0109724820688584`, 1.2363850576500073`}, {
          3.0109724820688584`, 1.2690494225584772`}, {2.9178823575931885`, 
          1.2690494225584772`}, {2.9178823575931885`, 1.2363850576500073`}, {
          2.9178823575931885`, 1.2690494225584772`}, {3.0109724820688584`, 
          1.2690494225584772`}, {3.0109724820688584`, 1.28}, {
          2.9178823575931885`, 1.28}, {2.9178823575931885`, 
          1.2690494225584772`}, {3.0109724820688584`, 1.28}, {
          3.574048663883448, 0.75}, {3.5740486638834477`, 
          0.7435836460303578}, {3.0109724820688584`, 1.2690494225584774`}, {
          3.0109724820688584`, 1.28}, {3.0109724820688584`, 
          1.2690494225584774`}, {3.5740486638834477`, 0.7435836460303578}, {
          3.574048663883448, 0.7244443697168013}, {3.0109724820688584`, 
          1.2363850576500075`}, {3.0109724820688584`, 1.2690494225584774`}, {
          3.0109724820688584`, 1.2363850576500075`}, {3.574048663883448, 
          0.7244443697168013}, {3.5740486638834477`, 0.692909649383465}, {
          3.0109724820688584`, 1.1825658016144471`}, {3.0109724820688584`, 
          1.2363850576500075`}, {3.0109724820688584`, 1.1825658016144471`}, {
          3.5740486638834477`, 0.692909649383465}, {3.574048663883448, 
          0.649519052838329}, {3.0109724820688584`, 1.1085125168440815`}, {
          3.0109724820688584`, 1.1825658016144471`}, {3.0109724820688584`, 
          1.1085125168440815`}, {3.574048663883448, 0.649519052838329}, {
          3.574048663883448, 0.5950150052184264}, {3.0109724820688584`, 
          1.015492275572781}, {3.0109724820688584`, 1.1085125168440815`}, {
          3.0109724820688584`, 1.015492275572781}, {3.574048663883448, 
          0.5950150052184264}, {3.574048663883448, 0.5303300858899107}, {
          3.0109724820688584`, 0.9050966799187811}, {3.0109724820688584`, 
          1.015492275572781}, {3.0109724820688584`, 0.905096679918781}, {
          3.574048663883448, 0.5303300858899107}, {3.574048663883448, 
          0.45657107175654055`}, {3.0109724820688584`, 0.7792146291311626}, {
          3.0109724820688584`, 0.905096679918781}, {3.0109724820688584`, 
          0.7792146291311626}, {3.574048663883448, 0.45657107175654055`}, {
          3.574048663883448, 0.3750000000000001}, {3.0109724820688584`, 
          0.6400000000000001}, {3.0109724820688584`, 0.7792146291311626}, {
          3.0109724820688584`, 0.6400000000000001}, {3.574048663883448, 
          0.3750000000000001}, {3.5740486638834477`, 0.2870125742738174}, {
          3.0109724820688584`, 0.489834793427315}, {3.0109724820688584`, 
          0.6400000000000001}, {3.0109724820688584`, 0.489834793427315}, {
          3.5740486638834477`, 0.2870125742738174}, {3.574048663883448, 
          0.19411428382689055`}, {3.0109724820688584`, 
          0.33128837773122655`}, {3.0109724820688584`, 0.489834793427315}, {
          3.0109724820688584`, 0.3312883777312268}, {3.574048663883448, 
          0.19411428382689072`}, {3.574048663883448, 0.09789464416503879}, {
          3.0109724820688584`, 0.1670735260416662}, {3.0109724820688584`, 
          0.3312883777312268}, {3.0109724820688584`, 0.1670735260416662}, {
          3.574048663883448, 0.09789464416503879}, {3.574048663883448, 
          4.592425496802574*^-17}, {3.0109724820688584`, 
          7.83773951454306*^-17}, {3.0109724820688584`, 0.1670735260416662}, {
          3.0109724820688584`, 7.83773951454306*^-17}, {3.574048663883448, 
          4.592425496802574*^-17}, {
          3.574048663883448, -0.09789464416503871}, {
          3.0109724820688584`, -0.16707352604166606`}, {3.0109724820688584`, 
          7.83773951454306*^-17}, {
          3.0109724820688584`, -0.16707352604166578`}, {
          3.574048663883448, -0.09789464416503854}, {
          3.574048663883448, -0.19411428382689047`}, {
          3.0109724820688584`, -0.33128837773122644`}, {
          3.0109724820688584`, -0.16707352604166578`}, {
          3.0109724820688584`, -0.33128837773122644`}, {
          3.574048663883448, -0.19411428382689047`}, {
          3.5740486638834477`, -0.2870125742738173}, {
          3.0109724820688584`, -0.48983479342731484`}, {
          3.0109724820688584`, -0.33128837773122644`}, {
          3.0109724820688584`, -0.48983479342731456`}, {
          3.574048663883448, -0.2870125742738171}, {
          3.574048663883448, -0.37499999999999983`}, {
          3.0109724820688584`, -0.6399999999999997}, {
          3.0109724820688584`, -0.48983479342731456`}, {
          3.0109724820688584`, -0.6399999999999997}, {
          3.574048663883448, -0.37499999999999983`}, {
          3.574048663883448, -0.4565710717565402}, {
          3.0109724820688584`, -0.779214629131162}, {
          3.0109724820688584`, -0.6399999999999997}, {
          3.0109724820688584`, -0.779214629131162}, {
          3.574048663883448, -0.4565710717565402}, {
          3.574048663883448, -0.5303300858899104}, {
          3.0109724820688584`, -0.9050966799187803}, {
          3.0109724820688584`, -0.779214629131162}, {
          3.0109724820688584`, -0.9050966799187807}, {
          3.574048663883448, -0.5303300858899106}, {
          3.574048663883448, -0.5950150052184262}, {
          3.0109724820688584`, -1.0154922755727807`}, {
          3.0109724820688584`, -0.9050966799187807}, {
          3.0109724820688584`, -1.0154922755727807`}, {
          3.574048663883448, -0.5950150052184262}, {
          3.574048663883448, -0.6495190528383289}, {
          3.0109724820688584`, -1.1085125168440813`}, {
          3.0109724820688584`, -1.0154922755727807`}, {
          3.0109724820688584`, -1.1085125168440813`}, {
          3.574048663883448, -0.6495190528383289}, {
          3.574048663883448, -0.6929096493834649}, {
          3.0109724820688584`, -1.1825658016144467`}, {
          3.0109724820688584`, -1.1085125168440813`}, {
          3.0109724820688584`, -1.1825658016144471`}, {
          3.5740486638834477`, -0.692909649383465}, {
          3.574048663883448, -0.7244443697168012}, {
          3.0109724820688584`, -1.2363850576500073`}, {
          3.0109724820688584`, -1.1825658016144471`}, {
          3.0109724820688584`, -1.2363850576500073`}, {
          3.574048663883448, -0.7244443697168012}, {
          3.5740486638834477`, -0.7435836460303578}, {
          3.0109724820688584`, -1.2690494225584774`}, {
          3.0109724820688584`, -1.2363850576500073`}, {
          3.0109724820688584`, -1.2690494225584774`}, {
          3.5740486638834477`, -0.7435836460303578}, {
          3.574048663883448, -0.75}, {3.0109724820688584`, -1.28}, {
          3.0109724820688584`, -1.2690494225584774`}, {
          3.0109724820688584`, -1.28}, {3.574048663883448, -0.75}, {
          3.574048663883448, -0.7435836460303579}, {
          3.0109724820688584`, -1.2690494225584774`}, {
          3.0109724820688584`, -1.28}, {
          3.0109724820688584`, -1.2690494225584774`}, {
          3.574048663883448, -0.7435836460303579}, {
          3.574048663883448, -0.7244443697168013}, {
          3.0109724820688584`, -1.2363850576500075`}, {
          3.0109724820688584`, -1.2690494225584774`}, {
          3.0109724820688584`, -1.2363850576500075`}, {
          3.574048663883448, -0.7244443697168013}, {
          3.574048663883448, -0.6929096493834652}, {
          3.0109724820688584`, -1.1825658016144474`}, {
          3.0109724820688584`, -1.2363850576500075`}, {
          3.0109724820688584`, -1.1825658016144474`}, {
          3.574048663883448, -0.6929096493834652}, {
          3.574048663883448, -0.6495190528383292}, {
          3.0109724820688584`, -1.108512516844082}, {
          3.0109724820688584`, -1.1825658016144474`}, {
          3.0109724820688584`, -1.1085125168440817`}, {
          3.574048663883448, -0.6495190528383291}, {
          3.574048663883448, -0.5950150052184265}, {
          3.0109724820688584`, -1.0154922755727813`}, {
          3.0109724820688584`, -1.1085125168440817`}, {
          3.0109724820688584`, -1.0154922755727813`}, {
          3.574048663883448, -0.5950150052184265}, {
          3.574048663883448, -0.5303300858899109}, {
          3.0109724820688584`, -0.9050966799187813}, {
          3.0109724820688584`, -1.0154922755727813`}, {
          3.0109724820688584`, -0.9050966799187813}, {
          3.574048663883448, -0.5303300858899109}, {
          3.574048663883448, -0.45657107175654066`}, {
          3.0109724820688584`, -0.7792146291311628}, {
          3.0109724820688584`, -0.9050966799187813}, {
          3.0109724820688584`, -0.7792146291311628}, {
          3.574048663883448, -0.45657107175654066`}, {
          3.574048663883448, -0.37500000000000033`}, {
          3.0109724820688584`, -0.6400000000000006}, {
          3.0109724820688584`, -0.7792146291311628}, {
          3.0109724820688584`, -0.6400000000000006}, {
          3.574048663883448, -0.37500000000000033`}, {
          3.574048663883448, -0.28701257427381777`}, {
          3.0109724820688584`, -0.4898347934273156}, {
          3.0109724820688584`, -0.6400000000000006}, {
          3.0109724820688584`, -0.4898347934273156}, {
          3.574048663883448, -0.28701257427381777`}, {
          3.574048663883448, -0.1941142838268911}, {
          3.0109724820688584`, -0.3312883777312275}, {
          3.0109724820688584`, -0.4898347934273156}, {
          3.0109724820688584`, -0.3312883777312275}, {
          3.574048663883448, -0.1941142838268911}, {
          3.574048663883448, -0.09789464416503939}, {
          3.0109724820688584`, -0.16707352604166723`}, {
          3.0109724820688584`, -0.3312883777312275}, {
          3.0109724820688584`, -0.16707352604166723`}, {
          3.574048663883448, -0.09789464416503939}, {
          3.574048663883448, -8.039065796791712*^-16}, {
          3.0109724820688584`, -1.372000562652452*^-15}, {
          3.0109724820688584`, -0.16707352604166723`}, {
          3.0109724820688584`, -2.351321854362918*^-16}, {
          3.574048663883448, -1.3777276490407724`*^-16}, {3.574048663883448, 
          0.09789464416503843}, {3.0109724820688584`, 0.1670735260416656}, {
          3.0109724820688584`, -2.351321854362918*^-16}, {3.0109724820688584`,
           0.1670735260416656}, {3.574048663883448, 0.09789464416503843}, {
          3.574048663883448, 0.19411428382689022`}, {3.0109724820688584`, 
          0.331288377731226}, {3.0109724820688584`, 0.1670735260416656}, {
          3.0109724820688584`, 0.331288377731226}, {3.574048663883448, 
          0.19411428382689022`}, {3.574048663883448, 0.2870125742738169}, {
          3.0109724820688584`, 0.4898347934273142}, {3.0109724820688584`, 
          0.331288377731226}, {3.0109724820688584`, 0.4898347934273142}, {
          3.574048663883448, 0.2870125742738169}, {3.574048663883448, 
          0.37499999999999944`}, {3.0109724820688584`, 0.6399999999999991}, {
          3.0109724820688584`, 0.4898347934273142}, {3.0109724820688584`, 
          0.6399999999999991}, {3.574048663883448, 0.37499999999999944`}, {
          3.5740486638834477`, 0.4565710717565399}, {3.0109724820688584`, 
          0.7792146291311615}, {3.0109724820688584`, 0.6399999999999991}, {
          3.0109724820688584`, 0.7792146291311615}, {3.5740486638834477`, 
          0.4565710717565399}, {3.574048663883448, 0.53033008588991}, {
          3.0109724820688584`, 0.9050966799187797}, {3.0109724820688584`, 
          0.7792146291311615}, {3.0109724820688584`, 0.9050966799187807}, {
          3.574048663883448, 0.5303300858899106}, {3.574048663883448, 
          0.5950150052184262}, {3.0109724820688584`, 1.0154922755727807`}, {
          3.0109724820688584`, 0.9050966799187807}, {3.0109724820688584`, 
          1.0154922755727807`}, {3.574048663883448, 0.5950150052184262}, {
          3.574048663883448, 0.6495190528383288}, {3.0109724820688584`, 
          1.1085125168440813`}, {3.0109724820688584`, 1.0154922755727807`}, {
          3.0109724820688584`, 1.1085125168440813`}, {3.574048663883448, 
          0.6495190528383288}, {3.574048663883448, 0.6929096493834649}, {
          3.0109724820688584`, 1.1825658016144467`}, {3.0109724820688584`, 
          1.1085125168440813`}, {3.0109724820688584`, 1.1825658016144467`}, {
          3.574048663883448, 0.6929096493834649}, {3.574048663883448, 
          0.724444369716801}, {3.0109724820688584`, 1.2363850576500073`}, {
          3.0109724820688584`, 1.1825658016144467`}, {3.0109724820688584`, 
          1.2363850576500073`}, {3.574048663883448, 0.724444369716801}, {
          3.574048663883448, 0.7435836460303578}, {3.0109724820688584`, 
          1.2690494225584772`}, {3.0109724820688584`, 1.2363850576500073`}, {
          3.0109724820688584`, 1.2690494225584772`}, {3.574048663883448, 
          0.7435836460303578}, {3.574048663883448, 0.75}, {
          3.0109724820688584`, 1.28}, {3.0109724820688584`, 
          1.2690494225584772`}, {3.711, 0.63}, {3.711, 0.6246102626655006}, {
          3.711, 0.608533270562113}, {3.711, 0.5820441054821106}, {3.711, 
          0.5455960043841964}, {3.711, 0.49981260438347813`}, {3.711, 
          0.44547727214752497`}, {3.711, 0.3835197002754941}, {3.711, 
          0.31500000000000006`}, {3.711, 0.2410905623900066}, {3.711, 
          0.1630559984145882}, {3.711, 0.08223150109863257}, {3.711, 
          3.8576374173141627`*^-17}, {3.711, -0.08223150109863236}, {
          3.711, -0.163055998414588}, {3.711, -0.2410905623900064}, {
          3.711, -0.31499999999999984`}, {3.711, -0.3835197002754938}, {
          3.711, -0.4454772721475249}, {3.711, -0.499812604383478}, {
          3.711, -0.5455960043841962}, {3.711, -0.5820441054821106}, {
          3.711, -0.6085332705621129}, {3.711, -0.6246102626655006}, {
          3.711, -0.63}, {3.711, -0.6246102626655006}, {
          3.711, -0.6085332705621131}, {3.711, -0.5820441054821108}, {
          3.711, -0.5455960043841964}, {3.711, -0.4998126043834783}, {
          3.711, -0.4454772721475252}, {3.711, -0.38351970027549415`}, {
          3.711, -0.3150000000000003}, {3.711, -0.24109056239000692`}, {
          3.711, -0.1630559984145885}, {3.711, -0.08223150109863309}, {
          3.711, -1.1572912251942488`*^-16}, {3.711, 0.08223150109863228}, {
          3.711, 0.1630559984145878}, {3.711, 0.24109056239000617`}, {3.711, 
          0.31499999999999956`}, {3.711, 0.38351970027549354`}, {3.711, 
          0.4454772721475249}, {3.711, 0.499812604383478}, {3.711, 
          0.5455960043841962}, {3.711, 0.5820441054821105}, {3.711, 
          0.6085332705621129}, {3.711, 0.6246102626655005}, {3.711, 0.63}, {
          3.711, 0.7875}, {3.711, 0.7807628283318756}, {3.711, 
          0.7606665882026413}, {3.711, 0.7275551318526383}, {3.711, 
          0.6819950054802455}, {3.711, 0.6247657554793477}, {3.711, 
          0.5568465901844062}, {3.711, 0.4793996253443676}, {3.711, 
          0.3937500000000001}, {3.711, 0.30136320298750824`}, {3.711, 
          0.20381999801823525`}, {3.711, 0.10278937637329072`}, {3.711, 
          4.8220467716427034`*^-17}, {3.711, -0.10278937637329046`}, {
          3.711, -0.203819998018235}, {3.711, -0.30136320298750796`}, {
          3.711, -0.3937499999999998}, {3.711, -0.47939962534436725`}, {
          3.711, -0.5568465901844061}, {3.711, -0.6247657554793475}, {
          3.711, -0.6819950054802453}, {3.711, -0.7275551318526383}, {
          3.711, -0.7606665882026412}, {3.711, -0.7807628283318756}, {
          3.711, -0.7875}, {3.711, -0.7807628283318757}, {
          3.711, -0.7606665882026413}, {3.711, -0.7275551318526384}, {
          3.711, -0.6819950054802455}, {3.711, -0.6247657554793479}, {
          3.711, -0.5568465901844064}, {3.711, -0.4793996253443677}, {
          3.711, -0.3937500000000003}, {3.711, -0.3013632029875086}, {
          3.711, -0.20381999801823564`}, {3.711, -0.10278937637329136`}, {
          3.711, -1.4466140314928108`*^-16}, {3.711, 0.10278937637329034`}, {
          3.711, 0.20381999801823472`}, {3.711, 0.30136320298750774`}, {3.711,
           0.39374999999999943`}, {3.711, 0.47939962534436686`}, {3.711, 
          0.5568465901844061}, {3.711, 0.6247657554793475}, {3.711, 
          0.6819950054802452}, {3.711, 0.7275551318526381}, {3.711, 
          0.7606665882026411}, {3.711, 0.7807628283318756}, {3.711, 0.7875}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.8}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.1699049364210963`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7931558890990483}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.8}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7931558890990483}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.1699049364210963`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           1.1397924750211006`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7727406610312547}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7931558890990483}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7727406610312547}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           1.1397924750211006`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0901778483633182`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7391036260090295}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7727406610312547}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7391036260090295}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0901778483633182`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0219099764656376`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.692820323027551}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7391036260090295}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.692820323027551}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0219099764656376`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9361569415436575}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6399999999999999 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.6346826722329881}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.692820323027551}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6399999999999999 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.6346826722329881}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9361569415436575}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924000000000003` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.8343860018001262}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.5656854249492381}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6399999999999999 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.6346826722329881}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.5656854249492381}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.8343860018001261}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7183384862302905}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.48700914320697664`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.5656854249492381}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.48700914320697664`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7183384862302905}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.5900000000000001}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.40000000000000013`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.48700914320697664`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.40000000000000013`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.5900000000000001}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.451566450190806}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.3061467458920719}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.40000000000000013`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.3061467458920719}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.451566450190806}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           0.3054064732209745}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.2070552360820166}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.3061467458920719}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.20705523608201679`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.3054064732209747}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.15402090681966102`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.10442095377604138`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.20705523608201679`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.10442095377604138`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.15402090681966102`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 7.225416114969384*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 4.898587196589413*^-17}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.10442095377604138`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 4.898587196589413*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 7.225416114969384*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.15402090681966088`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.10442095377604128`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 4.898587196589413*^-17}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.1044209537760411}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.15402090681966063`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3054064732209743}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.2070552360820165}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.1044209537760411}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.2070552360820165}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3054064732209743}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.4515664501908059}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.3061467458920718}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.2070552360820165}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.30614674589207164`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.4515664501908056}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.5899999999999997}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000002 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.39999999999999986`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.30614674589207164`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000002 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.39999999999999986`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.5899999999999997}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.71833848623029}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.4870091432069763}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000002 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.39999999999999986`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.4870091432069763}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.71833848623029}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.8343860018001256}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.5656854249492377}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.4870091432069763}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.565685424949238}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.834386001800126}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9361569415436571}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.634682672232988}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.565685424949238}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.634682672232988}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9361569415436571}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0219099764656374`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.6928203230275508}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.634682672232988}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.6928203230275508}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0219099764656374`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.090177848363318}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7391036260090292}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.6928203230275508}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7391036260090295}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0901778483633182`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1397924750211004`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7727406610312546}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7391036260090295}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7727406610312546}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1397924750211004`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1699049364210963`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7931558890990483}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7727406610312546}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7931558890990483}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1699049364210963`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.18}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.8}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7931558890990483}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.8}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1699049364210963`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7931558890990484}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.8}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7931558890990484}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1699049364210963`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1397924750211006`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7727406610312548}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7931558890990484}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7727406610312548}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1397924750211006`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0901778483633187`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7391036260090296}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7727406610312548}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7391036260090296}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0901778483633187`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.021909976465638}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.6928203230275513}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.7391036260090296}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000002 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.6928203230275511}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0219099764656379`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9361569415436577}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.6346826722329884}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000002 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.6928203230275511}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.6346826722329884}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9361569415436577}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.8343860018001265}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.5656854249492383}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.6346826722329884}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.5656854249492383}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.8343860018001265}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.7183384862302906}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.48700914320697675`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.5656854249492383}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.48700914320697675`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.7183384862302906}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.5900000000000005}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.40000000000000036`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.48700914320697675`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.40000000000000036`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.5900000000000005}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.4515664501908066}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.3061467458920723}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.40000000000000036`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.3061467458920723}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.4515664501908066}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3054064732209753}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.20705523608201717`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.3061467458920723}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.20705523608201717`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3054064732209753}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.15402090681966196`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.10442095377604202`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.20705523608201717`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.10442095377604202`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.15402090681966196`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.2648130186952292`*^-15}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -8.575003516577826*^-16}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -0.10442095377604202`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -1.4695761589768238`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -2.1676248344908148`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.15402090681966046`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.10442095377604099`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], -1.4695761589768238`*^-16}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.10442095377604099`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.15402090681966046`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.3054064732209739}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.20705523608201626`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.10442095377604099`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.20705523608201626`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.3054064732209739}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           0.4515664501908052}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.30614674589207136`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.20705523608201626`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.30614674589207136`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           0.4515664501908052}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.5899999999999991}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.39999999999999947`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.30614674589207136`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.39999999999999947`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.5899999999999991}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7183384862302894}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.4870091432069759}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.39999999999999947`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.4870091432069759}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7183384862302894}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.834386001800125}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6399999999999999 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.5656854249492373}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.4870091432069759}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.565685424949238}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924000000000003` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.834386001800126}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9361569415436571}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.634682672232988}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.565685424949238}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.634682672232988}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9361569415436571}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0219099764656372`}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.6928203230275507}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.634682672232988}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.6928203230275507}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0219099764656372`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.090177848363318}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7391036260090292}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.6928203230275507}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7391036260090292}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.090177848363318}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           1.1397924750211004`}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7727406610312545}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7391036260090292}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7727406610312545}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           1.1397924750211004`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.169904936421096}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7931558890990482}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7727406610312545}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7931558890990482}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.169904936421096}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.18}, {
          4.202 + $CellContext`rr6 - 1. 
           Sqrt[-0.6400000000000001 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.8}, {
          4.202 + $CellContext`rr6 - 1. Sqrt[-0.64 + $CellContext`rr6^2] 
           Sign[$CellContext`rr6], 0.7931558890990482}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.18}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.18}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.1699049364210963`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.1699049364210963`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.1699049364210963`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.1699049364210963`}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.1397924750211006`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           1.1397924750211006`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.1699049364210963`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           1.1397924750211006`}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.1397924750211006`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.0901778483633182`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0901778483633182`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           1.1397924750211006`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0901778483633182`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.0901778483633182`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.0219099764656376`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0219099764656376`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0901778483633182`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0219099764656376`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.0219099764656376`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.9361569415436575}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9361569415436575}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0219099764656376`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9361569415436575}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.9361569415436575}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3924000000000003` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.8343860018001262}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924000000000003` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.8343860018001262}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9361569415436575}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.8343860018001261}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.8343860018001261}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.7183384862302905}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7183384862302905}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.8343860018001261}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7183384862302905}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.7183384862302905}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.5900000000000001}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.5900000000000001}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7183384862302905}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.5900000000000001}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.5900000000000001}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.451566450190806}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.451566450190806}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.5900000000000001}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.451566450190806}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.451566450190806}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.3054064732209745}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           0.3054064732209745}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.451566450190806}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.3054064732209747}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.3054064732209747}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.15402090681966102`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.15402090681966102`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.3054064732209747}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.15402090681966102`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.15402090681966102`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 7.225416114969384*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 7.225416114969384*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.15402090681966102`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 7.225416114969384*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 7.225416114969384*^-17}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.15402090681966088`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.15402090681966088`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 7.225416114969384*^-17}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.15402090681966063`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.15402090681966063`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.3054064732209743}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3054064732209743}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.15402090681966063`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3054064732209743}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.3054064732209743}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.4515664501908059}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.4515664501908059}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3054064732209743}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.4515664501908056}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.4515664501908056}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.5899999999999997}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.5899999999999997}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.4515664501908056}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.5899999999999997}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.5899999999999997}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.71833848623029}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.71833848623029}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.5899999999999997}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.71833848623029}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.71833848623029}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.8343860018001256}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.8343860018001256}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.71833848623029}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.834386001800126}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.834386001800126}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.9361569415436571}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9361569415436571}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.834386001800126}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9361569415436571}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.9361569415436571}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.0219099764656374`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0219099764656374`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9361569415436571}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0219099764656374`}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.0219099764656374`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.090177848363318}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.090177848363318}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0219099764656374`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0901778483633182`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.0901778483633182`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.1397924750211004`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1397924750211004`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0901778483633182`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1397924750211004`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.1397924750211004`}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.1699049364210963`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1699049364210963`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1397924750211004`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1699049364210963`}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.1699049364210963`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1699049364210963`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.18}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.18}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.1699049364210963`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1699049364210963`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1699049364210963`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.1699049364210963`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.1397924750211006`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1397924750211006`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1699049364210963`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1397924750211006`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.1397924750211006`}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.0901778483633187`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0901778483633187`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.1397924750211006`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0901778483633187`}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.0901778483633187`}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.021909976465638}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.021909976465638}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0901778483633187`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0219099764656379`}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.0219099764656379`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.9361569415436577}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9361569415436577}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.0219099764656379`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9361569415436577}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.9361569415436577}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.8343860018001265}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.8343860018001265}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.9361569415436577}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.8343860018001265}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.8343860018001265}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.7183384862302906}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.7183384862302906}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.8343860018001265}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.7183384862302906}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.7183384862302906}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.5900000000000005}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.5900000000000005}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.7183384862302906}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.5900000000000005}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.5900000000000005}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.4515664501908066}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.4515664501908066}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.5900000000000005}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.4515664501908066}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.4515664501908066}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.3054064732209753}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3054064732209753}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.4515664501908066}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3054064732209753}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.3054064732209753}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.15402090681966196`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.15402090681966196`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.3054064732209753}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.15402090681966196`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -0.15402090681966196`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -1.2648130186952292`*^-15}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -1.2648130186952292`*^-15}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -0.15402090681966196`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -2.1676248344908148`*^-16}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], -2.1676248344908148`*^-16}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.15402090681966046`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.15402090681966046`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], -2.1676248344908148`*^-16}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.15402090681966046`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.15402090681966046`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.3054064732209739}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.3054064732209739}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.15402090681966046`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.3054064732209739}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.3054064732209739}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.4515664501908052}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           0.4515664501908052}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999996` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.3054064732209739}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           0.4515664501908052}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.4515664501908052}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.5899999999999991}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.5899999999999991}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           0.4515664501908052}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.5899999999999991}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.5899999999999991}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.7183384862302894}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7183384862302894}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.5899999999999991}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7183384862302894}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.7183384862302894}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.834386001800125}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.834386001800125}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.7183384862302894}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924000000000003` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.834386001800126}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3924000000000003` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.834386001800126}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.9361569415436571}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9361569415436571}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924000000000003` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.834386001800126}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9361569415436571}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 0.9361569415436571}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.0219099764656372`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0219099764656372`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 0.9361569415436571}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0219099764656372`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.0219099764656372`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.090177848363318}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.090177848363318}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.0219099764656372`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.090177848363318}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.090177848363318}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.1397924750211004`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           1.1397924750211004`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.090177848363318}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           1.1397924750211004`}, {
          5.075 + $CellContext`rr8 - 1. Sqrt[-1.3924 + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.1397924750211004`}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.169904936421096}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.169904936421096}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3924 + $CellContext`rr7^2] Sign[$CellContext`rr7], 
           1.1397924750211004`}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.169904936421096}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.169904936421096}, {
          5.075 + $CellContext`rr8 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr8^2] 
           Sign[$CellContext`rr8], 1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.18}, {
          4.4030000000000005` + $CellContext`rr7 - 1. 
           Sqrt[-1.3923999999999999` + $CellContext`rr7^2] 
           Sign[$CellContext`rr7], 1.169904936421096}, {5.534443062211261, 
          1.5}, {5.627613727648733, 1.5}, {5.627613727648733, 
          1.4871672920607155`}, {5.534443062211261, 1.4871672920607155`}, {
          5.534443062211261, 1.5}, {5.534443062211261, 1.4871672920607155`}, {
          5.627613727648733, 1.4871672920607155`}, {5.627613727648731, 
          1.4488887394336025`}, {5.534443062211261, 1.4488887394336025`}, {
          5.534443062211261, 1.4871672920607155`}, {5.534443062211261, 
          1.4488887394336025`}, {5.627613727648731, 1.4488887394336025`}, {
          5.627613727648733, 1.38581929876693}, {5.534443062211261, 
          1.38581929876693}, {5.534443062211261, 1.4488887394336025`}, {
          5.534443062211261, 1.38581929876693}, {5.627613727648733, 
          1.38581929876693}, {5.627613727648733, 1.299038105676658}, {
          5.534443062211261, 1.299038105676658}, {5.534443062211261, 
          1.38581929876693}, {5.534443062211261, 1.299038105676658}, {
          5.627613727648733, 1.299038105676658}, {5.627613727648733, 
          1.1900300104368529`}, {5.534443062211261, 1.1900300104368529`}, {
          5.534443062211261, 1.299038105676658}, {5.534443062211261, 
          1.1900300104368529`}, {5.627613727648733, 1.1900300104368529`}, {
          5.627613727648733, 1.0606601717798214`}, {5.534443062211261, 
          1.0606601717798214`}, {5.534443062211261, 1.1900300104368529`}, {
          5.534443062211261, 1.0606601717798214`}, {5.627613727648733, 
          1.0606601717798214`}, {5.627613727648733, 0.9131421435130811}, {
          5.534443062211261, 0.9131421435130811}, {5.534443062211261, 
          1.0606601717798214`}, {5.534443062211261, 0.9131421435130811}, {
          5.627613727648733, 0.9131421435130811}, {5.627613727648733, 
          0.7500000000000002}, {5.534443062211261, 0.7500000000000002}, {
          5.534443062211261, 0.9131421435130811}, {5.534443062211261, 
          0.7500000000000002}, {5.627613727648733, 0.7500000000000002}, {
          5.627613727648733, 0.5740251485476348}, {5.534443062211261, 
          0.5740251485476348}, {5.534443062211261, 0.7500000000000002}, {
          5.534443062211261, 0.5740251485476348}, {5.627613727648733, 
          0.5740251485476348}, {5.627613727648733, 0.3882285676537811}, {
          5.534443062211261, 0.3882285676537811}, {5.534443062211261, 
          0.5740251485476348}, {5.534443062211261, 0.38822856765378144`}, {
          5.627613727648733, 0.38822856765378144`}, {5.627613727648733, 
          0.19578928833007758`}, {5.534443062211261, 0.19578928833007758`}, {
          5.534443062211261, 0.38822856765378144`}, {5.534443062211261, 
          0.19578928833007758`}, {5.627613727648733, 0.19578928833007758`}, {
          5.627613727648733, 9.184850993605148*^-17}, {5.534443062211261, 
          9.184850993605148*^-17}, {5.534443062211261, 
          0.19578928833007758`}, {5.534443062211261, 
          9.184850993605148*^-17}, {5.627613727648733, 
          9.184850993605148*^-17}, {
          5.627613727648733, -0.19578928833007742`}, {
          5.534443062211261, -0.19578928833007742`}, {5.534443062211261, 
          9.184850993605148*^-17}, {
          5.534443062211261, -0.19578928833007708`}, {
          5.627613727648733, -0.19578928833007708`}, {
          5.627613727648733, -0.38822856765378094`}, {
          5.534443062211261, -0.38822856765378094`}, {
          5.534443062211261, -0.19578928833007708`}, {
          5.534443062211261, -0.38822856765378094`}, {
          5.627613727648733, -0.38822856765378094`}, {
          5.627613727648733, -0.5740251485476346}, {
          5.534443062211261, -0.5740251485476346}, {
          5.534443062211261, -0.38822856765378094`}, {
          5.534443062211261, -0.5740251485476342}, {
          5.627613727648733, -0.5740251485476342}, {
          5.627613727648733, -0.7499999999999997}, {
          5.534443062211261, -0.7499999999999997}, {
          5.534443062211261, -0.5740251485476342}, {
          5.534443062211261, -0.7499999999999997}, {
          5.627613727648733, -0.7499999999999997}, {
          5.627613727648733, -0.9131421435130804}, {
          5.534443062211261, -0.9131421435130804}, {
          5.534443062211261, -0.7499999999999997}, {
          5.534443062211261, -0.9131421435130804}, {
          5.627613727648733, -0.9131421435130804}, {
          5.627613727648733, -1.0606601717798207`}, {
          5.534443062211261, -1.0606601717798207`}, {
          5.534443062211261, -0.9131421435130804}, {
          5.534443062211261, -1.0606601717798212`}, {
          5.627613727648733, -1.0606601717798212`}, {
          5.627613727648733, -1.1900300104368524`}, {
          5.534443062211261, -1.1900300104368524`}, {
          5.534443062211261, -1.0606601717798212`}, {
          5.534443062211261, -1.1900300104368524`}, {
          5.627613727648733, -1.1900300104368524`}, {
          5.627613727648733, -1.2990381056766578`}, {
          5.534443062211261, -1.2990381056766578`}, {
          5.534443062211261, -1.1900300104368524`}, {
          5.534443062211261, -1.2990381056766578`}, {
          5.627613727648733, -1.2990381056766578`}, {
          5.627613727648733, -1.3858192987669298`}, {
          5.534443062211261, -1.3858192987669298`}, {
          5.534443062211261, -1.2990381056766578`}, {
          5.534443062211261, -1.38581929876693}, {
          5.627613727648733, -1.38581929876693}, {
          5.627613727648733, -1.4488887394336023`}, {
          5.534443062211261, -1.4488887394336023`}, {
          5.534443062211261, -1.38581929876693}, {
          5.534443062211261, -1.4488887394336023`}, {
          5.627613727648733, -1.4488887394336023`}, {
          5.627613727648733, -1.4871672920607155`}, {
          5.534443062211261, -1.4871672920607155`}, {
          5.534443062211261, -1.4488887394336023`}, {
          5.534443062211261, -1.4871672920607155`}, {
          5.627613727648733, -1.4871672920607155`}, {
          5.627613727648733, -1.5}, {5.534443062211261, -1.5}, {
          5.534443062211261, -1.4871672920607155`}, {
          5.534443062211261, -1.5}, {5.627613727648733, -1.5}, {
          5.627613727648733, -1.4871672920607157`}, {
          5.534443062211261, -1.4871672920607157`}, {
          5.534443062211261, -1.5}, {
          5.534443062211261, -1.4871672920607157`}, {
          5.627613727648733, -1.4871672920607157`}, {
          5.627613727648733, -1.4488887394336025`}, {
          5.534443062211261, -1.4488887394336025`}, {
          5.534443062211261, -1.4871672920607157`}, {
          5.534443062211261, -1.4488887394336025`}, {
          5.627613727648733, -1.4488887394336025`}, {
          5.627613727648733, -1.3858192987669304`}, {
          5.534443062211261, -1.3858192987669304`}, {
          5.534443062211261, -1.4488887394336025`}, {
          5.534443062211261, -1.3858192987669304`}, {
          5.627613727648733, -1.3858192987669304`}, {
          5.627613727648733, -1.2990381056766584`}, {
          5.534443062211261, -1.2990381056766584`}, {
          5.534443062211261, -1.3858192987669304`}, {
          5.534443062211261, -1.2990381056766582`}, {
          5.627613727648733, -1.2990381056766582`}, {
          5.627613727648733, -1.190030010436853}, {
          5.534443062211261, -1.190030010436853}, {
          5.534443062211261, -1.2990381056766582`}, {
          5.534443062211261, -1.190030010436853}, {
          5.627613727648733, -1.190030010436853}, {
          5.627613727648733, -1.0606601717798219`}, {
          5.534443062211261, -1.0606601717798219`}, {
          5.534443062211261, -1.190030010436853}, {
          5.534443062211261, -1.0606601717798219`}, {
          5.627613727648733, -1.0606601717798219`}, {
          5.627613727648733, -0.9131421435130813}, {
          5.534443062211261, -0.9131421435130813}, {
          5.534443062211261, -1.0606601717798219`}, {
          5.534443062211261, -0.9131421435130813}, {
          5.627613727648733, -0.9131421435130813}, {
          5.627613727648733, -0.7500000000000007}, {
          5.534443062211261, -0.7500000000000007}, {
          5.534443062211261, -0.9131421435130813}, {
          5.534443062211261, -0.7500000000000007}, {
          5.627613727648733, -0.7500000000000007}, {
          5.627613727648733, -0.5740251485476355}, {
          5.534443062211261, -0.5740251485476355}, {
          5.534443062211261, -0.7500000000000007}, {
          5.534443062211261, -0.5740251485476355}, {
          5.627613727648733, -0.5740251485476355}, {
          5.627613727648733, -0.3882285676537822}, {
          5.534443062211261, -0.3882285676537822}, {
          5.534443062211261, -0.5740251485476355}, {
          5.534443062211261, -0.3882285676537822}, {
          5.627613727648733, -0.3882285676537822}, {
          5.627613727648733, -0.19578928833007878`}, {
          5.534443062211261, -0.19578928833007878`}, {
          5.534443062211261, -0.3882285676537822}, {
          5.534443062211261, -0.19578928833007878`}, {
          5.627613727648733, -0.19578928833007878`}, {
          5.627613727648733, -1.6078131593583423`*^-15}, {
          5.534443062211261, -1.6078131593583423`*^-15}, {
          5.534443062211261, -0.19578928833007878`}, {
          5.534443062211261, -2.755455298081545*^-16}, {
          5.627613727648733, -2.755455298081545*^-16}, {5.627613727648733, 
          0.19578928833007686`}, {5.534443062211261, 0.19578928833007686`}, {
          5.534443062211261, -2.755455298081545*^-16}, {5.534443062211261, 
          0.19578928833007686`}, {5.627613727648733, 0.19578928833007686`}, {
          5.627613727648733, 0.38822856765378044`}, {5.534443062211261, 
          0.38822856765378044`}, {5.534443062211261, 0.19578928833007686`}, {
          5.534443062211261, 0.38822856765378044`}, {5.627613727648733, 
          0.38822856765378044`}, {5.627613727648733, 0.5740251485476338}, {
          5.534443062211261, 0.5740251485476338}, {5.534443062211261, 
          0.38822856765378044`}, {5.534443062211261, 0.5740251485476338}, {
          5.627613727648733, 0.5740251485476338}, {5.627613727648733, 
          0.7499999999999989}, {5.534443062211261, 0.7499999999999989}, {
          5.534443062211261, 0.5740251485476338}, {5.534443062211261, 
          0.7499999999999989}, {5.627613727648733, 0.7499999999999989}, {
          5.627613727648733, 0.9131421435130798}, {5.534443062211261, 
          0.9131421435130798}, {5.534443062211261, 0.7499999999999989}, {
          5.534443062211261, 0.9131421435130798}, {5.627613727648733, 
          0.9131421435130798}, {5.627613727648733, 1.06066017177982}, {
          5.534443062211261, 1.06066017177982}, {5.534443062211261, 
          0.9131421435130798}, {5.534443062211261, 1.0606601717798212`}, {
          5.627613727648733, 1.0606601717798212`}, {5.627613727648733, 
          1.1900300104368524`}, {5.534443062211261, 1.1900300104368524`}, {
          5.534443062211261, 1.0606601717798212`}, {5.534443062211261, 
          1.1900300104368524`}, {5.627613727648733, 1.1900300104368524`}, {
          5.627613727648733, 1.2990381056766576`}, {5.534443062211261, 
          1.2990381056766576`}, {5.534443062211261, 1.1900300104368524`}, {
          5.534443062211261, 1.2990381056766576`}, {5.627613727648733, 
          1.2990381056766576`}, {5.627613727648733, 1.3858192987669298`}, {
          5.534443062211261, 1.3858192987669298`}, {5.534443062211261, 
          1.2990381056766576`}, {5.534443062211261, 1.3858192987669298`}, {
          5.627613727648733, 1.3858192987669298`}, {5.627613727648733, 
          1.448888739433602}, {5.534443062211261, 1.448888739433602}, {
          5.534443062211261, 1.3858192987669298`}, {5.534443062211261, 
          1.448888739433602}, {5.627613727648733, 1.448888739433602}, {
          5.627613727648733, 1.4871672920607155`}, {5.534443062211261, 
          1.4871672920607155`}, {5.534443062211261, 1.448888739433602}, {
          5.534443062211261, 1.4871672920607155`}, {5.627613727648733, 
          1.4871672920607155`}, {5.627613727648733, 1.5}, {5.534443062211261, 
          1.5}, {5.534443062211261, 1.4871672920607155`}}]); 
     Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.53814068201661*^9}]
}, Open  ]]
},
WindowSize->{1054, 718},
WindowMargins->{{292, Automatic}, {105, Automatic}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 5, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1212, 19, 231, "Input"],
Cell[CellGroupData[{
Cell[1782, 43, 3222, 70, 133, "Input"],
Cell[CellGroupData[{
Cell[5029, 117, 96376, 1596, 229, "Print"],
Cell[101408, 1715, 3639, 86, 111, "Print"]
}, Open  ]],
Cell[105062, 1804, 374, 5, 27, "Output"]
}, Open  ]],
Cell[105451, 1812, 92, 1, 27, "Input"],
Cell[105546, 1815, 347, 7, 27, "Input"],
Cell[CellGroupData[{
Cell[105918, 1826, 4899, 119, 178, "Input"],
Cell[110820, 1947, 749797, 12737, 779, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
