(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    425227,       7390]
NotebookOptionsPosition[    424336,       7353]
NotebookOutlinePosition[    424868,       7376]
CellTagsIndexPosition[    424781,       7371]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"?", "LensDoublet"}]}]], "Input",
 CellChangeTimes->{{3.408328603406026*^9, 3.408328608154235*^9}}],

Cell[BoxData[
 StyleBox["\<\"LensDoublet[r1, r2, r3, aperture, t1, t2, index1, index2, \
label, options] designates a lens having three spherical surfaces. \\n\\nThe \
radii of curvatures are specified by r1, r2, and r3, where Infinity is used \
to indicate planar surfaces. In addition, LensDoublet is specified by two \
thicknesses: t1, t2. The two refractive indexes must also be specified either \
as a function of wavelength or using one of the built-in optical material \
labels. LensDoublet is created with its first surface centered about the \
origin and the remaining surfaces positioned down the x axis. The aperture \
parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user-named label parameter is \
optional and can be omitted. When it is present, its text content is used to \
identify the object in both the rendered graphics and the output cell \
expression. When it is omitted, Optica uses the default setting of the Labels \
option with the rendered graphics. See also: LensTriplet and \
CompoundLens.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.544879500717266*^9},
 CellTags->"Info3544861499-7689995"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LensDoublet", "[", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"r11", ",", "71.89"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"r12", ",", "26.81"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"r13", ",", 
     RowBox[{"-", "38.35"}]}], "}"}], ",", "25.4", ",", "2.1", ",", " ", 
   "7.5", ",", "SF5", ",", " ", "BK7"}], "]"}]], "Input",
 CellChangeTimes->{{3.408378350614787*^9, 3.408378371011744*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"LensDoublet", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r11", ",", "71.89`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"r12", ",", "26.81`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"r13", ",", 
        RowBox[{"-", "38.35`"}]}], "}"}], ",", "25.4`", ",", "2.1`", ",", 
      "7.5`", ",", "SF5", ",", "BK7"}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{{3.408378360466155*^9, 3.408378372093095*^9}, 
   3.544879502612832*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mysystem1", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Move", "[", 
     RowBox[{
      RowBox[{"WedgeOfRays", "[", 
       RowBox[{"10", " ", ",", 
        RowBox[{"NumberOfRays", " ", "->", " ", "6"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x0", ",", " ", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y0", ",", " ", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]0", ",", "0"}], "}"}]}], "]"}], ",", "\n", 
    RowBox[{"Move", "[", 
     RowBox[{
      RowBox[{"LensDoublet", "[", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"r11", ",", "71.89"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"r12", ",", "26.81"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"r13", ",", 
          RowBox[{"-", "38.35"}]}], "}"}], ",", "25.4", ",", "2.1", ",", " ", 
        "7.5", ",", "SF5", ",", " ", "BK7"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x13", ",", " ", "50"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y13", ",", " ", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]13", ",", "0"}], "}"}]}], "]"}], ",", 
    RowBox[{"Move", "[", 
     RowBox[{
      RowBox[{"LensDoublet", "[", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"r21", ",", "38.35"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r22", ",", " ", 
          RowBox[{"-", "26.81"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r23", ",", 
          RowBox[{"-", "71.89"}]}], "}"}], ",", "25.4", ",", "7.5", ",", 
        "2.1", ",", "BK7", ",", "SF5"}], " ", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x23", ",", " ", "100"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y23", ",", " ", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]23", ",", "0"}], "}"}]}], "]"}], ",", "\n", 
    RowBox[{"Boundary", "[", "200", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.408328505459231*^9, 3.408328510137191*^9}, {
  3.408328672275153*^9, 3.40832867728148*^9}, {3.408328750179144*^9, 
  3.408328788209404*^9}, {3.4083288366752872`*^9, 3.4083288417773438`*^9}, {
  3.408328881251794*^9, 3.408329014650679*^9}, {3.4083290512122307`*^9, 
  3.4083290900906687`*^9}, {3.408329167532148*^9, 3.408329174314644*^9}, {
  3.408329256172338*^9, 3.408329259106512*^9}, {3.408329301516226*^9, 
  3.408329304162271*^9}, {3.408329547252351*^9, 3.408329584506577*^9}, {
  3.408329655756466*^9, 3.408329664994575*^9}, {3.408378379755653*^9, 
  3.408378384822049*^9}, {3.4083784404870777`*^9, 3.408378456792292*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"WedgeOfRays", "[", 
         RowBox[{"10", ",", 
          RowBox[{"NumberOfRays", "\[Rule]", "6"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"y0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]0", ",", "0.`"}], "}"}], ",", 
        RowBox[{"SymbolicValues", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Theta]0", "\[Rule]", "0"}], ",", 
           RowBox[{"x0", "\[Rule]", "0"}], ",", 
           RowBox[{"y0", "\[Rule]", "0"}]}], "}"}]}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"LensDoublet", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"r11", ",", "71.89`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"r12", ",", "26.81`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"r13", ",", 
            RowBox[{"-", "38.35`"}]}], "}"}], ",", "25.4`", ",", "2.1`", ",", 
          "7.5`", ",", "SF5", ",", "BK7"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x13", ",", "50.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"y13", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]13", ",", "0.`"}], "}"}], ",", 
        RowBox[{"SymbolicValues", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Theta]13", "\[Rule]", "0"}], ",", 
           RowBox[{"x13", "\[Rule]", "50"}], ",", 
           RowBox[{"y13", "\[Rule]", "0"}]}], "}"}]}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"LensDoublet", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"r21", ",", "38.35`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"r22", ",", 
            RowBox[{"-", "26.81`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"r23", ",", 
            RowBox[{"-", "71.89`"}]}], "}"}], ",", "25.4`", ",", "7.5`", ",", 
          "2.1`", ",", "BK7", ",", "SF5"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x23", ",", "100.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"y23", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]23", ",", "0.`"}], "}"}], ",", 
        RowBox[{"SymbolicValues", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Theta]23", "\[Rule]", "0"}], ",", 
           RowBox[{"x23", "\[Rule]", "100"}], ",", 
           RowBox[{"y23", "\[Rule]", "0"}]}], "}"}]}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Boundary", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "100"}], ",", 
          RowBox[{"-", "100"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"200", ",", "100", ",", "100"}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{3.408378390035376*^9, 3.408378464111353*^9, 
  3.544879504955936*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ManipulateSystem", "[", 
  RowBox[{"mysystem1", ",", " ", 
   RowBox[{"Axes", " ", "\[Rule]", " ", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.408328473011342*^9, 3.408328486271277*^9}, {
  3.4083294332090187`*^9, 3.408329436159306*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`lastlocpos\[Theta]0$$ = {5., 
    0.}, $CellContext`lastlocpos\[Theta]13$$ = {55., 
    0.}, $CellContext`lastlocpos\[Theta]23$$ = {105., 
    0.}, $CellContext`laststartpos\[Theta]0$$ = {0., 
    0.}, $CellContext`laststartpos\[Theta]13$$ = {50., 
    0.}, $CellContext`laststartpos\[Theta]23$$ = {100., 
    0.}, $CellContext`last\[Theta]0$$ = 0., $CellContext`last\[Theta]13$$ = 
    0., $CellContext`last\[Theta]23$$ = 0., $CellContext`maxr11$$ = 
    144, $CellContext`maxr12$$ = 
    54, $CellContext`maxr13$$ = -0.383, $CellContext`maxr21$$ = 
    77, $CellContext`maxr22$$ = -0.268, $CellContext`maxr23$$ = -0.718, \
$CellContext`maxx0$$ = 10, $CellContext`maxx13$$ = 
    100, $CellContext`maxx23$$ = 200, $CellContext`maxy0$$ = 
    10, $CellContext`maxy13$$ = 10, $CellContext`maxy23$$ = 
    10, $CellContext`max\[Theta]0$$ = 180., $CellContext`max\[Theta]13$$ = 
    180., $CellContext`max\[Theta]23$$ = 180., $CellContext`minr11$$ = 
    0.718, $CellContext`minr12$$ = 
    0.268, $CellContext`minr13$$ = -77, $CellContext`minr21$$ = 
    0.383, $CellContext`minr22$$ = -54, $CellContext`minr23$$ = -144, \
$CellContext`minx0$$ = -10, $CellContext`minx13$$ = 
    0.5, $CellContext`minx23$$ = 
    1., $CellContext`miny0$$ = -10, $CellContext`miny13$$ = -10, \
$CellContext`miny23$$ = -10, $CellContext`min\[Theta]0$$ = -180., \
$CellContext`min\[Theta]13$$ = -180., $CellContext`min\[Theta]23$$ = -180., \
$CellContext`r11$$ = 71.89, $CellContext`r12$$ = 
    26.81, $CellContext`r13$$ = -38.35, $CellContext`r21$$ = 
    38.35, $CellContext`r22$$ = -26.81, $CellContext`r23$$ = -71.89, \
$CellContext`radius\[Theta]0$$ = 5., $CellContext`radius\[Theta]13$$ = 
    5., $CellContext`radius\[Theta]23$$ = 
    5., $CellContext`staticpolygons138408620125111455390175$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigIFMBwgd6YDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4AItYluA==
      "]]}, $CellContext`x0$$ = 
    0., $CellContext`x13$$ = 50., $CellContext`x23$$ = 
    100., $CellContext`xoff\[Theta]0$$ = 5., $CellContext`xoff\[Theta]13$$ = 
    5., $CellContext`xoff\[Theta]23$$ = 5., $CellContext`x\[Theta]0$$ = 
    5., $CellContext`x\[Theta]13$$ = 55., $CellContext`x\[Theta]23$$ = 
    105., $CellContext`y0$$ = 0., $CellContext`y13$$ = 
    0., $CellContext`y23$$ = 0., $CellContext`yoff\[Theta]0$$ = 
    0., $CellContext`yoff\[Theta]13$$ = 0., $CellContext`yoff\[Theta]23$$ = 
    0., $CellContext`y\[Theta]0$$ = 0., $CellContext`y\[Theta]13$$ = 
    0., $CellContext`y\[Theta]23$$ = 0., $CellContext`\[Theta]0$$ = 
    0., $CellContext`\[Theta]13$$ = 0., $CellContext`\[Theta]23$$ = 0., 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`x0$$], 0.}, -10, 10}, {{
       Hold[$CellContext`y0$$], 0.}, -10, 10}, {{
       Hold[$CellContext`\[Theta]0$$], 0.}, -180., 180.}, {{
       Hold[$CellContext`r11$$], 71.89}, 0.718, 144}, {{
       Hold[$CellContext`r12$$], 26.81}, 0.268, 54}, {{
       Hold[$CellContext`r13$$], -38.35}, -77, -0.383}, {{
       Hold[$CellContext`r21$$], 38.35}, 0.383, 77}, {{
       Hold[$CellContext`r22$$], -26.81}, -54, -0.268}, {{
       Hold[$CellContext`r23$$], -71.89}, -144, -0.718}, {{
       Hold[$CellContext`x13$$], 50.}, 0.5, 100}, {{
       Hold[$CellContext`x23$$], 100.}, 1., 200}, {{
       Hold[$CellContext`y13$$], 0.}, -10, 10}, {{
       Hold[$CellContext`y23$$], 0.}, -10, 10}, {{
       Hold[$CellContext`\[Theta]13$$], 0.}, -180., 180.}, {{
       Hold[$CellContext`\[Theta]23$$], 0.}, -180., 180.}, {
      Hold[
       Style[
        Grid[{{"r11", 
           InputField[
            Dynamic[$CellContext`minr11$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable15938408620125111456999432; $CellContext`r11$$, \
($CellContext`r11$$ = #)& ], {
             Dynamic[$CellContext`minr11$$], 
             Dynamic[$CellContext`maxr11$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxr11$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`nonexistantvariable15938408620125111456999432; \
$CellContext`r11$$, ($CellContext`r11$$ = #)& ]}}]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minr11$$], 0.718}}, {{
       Hold[$CellContext`maxr11$$], 144}}, {
      Hold[
       Style[
        Grid[{{"r12", 
           InputField[
            Dynamic[$CellContext`minr12$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable15938408620125111456999644; $CellContext`r12$$, \
($CellContext`r12$$ = #)& ], {
             Dynamic[$CellContext`minr12$$], 
             Dynamic[$CellContext`maxr12$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxr12$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`nonexistantvariable15938408620125111456999644; \
$CellContext`r12$$, ($CellContext`r12$$ = #)& ]}}]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minr12$$], 0.268}}, {{
       Hold[$CellContext`maxr12$$], 54}}, {
      Hold[
       Style[
        Grid[{{"r13", 
           InputField[
            Dynamic[$CellContext`minr13$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable15938408620125111456999820; $CellContext`r13$$, \
($CellContext`r13$$ = #)& ], {
             Dynamic[$CellContext`minr13$$], 
             Dynamic[$CellContext`maxr13$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxr13$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`nonexistantvariable15938408620125111456999820; \
$CellContext`r13$$, ($CellContext`r13$$ = #)& ]}}]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minr13$$], -77}}, {{
       Hold[$CellContext`maxr13$$], -0.383}}, {
      Hold[
       Style[
        Grid[{{"r21", 
           InputField[
            Dynamic[$CellContext`minr21$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable15938408620125111456999991; $CellContext`r21$$, \
($CellContext`r21$$ = #)& ], {
             Dynamic[$CellContext`minr21$$], 
             Dynamic[$CellContext`maxr21$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxr21$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`nonexistantvariable15938408620125111456999991; \
$CellContext`r21$$, ($CellContext`r21$$ = #)& ]}}]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minr21$$], 0.383}}, {{
       Hold[$CellContext`maxr21$$], 77}}, {
      Hold[
       Style[
        Grid[{{"r22", 
           InputField[
            Dynamic[$CellContext`minr22$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable15938408620125111457000167; $CellContext`r22$$, \
($CellContext`r22$$ = #)& ], {
             Dynamic[$CellContext`minr22$$], 
             Dynamic[$CellContext`maxr22$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxr22$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`nonexistantvariable15938408620125111457000167; \
$CellContext`r22$$, ($CellContext`r22$$ = #)& ]}}]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minr22$$], -54}}, {{
       Hold[$CellContext`maxr22$$], -0.268}}, {
      Hold[
       Style[
        Grid[{{"r23", 
           InputField[
            Dynamic[$CellContext`minr23$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable15938408620125111457000338; $CellContext`r23$$, \
($CellContext`r23$$ = #)& ], {
             Dynamic[$CellContext`minr23$$], 
             Dynamic[$CellContext`maxr23$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxr23$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`nonexistantvariable15938408620125111457000338; \
$CellContext`r23$$, ($CellContext`r23$$ = #)& ]}}]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minr23$$], -144}}, {{
       Hold[$CellContext`maxr23$$], -0.718}}, {{
       Hold[$CellContext`minx0$$], -10}}, {{
       Hold[$CellContext`maxx0$$], 10}}, {{
       Hold[$CellContext`miny0$$], -10}}, {{
       Hold[$CellContext`maxy0$$], 10}}, {{
       Hold[$CellContext`min\[Theta]0$$], -180.}}, {{
       Hold[$CellContext`max\[Theta]0$$], 180.}}, {{
       Hold[$CellContext`minx13$$], 0.5}}, {{
       Hold[$CellContext`maxx13$$], 100}}, {{
       Hold[$CellContext`minx23$$], 1.}}, {{
       Hold[$CellContext`maxx23$$], 200}}, {{
       Hold[$CellContext`miny13$$], -10}}, {{
       Hold[$CellContext`maxy13$$], 10}}, {{
       Hold[$CellContext`miny23$$], -10}}, {{
       Hold[$CellContext`maxy23$$], 10}}, {{
       Hold[$CellContext`min\[Theta]13$$], -180.}}, {{
       Hold[$CellContext`max\[Theta]13$$], 180.}}, {{
       Hold[$CellContext`min\[Theta]23$$], -180.}}, {{
       Hold[$CellContext`max\[Theta]23$$], 180.}}, {{
       Hold[$CellContext`minr11$$], 0.718}}, {{
       Hold[$CellContext`maxr11$$], 144}}, {{
       Hold[$CellContext`minr12$$], 0.268}}, {{
       Hold[$CellContext`maxr12$$], 54}}, {{
       Hold[$CellContext`minr13$$], -77}}, {{
       Hold[$CellContext`maxr13$$], -0.383}}, {{
       Hold[$CellContext`minr21$$], 0.383}}, {{
       Hold[$CellContext`maxr21$$], 77}}, {{
       Hold[$CellContext`minr22$$], -54}}, {{
       Hold[$CellContext`maxr22$$], -0.268}}, {{
       Hold[$CellContext`minr23$$], -144}}, {{
       Hold[$CellContext`maxr23$$], -0.718}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{
              "r11", "r12", "r13", "r21", "r22", "r23", "x0", "x13", "x23", 
               "y0", "y13", "y23", "\[Theta]0", "\[Theta]13", 
               "\[Theta]23"}, {$CellContext`r11$$, $CellContext`r12$$, \
$CellContext`r13$$, $CellContext`r21$$, $CellContext`r22$$, \
$CellContext`r23$$, $CellContext`x0$$, $CellContext`x13$$, \
$CellContext`x23$$, $CellContext`y0$$, $CellContext`y13$$, \
$CellContext`y23$$, $CellContext`\[Theta]0$$, $CellContext`\[Theta]13$$, \
$CellContext`\[Theta]23$$}}], 
           Optica`Optica`SymbolicRanges -> {$CellContext`x0$$ -> {-10, 
              10}, $CellContext`y0$$ -> {-10, 
              10}, $CellContext`\[Theta]0$$ -> {-180., 
              180.}, $CellContext`r11$$ -> {
              0.718, 144}, $CellContext`r12$$ -> {
              0.268, 54}, $CellContext`r13$$ -> {-77, -0.383}, \
$CellContext`r21$$ -> {
              0.383, 77}, $CellContext`r22$$ -> {-54, -0.268}, \
$CellContext`r23$$ -> {-144, -0.718}, $CellContext`x13$$ -> {
              0.5, 100}, $CellContext`x23$$ -> {
              1., 200}, $CellContext`y13$$ -> {-10, 
              10}, $CellContext`y23$$ -> {-10, 
              10}, $CellContext`\[Theta]13$$ -> {-180., 
              180.}, $CellContext`\[Theta]23$$ -> {-180., 180.}}}; 
        Optica`Optica`$OpticalSystemScript = 
         "{Move[WedgeOfRays[10, NumberOfRays -> 6], {{x0, 0}, {y0, 0}}, {\
\[Theta]0, 0.}, SymbolicValues -> {\[Theta]0 -> 0, x0 -> 0, y0 -> 0}], \
Move[LensDoublet[{r11, 71.89}, {r12, 26.81}, {r13, -38.35}, 25.4, 2.1, 7.5, \
SF5, BK7], {{x13, 50.}, {y13, 0}}, {\[Theta]13, 0.}, SymbolicValues -> {\
\[Theta]13 -> 0, x13 -> 50, y13 -> 0}], Move[LensDoublet[{r21, 38.35}, {r22, \
-26.81}, {r23, -71.89}, 25.4, 7.5, 2.1, BK7, SF5], {{x23, 100.}, {y23, 0}}, {\
\[Theta]23, 0.}, SymbolicValues -> {\[Theta]23 -> 0, x23 -> 100, y23 -> 0}], \
Boundary[{0, -100, -100}, {200, 100, 100}]}"; Print[
          InputForm[
           StringJoin["SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "r11", "r12", "r13", "r21", "r22", "r23", "x0", "x13", "x23", 
                "y0", "y13", "y23", "\[Theta]0", "\[Theta]13", 
                "\[Theta]23"}, {$CellContext`r11$$, $CellContext`r12$$, \
$CellContext`r13$$, $CellContext`r21$$, $CellContext`r22$$, \
$CellContext`r23$$, $CellContext`x0$$, $CellContext`x13$$, \
$CellContext`x23$$, $CellContext`y0$$, $CellContext`y13$$, \
$CellContext`y23$$, $CellContext`\[Theta]0$$, $CellContext`\[Theta]13$$, \
$CellContext`\[Theta]23$$}}]]]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`x\[Theta]0$$], 5.}}, {{
       Hold[$CellContext`y\[Theta]0$$], 0.}}, {{
       Hold[$CellContext`radius\[Theta]0$$], 5.}}, {{
       Hold[$CellContext`xoff\[Theta]0$$], 5.}}, {{
       Hold[$CellContext`yoff\[Theta]0$$], 0.}}, {{
       Hold[$CellContext`laststartpos\[Theta]0$$], {0., 0.}}}, {{
       Hold[$CellContext`lastlocpos\[Theta]0$$], {5., 0.}}}, {{
       Hold[$CellContext`last\[Theta]0$$], 0}}, {{
       Hold[$CellContext`x\[Theta]13$$], 55.}}, {{
       Hold[$CellContext`y\[Theta]13$$], 0.}}, {{
       Hold[$CellContext`radius\[Theta]13$$], 5.}}, {{
       Hold[$CellContext`xoff\[Theta]13$$], 5.}}, {{
       Hold[$CellContext`yoff\[Theta]13$$], 0.}}, {{
       Hold[$CellContext`laststartpos\[Theta]13$$], {50., 0.}}}, {{
       Hold[$CellContext`lastlocpos\[Theta]13$$], {55., 0.}}}, {{
       Hold[$CellContext`last\[Theta]13$$], 0}}, {{
       Hold[$CellContext`x\[Theta]23$$], 105.}}, {{
       Hold[$CellContext`y\[Theta]23$$], 0.}}, {{
       Hold[$CellContext`radius\[Theta]23$$], 5.}}, {{
       Hold[$CellContext`xoff\[Theta]23$$], 5.}}, {{
       Hold[$CellContext`yoff\[Theta]23$$], 0.}}, {{
       Hold[$CellContext`laststartpos\[Theta]23$$], {100., 0.}}}, {{
       Hold[$CellContext`lastlocpos\[Theta]23$$], {105., 0.}}}, {{
       Hold[$CellContext`last\[Theta]23$$], 0}}, {{
       Hold[$CellContext`staticpolygons138408620125111455390175$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigIFMBwgd6YDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4AItYluA==
         "]]}}}}, Typeset`size$$ = {
    815., {417.34375, 422.65625}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`x0$59652$$ = 
    0, $CellContext`y0$59653$$ = 0, $CellContext`\[Theta]0$59654$$ = 
    0, $CellContext`r11$59655$$ = 0, $CellContext`r12$59656$$ = 
    0, $CellContext`r13$59657$$ = 0, $CellContext`r21$59658$$ = 
    0, $CellContext`r22$59659$$ = 0, $CellContext`r23$59660$$ = 
    0, $CellContext`x13$59661$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`lastlocpos\[Theta]0$$ = {5., 
         0.}, $CellContext`lastlocpos\[Theta]13$$ = {55., 
         0.}, $CellContext`lastlocpos\[Theta]23$$ = {105., 
         0.}, $CellContext`laststartpos\[Theta]0$$ = {0., 
         0.}, $CellContext`laststartpos\[Theta]13$$ = {50., 
         0.}, $CellContext`laststartpos\[Theta]23$$ = {100., 
         0.}, $CellContext`last\[Theta]0$$ = 0, $CellContext`last\[Theta]13$$ = 
        0, $CellContext`last\[Theta]23$$ = 0, $CellContext`maxr11$$ = 
        144, $CellContext`maxr12$$ = 
        54, $CellContext`maxr13$$ = -0.383, $CellContext`maxr21$$ = 
        77, $CellContext`maxr22$$ = -0.268, $CellContext`maxr23$$ = -0.718, \
$CellContext`maxx0$$ = 10, $CellContext`maxx13$$ = 100, $CellContext`maxx23$$ = 
        200, $CellContext`maxy0$$ = 10, $CellContext`maxy13$$ = 
        10, $CellContext`maxy23$$ = 10, $CellContext`max\[Theta]0$$ = 
        180., $CellContext`max\[Theta]13$$ = 
        180., $CellContext`max\[Theta]23$$ = 180., $CellContext`minr11$$ = 
        0.718, $CellContext`minr12$$ = 
        0.268, $CellContext`minr13$$ = -77, $CellContext`minr21$$ = 
        0.383, $CellContext`minr22$$ = -54, $CellContext`minr23$$ = -144, \
$CellContext`minx0$$ = -10, $CellContext`minx13$$ = 
        0.5, $CellContext`minx23$$ = 
        1., $CellContext`miny0$$ = -10, $CellContext`miny13$$ = -10, \
$CellContext`miny23$$ = -10, $CellContext`min\[Theta]0$$ = -180., \
$CellContext`min\[Theta]13$$ = -180., $CellContext`min\[Theta]23$$ = -180., \
$CellContext`r11$$ = 71.89, $CellContext`r12$$ = 
        26.81, $CellContext`r13$$ = -38.35, $CellContext`r21$$ = 
        38.35, $CellContext`r22$$ = -26.81, $CellContext`r23$$ = -71.89, \
$CellContext`radius\[Theta]0$$ = 5., $CellContext`radius\[Theta]13$$ = 
        5., $CellContext`radius\[Theta]23$$ = 
        5., $CellContext`staticpolygons138408620125111455390175$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigIFMBwgd6YDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4AItYluA==
           "]]}, $CellContext`x0$$ = 
        0., $CellContext`x13$$ = 50., $CellContext`x23$$ = 
        100., $CellContext`xoff\[Theta]0$$ = 
        5., $CellContext`xoff\[Theta]13$$ = 5., $CellContext`xoff\[Theta]23$$ = 
        5., $CellContext`x\[Theta]0$$ = 5., $CellContext`x\[Theta]13$$ = 
        55., $CellContext`x\[Theta]23$$ = 105., $CellContext`y0$$ = 
        0., $CellContext`y13$$ = 0., $CellContext`y23$$ = 
        0., $CellContext`yoff\[Theta]0$$ = 0., $CellContext`yoff\[Theta]13$$ = 
        0., $CellContext`yoff\[Theta]23$$ = 0., $CellContext`y\[Theta]0$$ = 
        0., $CellContext`y\[Theta]13$$ = 0., $CellContext`y\[Theta]23$$ = 
        0., $CellContext`\[Theta]0$$ = 0., $CellContext`\[Theta]13$$ = 
        0., $CellContext`\[Theta]23$$ = 0.}, "ControllerVariables" :> {
        Hold[$CellContext`x0$$, $CellContext`x0$59652$$, 0], 
        Hold[$CellContext`y0$$, $CellContext`y0$59653$$, 0], 
        Hold[$CellContext`\[Theta]0$$, $CellContext`\[Theta]0$59654$$, 0], 
        Hold[$CellContext`r11$$, $CellContext`r11$59655$$, 0], 
        Hold[$CellContext`r12$$, $CellContext`r12$59656$$, 0], 
        Hold[$CellContext`r13$$, $CellContext`r13$59657$$, 0], 
        Hold[$CellContext`r21$$, $CellContext`r21$59658$$, 0], 
        Hold[$CellContext`r22$$, $CellContext`r22$59659$$, 0], 
        Hold[$CellContext`r23$$, $CellContext`r23$59660$$, 0], 
        Hold[$CellContext`x13$$, $CellContext`x13$59661$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         OpenerView[{"TopView", 
           Show[{
             Graphics[{{
                Opacity[0.8], 
                GeometricTransformation[{
                  AbsoluteThickness[1], 
                  AbsolutePointSize[1], 
                  EdgeForm[], 
                  RGBColor[0.4, 0.6, 0.8], 
                  Polygon[
                   Dynamic[
                    (Map[
                    Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], {{1, 27}, {28, 54}}]& )[
                    $CellContext`polygons118408620125111455363987[$\
CellContext`r11$$, $CellContext`r12$$, $CellContext`r13$$]]]]}, 
                 Dynamic[BesselJ[1., 3.]; {{{
                    Cos[Degree $CellContext`\[Theta]13$$], -
                    Sin[Degree $CellContext`\[Theta]13$$]}, {
                    Sin[Degree $CellContext`\[Theta]13$$], 
                    Cos[
                    Degree $CellContext`\[Theta]13$$]}}, {$CellContext`x13$$, \
$CellContext`y13$$}}]], 
                GeometricTransformation[{
                  AbsoluteThickness[1], 
                  AbsolutePointSize[1], 
                  EdgeForm[], 
                  RGBColor[0.4, 0.6, 0.8], 
                  Polygon[
                   Dynamic[
                    (Map[
                    Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], {{1, 27}, {28, 54}}]& )[
                    $CellContext`polygons128408620125111455388113[$\
CellContext`r21$$, $CellContext`r22$$, $CellContext`r23$$]]]]}, 
                 Dynamic[BesselJ[1., 3.]; {{{
                    Cos[Degree $CellContext`\[Theta]23$$], -
                    Sin[Degree $CellContext`\[Theta]23$$]}, {
                    Sin[Degree $CellContext`\[Theta]23$$], 
                    Cos[
                    Degree $CellContext`\[Theta]23$$]}}, {$CellContext`x23$$, \
$CellContext`y23$$}}]], $CellContext`staticpolygons138408620125111455390175$$, 
                Opacity[1], 
                RGBColor[
                0.038747429704798886`, 0.9161617552424038, 
                 0.039847212269181365`], 
                AbsoluteThickness[Medium], 
                Line[
                 Dynamic[
                  Refresh[
                   Map[{
                    Part[#, {1, 2}], 
                    Part[#, {4, 5}]}& , 
                    Select[
                    $CellContext`raytracefunction18408620125111455401102[$\
CellContext`x0$$, $CellContext`y0$$, $CellContext`\[Theta]0$$, \
$CellContext`r11$$, $CellContext`r12$$, $CellContext`r13$$, \
$CellContext`r21$$, $CellContext`r22$$, $CellContext`r23$$, \
$CellContext`x13$$, $CellContext`x23$$, $CellContext`y13$$, \
$CellContext`y23$$, $CellContext`\[Theta]13$$, $CellContext`\[Theta]23$$], 
                    And[Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]], 
                   TrackedSymbols :> {$CellContext`x0$$, $CellContext`y0$$, \
$CellContext`\[Theta]0$$, $CellContext`r11$$, $CellContext`r12$$, \
$CellContext`r13$$, $CellContext`r21$$, $CellContext`r22$$, \
$CellContext`r23$$, $CellContext`x13$$, $CellContext`x23$$, \
$CellContext`y13$$, $CellContext`y23$$, $CellContext`\[Theta]13$$, \
$CellContext`\[Theta]23$$}], SynchronousUpdating -> False]], 
                Arrowheads[Large], 
                Thickness[Large], 
                Dashing[{Small, Small}], 
                RGBColor[1, 1, 0], 
                Arrow[
                 Dynamic[If[
                    
                    Or[$CellContext`laststartpos\[Theta]0$$ != \
{$CellContext`x0$$, $CellContext`y0$$}, $CellContext`last\[Theta]0$$ =!= \
$CellContext`\[Theta]0$$], $CellContext`laststartpos\[Theta]0$$ = \
{$CellContext`x0$$, $CellContext`y0$$}; $CellContext`last\[Theta]0$$ = \
$CellContext`\[Theta]0$$; {$CellContext`x\[Theta]0$$, \
$CellContext`y\[Theta]0$$} = $CellContext`laststartpos\[Theta]0$$ + \
$CellContext`radius\[Theta]0$$ {
                    Cos[$CellContext`\[Theta]0$$ Degree], 
                    
                    Sin[$CellContext`\[Theta]0$$ 
                    Degree]}]; {$CellContext`laststartpos\[Theta]0$$, \
{$CellContext`x\[Theta]0$$, $CellContext`y\[Theta]0$$}}, \
({$CellContext`laststartpos\[Theta]0$$, {$CellContext`x\[Theta]0$$, \
$CellContext`y\[Theta]0$$}} = #)& ]], 
                Tooltip[
                 Locator[
                  Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`x\[Theta]0$$, $CellContext`y\[Theta]0$$} != \
$CellContext`lastlocpos\[Theta]0$$, $CellContext`last\[Theta]0$$ != \
$CellContext`\[Theta]0$$], $CellContext`lastlocpos\[Theta]0$$ = \
{$CellContext`x\[Theta]0$$, $CellContext`y\[Theta]0$$}; $CellContext`last\
\[Theta]0$$ = $CellContext`\[Theta]0$$; {$CellContext`x\[Theta]0$$, \
$CellContext`y\[Theta]0$$} = $CellContext`laststartpos\[Theta]0$$ + \
$CellContext`radius\[Theta]0$$ {
                    Cos[$CellContext`\[Theta]0$$ Degree], 
                    
                    Sin[$CellContext`\[Theta]0$$ 
                    Degree]}]; {$CellContext`x\[Theta]0$$, $CellContext`y\
\[Theta]0$$}), ({$CellContext`x\[Theta]0$$, $CellContext`y\[Theta]0$$} = #; \
$CellContext`xoff\[Theta]0$$ = $CellContext`x\[Theta]0$$ - $CellContext`x0$$; \
$CellContext`yoff\[Theta]0$$ = $CellContext`y\[Theta]0$$ - $CellContext`y0$$; \
$CellContext`radius\[Theta]0$$ = 
                    Sqrt[$CellContext`xoff\[Theta]0$$^2 + $CellContext`yoff\
\[Theta]0$$^2]; $CellContext`\[Theta]0$$ = 
                    Chop[ArcTan[$CellContext`xoff\[Theta]0$$, \
$CellContext`yoff\[Theta]0$$]/
                    Degree]; {$CellContext`x\[Theta]0$$, $CellContext`y\
\[Theta]0$$})& ], 
                  Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                 Dynamic[
                  StringJoin["\[Theta]0 = ", 
                   ToString[$CellContext`\[Theta]0$$]]]], 
                Arrowheads[Large], 
                Thickness[Large], 
                Dashing[{Small, Small}], 
                RGBColor[1, 1, 0], 
                Arrow[
                 Dynamic[If[
                    
                    Or[$CellContext`laststartpos\[Theta]13$$ != \
{$CellContext`x13$$, $CellContext`y13$$}, $CellContext`last\[Theta]13$$ =!= \
$CellContext`\[Theta]13$$], $CellContext`laststartpos\[Theta]13$$ = \
{$CellContext`x13$$, $CellContext`y13$$}; $CellContext`last\[Theta]13$$ = \
$CellContext`\[Theta]13$$; {$CellContext`x\[Theta]13$$, \
$CellContext`y\[Theta]13$$} = $CellContext`laststartpos\[Theta]13$$ + \
$CellContext`radius\[Theta]13$$ {
                    Cos[$CellContext`\[Theta]13$$ Degree], 
                    
                    Sin[$CellContext`\[Theta]13$$ 
                    Degree]}]; {$CellContext`laststartpos\[Theta]13$$, \
{$CellContext`x\[Theta]13$$, $CellContext`y\[Theta]13$$}}, \
({$CellContext`laststartpos\[Theta]13$$, {$CellContext`x\[Theta]13$$, \
$CellContext`y\[Theta]13$$}} = #)& ]], 
                Tooltip[
                 Locator[
                  Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`x\[Theta]13$$, \
$CellContext`y\[Theta]13$$} != $CellContext`lastlocpos\[Theta]13$$, \
$CellContext`last\[Theta]13$$ != $CellContext`\[Theta]13$$], \
$CellContext`lastlocpos\[Theta]13$$ = {$CellContext`x\[Theta]13$$, \
$CellContext`y\[Theta]13$$}; $CellContext`last\[Theta]13$$ = $CellContext`\
\[Theta]13$$; {$CellContext`x\[Theta]13$$, $CellContext`y\[Theta]13$$} = \
$CellContext`laststartpos\[Theta]13$$ + $CellContext`radius\[Theta]13$$ {
                    Cos[$CellContext`\[Theta]13$$ Degree], 
                    
                    Sin[$CellContext`\[Theta]13$$ 
                    Degree]}]; {$CellContext`x\[Theta]13$$, $CellContext`y\
\[Theta]13$$}), ({$CellContext`x\[Theta]13$$, $CellContext`y\[Theta]13$$} = #; \
$CellContext`xoff\[Theta]13$$ = $CellContext`x\[Theta]13$$ - \
$CellContext`x13$$; $CellContext`yoff\[Theta]13$$ = \
$CellContext`y\[Theta]13$$ - $CellContext`y13$$; \
$CellContext`radius\[Theta]13$$ = 
                    Sqrt[$CellContext`xoff\[Theta]13$$^2 + $CellContext`yoff\
\[Theta]13$$^2]; $CellContext`\[Theta]13$$ = 
                    Chop[ArcTan[$CellContext`xoff\[Theta]13$$, \
$CellContext`yoff\[Theta]13$$]/
                    Degree]; {$CellContext`x\[Theta]13$$, $CellContext`y\
\[Theta]13$$})& ], 
                  Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                 Dynamic[
                  StringJoin["\[Theta]13 = ", 
                   ToString[$CellContext`\[Theta]13$$]]]], 
                Arrowheads[Large], 
                Thickness[Large], 
                Dashing[{Small, Small}], 
                RGBColor[1, 1, 0], 
                Arrow[
                 Dynamic[If[
                    
                    Or[$CellContext`laststartpos\[Theta]23$$ != \
{$CellContext`x23$$, $CellContext`y23$$}, $CellContext`last\[Theta]23$$ =!= \
$CellContext`\[Theta]23$$], $CellContext`laststartpos\[Theta]23$$ = \
{$CellContext`x23$$, $CellContext`y23$$}; $CellContext`last\[Theta]23$$ = \
$CellContext`\[Theta]23$$; {$CellContext`x\[Theta]23$$, \
$CellContext`y\[Theta]23$$} = $CellContext`laststartpos\[Theta]23$$ + \
$CellContext`radius\[Theta]23$$ {
                    Cos[$CellContext`\[Theta]23$$ Degree], 
                    
                    Sin[$CellContext`\[Theta]23$$ 
                    Degree]}]; {$CellContext`laststartpos\[Theta]23$$, \
{$CellContext`x\[Theta]23$$, $CellContext`y\[Theta]23$$}}, \
({$CellContext`laststartpos\[Theta]23$$, {$CellContext`x\[Theta]23$$, \
$CellContext`y\[Theta]23$$}} = #)& ]], 
                Tooltip[
                 Locator[
                  Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`x\[Theta]23$$, \
$CellContext`y\[Theta]23$$} != $CellContext`lastlocpos\[Theta]23$$, \
$CellContext`last\[Theta]23$$ != $CellContext`\[Theta]23$$], \
$CellContext`lastlocpos\[Theta]23$$ = {$CellContext`x\[Theta]23$$, \
$CellContext`y\[Theta]23$$}; $CellContext`last\[Theta]23$$ = $CellContext`\
\[Theta]23$$; {$CellContext`x\[Theta]23$$, $CellContext`y\[Theta]23$$} = \
$CellContext`laststartpos\[Theta]23$$ + $CellContext`radius\[Theta]23$$ {
                    Cos[$CellContext`\[Theta]23$$ Degree], 
                    
                    Sin[$CellContext`\[Theta]23$$ 
                    Degree]}]; {$CellContext`x\[Theta]23$$, $CellContext`y\
\[Theta]23$$}), ({$CellContext`x\[Theta]23$$, $CellContext`y\[Theta]23$$} = #; \
$CellContext`xoff\[Theta]23$$ = $CellContext`x\[Theta]23$$ - \
$CellContext`x23$$; $CellContext`yoff\[Theta]23$$ = \
$CellContext`y\[Theta]23$$ - $CellContext`y23$$; \
$CellContext`radius\[Theta]23$$ = 
                    Sqrt[$CellContext`xoff\[Theta]23$$^2 + $CellContext`yoff\
\[Theta]23$$^2]; $CellContext`\[Theta]23$$ = 
                    Chop[ArcTan[$CellContext`xoff\[Theta]23$$, \
$CellContext`yoff\[Theta]23$$]/
                    Degree]; {$CellContext`x\[Theta]23$$, $CellContext`y\
\[Theta]23$$})& ], 
                  Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                 Dynamic[
                  StringJoin["\[Theta]23 = ", 
                   ToString[$CellContext`\[Theta]23$$]]]], 
                Tooltip[
                 Locator[
                  Dynamic[
                  BesselJ[
                    1., 3.]; {$CellContext`x0$$, $CellContext`y0$$}, \
({$CellContext`x0$$, $CellContext`y0$$} = Chop[#])& ], 
                  Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                 Dynamic[
                  StringJoin["{x0, y0} = ", 
                   ToString[
                    Chop[{$CellContext`x0$$, $CellContext`y0$$}]]]]], 
                Tooltip[
                 Locator[
                  Dynamic[
                  BesselJ[
                    1., 3.]; {$CellContext`x13$$, $CellContext`y13$$}, \
({$CellContext`x13$$, $CellContext`y13$$} = Chop[#])& ], 
                  Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                 Dynamic[
                  StringJoin["{x13, y13} = ", 
                   ToString[
                    Chop[{$CellContext`x13$$, $CellContext`y13$$}]]]]], 
                Tooltip[
                 Locator[
                  Dynamic[
                  BesselJ[
                    1., 3.]; {$CellContext`x23$$, $CellContext`y23$$}, \
({$CellContext`x23$$, $CellContext`y23$$} = Chop[#])& ], 
                  Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                 Dynamic[
                  StringJoin["{x23, y23} = ", 
                   ToString[
                    Chop[{$CellContext`x23$$, $CellContext`y23$$}]]]]]}}]}, {
            PlotLabel -> "TopView", Axes -> True, ImageSize -> 800, 
             AspectRatio -> Automatic}]}, True], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`x0$$, 0.}, -10, 10, ControlType -> 
         None}, {{$CellContext`y0$$, 0.}, -10, 10, ControlType -> 
         None}, {{$CellContext`\[Theta]0$$, 0.}, -180., 180., ControlType -> 
         None}, {{$CellContext`r11$$, 71.89}, 0.718, 144, ControlType -> 
         None}, {{$CellContext`r12$$, 26.81}, 0.268, 54, ControlType -> 
         None}, {{$CellContext`r13$$, -38.35}, -77, -0.383, ControlType -> 
         None}, {{$CellContext`r21$$, 38.35}, 0.383, 77, ControlType -> 
         None}, {{$CellContext`r22$$, -26.81}, -54, -0.268, ControlType -> 
         None}, {{$CellContext`r23$$, -71.89}, -144, -0.718, ControlType -> 
         None}, {{$CellContext`x13$$, 50.}, 0.5, 100, ControlType -> 
         None}, {{$CellContext`x23$$, 100.}, 1., 200, ControlType -> 
         None}, {{$CellContext`y13$$, 0.}, -10, 10, ControlType -> 
         None}, {{$CellContext`y23$$, 0.}, -10, 10, ControlType -> 
         None}, {{$CellContext`\[Theta]13$$, 0.}, -180., 180., ControlType -> 
         None}, {{$CellContext`\[Theta]23$$, 0.}, -180., 180., ControlType -> 
         None}, 
        Style[
         Grid[{{"r11", 
            InputField[
             Dynamic[$CellContext`minr11$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable15938408620125111456999432; $CellContext`r11$$, \
($CellContext`r11$$ = #)& ], {
              Dynamic[$CellContext`minr11$$], 
              Dynamic[$CellContext`maxr11$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxr11$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable15938408620125111456999432; $CellContext`r11$$, \
($CellContext`r11$$ = #)& ]}}]], {{$CellContext`minr11$$, 0.718}, ControlType -> 
         None}, {{$CellContext`maxr11$$, 144}, ControlType -> None}, 
        Style[
         Grid[{{"r12", 
            InputField[
             Dynamic[$CellContext`minr12$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable15938408620125111456999644; $CellContext`r12$$, \
($CellContext`r12$$ = #)& ], {
              Dynamic[$CellContext`minr12$$], 
              Dynamic[$CellContext`maxr12$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxr12$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable15938408620125111456999644; $CellContext`r12$$, \
($CellContext`r12$$ = #)& ]}}]], {{$CellContext`minr12$$, 0.268}, ControlType -> 
         None}, {{$CellContext`maxr12$$, 54}, ControlType -> None}, 
        Style[
         Grid[{{"r13", 
            InputField[
             Dynamic[$CellContext`minr13$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable15938408620125111456999820; $CellContext`r13$$, \
($CellContext`r13$$ = #)& ], {
              Dynamic[$CellContext`minr13$$], 
              Dynamic[$CellContext`maxr13$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxr13$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable15938408620125111456999820; $CellContext`r13$$, \
($CellContext`r13$$ = #)& ]}}]], {{$CellContext`minr13$$, -77}, ControlType -> 
         None}, {{$CellContext`maxr13$$, -0.383}, ControlType -> None}, 
        Style[
         Grid[{{"r21", 
            InputField[
             Dynamic[$CellContext`minr21$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable15938408620125111456999991; $CellContext`r21$$, \
($CellContext`r21$$ = #)& ], {
              Dynamic[$CellContext`minr21$$], 
              Dynamic[$CellContext`maxr21$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxr21$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable15938408620125111456999991; $CellContext`r21$$, \
($CellContext`r21$$ = #)& ]}}]], {{$CellContext`minr21$$, 0.383}, ControlType -> 
         None}, {{$CellContext`maxr21$$, 77}, ControlType -> None}, 
        Style[
         Grid[{{"r22", 
            InputField[
             Dynamic[$CellContext`minr22$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable15938408620125111457000167; $CellContext`r22$$, \
($CellContext`r22$$ = #)& ], {
              Dynamic[$CellContext`minr22$$], 
              Dynamic[$CellContext`maxr22$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxr22$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable15938408620125111457000167; $CellContext`r22$$, \
($CellContext`r22$$ = #)& ]}}]], {{$CellContext`minr22$$, -54}, ControlType -> 
         None}, {{$CellContext`maxr22$$, -0.268}, ControlType -> None}, 
        Style[
         Grid[{{"r23", 
            InputField[
             Dynamic[$CellContext`minr23$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable15938408620125111457000338; $CellContext`r23$$, \
($CellContext`r23$$ = #)& ], {
              Dynamic[$CellContext`minr23$$], 
              Dynamic[$CellContext`maxr23$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxr23$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable15938408620125111457000338; $CellContext`r23$$, \
($CellContext`r23$$ = #)& ]}}]], {{$CellContext`minr23$$, -144}, ControlType -> 
         None}, {{$CellContext`maxr23$$, -0.718}, ControlType -> 
         None}, {{$CellContext`minx0$$, -10}, ControlType -> 
         None}, {{$CellContext`maxx0$$, 10}, ControlType -> 
         None}, {{$CellContext`miny0$$, -10}, ControlType -> 
         None}, {{$CellContext`maxy0$$, 10}, ControlType -> 
         None}, {{$CellContext`min\[Theta]0$$, -180.}, ControlType -> 
         None}, {{$CellContext`max\[Theta]0$$, 180.}, ControlType -> 
         None}, {{$CellContext`minx13$$, 0.5}, ControlType -> 
         None}, {{$CellContext`maxx13$$, 100}, ControlType -> 
         None}, {{$CellContext`minx23$$, 1.}, ControlType -> 
         None}, {{$CellContext`maxx23$$, 200}, ControlType -> 
         None}, {{$CellContext`miny13$$, -10}, ControlType -> 
         None}, {{$CellContext`maxy13$$, 10}, ControlType -> 
         None}, {{$CellContext`miny23$$, -10}, ControlType -> 
         None}, {{$CellContext`maxy23$$, 10}, ControlType -> 
         None}, {{$CellContext`min\[Theta]13$$, -180.}, ControlType -> 
         None}, {{$CellContext`max\[Theta]13$$, 180.}, ControlType -> 
         None}, {{$CellContext`min\[Theta]23$$, -180.}, ControlType -> 
         None}, {{$CellContext`max\[Theta]23$$, 180.}, ControlType -> 
         None}, {{$CellContext`minr11$$, 0.718}, ControlType -> 
         None}, {{$CellContext`maxr11$$, 144}, ControlType -> 
         None}, {{$CellContext`minr12$$, 0.268}, ControlType -> 
         None}, {{$CellContext`maxr12$$, 54}, ControlType -> 
         None}, {{$CellContext`minr13$$, -77}, ControlType -> 
         None}, {{$CellContext`maxr13$$, -0.383}, ControlType -> 
         None}, {{$CellContext`minr21$$, 0.383}, ControlType -> 
         None}, {{$CellContext`maxr21$$, 77}, ControlType -> 
         None}, {{$CellContext`minr22$$, -54}, ControlType -> 
         None}, {{$CellContext`maxr22$$, -0.268}, ControlType -> 
         None}, {{$CellContext`minr23$$, -144}, ControlType -> 
         None}, {{$CellContext`maxr23$$, -0.718}, ControlType -> None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{
               "r11", "r12", "r13", "r21", "r22", "r23", "x0", "x13", "x23", 
                "y0", "y13", "y23", "\[Theta]0", "\[Theta]13", 
                "\[Theta]23"}, {$CellContext`r11$$, $CellContext`r12$$, \
$CellContext`r13$$, $CellContext`r21$$, $CellContext`r22$$, \
$CellContext`r23$$, $CellContext`x0$$, $CellContext`x13$$, \
$CellContext`x23$$, $CellContext`y0$$, $CellContext`y13$$, \
$CellContext`y23$$, $CellContext`\[Theta]0$$, $CellContext`\[Theta]13$$, \
$CellContext`\[Theta]23$$}}], 
            Optica`Optica`SymbolicRanges -> {$CellContext`x0$$ -> {-10, 
               10}, $CellContext`y0$$ -> {-10, 
               10}, $CellContext`\[Theta]0$$ -> {-180., 
               180.}, $CellContext`r11$$ -> {
               0.718, 144}, $CellContext`r12$$ -> {
               0.268, 54}, $CellContext`r13$$ -> {-77, -0.383}, \
$CellContext`r21$$ -> {
               0.383, 77}, $CellContext`r22$$ -> {-54, -0.268}, \
$CellContext`r23$$ -> {-144, -0.718}, $CellContext`x13$$ -> {
               0.5, 100}, $CellContext`x23$$ -> {
               1., 200}, $CellContext`y13$$ -> {-10, 
               10}, $CellContext`y23$$ -> {-10, 
               10}, $CellContext`\[Theta]13$$ -> {-180., 
               180.}, $CellContext`\[Theta]23$$ -> {-180., 180.}}}; 
         Optica`Optica`$OpticalSystemScript = 
          "{Move[WedgeOfRays[10, NumberOfRays -> 6], {{x0, 0}, {y0, 0}}, {\
\[Theta]0, 0.}, SymbolicValues -> {\[Theta]0 -> 0, x0 -> 0, y0 -> 0}], \
Move[LensDoublet[{r11, 71.89}, {r12, 26.81}, {r13, -38.35}, 25.4, 2.1, 7.5, \
SF5, BK7], {{x13, 50.}, {y13, 0}}, {\[Theta]13, 0.}, SymbolicValues -> {\
\[Theta]13 -> 0, x13 -> 50, y13 -> 0}], Move[LensDoublet[{r21, 38.35}, {r22, \
-26.81}, {r23, -71.89}, 25.4, 7.5, 2.1, BK7, SF5], {{x23, 100.}, {y23, 0}}, {\
\[Theta]23, 0.}, SymbolicValues -> {\[Theta]23 -> 0, x23 -> 100, y23 -> 0}], \
Boundary[{0, -100, -100}, {200, 100, 100}]}"; Print[
           InputForm[
            StringJoin["SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "r11", "r12", "r13", "r21", "r22", "r23", "x0", "x13", "x23", 
                 "y0", "y13", "y23", "\[Theta]0", "\[Theta]13", 
                 "\[Theta]23"}, {$CellContext`r11$$, $CellContext`r12$$, \
$CellContext`r13$$, $CellContext`r21$$, $CellContext`r22$$, \
$CellContext`r23$$, $CellContext`x0$$, $CellContext`x13$$, \
$CellContext`x23$$, $CellContext`y0$$, $CellContext`y13$$, \
$CellContext`y23$$, $CellContext`\[Theta]0$$, $CellContext`\[Theta]13$$, \
$CellContext`\[Theta]23$$}}]]]]], ImageSize -> 
         Automatic], {{$CellContext`x\[Theta]0$$, 5.}, ControlType -> 
         None}, {{$CellContext`y\[Theta]0$$, 0.}, ControlType -> 
         None}, {{$CellContext`radius\[Theta]0$$, 5.}, ControlType -> 
         None}, {{$CellContext`xoff\[Theta]0$$, 5.}, ControlType -> 
         None}, {{$CellContext`yoff\[Theta]0$$, 0.}, ControlType -> 
         None}, {{$CellContext`laststartpos\[Theta]0$$, {0., 0.}}, 
         ControlType -> 
         None}, {{$CellContext`lastlocpos\[Theta]0$$, {5., 0.}}, ControlType -> 
         None}, {{$CellContext`last\[Theta]0$$, 0}, ControlType -> 
         None}, {{$CellContext`x\[Theta]13$$, 55.}, ControlType -> 
         None}, {{$CellContext`y\[Theta]13$$, 0.}, ControlType -> 
         None}, {{$CellContext`radius\[Theta]13$$, 5.}, ControlType -> 
         None}, {{$CellContext`xoff\[Theta]13$$, 5.}, ControlType -> 
         None}, {{$CellContext`yoff\[Theta]13$$, 0.}, ControlType -> 
         None}, {{$CellContext`laststartpos\[Theta]13$$, {50., 0.}}, 
         ControlType -> 
         None}, {{$CellContext`lastlocpos\[Theta]13$$, {55., 0.}}, 
         ControlType -> None}, {{$CellContext`last\[Theta]13$$, 0}, 
         ControlType -> None}, {{$CellContext`x\[Theta]23$$, 105.}, 
         ControlType -> None}, {{$CellContext`y\[Theta]23$$, 0.}, ControlType -> 
         None}, {{$CellContext`radius\[Theta]23$$, 5.}, ControlType -> 
         None}, {{$CellContext`xoff\[Theta]23$$, 5.}, ControlType -> 
         None}, {{$CellContext`yoff\[Theta]23$$, 0.}, ControlType -> 
         None}, {{$CellContext`laststartpos\[Theta]23$$, {100., 0.}}, 
         ControlType -> 
         None}, {{$CellContext`lastlocpos\[Theta]23$$, {105., 0.}}, 
         ControlType -> None}, {{$CellContext`last\[Theta]23$$, 0}, 
         ControlType -> 
         None}, {{$CellContext`staticpolygons138408620125111455390175$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigIFMBwgd6YDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4AItYluA==
            "]]}}, ControlType -> 
         None}}, "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 
         15}, SynchronousInitialization -> False, SynchronousUpdating -> 
        False, BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{858., {549., 555.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`raytracefunction18408620125111455401102 = 
       Compile[{{$CellContext`x0$$, 
           Blank[Real]}, {$CellContext`y0$$, 
           Blank[Real]}, {$CellContext`\[Theta]0$$, 
           Blank[Real]}, {$CellContext`r11$$, 
           Blank[Real]}, {$CellContext`r12$$, 
           Blank[Real]}, {$CellContext`r13$$, 
           Blank[Real]}, {$CellContext`r21$$, 
           Blank[Real]}, {$CellContext`r22$$, 
           Blank[Real]}, {$CellContext`r23$$, 
           Blank[Real]}, {$CellContext`x13$$, 
           Blank[Real]}, {$CellContext`x23$$, 
           Blank[Real]}, {$CellContext`y13$$, 
           Blank[Real]}, {$CellContext`y23$$, 
           Blank[Real]}, {$CellContext`\[Theta]13$$, 
           Blank[Real]}, {$CellContext`\[Theta]23$$, 
           Blank[Real]}}, 
         Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
           Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`activeregion$ = 
           1.; $CellContext`allcreatedamplitudes$ = {{
             0. + 0. I, 0. + 0. I, 0. + 
              0. I}}; $CellContext`allcreatedrays$ = {{
            1.}}; $CellContext`allowzeroraylength$ = 
           True; $CellContext`alternateindex$ = 
           1.; $CellContext`amplitude$ = {
            1. + 0. I, 0. + 0. I, 0. + 0. I}; $CellContext`axismagnitude$ = 
           1.; $CellContext`axismatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}; $CellContext`clonedata$ = {{
            1.}}; $CellContext`clonegenerationnumber$ = 
           1.; $CellContext`cloneinput$ = {1.}; $CellContext`clonenumber$ = 
           1; $CellContext`cloneposition$ = {0., 0., 
            0.}; $CellContext`clonereportedrays$ = {{
            1.}}; $CellContext`clonerotation$ = {{
            1.}}; $CellContext`clonescale$ = 
           1.; $CellContext`clonescalevector$ = {
            1.}; $CellContext`clonesorthistogram$ = {
            1}; $CellContext`clonetraceinput$ = {{
            1.}}; $CellContext`clonetraceoutput$ = {{
            1.}}; $CellContext`closestdistances$ = {
            1.}; $CellContext`closestposition$ = 
           0; $CellContext`closestpositions$ = {
            0}; $CellContext`closestraylength$ = 
           1.; $CellContext`completedray$ = {
            1.}; $CellContext`componentnumber$ = -1.; $CellContext`cosangle$ = 
           1.; $CellContext`crossmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}; $CellContext`deflecteddummyrayspresent$ = 
           False; $CellContext`deflectedlocalrays$ = {{
            1.}}; $CellContext`deflectedrays$ = {{
            1.}}; $CellContext`deflectedrayspresent$ = 
           False; $CellContext`dummymatrix$ = {{
            1.}}; $CellContext`dummymatrixlist$ = {{{
            1.}}}; $CellContext`dummyvector$ = {1.}; $CellContext`frontid$ = 
           1.; $CellContext`generationlimit$ = 
           200.; $CellContext`generationnumber$ = 
           1.; $CellContext`holeintersections$ = {{-1., 0., 
            0.}}; $CellContext`holeQ$ = 
           False; $CellContext`holeQlist$ = {0}; $CellContext`hor$ = 
           1. + 0. I; $CellContext`index$ = 1.; $CellContext`index1$ = 
           1.; $CellContext`index2$ = 
           1.; $CellContext`inrays$ = {{1.}}; $CellContext`intensity$ = 
           1.; $CellContext`intensityscale$ = 
           1.; $CellContext`intersectionnumber$ = 
           1.; $CellContext`intersections$ = {{-1., 0., 
            0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
            0.}}}; $CellContext`intersectionspresent$ = 
           False; $CellContext`localdummyoutrayspresent$ = 
           False; $CellContext`localoutrays$ = {{
            1.}}; $CellContext`localoutrayspresent$ = 
           False; $CellContext`magnitude$ = 
           1.; $CellContext`maxclonegenerationnumber$ = 
           1.; $CellContext`maximumposition$ = 
           1; $CellContext`minimumraylength$ = 
           0.0001; $CellContext`minresonateraylength$ = 1.; $CellContext`n12$ = 
           1.; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newdeflectedrays$ = {{1.}}; $CellContext`newdistance$ = 
           1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`nonintersectingrays$ = {{
            1.}}; $CellContext`normalizedpolarization$ = {1., 
            1.}; $CellContext`oldgenerationnumber$ = 
           1.; $CellContext`opticallength$ = 
           1.; $CellContext`originalray$ = {
            1.}; $CellContext`originalraytilt$ = {
            1.}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 1., 
            0.}, {0., 0., 1.}}; $CellContext`originalsurfnorm$ = {{
            1.}}; $CellContext`outrays$ = {{
            1.}}; $CellContext`parallelamplitude$ = 
           1. + 0. I; $CellContext`PAxis$ = {1., 0., 
            0.}; $CellContext`perpendicularamplitude$ = 
           1. + 0. I; $CellContext`phaseshift$ = 0.; $CellContext`pol1$ = 
           1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
           1.; $CellContext`previoustilt$ = {1., 0., 
            0.}; $CellContext`propagate$ = 
           True; $CellContext`propagatedrays$ = {{1.}}; $CellContext`r1$ = 
           1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 1.; $CellContext`r4$ = 
           1.; $CellContext`r5$ = 1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
           1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
           1.; $CellContext`ray1$ = 1.; $CellContext`ray2$ = 
           1.; $CellContext`ray3$ = 1.; $CellContext`LocRayL$ = 
           1.; $CellContext`rayslot$ = 1.; $CellContext`raysreported$ = 
           False; $CellContext`raytiltx$ = 1.; $CellContext`raytiltz$ = 
           1.; $CellContext`reporteddummyrayspresent$ = 
           False; $CellContext`reportedlocalrays$ = {{
            1.}}; $CellContext`reportedrays$ = {{
            1.}}; $CellContext`reportedrayspresent$ = 
           False; $CellContext`resonateintersections$ = {{-1., 0., 
            0.}}; $CellContext`resonatenumber$ = 
           0; $CellContext`resonateraylength$ = 1.; $CellContext`rex$ = 
           1.; $CellContext`rey$ = 1.; $CellContext`rez$ = 
           1.; $CellContext`rsx$ = 1.; $CellContext`LocRSx$ = 
           1.; $CellContext`rsy$ = 1.; $CellContext`LocRSy$ = 
           1.; $CellContext`rsz$ = 1.; $CellContext`LocRSz$ = 1.; 
          Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
           1.; $CellContext`LocRTz$ = 1.; $CellContext`rx$ = 
           1.; $CellContext`rxhlp$ = 1.; $CellContext`ry$ = 
           1.; $CellContext`ryhlp$ = 1.; $CellContext`rz$ = 
           1.; $CellContext`rzhlp$ = 1.; $CellContext`LocSCx$ = 
           1.; $CellContext`LocSCy$ = 1.; $CellContext`sid$ = 
           1.; $CellContext`sinangle$ = 1.; $CellContext`sno1$ = 
           1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
           1.; $CellContext`sno4$ = 
           1.; $CellContext`surfaceid$ = -1.; $CellContext`surfacenumber$ = \
-1.; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}; $CellContext`surfacetranslationvector$ = {0., 0., 
            0.}; $CellContext`surfnorm$ = {{1.}}; $CellContext`symr1$ = 
           1.; $CellContext`symr2$ = 1.; $CellContext`symr3$ = 
           1.; $CellContext`symr4$ = 1.; $CellContext`symr5$ = 
           1.; $CellContext`symr6$ = 1.; $CellContext`symr7$ = 
           1.; $CellContext`symr8$ = 1.; $CellContext`symr9$ = 
           1.; $CellContext`tempclonedata$ = {{
            1.}}; $CellContext`terminatedeflection$ = 
           False; $CellContext`thresholdintensity$ = 
           1.; $CellContext`tiltmagnitude$ = 
           1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}}; $CellContext`LocTV1$ = 1.; $CellContext`LocTV10$ = 
           1.; $CellContext`LocTV2$ = 1.; $CellContext`LocTV3$ = 
           1.; $CellContext`LocTV4$ = 1.; $CellContext`LocTV5$ = 
           1.; $CellContext`LocTV6$ = 1.; $CellContext`LocTV7$ = 
           1.; $CellContext`LocTV8$ = 1.; $CellContext`LocTV9$ = 
           1.; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
            0.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`ver$ = 0. + 0. I; $CellContext`wavelength$ = 
           1.; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`xunit$ = 
           1.; $CellContext`YAxis$ = {1., 0., 0.}; $CellContext`yunit$ = 
           1.; $CellContext`ZAxis$ = {1., 0., 0.}; $CellContext`zunit$ = 
           1.; $CellContext`propagatedrays$ = 
           Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                 Cos[Degree $CellContext`\[Theta]0$$], 
                 Sin[Degree $CellContext`\[Theta]0$$], 0, -
                 Sin[Degree $CellContext`\[Theta]0$$], 
                 Cos[Degree $CellContext`\[Theta]0$$], 0, 0, 0, 1}]; 
             Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`x0$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`y0$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`x0$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`y0$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + \
$CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ $CellContext`symr2$ + \
$CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ $CellContext`symr8$, \
$CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ $CellContext`symr6$ + \
$CellContext`r3$ $CellContext`symr9$}; {$CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$} = {$CellContext`r4$ \
$CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + $CellContext`r6$ \
$CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + $CellContext`r5$ \
$CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, $CellContext`r4$ \
$CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + $CellContext`r6$ \
$CellContext`symr9$}; {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$} = {$CellContext`r7$ $CellContext`symr1$ + \
$CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ $CellContext`symr7$, \
$CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ $CellContext`symr5$ + \
$CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ $CellContext`symr3$ + \
$CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ $CellContext`symr9$}; \
{{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}} = {{$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}, {$CellContext`LocTV4$, $CellContext`LocTV5$, \
$CellContext`LocTV6$}, {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$}}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJxTTMoPSmViYGBgA2J1BtLBIlGJLZcfvLdnajy045r/NnuYOJS/HyaP35QP
9guk9O+qsD2Eqot0CAsFgaNwfU+UgrukGD/gMAeXOCpIuPvGAZlG6JNA4xNr
LnH2YgOyz4TeHv3y3p7v5HuP46dXwc2B8vfD5AnZPzDhxgClJdD4xJpLfrh1
rf86/cC/9/Zydzu1ue9PhJsD5e+HyROyf2DCjQNKS6DxiTWXauG2HyYOC8fB
HW4CUFoCjU+suVTLp/Bwg+XbwZ1PRaC0BBqfWHPJDze0egEebrB6YnDXCxI4
aGLNRcgDAIT87NU=
               "]]]; $CellContext`propagatedrays$ = 
           Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
              1.; $CellContext`frontid$ = 
              1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
           200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
           0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

             "]; $CellContext`deflectedrayspresent$ = 
            True; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = True; While[
             And[$CellContext`deflectedrayspresent$, $CellContext`propagate$],
              AddTo[$CellContext`generationnumber$, 
               1.]; ($CellContext`deflecteddummyrayspresent$ = 
               False; $CellContext`deflectedrayspresent$ = 
               False; $CellContext`reportedrayspresent$ = 
               False; $CellContext`reporteddummyrayspresent$ = 
               True; $CellContext`localdummyoutrayspresent$ = 
               False; $CellContext`localoutrayspresent$ = 
               False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
               Map[Flatten[#, 1]& , 
                 Transpose[
                  
                  Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]13$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
($CellContext`rex$ - 1. Re[$CellContext`x13$$]) Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] + \
($CellContext`rey$ - 1. Re[$CellContext`y13$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`ry$ = ($CellContext`rey$ - 1. Re[$CellContext`y13$$]) Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]] - 
                    1. ($CellContext`rex$ - 1. Re[$CellContext`x13$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]13$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`r11$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`r11$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    161.29, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`r11$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`r11$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`r11$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    161.29, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`r11$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`r11$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`r11$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 59282.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]13$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x13$$ + 
                    2.1 Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y13$$ + 
                    2.1 Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x13$$ + 
                    2.1 Cos[0.017453292519943295` $CellContext`\[Theta]13$$]])
                     Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]] + Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y13$$ + 
                    2.1 Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]13$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`r12$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`r12$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    161.29, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`r12$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`r12$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`r12$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    161.29, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`r12$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`r12$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`r12$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 59283.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]13$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x13$$ + 
                    9.6 Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y13$$ + 
                    9.6 Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x13$$ + 
                    9.6 Cos[0.017453292519943295` $CellContext`\[Theta]13$$]])
                     Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]] + Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y13$$ + 
                    9.6 Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]13$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`r13$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`r13$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    161.29, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`r13$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`r13$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`r13$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    161.29, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`r13$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`r13$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`r13$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 59284.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]13$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
($CellContext`rex$ - 1. Re[$CellContext`x13$$]) Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] + \
($CellContext`rey$ - 1. Re[$CellContext`y13$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`ry$ = ($CellContext`rey$ - 1. Re[$CellContext`y13$$]) Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]] - 
                    1. ($CellContext`rex$ - 1. Re[$CellContext`x13$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]13$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    59282.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 1., 
                    59282.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    Re[$CellContext`x13$$] + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`rey$ = Re[$CellContext`y13$$] + $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]13$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`r11$$] \
$CellContext`ray2$)/($CellContext`r11$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`r11$$] \
$CellContext`ray3$)/($CellContext`r11$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`r11$$] \
$CellContext`ray2$)/($CellContext`r11$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`r11$$] \
$CellContext`ray3$)/($CellContext`r11$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`x13$$], 
                    Re[$CellContext`y13$$], 0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]13$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x13$$ + 
                    2.1 Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y13$$ + 
                    2.1 Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x13$$ + 
                    2.1 Cos[0.017453292519943295` $CellContext`\[Theta]13$$]])
                     Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]] + Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y13$$ + 
                    2.1 Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]13$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    59283.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 2., 
                    59283.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]] + 
                    Re[$CellContext`x13$$ + 
                    2.1 Cos[0.017453292519943295` $CellContext`\[Theta]13$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]] + 
                    Re[$CellContext`y13$$ + 
                    2.1 Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]13$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`r12$$] \
$CellContext`ray2$)/($CellContext`r12$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`r12$$] \
$CellContext`ray3$)/($CellContext`r12$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`r12$$] \
$CellContext`ray2$)/($CellContext`r12$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`r12$$] \
$CellContext`ray3$)/($CellContext`r12$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    
                    Re[$CellContext`x13$$ + 
                    2.1 Cos[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    
                    Re[$CellContext`y13$$ + 
                    2.1 Sin[0.017453292519943295` $CellContext`\[Theta]13$$]],
                     0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]13$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x13$$ + 
                    9.6 Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y13$$ + 
                    9.6 Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x13$$ + 
                    9.6 Cos[0.017453292519943295` $CellContext`\[Theta]13$$]])
                     Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]] + Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y13$$ + 
                    9.6 Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]13$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    59284.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 3., 
                    59284.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]] + 
                    Re[$CellContext`x13$$ + 
                    9.6 Cos[0.017453292519943295` $CellContext`\[Theta]13$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]13$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]] + 
                    Re[$CellContext`y13$$ + 
                    9.6 Sin[
                    0.017453292519943295` $CellContext`\[Theta]13$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]13$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`r13$$] \
$CellContext`ray2$)/($CellContext`r13$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`r13$$] \
$CellContext`ray3$)/($CellContext`r13$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`r13$$] \
$CellContext`ray2$)/($CellContext`r13$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`r13$$] \
$CellContext`ray3$)/($CellContext`r13$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    
                    Re[$CellContext`x13$$ + 
                    9.6 Cos[0.017453292519943295` $CellContext`\[Theta]13$$]], 
                    
                    Re[$CellContext`y13$$ + 
                    9.6 Sin[0.017453292519943295` $CellContext`\[Theta]13$$]],
                     0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[
                    Abs[$CellContext`alternateindex$ - $CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                
                And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                 1., 1.]; 
              If[$CellContext`localoutrayspresent$, 
                If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                   Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 1.,
                   1.]; $CellContext`outrays$ = 
                 Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1., 
                1.]; If[
                
                And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                 Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                1., 1.]); 
             If[$CellContext`reportedrayspresent$, $CellContext`raysreported$ = 
                True; $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
            If[Length[$CellContext`outrays$] > 1, 
              Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
             
             And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
              Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
             1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

             "]; $CellContext`deflectedrayspresent$ = 
            True; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = True; While[
             And[$CellContext`deflectedrayspresent$, $CellContext`propagate$],
              AddTo[$CellContext`generationnumber$, 
               1.]; ($CellContext`deflecteddummyrayspresent$ = 
               False; $CellContext`deflectedrayspresent$ = 
               False; $CellContext`reportedrayspresent$ = 
               False; $CellContext`reporteddummyrayspresent$ = 
               True; $CellContext`localdummyoutrayspresent$ = 
               False; $CellContext`localoutrayspresent$ = 
               False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
               Map[Flatten[#, 1]& , 
                 Transpose[
                  
                  Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]23$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
($CellContext`rex$ - 1. Re[$CellContext`x23$$]) Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] + \
($CellContext`rey$ - 1. Re[$CellContext`y23$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`ry$ = ($CellContext`rey$ - 1. Re[$CellContext`y23$$]) Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]] - 
                    1. ($CellContext`rex$ - 1. Re[$CellContext`x23$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]23$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`r21$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`r21$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    161.29, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`r21$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`r21$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`r21$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    161.29, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`r21$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`r21$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`r21$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 59455.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]23$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x23$$ + 
                    7.5 Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y23$$ + 
                    7.5 Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x23$$ + 
                    7.5 Cos[0.017453292519943295` $CellContext`\[Theta]23$$]])
                     Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]] + Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y23$$ + 
                    7.5 Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]23$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`r22$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`r22$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    161.29, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`r22$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`r22$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`r22$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    161.29, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`r22$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`r22$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`r22$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 59456.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]23$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x23$$ + 
                    9.6 Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y23$$ + 
                    9.6 Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x23$$ + 
                    9.6 Cos[0.017453292519943295` $CellContext`\[Theta]23$$]])
                     Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]] + Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y23$$ + 
                    9.6 Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]23$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`r23$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`r23$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    161.29, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`r23$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`r23$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`r23$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    161.29, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`r23$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`r23$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`r23$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 59457.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]23$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
($CellContext`rex$ - 1. Re[$CellContext`x23$$]) Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] + \
($CellContext`rey$ - 1. Re[$CellContext`y23$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`ry$ = ($CellContext`rey$ - 1. Re[$CellContext`y23$$]) Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]] - 
                    1. ($CellContext`rex$ - 1. Re[$CellContext`x23$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]23$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    59455.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 1., 
                    59455.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    Re[$CellContext`x23$$] + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`rey$ = Re[$CellContext`y23$$] + $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]23$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`r21$$] \
$CellContext`ray2$)/($CellContext`r21$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`r21$$] \
$CellContext`ray3$)/($CellContext`r21$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`r21$$] \
$CellContext`ray2$)/($CellContext`r21$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`r21$$] \
$CellContext`ray3$)/($CellContext`r21$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`x23$$], 
                    Re[$CellContext`y23$$], 0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]23$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x23$$ + 
                    7.5 Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y23$$ + 
                    7.5 Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x23$$ + 
                    7.5 Cos[0.017453292519943295` $CellContext`\[Theta]23$$]])
                     Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]] + Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y23$$ + 
                    7.5 Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]23$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    59456.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 2., 
                    59456.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]] + 
                    Re[$CellContext`x23$$ + 
                    7.5 Cos[0.017453292519943295` $CellContext`\[Theta]23$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]] + 
                    Re[$CellContext`y23$$ + 
                    7.5 Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]23$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`r22$$] \
$CellContext`ray2$)/($CellContext`r22$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`r22$$] \
$CellContext`ray3$)/($CellContext`r22$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`r22$$] \
$CellContext`ray2$)/($CellContext`r22$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`r22$$] \
$CellContext`ray3$)/($CellContext`r22$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    
                    Re[$CellContext`x23$$ + 
                    7.5 Cos[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    
                    Re[$CellContext`y23$$ + 
                    7.5 Sin[0.017453292519943295` $CellContext`\[Theta]23$$]],
                     0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]23$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x23$$ + 
                    9.6 Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y23$$ + 
                    9.6 Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x23$$ + 
                    9.6 Cos[0.017453292519943295` $CellContext`\[Theta]23$$]])
                     Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]] + Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y23$$ + 
                    9.6 Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]23$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    59457.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 3., 
                    59457.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]] + 
                    Re[$CellContext`x23$$ + 
                    9.6 Cos[0.017453292519943295` $CellContext`\[Theta]23$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]23$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]] + 
                    Re[$CellContext`y23$$ + 
                    9.6 Sin[
                    0.017453292519943295` $CellContext`\[Theta]23$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]23$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`r23$$] \
$CellContext`ray2$)/($CellContext`r23$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`r23$$] \
$CellContext`ray3$)/($CellContext`r23$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`r23$$] \
$CellContext`ray2$)/($CellContext`r23$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`r23$$] \
$CellContext`ray3$)/($CellContext`r23$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    
                    Re[$CellContext`x23$$ + 
                    9.6 Cos[0.017453292519943295` $CellContext`\[Theta]23$$]], 
                    
                    Re[$CellContext`y23$$ + 
                    9.6 Sin[0.017453292519943295` $CellContext`\[Theta]23$$]],
                     0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                
                And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                 1., 1.]; 
              If[$CellContext`localoutrayspresent$, 
                If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                   Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 1.,
                   1.]; $CellContext`outrays$ = 
                 Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1., 
                1.]; If[
                
                And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                 Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                1., 1.]); 
             If[$CellContext`reportedrayspresent$, $CellContext`raysreported$ = 
                True; $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
            If[Length[$CellContext`outrays$] > 1, 
              Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
             
             And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
              Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
             1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

             "]; $CellContext`deflectedrayspresent$ = 
            True; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = True; While[
             And[$CellContext`deflectedrayspresent$, $CellContext`propagate$],
              AddTo[$CellContext`generationnumber$, 
               1.]; ($CellContext`deflecteddummyrayspresent$ = 
               False; $CellContext`deflectedrayspresent$ = 
               False; $CellContext`reportedrayspresent$ = 
               False; $CellContext`reporteddummyrayspresent$ = 
               True; $CellContext`localdummyoutrayspresent$ = 
               False; $CellContext`localoutrayspresent$ = 
               False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
               Map[Flatten[#, 1]& , 
                 Transpose[
                  
                  Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-200. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2665}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 100., Part[#, 2] >= -100., 
                    Part[#, 3] >= -100., Part[#, 3] <= 100.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2665 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2665), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2665, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2665}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 59560.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    100. + $CellContext`rey$; $CellContext`ry$ = -(-100. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2667}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 100., Part[#, 2] >= -100., 
                    Part[#, 3] >= -100., Part[#, 3] <= 100.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2667 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2667), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2667, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2667}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 59561.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2665}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 100., Part[#, 2] >= -100., 
                    Part[#, 3] >= -100., Part[#, 3] <= 100.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2665 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2665), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2665, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2665}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 59562.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-100. + \
$CellContext`rey$); $CellContext`ry$ = -100. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2667}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 100., Part[#, 2] >= -100., 
                    Part[#, 3] >= -100., Part[#, 3] <= 100.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    
                    Compile`$2667 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2667), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2667, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2667}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 59563.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    100. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-100. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2666}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[Part[#, 2] <= 100., Part[#, 2] >= -100., 
                    Part[#, 3] >= -100., Part[#, 3] <= 100.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2666 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2666), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2666, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2666}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 59564.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-100. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-100. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2666}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 100., Part[#, 2] >= -100., 
                    Part[#, 3] >= -100., Part[#, 3] <= 100.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2666 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2666), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2666, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2666}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 59565.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-200. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 1., 
                    59560.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {3., 1., 
                    59560.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    200. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    200., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    100. + $CellContext`rey$; $CellContext`ry$ = -(-100. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 2., 
                    59561.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {3., 2., 
                    59561.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    100. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -100. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    100., -100., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 3., 
                    59562.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {3., 3., 
                    59562.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-100. + \
$CellContext`rey$); $CellContext`ry$ = -100. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 4., 
                    59563.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {3., 4., 
                    59563.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    100. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    100. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    100., 100., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    100. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-100. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 5., 
                    59564.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {3., 5., 
                    59564.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    100. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -100. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    100., 0, -100.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-100. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-100. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 6., 
                    59565.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {3., 6., 
                    59565.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    100. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    100. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    100., 0, 100.}; $CellContext`activeregion$ = 
                    
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                
                And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                 1., 1.]; 
              If[$CellContext`localoutrayspresent$, 
                If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                   Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 1.,
                   1.]; $CellContext`outrays$ = 
                 Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1., 
                1.]; If[
                
                And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                 Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                1., 1.]); 
             If[$CellContext`reportedrayspresent$, $CellContext`raysreported$ = 
                True; $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
            If[Length[$CellContext`outrays$] > 1, 
              Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
             
             And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
              Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
          If[Length[$CellContext`reportedrays$] > 
            2, $CellContext`reportedrays$ = 
            Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
          Map[{
             Part[#, 1], 
             Part[#, 2], 
             Part[#, 3], 
             Part[#, 4], 
             Part[#, 5], 
             Part[#, 6]}& , $CellContext`reportedrays$]], {
         CompilationTarget -> "MVM", RuntimeAttributes -> {Listable}, 
          Parallelization -> False, 
          RuntimeOptions -> {}}]; \
$CellContext`polygons118408620125111455363987 = 
       Compile[{$CellContext`r11, $CellContext`r12, $CellContext`r13}, \
{{$CellContext`r11 - 1. Sqrt[-161.29 + $CellContext`r11^2] 
           Sign[$CellContext`r11], -12.7}, {$CellContext`r11 - 1. 
           Sqrt[-112.00694444444441` + $CellContext`r11^2] 
           Sign[$CellContext`r11], -10.583333333333332`}, {$CellContext`r11 - 
           1. Sqrt[-71.68444444444445 + $CellContext`r11^2] 
           Sign[$CellContext`r11], -8.466666666666667}, {$CellContext`r11 - 
           1. Sqrt[-40.322500000000005` + $CellContext`r11^2] 
           Sign[$CellContext`r11], -6.3500000000000005`}, {$CellContext`r11 - 
           1. Sqrt[-17.92111111111112 + $CellContext`r11^2] 
           Sign[$CellContext`r11], -4.233333333333334}, {$CellContext`r11 - 
           1. Sqrt[-4.48027777777778 + $CellContext`r11^2] 
           Sign[$CellContext`r11], -2.116666666666667}, {$CellContext`r11 - 
           1. Sqrt[-3.1554436208840472`*^-30 + $CellContext`r11^2] 
           Sign[$CellContext`r11], -1.7763568394002505`*^-15}, \
{$CellContext`r11 - 1. Sqrt[-4.480277777777765 + $CellContext`r11^2] 
           Sign[$CellContext`r11], 2.1166666666666636`}, {$CellContext`r11 - 
           1. Sqrt[-17.921111111111088` + $CellContext`r11^2] 
           Sign[$CellContext`r11], 4.233333333333331}, {$CellContext`r11 - 1. 
           Sqrt[-40.32249999999997 + $CellContext`r11^2] 
           Sign[$CellContext`r11], 6.349999999999998}, {$CellContext`r11 - 1. 
           Sqrt[-71.68444444444441 + $CellContext`r11^2] 
           Sign[$CellContext`r11], 8.466666666666665}, {$CellContext`r11 - 1. 
           Sqrt[-112.00694444444434` + $CellContext`r11^2] 
           Sign[$CellContext`r11], 10.583333333333329`}, {$CellContext`r11 - 
           1. Sqrt[-161.28999999999988` + $CellContext`r11^2] 
           Sign[$CellContext`r11], 12.699999999999996`}, {
          2.1 + $CellContext`r12 - 1. Sqrt[-161.29 + $CellContext`r12^2] 
           Sign[$CellContext`r12], 12.7}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-112.00694444444441` + $CellContext`r12^2] 
           Sign[$CellContext`r12], 10.583333333333332`}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-71.68444444444445 + $CellContext`r12^2] 
           Sign[$CellContext`r12], 8.466666666666667}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-40.322500000000005` + $CellContext`r12^2] 
           Sign[$CellContext`r12], 6.3500000000000005`}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-17.92111111111112 + $CellContext`r12^2] 
           Sign[$CellContext`r12], 4.233333333333334}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-4.48027777777778 + $CellContext`r12^2] 
           Sign[$CellContext`r12], 2.116666666666667}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-3.1554436208840472`*^-30 + $CellContext`r12^2] 
           Sign[$CellContext`r12], 1.7763568394002505`*^-15}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-4.480277777777765 + $CellContext`r12^2] 
           Sign[$CellContext`r12], -2.1166666666666636`}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-17.921111111111088` + $CellContext`r12^2] 
           Sign[$CellContext`r12], -4.233333333333331}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-40.32249999999997 + $CellContext`r12^2] 
           Sign[$CellContext`r12], -6.349999999999998}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-71.68444444444441 + $CellContext`r12^2] 
           Sign[$CellContext`r12], -8.466666666666665}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-112.00694444444434` + $CellContext`r12^2] 
           Sign[$CellContext`r12], -10.583333333333329`}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-161.28999999999988` + $CellContext`r12^2] 
           Sign[$CellContext`r12], -12.699999999999996`}, {$CellContext`r11 - 
           1. Sqrt[-161.29 + $CellContext`r11^2] 
           Sign[$CellContext`r11], -12.7}, {
          2.1 + $CellContext`r12 - 1. Sqrt[-161.29 + $CellContext`r12^2] 
           Sign[$CellContext`r12], -12.7}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-112.00694444444441` + $CellContext`r12^2] 
           Sign[$CellContext`r12], -10.583333333333332`}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-71.68444444444445 + $CellContext`r12^2] 
           Sign[$CellContext`r12], -8.466666666666667}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-40.322500000000005` + $CellContext`r12^2] 
           Sign[$CellContext`r12], -6.3500000000000005`}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-17.92111111111112 + $CellContext`r12^2] 
           Sign[$CellContext`r12], -4.233333333333334}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-4.48027777777778 + $CellContext`r12^2] 
           Sign[$CellContext`r12], -2.116666666666667}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-3.1554436208840472`*^-30 + $CellContext`r12^2] 
           Sign[$CellContext`r12], -1.7763568394002505`*^-15}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-4.480277777777765 + $CellContext`r12^2] 
           Sign[$CellContext`r12], 2.1166666666666636`}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-17.921111111111088` + $CellContext`r12^2] 
           Sign[$CellContext`r12], 4.233333333333331}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-40.32249999999997 + $CellContext`r12^2] 
           Sign[$CellContext`r12], 6.349999999999998}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-71.68444444444441 + $CellContext`r12^2] 
           Sign[$CellContext`r12], 8.466666666666665}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-112.00694444444434` + $CellContext`r12^2] 
           Sign[$CellContext`r12], 10.583333333333329`}, {
          2.1 + $CellContext`r12 - 1. 
           Sqrt[-161.28999999999988` + $CellContext`r12^2] 
           Sign[$CellContext`r12], 12.699999999999996`}, {
          9.6 + $CellContext`r13 - 1. Sqrt[-161.29 + $CellContext`r13^2] 
           Sign[$CellContext`r13], 12.7}, {
          9.6 + $CellContext`r13 - 1. 
           Sqrt[-112.00694444444441` + $CellContext`r13^2] 
           Sign[$CellContext`r13], 10.583333333333332`}, {
          9.6 + $CellContext`r13 - 1. 
           Sqrt[-71.68444444444445 + $CellContext`r13^2] 
           Sign[$CellContext`r13], 8.466666666666667}, {
          9.6 + $CellContext`r13 - 1. 
           Sqrt[-40.322500000000005` + $CellContext`r13^2] 
           Sign[$CellContext`r13], 6.3500000000000005`}, {
          9.6 + $CellContext`r13 - 1. 
           Sqrt[-17.92111111111112 + $CellContext`r13^2] 
           Sign[$CellContext`r13], 4.233333333333334}, {
          9.6 + $CellContext`r13 - 1. 
           Sqrt[-4.48027777777778 + $CellContext`r13^2] 
           Sign[$CellContext`r13], 2.116666666666667}, {
          9.6 + $CellContext`r13 - 1. 
           Sqrt[-3.1554436208840472`*^-30 + $CellContext`r13^2] 
           Sign[$CellContext`r13], 1.7763568394002505`*^-15}, {
          9.6 + $CellContext`r13 - 1. 
           Sqrt[-4.480277777777765 + $CellContext`r13^2] 
           Sign[$CellContext`r13], -2.1166666666666636`}, {
          9.6 + $CellContext`r13 - 1. 
           Sqrt[-17.921111111111088` + $CellContext`r13^2] 
           Sign[$CellContext`r13], -4.233333333333331}, {
          9.6 + $CellContext`r13 - 1. 
           Sqrt[-40.32249999999997 + $CellContext`r13^2] 
           Sign[$CellContext`r13], -6.349999999999998}, {
          9.6 + $CellContext`r13 - 1. 
           Sqrt[-71.68444444444441 + $CellContext`r13^2] 
           Sign[$CellContext`r13], -8.466666666666665}, {
          9.6 + $CellContext`r13 - 1. 
           Sqrt[-112.00694444444434` + $CellContext`r13^2] 
           Sign[$CellContext`r13], -10.583333333333329`}, {
          9.6 + $CellContext`r13 - 1. 
           Sqrt[-161.28999999999988` + $CellContext`r13^2] 
           Sign[$CellContext`r13], -12.699999999999996`}, {
          2.1 + $CellContext`r12 - 1. Sqrt[-161.29 + $CellContext`r12^2] 
           Sign[$CellContext`r12], -12.7}}]; \
$CellContext`polygons128408620125111455388113 = 
       Compile[{$CellContext`r21, $CellContext`r22, $CellContext`r23}, \
{{$CellContext`r21 - 1. Sqrt[-161.29 + $CellContext`r21^2] 
           Sign[$CellContext`r21], -12.7}, {$CellContext`r21 - 1. 
           Sqrt[-112.00694444444441` + $CellContext`r21^2] 
           Sign[$CellContext`r21], -10.583333333333332`}, {$CellContext`r21 - 
           1. Sqrt[-71.68444444444445 + $CellContext`r21^2] 
           Sign[$CellContext`r21], -8.466666666666667}, {$CellContext`r21 - 
           1. Sqrt[-40.322500000000005` + $CellContext`r21^2] 
           Sign[$CellContext`r21], -6.3500000000000005`}, {$CellContext`r21 - 
           1. Sqrt[-17.92111111111112 + $CellContext`r21^2] 
           Sign[$CellContext`r21], -4.233333333333334}, {$CellContext`r21 - 
           1. Sqrt[-4.48027777777778 + $CellContext`r21^2] 
           Sign[$CellContext`r21], -2.116666666666667}, {$CellContext`r21 - 
           1. Sqrt[-3.1554436208840472`*^-30 + $CellContext`r21^2] 
           Sign[$CellContext`r21], -1.7763568394002505`*^-15}, \
{$CellContext`r21 - 1. Sqrt[-4.480277777777765 + $CellContext`r21^2] 
           Sign[$CellContext`r21], 2.1166666666666636`}, {$CellContext`r21 - 
           1. Sqrt[-17.921111111111088` + $CellContext`r21^2] 
           Sign[$CellContext`r21], 4.233333333333331}, {$CellContext`r21 - 1. 
           Sqrt[-40.32249999999997 + $CellContext`r21^2] 
           Sign[$CellContext`r21], 6.349999999999998}, {$CellContext`r21 - 1. 
           Sqrt[-71.68444444444441 + $CellContext`r21^2] 
           Sign[$CellContext`r21], 8.466666666666665}, {$CellContext`r21 - 1. 
           Sqrt[-112.00694444444434` + $CellContext`r21^2] 
           Sign[$CellContext`r21], 10.583333333333329`}, {$CellContext`r21 - 
           1. Sqrt[-161.28999999999988` + $CellContext`r21^2] 
           Sign[$CellContext`r21], 12.699999999999996`}, {
          7.5 + $CellContext`r22 - 1. Sqrt[-161.29 + $CellContext`r22^2] 
           Sign[$CellContext`r22], 12.7}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-112.00694444444441` + $CellContext`r22^2] 
           Sign[$CellContext`r22], 10.583333333333332`}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-71.68444444444445 + $CellContext`r22^2] 
           Sign[$CellContext`r22], 8.466666666666667}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-40.322500000000005` + $CellContext`r22^2] 
           Sign[$CellContext`r22], 6.3500000000000005`}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-17.92111111111112 + $CellContext`r22^2] 
           Sign[$CellContext`r22], 4.233333333333334}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-4.48027777777778 + $CellContext`r22^2] 
           Sign[$CellContext`r22], 2.116666666666667}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-3.1554436208840472`*^-30 + $CellContext`r22^2] 
           Sign[$CellContext`r22], 1.7763568394002505`*^-15}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-4.480277777777765 + $CellContext`r22^2] 
           Sign[$CellContext`r22], -2.1166666666666636`}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-17.921111111111088` + $CellContext`r22^2] 
           Sign[$CellContext`r22], -4.233333333333331}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-40.32249999999997 + $CellContext`r22^2] 
           Sign[$CellContext`r22], -6.349999999999998}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-71.68444444444441 + $CellContext`r22^2] 
           Sign[$CellContext`r22], -8.466666666666665}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-112.00694444444434` + $CellContext`r22^2] 
           Sign[$CellContext`r22], -10.583333333333329`}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-161.28999999999988` + $CellContext`r22^2] 
           Sign[$CellContext`r22], -12.699999999999996`}, {$CellContext`r21 - 
           1. Sqrt[-161.29 + $CellContext`r21^2] 
           Sign[$CellContext`r21], -12.7}, {
          7.5 + $CellContext`r22 - 1. Sqrt[-161.29 + $CellContext`r22^2] 
           Sign[$CellContext`r22], -12.7}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-112.00694444444441` + $CellContext`r22^2] 
           Sign[$CellContext`r22], -10.583333333333332`}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-71.68444444444445 + $CellContext`r22^2] 
           Sign[$CellContext`r22], -8.466666666666667}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-40.322500000000005` + $CellContext`r22^2] 
           Sign[$CellContext`r22], -6.3500000000000005`}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-17.92111111111112 + $CellContext`r22^2] 
           Sign[$CellContext`r22], -4.233333333333334}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-4.48027777777778 + $CellContext`r22^2] 
           Sign[$CellContext`r22], -2.116666666666667}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-3.1554436208840472`*^-30 + $CellContext`r22^2] 
           Sign[$CellContext`r22], -1.7763568394002505`*^-15}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-4.480277777777765 + $CellContext`r22^2] 
           Sign[$CellContext`r22], 2.1166666666666636`}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-17.921111111111088` + $CellContext`r22^2] 
           Sign[$CellContext`r22], 4.233333333333331}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-40.32249999999997 + $CellContext`r22^2] 
           Sign[$CellContext`r22], 6.349999999999998}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-71.68444444444441 + $CellContext`r22^2] 
           Sign[$CellContext`r22], 8.466666666666665}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-112.00694444444434` + $CellContext`r22^2] 
           Sign[$CellContext`r22], 10.583333333333329`}, {
          7.5 + $CellContext`r22 - 1. 
           Sqrt[-161.28999999999988` + $CellContext`r22^2] 
           Sign[$CellContext`r22], 12.699999999999996`}, {
          9.6 + $CellContext`r23 - 1. Sqrt[-161.29 + $CellContext`r23^2] 
           Sign[$CellContext`r23], 12.7}, {
          9.6 + $CellContext`r23 - 1. 
           Sqrt[-112.00694444444441` + $CellContext`r23^2] 
           Sign[$CellContext`r23], 10.583333333333332`}, {
          9.6 + $CellContext`r23 - 1. 
           Sqrt[-71.68444444444445 + $CellContext`r23^2] 
           Sign[$CellContext`r23], 8.466666666666667}, {
          9.6 + $CellContext`r23 - 1. 
           Sqrt[-40.322500000000005` + $CellContext`r23^2] 
           Sign[$CellContext`r23], 6.3500000000000005`}, {
          9.6 + $CellContext`r23 - 1. 
           Sqrt[-17.92111111111112 + $CellContext`r23^2] 
           Sign[$CellContext`r23], 4.233333333333334}, {
          9.6 + $CellContext`r23 - 1. 
           Sqrt[-4.48027777777778 + $CellContext`r23^2] 
           Sign[$CellContext`r23], 2.116666666666667}, {
          9.6 + $CellContext`r23 - 1. 
           Sqrt[-3.1554436208840472`*^-30 + $CellContext`r23^2] 
           Sign[$CellContext`r23], 1.7763568394002505`*^-15}, {
          9.6 + $CellContext`r23 - 1. 
           Sqrt[-4.480277777777765 + $CellContext`r23^2] 
           Sign[$CellContext`r23], -2.1166666666666636`}, {
          9.6 + $CellContext`r23 - 1. 
           Sqrt[-17.921111111111088` + $CellContext`r23^2] 
           Sign[$CellContext`r23], -4.233333333333331}, {
          9.6 + $CellContext`r23 - 1. 
           Sqrt[-40.32249999999997 + $CellContext`r23^2] 
           Sign[$CellContext`r23], -6.349999999999998}, {
          9.6 + $CellContext`r23 - 1. 
           Sqrt[-71.68444444444441 + $CellContext`r23^2] 
           Sign[$CellContext`r23], -8.466666666666665}, {
          9.6 + $CellContext`r23 - 1. 
           Sqrt[-112.00694444444434` + $CellContext`r23^2] 
           Sign[$CellContext`r23], -10.583333333333329`}, {
          9.6 + $CellContext`r23 - 1. 
           Sqrt[-161.28999999999988` + $CellContext`r23^2] 
           Sign[$CellContext`r23], -12.699999999999996`}, {
          7.5 + $CellContext`r22 - 1. Sqrt[-161.29 + $CellContext`r22^2] 
           Sign[$CellContext`r22], -12.7}}]); Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.544879508363927*^9}]
}, Open  ]]
},
WindowSize->{1106, 833},
WindowMargins->{{Automatic, 260}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 5, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3544861499-7689995"->{
  Cell[749, 27, 1207, 17, 148, "Print",
   CellTags->"Info3544861499-7689995"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3544861499-7689995", 424677, 7365}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 179, 3, 58, "Input"],
Cell[749, 27, 1207, 17, 148, "Print",
 CellTags->"Info3544861499-7689995"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1993, 49, 439, 11, 27, "Input"],
Cell[2435, 62, 583, 18, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3055, 85, 2721, 67, 73, "Input"],
Cell[5779, 154, 3634, 108, 73, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9450, 267, 268, 5, 27, "Input"],
Cell[9721, 274, 414599, 7076, 1121, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
