(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   2023240,      35940]
NotebookOptionsPosition[   2022289,      35902]
NotebookOutlinePosition[   2022824,      35925]
CellTagsIndexPosition[   2022735,      35920]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{
  RowBox[{"?", "LensTriplet"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.4083302288969107`*^9, 3.408330239287177*^9}}],

Cell[BoxData[
 StyleBox["\<\"LensTriplet[r1, r2, r3, r4, aperture, t1, t2, t3, index1, \
index2, index3, label, options] refers to a lens having four spherical \
surfaces. \\n\\nThe radii of curvatures are specified by r1, r2, r3, and r4, \
where Infinity is used to indicate planar surfaces. In addition, LensTriplet \
is specified by three thicknesses: t1, t2, and t3. The three refractive \
indexes must also be specified either as a function of wavelength or using \
one of the built-in index functions. LensTriplet is created with its first \
surface centered about the origin and the remaining surfaces positioned down \
the x axis. The aperture parameter may indicate a circle, rectangle, or \
polygon depending on the number and type of elements listed by it. The \
user-named label parameter is optional and can be omitted. When it is \
present, its text content is used to identify the object in both the rendered \
graphics and the output cell expression. When it is omitted, Optica uses the \
default setting of the Labels option with the rendered graphics. See also: \
LensDoublet and CompoundLens.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.544879553086574*^9},
 CellTags->"Info3544861552-7689995"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"mysystem2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"LineOfRays", "[", 
        RowBox[{"10", " ", ",", 
         RowBox[{"NumberOfRays", " ", "->", " ", "6"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x0", ",", " ", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y0", ",", " ", "0"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]0", ",", "0"}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"BaffleWithHole", "[", 
        RowBox[{"20", ",", " ", "9"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"xb", ",", " ", "10"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"yb", ",", " ", "0"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]b", ",", "0"}], "}"}]}], "]"}], ",", "\n", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"LensTriplet", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ro", ",", "9.0"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"ri", ",", "6.0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "ri"}], ",", " ", 
           RowBox[{"-", "6.0"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "ro"}], ",", 
           RowBox[{"-", "9.0"}]}], "}"}], ",", "8.5", ",", 
         RowBox[{"{", 
          RowBox[{"to", ",", "0.6"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"ti", ",", "5.4"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"to", ",", "0.6"}], "}"}], ",", "SF5", ",", "BK7", ",", 
         "SF5", ",", 
         RowBox[{"SymbolicValues", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ro", "\[Rule]", "9"}], ",", 
            RowBox[{"ri", "\[Rule]", "6"}], ",", 
            RowBox[{"to", "\[Rule]", ".6"}], ",", 
            RowBox[{"ti", "\[Rule]", "5.4"}]}], "}"}]}]}], " ", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x1", ",", " ", "20"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y1", ",", " ", "0"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]1", ",", "0"}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"Screen", "[", "20", "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"XS", ",", " ", "40"}], "}"}]}], "]"}], ",", "\n", 
     RowBox[{"Boundary", "[", "50", "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4083303456923523`*^9, 3.4083303778095303`*^9}, {
  3.4083305999316607`*^9, 3.408330660282381*^9}, {3.408330697900073*^9, 
  3.408330731722158*^9}, {3.4083307696193953`*^9, 3.4083308110419407`*^9}, {
  3.408330917123814*^9, 3.408330917442017*^9}, {3.408331596092424*^9, 
  3.408331620146339*^9}, {3.408331653380299*^9, 3.408331689210868*^9}, {
  3.408378959810568*^9, 3.4083790212743587`*^9}, {3.4083791330596743`*^9, 
  3.4083791683277693`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DrawSystem", "[", 
    RowBox[{"mysystem2", ",", " ", 
     RowBox[{"Axes", " ", "\[Rule]", " ", "True"}], ",", " ", 
     RowBox[{
     "PlotLabel", " ", "\[Rule]", " ", "\"\<Hastings Triplet Achromat\>\""}], 
     ",", " ", 
     RowBox[{"SimplifyGraphics", " ", "\[Rule]", " ", "False"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.408331799736559*^9, 3.408331808112245*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{10., 4.5, 0.}, {10., 6.333333333333333, 0.}, {10., 
      6.117530233164098, 1.639187285649298}, {10., 4.346666218300807, 
      1.1646857029613433`}, {10., 4.5, 0.}}], 
     Polygon3DBox[{{10., 4.346666218300807, 1.1646857029613433`}, {10., 
      6.117530233164098, 1.639187285649298}, {10., 5.484827557301444, 
      3.1666666666666665`}, {10., 3.8971143170299736`, 2.25}, {10., 
      4.346666218300807, 1.1646857029613433`}}], 
     Polygon3DBox[{{10., 3.8971143170299736`, 2.25}, {10., 5.484827557301444, 
      3.1666666666666665`}, {10., 4.4783429475148, 4.4783429475148}, {10., 
      3.181980515339464, 3.181980515339464}, {10., 3.8971143170299736`, 
      2.25}}], Polygon3DBox[{{10., 3.181980515339464, 3.181980515339464}, {
      10., 4.4783429475148, 4.4783429475148}, {10., 3.1666666666666665`, 
      5.484827557301444}, {10., 2.25, 3.8971143170299736`}, {10., 
      3.181980515339464, 3.181980515339464}}], 
     Polygon3DBox[{{10., 2.25, 3.8971143170299736`}, {10., 
      3.1666666666666665`, 5.484827557301444}, {10., 1.639187285649298, 
      6.117530233164098}, {10., 1.1646857029613433`, 4.346666218300807}, {10.,
       2.25, 3.8971143170299736`}}], 
     Polygon3DBox[{{10., 1.1646857029613433`, 4.346666218300807}, {10., 
      1.639187285649298, 6.117530233164098}, {10., 0., 6.333333333333333}, {
      10., 0., 4.5}, {10., 1.1646857029613433`, 4.346666218300807}}], 
     Polygon3DBox[{{10., 0., 4.5}, {10., 0., 6.333333333333333}, {
      10., -1.639187285649298, 6.117530233164098}, {10., -1.1646857029613433`,
       4.346666218300807}, {10., 0., 4.5}}], 
     Polygon3DBox[{{10., -1.1646857029613433`, 4.346666218300807}, {
      10., -1.639187285649298, 6.117530233164098}, {10., -3.1666666666666665`,
       5.484827557301444}, {10., -2.25, 3.8971143170299736`}, {
      10., -1.1646857029613433`, 4.346666218300807}}], 
     Polygon3DBox[{{10., -2.25, 3.8971143170299736`}, {
      10., -3.1666666666666665`, 5.484827557301444}, {10., -4.4783429475148, 
      4.4783429475148}, {10., -3.181980515339464, 3.181980515339464}, {
      10., -2.25, 3.8971143170299736`}}], 
     Polygon3DBox[{{10., -3.181980515339464, 3.181980515339464}, {
      10., -4.4783429475148, 4.4783429475148}, {10., -5.484827557301444, 
      3.1666666666666665`}, {10., -3.8971143170299736`, 2.25}, {
      10., -3.181980515339464, 3.181980515339464}}], 
     Polygon3DBox[{{10., -3.8971143170299736`, 2.25}, {
      10., -5.484827557301444, 3.1666666666666665`}, {10., -6.117530233164098,
       1.639187285649298}, {10., -4.346666218300807, 1.1646857029613433`}, {
      10., -3.8971143170299736`, 2.25}}], 
     Polygon3DBox[{{10., -4.346666218300807, 1.1646857029613433`}, {
      10., -6.117530233164098, 1.639187285649298}, {10., -6.333333333333333, 
      0.}, {10., -4.5, 0.}, {10., -4.346666218300807, 1.1646857029613433`}}], 
     Polygon3DBox[{{10., -4.5, 0.}, {10., -6.333333333333333, 0.}, {
      10., -6.117530233164098, -1.639187285649298}, {
      10., -4.346666218300807, -1.1646857029613433`}, {10., -4.5, 0.}}], 
     Polygon3DBox[{{10., -4.346666218300807, -1.1646857029613433`}, {
      10., -6.117530233164098, -1.639187285649298}, {
      10., -5.484827557301444, -3.1666666666666665`}, {
      10., -3.8971143170299736`, -2.25}, {
      10., -4.346666218300807, -1.1646857029613433`}}], 
     Polygon3DBox[{{10., -3.8971143170299736`, -2.25}, {
      10., -5.484827557301444, -3.1666666666666665`}, {
      10., -4.4783429475148, -4.4783429475148}, {
      10., -3.181980515339464, -3.181980515339464}, {
      10., -3.8971143170299736`, -2.25}}], 
     Polygon3DBox[{{10., -3.181980515339464, -3.181980515339464}, {
      10., -4.4783429475148, -4.4783429475148}, {
      10., -3.1666666666666665`, -5.484827557301444}, {
      10., -2.25, -3.8971143170299736`}, {
      10., -3.181980515339464, -3.181980515339464}}], 
     Polygon3DBox[{{10., -2.25, -3.8971143170299736`}, {
      10., -3.1666666666666665`, -5.484827557301444}, {
      10., -1.639187285649298, -6.117530233164098}, {
      10., -1.1646857029613433`, -4.346666218300807}, {
      10., -2.25, -3.8971143170299736`}}], 
     Polygon3DBox[{{10., -1.1646857029613433`, -4.346666218300807}, {
      10., -1.639187285649298, -6.117530233164098}, {10., 
      0., -6.333333333333333}, {10., 0., -4.5}, {
      10., -1.1646857029613433`, -4.346666218300807}}], 
     Polygon3DBox[{{10., 0., -4.5}, {10., 0., -6.333333333333333}, {10., 
      1.639187285649298, -6.117530233164098}, {10., 
      1.1646857029613433`, -4.346666218300807}, {10., 0., -4.5}}], 
     Polygon3DBox[{{10., 1.1646857029613433`, -4.346666218300807}, {10., 
      1.639187285649298, -6.117530233164098}, {10., 
      3.1666666666666665`, -5.484827557301444}, {10., 
      2.25, -3.8971143170299736`}, {10., 
      1.1646857029613433`, -4.346666218300807}}], 
     Polygon3DBox[{{10., 2.25, -3.8971143170299736`}, {10., 
      3.1666666666666665`, -5.484827557301444}, {10., 
      4.4783429475148, -4.4783429475148}, {10., 
      3.181980515339464, -3.181980515339464}, {10., 
      2.25, -3.8971143170299736`}}], 
     Polygon3DBox[{{10., 3.181980515339464, -3.181980515339464}, {10., 
      4.4783429475148, -4.4783429475148}, {10., 
      5.484827557301444, -3.1666666666666665`}, {10., 
      3.8971143170299736`, -2.25}, {10., 
      3.181980515339464, -3.181980515339464}}], 
     Polygon3DBox[{{10., 3.8971143170299736`, -2.25}, {10., 
      5.484827557301444, -3.1666666666666665`}, {10., 
      6.117530233164098, -1.639187285649298}, {10., 
      4.346666218300807, -1.1646857029613433`}, {10., 
      3.8971143170299736`, -2.25}}], 
     Polygon3DBox[{{10., 4.346666218300807, -1.1646857029613433`}, {10., 
      6.117530233164098, -1.639187285649298}, {10., 6.333333333333333, 0.}, {
      10., 4.5, 0.}, {10., 4.346666218300807, -1.1646857029613433`}}], 
     Polygon3DBox[{{10., 6.333333333333333, 0.}, {10., 8.166666666666666, 
      0.}, {10., 7.88839424802739, 2.1136888683372526`}, {10., 
      6.117530233164098, 1.639187285649298}, {10., 6.333333333333333, 0.}}], 
     Polygon3DBox[{{10., 6.117530233164098, 1.639187285649298}, {10., 
      7.88839424802739, 2.1136888683372526`}, {10., 7.072540797572914, 
      4.083333333333333}, {10., 5.484827557301444, 3.1666666666666665`}, {10.,
       6.117530233164098, 1.639187285649298}}], 
     Polygon3DBox[{{10., 5.484827557301444, 3.1666666666666665`}, {10., 
      7.072540797572914, 4.083333333333333}, {10., 5.774705379690138, 
      5.774705379690138}, {10., 4.4783429475148, 4.4783429475148}, {10., 
      5.484827557301444, 3.1666666666666665`}}], 
     Polygon3DBox[{{10., 4.4783429475148, 4.4783429475148}, {10., 
      5.774705379690138, 5.774705379690138}, {10., 4.083333333333333, 
      7.072540797572914}, {10., 3.1666666666666665`, 5.484827557301444}, {10.,
       4.4783429475148, 4.4783429475148}}], 
     Polygon3DBox[{{10., 3.1666666666666665`, 5.484827557301444}, {10., 
      4.083333333333333, 7.072540797572914}, {10., 2.1136888683372526`, 
      7.88839424802739}, {10., 1.639187285649298, 6.117530233164098}, {10., 
      3.1666666666666665`, 5.484827557301444}}], 
     Polygon3DBox[{{10., 1.639187285649298, 6.117530233164098}, {10., 
      2.1136888683372526`, 7.88839424802739}, {10., 0., 8.166666666666666}, {
      10., 0., 6.333333333333333}, {10., 1.639187285649298, 
      6.117530233164098}}], 
     Polygon3DBox[{{10., 0., 6.333333333333333}, {10., 0., 
      8.166666666666666}, {10., -2.1136888683372526`, 7.88839424802739}, {
      10., -1.639187285649298, 6.117530233164098}, {10., 0., 
      6.333333333333333}}], 
     Polygon3DBox[{{10., -1.639187285649298, 6.117530233164098}, {
      10., -2.1136888683372526`, 7.88839424802739}, {10., -4.083333333333333, 
      7.072540797572914}, {10., -3.1666666666666665`, 5.484827557301444}, {
      10., -1.639187285649298, 6.117530233164098}}], 
     Polygon3DBox[{{10., -3.1666666666666665`, 5.484827557301444}, {
      10., -4.083333333333333, 7.072540797572914}, {10., -5.774705379690138, 
      5.774705379690138}, {10., -4.4783429475148, 4.4783429475148}, {
      10., -3.1666666666666665`, 5.484827557301444}}], 
     Polygon3DBox[{{10., -4.4783429475148, 4.4783429475148}, {
      10., -5.774705379690138, 5.774705379690138}, {10., -7.072540797572914, 
      4.083333333333333}, {10., -5.484827557301444, 3.1666666666666665`}, {
      10., -4.4783429475148, 4.4783429475148}}], 
     Polygon3DBox[{{10., -5.484827557301444, 3.1666666666666665`}, {
      10., -7.072540797572914, 4.083333333333333}, {10., -7.88839424802739, 
      2.1136888683372526`}, {10., -6.117530233164098, 1.639187285649298}, {
      10., -5.484827557301444, 3.1666666666666665`}}], 
     Polygon3DBox[{{10., -6.117530233164098, 1.639187285649298}, {
      10., -7.88839424802739, 2.1136888683372526`}, {10., -8.166666666666666, 
      0.}, {10., -6.333333333333333, 0.}, {10., -6.117530233164098, 
      1.639187285649298}}], 
     Polygon3DBox[{{10., -6.333333333333333, 0.}, {10., -8.166666666666666, 
      0.}, {10., -7.88839424802739, -2.1136888683372526`}, {
      10., -6.117530233164098, -1.639187285649298}, {10., -6.333333333333333, 
      0.}}], Polygon3DBox[{{10., -6.117530233164098, -1.639187285649298}, {
      10., -7.88839424802739, -2.1136888683372526`}, {
      10., -7.072540797572914, -4.083333333333333}, {
      10., -5.484827557301444, -3.1666666666666665`}, {
      10., -6.117530233164098, -1.639187285649298}}], 
     Polygon3DBox[{{10., -5.484827557301444, -3.1666666666666665`}, {
      10., -7.072540797572914, -4.083333333333333}, {
      10., -5.774705379690138, -5.774705379690138}, {
      10., -4.4783429475148, -4.4783429475148}, {
      10., -5.484827557301444, -3.1666666666666665`}}], 
     Polygon3DBox[{{10., -4.4783429475148, -4.4783429475148}, {
      10., -5.774705379690138, -5.774705379690138}, {
      10., -4.083333333333333, -7.072540797572914}, {
      10., -3.1666666666666665`, -5.484827557301444}, {
      10., -4.4783429475148, -4.4783429475148}}], 
     Polygon3DBox[{{10., -3.1666666666666665`, -5.484827557301444}, {
      10., -4.083333333333333, -7.072540797572914}, {
      10., -2.1136888683372526`, -7.88839424802739}, {
      10., -1.639187285649298, -6.117530233164098}, {
      10., -3.1666666666666665`, -5.484827557301444}}], 
     Polygon3DBox[{{10., -1.639187285649298, -6.117530233164098}, {
      10., -2.1136888683372526`, -7.88839424802739}, {10., 
      0., -8.166666666666666}, {10., 0., -6.333333333333333}, {
      10., -1.639187285649298, -6.117530233164098}}], 
     Polygon3DBox[{{10., 0., -6.333333333333333}, {10., 
      0., -8.166666666666666}, {10., 
      2.1136888683372526`, -7.88839424802739}, {10., 
      1.639187285649298, -6.117530233164098}, {10., 0., -6.333333333333333}}],
      Polygon3DBox[{{10., 1.639187285649298, -6.117530233164098}, {10., 
      2.1136888683372526`, -7.88839424802739}, {10., 
      4.083333333333333, -7.072540797572914}, {10., 
      3.1666666666666665`, -5.484827557301444}, {10., 
      1.639187285649298, -6.117530233164098}}], 
     Polygon3DBox[{{10., 3.1666666666666665`, -5.484827557301444}, {10., 
      4.083333333333333, -7.072540797572914}, {10., 
      5.774705379690138, -5.774705379690138}, {10., 
      4.4783429475148, -4.4783429475148}, {10., 
      3.1666666666666665`, -5.484827557301444}}], 
     Polygon3DBox[{{10., 4.4783429475148, -4.4783429475148}, {10., 
      5.774705379690138, -5.774705379690138}, {10., 
      7.072540797572914, -4.083333333333333}, {10., 
      5.484827557301444, -3.1666666666666665`}, {10., 
      4.4783429475148, -4.4783429475148}}], 
     Polygon3DBox[{{10., 5.484827557301444, -3.1666666666666665`}, {10., 
      7.072540797572914, -4.083333333333333}, {10., 
      7.88839424802739, -2.1136888683372526`}, {10., 
      6.117530233164098, -1.639187285649298}, {10., 
      5.484827557301444, -3.1666666666666665`}}], 
     Polygon3DBox[{{10., 6.117530233164098, -1.639187285649298}, {10., 
      7.88839424802739, -2.1136888683372526`}, {10., 8.166666666666666, 0.}, {
      10., 6.333333333333333, 0.}, {10., 
      6.117530233164098, -1.639187285649298}}], 
     Polygon3DBox[{{10., 8.166666666666666, 0.}, {10., 10., 0.}, {10., 
      9.659258262890681, 2.5881904510252074`}, {10., 7.88839424802739, 
      2.1136888683372526`}, {10., 8.166666666666666, 0.}}], 
     Polygon3DBox[{{10., 7.88839424802739, 2.1136888683372526`}, {10., 
      9.659258262890681, 2.5881904510252074`}, {10., 8.660254037844386, 5.}, {
      10., 7.072540797572914, 4.083333333333333}, {10., 7.88839424802739, 
      2.1136888683372526`}}], 
     Polygon3DBox[{{10., 7.072540797572914, 4.083333333333333}, {10., 
      8.660254037844386, 5.}, {10., 7.071067811865475, 7.071067811865475}, {
      10., 5.774705379690138, 5.774705379690138}, {10., 7.072540797572914, 
      4.083333333333333}}], 
     Polygon3DBox[{{10., 5.774705379690138, 5.774705379690138}, {10., 
      7.071067811865475, 7.071067811865475}, {10., 5., 8.660254037844386}, {
      10., 4.083333333333333, 7.072540797572914}, {10., 5.774705379690138, 
      5.774705379690138}}], 
     Polygon3DBox[{{10., 4.083333333333333, 7.072540797572914}, {10., 5., 
      8.660254037844386}, {10., 2.5881904510252074`, 9.659258262890681}, {10.,
       2.1136888683372526`, 7.88839424802739}, {10., 4.083333333333333, 
      7.072540797572914}}], 
     Polygon3DBox[{{10., 2.1136888683372526`, 7.88839424802739}, {10., 
      2.5881904510252074`, 9.659258262890681}, {10., 0., 10.}, {10., 0., 
      8.166666666666666}, {10., 2.1136888683372526`, 7.88839424802739}}], 
     Polygon3DBox[{{10., 0., 8.166666666666666}, {10., 0., 10.}, {
      10., -2.5881904510252074`, 9.659258262890681}, {
      10., -2.1136888683372526`, 7.88839424802739}, {10., 0., 
      8.166666666666666}}], 
     Polygon3DBox[{{10., -2.1136888683372526`, 7.88839424802739}, {
      10., -2.5881904510252074`, 9.659258262890681}, {10., -5., 
      8.660254037844386}, {10., -4.083333333333333, 7.072540797572914}, {
      10., -2.1136888683372526`, 7.88839424802739}}], 
     Polygon3DBox[{{10., -4.083333333333333, 7.072540797572914}, {10., -5., 
      8.660254037844386}, {10., -7.071067811865475, 7.071067811865475}, {
      10., -5.774705379690138, 5.774705379690138}, {10., -4.083333333333333, 
      7.072540797572914}}], 
     Polygon3DBox[{{10., -5.774705379690138, 5.774705379690138}, {
      10., -7.071067811865475, 7.071067811865475}, {10., -8.660254037844386, 
      5.}, {10., -7.072540797572914, 4.083333333333333}, {
      10., -5.774705379690138, 5.774705379690138}}], 
     Polygon3DBox[{{10., -7.072540797572914, 4.083333333333333}, {
      10., -8.660254037844386, 5.}, {10., -9.659258262890681, 
      2.5881904510252074`}, {10., -7.88839424802739, 2.1136888683372526`}, {
      10., -7.072540797572914, 4.083333333333333}}], 
     Polygon3DBox[{{10., -7.88839424802739, 2.1136888683372526`}, {
      10., -9.659258262890681, 2.5881904510252074`}, {10., -10., 0.}, {
      10., -8.166666666666666, 0.}, {10., -7.88839424802739, 
      2.1136888683372526`}}], 
     Polygon3DBox[{{10., -8.166666666666666, 0.}, {10., -10., 0.}, {
      10., -9.659258262890681, -2.5881904510252074`}, {
      10., -7.88839424802739, -2.1136888683372526`}, {10., -8.166666666666666,
       0.}}], Polygon3DBox[{{10., -7.88839424802739, -2.1136888683372526`}, {
      10., -9.659258262890681, -2.5881904510252074`}, {
      10., -8.660254037844386, -5.}, {
      10., -7.072540797572914, -4.083333333333333}, {
      10., -7.88839424802739, -2.1136888683372526`}}], 
     Polygon3DBox[{{10., -7.072540797572914, -4.083333333333333}, {
      10., -8.660254037844386, -5.}, {
      10., -7.071067811865475, -7.071067811865475}, {
      10., -5.774705379690138, -5.774705379690138}, {
      10., -7.072540797572914, -4.083333333333333}}], 
     Polygon3DBox[{{10., -5.774705379690138, -5.774705379690138}, {
      10., -7.071067811865475, -7.071067811865475}, {
      10., -5., -8.660254037844386}, {
      10., -4.083333333333333, -7.072540797572914}, {
      10., -5.774705379690138, -5.774705379690138}}], 
     Polygon3DBox[{{10., -4.083333333333333, -7.072540797572914}, {
      10., -5., -8.660254037844386}, {
      10., -2.5881904510252074`, -9.659258262890681}, {
      10., -2.1136888683372526`, -7.88839424802739}, {
      10., -4.083333333333333, -7.072540797572914}}], 
     Polygon3DBox[{{10., -2.1136888683372526`, -7.88839424802739}, {
      10., -2.5881904510252074`, -9.659258262890681}, {10., 0., -10.}, {10., 
      0., -8.166666666666666}, {
      10., -2.1136888683372526`, -7.88839424802739}}], 
     Polygon3DBox[{{10., 0., -8.166666666666666}, {10., 0., -10.}, {10., 
      2.5881904510252074`, -9.659258262890681}, {10., 
      2.1136888683372526`, -7.88839424802739}, {10., 
      0., -8.166666666666666}}], 
     Polygon3DBox[{{10., 2.1136888683372526`, -7.88839424802739}, {10., 
      2.5881904510252074`, -9.659258262890681}, {10., 
      5., -8.660254037844386}, {10., 4.083333333333333, -7.072540797572914}, {
      10., 2.1136888683372526`, -7.88839424802739}}], 
     Polygon3DBox[{{10., 4.083333333333333, -7.072540797572914}, {10., 
      5., -8.660254037844386}, {10., 7.071067811865475, -7.071067811865475}, {
      10., 5.774705379690138, -5.774705379690138}, {10., 
      4.083333333333333, -7.072540797572914}}], 
     Polygon3DBox[{{10., 5.774705379690138, -5.774705379690138}, {10., 
      7.071067811865475, -7.071067811865475}, {10., 8.660254037844386, -5.}, {
      10., 7.072540797572914, -4.083333333333333}, {10., 
      5.774705379690138, -5.774705379690138}}], 
     Polygon3DBox[{{10., 7.072540797572914, -4.083333333333333}, {10., 
      8.660254037844386, -5.}, {10., 
      9.659258262890681, -2.5881904510252074`}, {10., 
      7.88839424802739, -2.1136888683372526`}, {10., 
      7.072540797572914, -4.083333333333333}}], 
     Polygon3DBox[{{10., 7.88839424802739, -2.1136888683372526`}, {10., 
      9.659258262890681, -2.5881904510252074`}, {10., 10., 0.}, {10., 
      8.166666666666666, 0.}, {10., 7.88839424802739, -2.1136888683372526`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhhQcYDQQg4MKEDFoea1RMWfJEGHpPSjlb2LPtnD
xB3Ckl29dPkd/oMBowNM3F3Z33hTCaeDG5SGiTOCaSYHe6g+mHga1NxqqD0w
8Y7nZT9f3dpsg+ouFYcEiPr9NWjq/0HcccAJzXyoOw64o7nHDqLuADPUXTBx
qDsOZKD5F+qOAxB3HbZBC58DUVB3wcSh7jgAcxdM3AvqHicoDRNngbjjgC1U
H0y8EGouzF0wce9oo7KEE2f3wNwFE4+EursGTf1PaDy5oJkPiycPNPdA3QF3
F1r4OBSh+RcWT5DwubwHAH/equ0=
       "]], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhhQcUClEeK55b0+XYHKDiYnvhvO3cICV/da3/wi
T5Ciw38wEIaLH+CSZzjmIeOwH0rDxBnBtIjDK6g+mLgl1NwcqD0wcc7im/vX
8x+zQXefEUT9gVw09f8g7jjwBs18qDsOHEBzD9QdB1ig7oKJQ91xwArNv1D6
AMRd1+DuyoOq14a6CyYOdccBmLtg4keg7tkNpWHirBB3HHgJ1QcTd4GaC3MX
TNxN7PH5w90P9sDcBRPXgro7D039D2g8vUUzHxZPh9DcA3UH3F1o4ePghuZf
1Hh7tgcAfMyjgA==
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{21.066684173688785`, -4.25, 0.}, {
      22.364731413475646`, -4.25, 1.0409497792752501`*^-15}, {
      21.31112278245919, -2.833333333333334, 8.674581493960419*^-16}, {
      20.457621980840333`, -2.8333333333333335`, 0.}, {
      21.066684173688785`, -4.25, 0.}}], 
     Polygon3DBox[{{20.457621980840333`, -2.8333333333333335`, 0.}, {
      21.31112278245919, -2.833333333333334, 8.674581493960419*^-16}, {
      20.769643616762735`, -1.416666666666667, 6.939665195168335*^-16}, {
      20.112196246791022`, -1.416666666666667, 0.}, {
      20.457621980840333`, -2.8333333333333335`, 0.}}], 
     Polygon3DBox[{{20.112196246791022`, -1.416666666666667, 0.}, {
      20.769643616762735`, -1.416666666666667, 6.939665195168335*^-16}, {
      20.6, -8.881784197001252*^-16, 5.204748896376253*^-16}, {20., 0., 0.}, {
      20.112196246791022`, -1.416666666666667, 0.}}], 
     Polygon3DBox[{{20., 0., 0.}, {20.6, 0., 5.204748896376251*^-16}, {
      20.769643616762735`, 1.4166666666666665`, 3.4698325975841675`*^-16}, {
      20.112196246791022`, 1.416666666666666, 0.}, {20., 0., 0.}}], 
     Polygon3DBox[{{20.112196246791022`, 1.416666666666666, 0.}, {
      20.769643616762735`, 1.4166666666666665`, 3.4698325975841675`*^-16}, {
      21.31112278245919, 2.833333333333333, 1.734916298792084*^-16}, {
      20.457621980840333`, 2.833333333333333, 0.}, {20.112196246791022`, 
      1.416666666666666, 0.}}], 
     Polygon3DBox[{{20.457621980840333`, 2.833333333333333, 0.}, {
      21.31112278245919, 2.8333333333333326`, 1.7349162987920847`*^-16}, {
      22.364731413475646`, 4.249999999999999, 8.66764809322393*^-32}, {
      21.066684173688785`, 4.249999999999998, 0.}, {20.457621980840333`, 
      2.833333333333333, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC5RP2kmJGjqwAAGggcYoODq4ovb1EpNHFavAgE2
uHjf5lVPdsiYOKwBi3/bz4ACTBwY0ABM/QqIent08yHibHB9aO6Biy/bvIUz
PtYMQ/z5Zvl9S/1NYe6Ei5tMMo5lPwp3J9zeWTNBANOdMPUr0PwFM38FWjig
uQcujis8AbipW3g=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{21.066684173688785`, 0., -4.25}, {22.364731413475646`, 
        5.204748896376251*^-16, -4.25}, {21.31112278245919, 
        4.3372907469802096`*^-16, -2.833333333333334}, {20.457621980840333`, 
        8.674581493960417*^-17, -2.8333333333333335`}, {21.066684173688785`, 
        0., -4.25}}], 
       Polygon3DBox[{{20.457621980840333`, 
        8.674581493960417*^-17, -2.8333333333333335`}, {21.31112278245919, 
        4.3372907469802096`*^-16, -2.833333333333334}, {20.769643616762735`, 
        3.4698325975841675`*^-16, -1.416666666666667}, {20.112196246791022`, 
        1.7349162987920835`*^-16, -1.416666666666667}, {20.457621980840333`, 
        8.674581493960417*^-17, -2.8333333333333335`}}], 
       Polygon3DBox[{{20.112196246791022`, 
        1.7349162987920835`*^-16, -1.416666666666667}, {20.769643616762735`, 
        3.4698325975841675`*^-16, -1.416666666666667}, {20.6, 
        2.6023744481881263`*^-16, -8.881784197001252*^-16}, {20., 
        2.6023744481881253`*^-16, 0.}, {20.112196246791022`, 
        1.7349162987920835`*^-16, -1.416666666666667}}], 
       Polygon3DBox[{{20., 2.6023744481881253`*^-16, 0.}, {20.6, 
        2.6023744481881253`*^-16, 0.}, {20.769643616762735`, 
        1.7349162987920837`*^-16, 1.4166666666666665`}, {20.112196246791022`, 
        3.469832597584167*^-16, 1.416666666666666}, {20., 
        2.6023744481881253`*^-16, 0.}}], 
       Polygon3DBox[{{20.112196246791022`, 3.469832597584167*^-16, 
        1.416666666666666}, {20.769643616762735`, 1.7349162987920837`*^-16, 
        1.4166666666666665`}, {21.31112278245919, 8.67458149396042*^-17, 
        2.833333333333333}, {20.457621980840333`, 4.337290746980209*^-16, 
        2.833333333333333}, {20.112196246791022`, 3.469832597584167*^-16, 
        1.416666666666666}}], 
       Polygon3DBox[{{20.457621980840333`, 4.337290746980209*^-16, 
        2.833333333333333}, {21.31112278245919, 8.674581493960424*^-17, 
        2.8333333333333326`}, {22.364731413475646`, 4.333824046611965*^-32, 
        4.249999999999999}, {21.066684173688785`, 5.20474889637625*^-16, 
        4.249999999999998}, {20.457621980840333`, 4.337290746980209*^-16, 
        2.833333333333333}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC5RP2kmJGjqwIACBA9cXXxxm1qpCVx89SoQYDvQ
t3nVkx0yCPE1YPFv+yE8EzRzGBjQ1a+AqLdHNx8izuaAwz0OyzZv4YyPNcMQ
f75Zft9Sf4R6qDsdTCYZx7IfxXCn/ayZIIDpTnT1UHfuRzcf6s4DONxzAFd4
AgBholt4
         "]], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{22.364731413475646`, -4.25, 0.}, {
          24.235268586524356`, -4.25, 1.0409497792752501`*^-15}, {
          25.28887721754081, -2.833333333333334, 8.674581493960419*^-16}, {
          21.31112278245919, -2.8333333333333335`, 0.}, {
          22.364731413475646`, -4.25, 0.}}], 
         Polygon3DBox[{{21.31112278245919, -2.8333333333333335`, 0.}, {
          25.28887721754081, -2.833333333333334, 8.674581493960419*^-16}, {
          25.830356383237266`, -1.416666666666667, 6.939665195168335*^-16}, {
          20.769643616762735`, -1.416666666666667, 0.}, {
          21.31112278245919, -2.8333333333333335`, 0.}}], 
         Polygon3DBox[{{20.769643616762735`, -1.416666666666667, 0.}, {
          25.830356383237266`, -1.416666666666667, 6.939665195168335*^-16}, {
          26., -8.881784197001252*^-16, 5.204748896376253*^-16}, {20.6, 0., 
          0.}, {20.769643616762735`, -1.416666666666667, 0.}}], 
         Polygon3DBox[{{20.6, 0., 0.}, {26., 0., 5.204748896376251*^-16}, {
          25.830356383237266`, 1.4166666666666665`, 
          3.4698325975841675`*^-16}, {20.769643616762735`, 1.416666666666666, 
          0.}, {20.6, 0., 0.}}], 
         Polygon3DBox[{{20.769643616762735`, 1.416666666666666, 0.}, {
          25.830356383237266`, 1.4166666666666665`, 
          3.4698325975841675`*^-16}, {25.28887721754081, 2.833333333333333, 
          1.734916298792084*^-16}, {21.31112278245919, 2.833333333333333, 
          0.}, {20.769643616762735`, 1.416666666666666, 0.}}], 
         Polygon3DBox[{{21.31112278245919, 2.833333333333333, 0.}, {
          25.28887721754081, 2.8333333333333326`, 1.7349162987920847`*^-16}, {
          24.235268586524356`, 4.249999999999999, 8.66764809322393*^-32}, {
          22.364731413475646`, 4.249999999999998, 0.}, {21.31112278245919, 
          2.833333333333333, 0.}}], 
         {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF62eQtnfKyZAwMYCB5ggILnm+X3LfU3dVi9CgTY
4OImk4xj2Y+aOKwBi3/bDxOfNRMETBwY0ABM/QqIent08yHibHB9aO6Bi395
+qTfysYCQ3zz08rbnz0tYe6Ei6exp9lMumIJcyfcXgiwwnAnTP0KNH/BzF+B
Fg5o7oGL4wpPALRHX3g=
           "]], 
          {GrayLevel[0.5], EdgeForm[None], 
           Polygon3DBox[{{22.364731413475646`, 0., -4.25}, {
            24.235268586524356`, 5.204748896376251*^-16, -4.25}, {
            25.28887721754081, 
            4.3372907469802096`*^-16, -2.833333333333334}, {21.31112278245919,
             8.674581493960417*^-17, -2.8333333333333335`}, {
            22.364731413475646`, 0., -4.25}}], 
           Polygon3DBox[{{21.31112278245919, 
            8.674581493960417*^-17, -2.8333333333333335`}, {25.28887721754081,
             4.3372907469802096`*^-16, -2.833333333333334}, {
            25.830356383237266`, 
            3.4698325975841675`*^-16, -1.416666666666667}, {
            20.769643616762735`, 
            1.7349162987920835`*^-16, -1.416666666666667}, {21.31112278245919,
             8.674581493960417*^-17, -2.8333333333333335`}}], 
           Polygon3DBox[{{20.769643616762735`, 
            1.7349162987920835`*^-16, -1.416666666666667}, {
            25.830356383237266`, 
            3.4698325975841675`*^-16, -1.416666666666667}, {26., 
            2.6023744481881263`*^-16, -8.881784197001252*^-16}, {20.6, 
            2.6023744481881253`*^-16, 0.}, {20.769643616762735`, 
            1.7349162987920835`*^-16, -1.416666666666667}}], 
           Polygon3DBox[{{20.6, 2.6023744481881253`*^-16, 0.}, {26., 
            2.6023744481881253`*^-16, 0.}, {25.830356383237266`, 
            1.7349162987920837`*^-16, 1.4166666666666665`}, {
            20.769643616762735`, 3.469832597584167*^-16, 1.416666666666666}, {
            20.6, 2.6023744481881253`*^-16, 0.}}], 
           Polygon3DBox[{{20.769643616762735`, 3.469832597584167*^-16, 
            1.416666666666666}, {25.830356383237266`, 
            1.7349162987920837`*^-16, 1.4166666666666665`}, {
            25.28887721754081, 8.67458149396042*^-17, 2.833333333333333}, {
            21.31112278245919, 4.337290746980209*^-16, 2.833333333333333}, {
            20.769643616762735`, 3.469832597584167*^-16, 1.416666666666666}}],
            Polygon3DBox[{{21.31112278245919, 4.337290746980209*^-16, 
            2.833333333333333}, {25.28887721754081, 8.674581493960424*^-17, 
            2.8333333333333326`}, {24.235268586524356`, 
            4.333824046611965*^-32, 4.249999999999999}, {22.364731413475646`, 
            5.20474889637625*^-16, 4.249999999999998}, {21.31112278245919, 
            4.337290746980209*^-16, 2.833333333333333}}], 
           {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF62eQtnfKyZAwMKEDzwfLP8vqX+pnDx1atAgO2A
ySTjWPajJnDxNWDxb/tnzQQBEzRzGBjQ1a+AqLdHNx8izuaAwz0OX54+6bey
scAQ3/y08vZnT0t0dzqksafZTLqCEIe60x7Cs8JwJ7p6qDv3o5sPdecBHO45
gCs8AV1AX3g=
             "]], 
            {GrayLevel[0.5], EdgeForm[None], 
             Polygon3DBox[{{24.235268586524356`, -4.25, 0.}, {
              25.533315826311217`, -4.25, 1.0409497792752501`*^-15}, {
              26.142378019159665`, -2.833333333333334, 
              8.674581493960419*^-16}, {
              25.28887721754081, -2.8333333333333335`, 0.}, {
              24.235268586524356`, -4.25, 0.}}], 
             Polygon3DBox[{{25.28887721754081, -2.8333333333333335`, 0.}, {
              26.142378019159665`, -2.833333333333334, 
              8.674581493960419*^-16}, {26.48780375320898, -1.416666666666667,
               6.939665195168335*^-16}, {
              25.830356383237266`, -1.416666666666667, 0.}, {
              25.28887721754081, -2.8333333333333335`, 0.}}], 
             Polygon3DBox[{{25.830356383237266`, -1.416666666666667, 0.}, {
              26.48780375320898, -1.416666666666667, 
              6.939665195168335*^-16}, {26.6, -8.881784197001252*^-16, 
              5.204748896376253*^-16}, {26., 0., 0.}, {
              25.830356383237266`, -1.416666666666667, 0.}}], 
             Polygon3DBox[{{26., 0., 0.}, {26.6, 0., 
              5.204748896376251*^-16}, {26.48780375320898, 
              1.4166666666666665`, 3.4698325975841675`*^-16}, {
              25.830356383237266`, 1.416666666666666, 0.}, {26., 0., 0.}}], 
             Polygon3DBox[{{25.830356383237266`, 1.416666666666666, 0.}, {
              26.48780375320898, 1.4166666666666665`, 
              3.4698325975841675`*^-16}, {26.14237801915967, 
              2.833333333333333, 1.734916298792084*^-16}, {25.28887721754081, 
              2.833333333333333, 0.}, {25.830356383237266`, 1.416666666666666,
               0.}}], Polygon3DBox[{{25.28887721754081, 2.833333333333333, 
              0.}, {26.14237801915967, 2.8333333333333326`, 
              1.7349162987920847`*^-16}, {25.533315826311217`, 
              4.249999999999999, 8.66764809322393*^-32}, {24.235268586524356`,
               4.249999999999998, 0.}, {25.28887721754081, 2.833333333333333, 
              0.}}], 
             {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["

1:eJxTTMoPSmViYGDgB2JmIP7y9Em/lY2FAwMYCB5ggILNTytvf/a0dFi9CgTY
4OJp7Gk2k65YOqwBi3/bz4ACrBwY0ABM/QqIent08yHibHB9aO6Bi6sVXUhq
77DEED/69fijIhUrmDvh4jzP3m15UGMFcyfc3lkzQQDTnTD1K9D8BTN/BVo4
oLkHLo4rPAFeNWVS
               "]], 
              {GrayLevel[0.5], EdgeForm[None], 
               Polygon3DBox[{{24.235268586524356`, 0., -4.25}, {
                25.533315826311217`, 5.204748896376251*^-16, -4.25}, {
                26.142378019159665`, 
                4.3372907469802096`*^-16, -2.833333333333334}, {
                25.28887721754081, 
                8.674581493960417*^-17, -2.8333333333333335`}, {
                24.235268586524356`, 0., -4.25}}], 
               Polygon3DBox[{{25.28887721754081, 
                8.674581493960417*^-17, -2.8333333333333335`}, {
                26.142378019159665`, 
                4.3372907469802096`*^-16, -2.833333333333334}, {
                26.48780375320898, 
                3.4698325975841675`*^-16, -1.416666666666667}, {
                25.830356383237266`, 
                1.7349162987920835`*^-16, -1.416666666666667}, {
                25.28887721754081, 
                8.674581493960417*^-17, -2.8333333333333335`}}], 
               Polygon3DBox[{{25.830356383237266`, 
                1.7349162987920835`*^-16, -1.416666666666667}, {
                26.48780375320898, 
                3.4698325975841675`*^-16, -1.416666666666667}, {26.6, 
                2.6023744481881263`*^-16, -8.881784197001252*^-16}, {26., 
                2.6023744481881253`*^-16, 0.}, {25.830356383237266`, 
                1.7349162987920835`*^-16, -1.416666666666667}}], 
               Polygon3DBox[{{26., 2.6023744481881253`*^-16, 0.}, {26.6, 
                2.6023744481881253`*^-16, 0.}, {26.48780375320898, 
                1.7349162987920837`*^-16, 1.4166666666666665`}, {
                25.830356383237266`, 3.469832597584167*^-16, 
                1.416666666666666}, {26., 2.6023744481881253`*^-16, 0.}}], 
               Polygon3DBox[{{25.830356383237266`, 3.469832597584167*^-16, 
                1.416666666666666}, {26.48780375320898, 
                1.7349162987920837`*^-16, 1.4166666666666665`}, {
                26.14237801915967, 8.67458149396042*^-17, 
                2.833333333333333}, {25.28887721754081, 
                4.337290746980209*^-16, 2.833333333333333}, {
                25.830356383237266`, 3.469832597584167*^-16, 
                1.416666666666666}}], 
               Polygon3DBox[{{25.28887721754081, 4.337290746980209*^-16, 
                2.833333333333333}, {26.14237801915967, 
                8.674581493960424*^-17, 2.8333333333333326`}, {
                25.533315826311217`, 4.333824046611965*^-32, 
                4.249999999999999}, {24.235268586524356`, 
                5.20474889637625*^-16, 4.249999999999998}, {25.28887721754081,
                 4.337290746980209*^-16, 2.833333333333333}}], 
               {GrayLevel[0], AbsoluteThickness[0.5], 
                Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP7y9Em/lY2FAwMKEDyw+Wnl7c+elnDx1atAgO1A
GnuazaQrCPE1YPFv+yE8KzRzGBjQ1a+AqLdHNx8izuaAwz0OakUXkto7LDHE
j349/qhIBWEv1J0OPM/ebXlQgxCHutN+1kwQwHQnunqoO/ejmw915wEc7jmA
KzwBBy5lUg==
                 "]]}}}}}}}}}}}}, {{}, {}, {}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{21.066684173688785`, 4.25, 0.}, {22.364731413475646`, 4.25, 
       0.}, {22.364731413475646`, 4.10518476172854, 1.0999809416857131`}, {
       21.066684173688785`, 4.10518476172854, 1.0999809416857131`}, {
       21.066684173688785`, 4.25, 0.}}], 
      Line3DBox[{{21.066684173688785`, 4.10518476172854, 
       1.0999809416857131`}, {22.364731413475646`, 4.10518476172854, 
       1.0999809416857131`}, {22.364731413475646`, 3.6806079660838646`, 
       2.1249999999999996`}, {21.066684173688785`, 3.6806079660838646`, 
       2.1249999999999996`}, {21.066684173688785`, 4.10518476172854, 
       1.0999809416857131`}}], 
      Line3DBox[{{21.066684173688785`, 3.6806079660838646`, 
       2.1249999999999996`}, {22.364731413475646`, 3.6806079660838646`, 
       2.1249999999999996`}, {22.364731413475646`, 3.0052038200428273`, 
       3.005203820042827}, {21.066684173688785`, 3.0052038200428273`, 
       3.005203820042827}, {21.066684173688785`, 3.6806079660838646`, 
       2.1249999999999996`}}], 
      Line3DBox[{{21.066684173688785`, 3.0052038200428273`, 
       3.005203820042827}, {22.364731413475646`, 3.0052038200428273`, 
       3.005203820042827}, {22.364731413475646`, 2.1250000000000004`, 
       3.680607966083864}, {21.066684173688785`, 2.1250000000000004`, 
       3.680607966083864}, {21.066684173688785`, 3.0052038200428273`, 
       3.005203820042827}}], 
      Line3DBox[{{21.066684173688785`, 2.1250000000000004`, 
       3.680607966083864}, {22.364731413475646`, 2.1250000000000004`, 
       3.680607966083864}, {22.364731413475646`, 1.099980941685714, 
       4.10518476172854}, {21.066684173688785`, 1.099980941685714, 
       4.10518476172854}, {21.066684173688785`, 2.1250000000000004`, 
       3.680607966083864}}], 
      Line3DBox[{{21.066684173688785`, 1.099980941685714, 4.10518476172854}, {
       22.364731413475646`, 1.099980941685714, 4.10518476172854}, {
       22.364731413475646`, 1.2039270157501956`*^-15, 4.25}, {
       21.066684173688785`, 1.2039270157501956`*^-15, 4.25}, {
       21.066684173688785`, 1.099980941685714, 4.10518476172854}}], 
      Line3DBox[{{21.066684173688785`, 2.6023744481881253`*^-16, 4.25}, {
       22.364731413475646`, 2.6023744481881253`*^-16, 4.25}, {
       22.364731413475646`, -1.0999809416857127`, 4.10518476172854}, {
       21.066684173688785`, -1.0999809416857127`, 4.10518476172854}, {
       21.066684173688785`, 2.6023744481881253`*^-16, 4.25}}], 
      Line3DBox[{{21.066684173688785`, -1.0999809416857127`, 
       4.10518476172854}, {22.364731413475646`, -1.0999809416857127`, 
       4.10518476172854}, {22.364731413475646`, -2.124999999999999, 
       3.680607966083865}, {21.066684173688785`, -2.124999999999999, 
       3.680607966083865}, {21.066684173688785`, -1.0999809416857127`, 
       4.10518476172854}}], 
      Line3DBox[{{21.066684173688785`, -2.124999999999999, 
       3.680607966083865}, {22.364731413475646`, -2.124999999999999, 
       3.680607966083865}, {22.364731413475646`, -3.005203820042827, 
       3.0052038200428273`}, {21.066684173688785`, -3.005203820042827, 
       3.0052038200428273`}, {21.066684173688785`, -2.124999999999999, 
       3.680607966083865}}], 
      Line3DBox[{{21.066684173688785`, -3.005203820042827, 
       3.0052038200428273`}, {22.364731413475646`, -3.005203820042827, 
       3.0052038200428273`}, {22.364731413475646`, -3.6806079660838646`, 
       2.1249999999999996`}, {21.066684173688785`, -3.6806079660838646`, 
       2.1249999999999996`}, {21.066684173688785`, -3.005203820042827, 
       3.0052038200428273`}}], 
      Line3DBox[{{21.066684173688785`, -3.6806079660838638`, 
       2.1250000000000013`}, {22.364731413475646`, -3.6806079660838638`, 
       2.1250000000000013`}, {22.364731413475646`, -4.10518476172854, 
       1.0999809416857143`}, {21.066684173688785`, -4.10518476172854, 
       1.0999809416857143`}, {21.066684173688785`, -3.6806079660838638`, 
       2.1250000000000013`}}], 
      Line3DBox[{{21.066684173688785`, -4.10518476172854, 
       1.0999809416857143`}, {22.364731413475646`, -4.10518476172854, 
       1.0999809416857143`}, {22.364731413475646`, -4.25, 
       5.204748896376251*^-16}, {21.066684173688785`, -4.25, 
       5.204748896376251*^-16}, {21.066684173688785`, -4.10518476172854, 
       1.0999809416857143`}}], 
      Line3DBox[{{21.066684173688785`, -4.25, 5.204748896376251*^-16}, {
       22.364731413475646`, -4.25, 5.204748896376251*^-16}, {
       22.364731413475646`, -4.10518476172854, -1.0999809416857134`}, {
       21.066684173688785`, -4.10518476172854, -1.0999809416857134`}, {
       21.066684173688785`, -4.25, 5.204748896376251*^-16}}], 
      Line3DBox[{{
       21.066684173688785`, -4.105184761728541, -1.0999809416857116`}, {
       22.364731413475646`, -4.105184761728541, -1.0999809416857116`}, {
       22.364731413475646`, -3.680607966083865, -2.124999999999999}, {
       21.066684173688785`, -3.680607966083865, -2.124999999999999}, {
       21.066684173688785`, -4.105184761728541, -1.0999809416857116`}}], 
      Line3DBox[{{
       21.066684173688785`, -3.680607966083865, -2.124999999999999}, {
       22.364731413475646`, -3.680607966083865, -2.124999999999999}, {
       22.364731413475646`, -3.0052038200428277`, -3.005203820042827}, {
       21.066684173688785`, -3.0052038200428277`, -3.005203820042827}, {
       21.066684173688785`, -3.680607966083865, -2.124999999999999}}], 
      Line3DBox[{{
       21.066684173688785`, -3.0052038200428286`, -3.0052038200428255`}, {
       22.364731413475646`, -3.0052038200428286`, -3.0052038200428255`}, {
       22.364731413475646`, -2.1250000000000018`, -3.680607966083863}, {
       21.066684173688785`, -2.1250000000000018`, -3.680607966083863}, {
       21.066684173688785`, -3.0052038200428286`, -3.0052038200428255`}}], 
      Line3DBox[{{
       21.066684173688785`, -2.1250000000000018`, -3.680607966083863}, {
       22.364731413475646`, -2.1250000000000018`, -3.680607966083863}, {
       22.364731413475646`, -1.0999809416857163`, -4.105184761728539}, {
       21.066684173688785`, -1.0999809416857163`, -4.105184761728539}, {
       21.066684173688785`, -2.1250000000000018`, -3.680607966083863}}], 
      Line3DBox[{{
       21.066684173688785`, -1.0999809416857163`, -4.105184761728539}, {
       22.364731413475646`, -1.0999809416857163`, -4.105184761728539}, {
       22.364731413475646`, -4.5554706181819696`*^-15, -4.25}, {
       21.066684173688785`, -4.5554706181819696`*^-15, -4.25}, {
       21.066684173688785`, -1.0999809416857163`, -4.105184761728539}}], 
      Line3DBox[{{21.066684173688785`, -7.807123344564377*^-16, -4.25}, {
       22.364731413475646`, -7.807123344564377*^-16, -4.25}, {
       22.364731413475646`, 1.0999809416857111`, -4.105184761728541}, {
       21.066684173688785`, 1.0999809416857111`, -4.105184761728541}, {
       21.066684173688785`, -7.807123344564377*^-16, -4.25}}], 
      Line3DBox[{{21.066684173688785`, 
       1.0999809416857111`, -4.105184761728541}, {22.364731413475646`, 
       1.0999809416857111`, -4.105184761728541}, {22.364731413475646`, 
       2.124999999999997, -3.680607966083866}, {21.066684173688785`, 
       2.124999999999997, -3.680607966083866}, {21.066684173688785`, 
       1.0999809416857111`, -4.105184761728541}}], 
      Line3DBox[{{21.066684173688785`, 
       2.124999999999997, -3.680607966083866}, {22.364731413475646`, 
       2.124999999999997, -3.680607966083866}, {22.364731413475646`, 
       3.0052038200428233`, -3.0052038200428304`}, {21.066684173688785`, 
       3.0052038200428233`, -3.0052038200428304`}, {21.066684173688785`, 
       2.124999999999997, -3.680607966083866}}], 
      Line3DBox[{{21.066684173688785`, 
       3.005203820042827, -3.0052038200428277`}, {22.364731413475646`, 
       3.005203820042827, -3.0052038200428277`}, {22.364731413475646`, 
       3.680607966083863, -2.1250000000000018`}, {21.066684173688785`, 
       3.680607966083863, -2.1250000000000018`}, {21.066684173688785`, 
       3.005203820042827, -3.0052038200428277`}}], 
      Line3DBox[{{21.066684173688785`, 
       3.680607966083863, -2.1250000000000018`}, {22.364731413475646`, 
       3.680607966083863, -2.1250000000000018`}, {22.364731413475646`, 
       4.105184761728539, -1.0999809416857165`}, {21.066684173688785`, 
       4.105184761728539, -1.0999809416857165`}, {21.066684173688785`, 
       3.680607966083863, -2.1250000000000018`}}], 
      Line3DBox[{{21.066684173688785`, 
       4.105184761728539, -1.0999809416857165`}, {22.364731413475646`, 
       4.105184761728539, -1.0999809416857165`}, {22.364731413475646`, 
       4.25, -4.8157080630007826`*^-15}, {21.066684173688785`, 
       4.25, -4.8157080630007826`*^-15}, {21.066684173688785`, 
       4.105184761728539, -1.0999809416857165`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{22.364731413475646`, 4.25, 0.}, {24.235268586524356`, 4.25, 
       0.}, {24.235268586524356`, 4.10518476172854, 1.0999809416857131`}, {
       22.364731413475646`, 4.10518476172854, 1.0999809416857131`}, {
       22.364731413475646`, 4.25, 0.}}], 
      Line3DBox[{{22.364731413475646`, 4.10518476172854, 
       1.0999809416857131`}, {24.235268586524356`, 4.10518476172854, 
       1.0999809416857131`}, {24.235268586524356`, 3.6806079660838646`, 
       2.1249999999999996`}, {22.364731413475646`, 3.6806079660838646`, 
       2.1249999999999996`}, {22.364731413475646`, 4.10518476172854, 
       1.0999809416857131`}}], 
      Line3DBox[{{22.364731413475646`, 3.6806079660838646`, 
       2.1249999999999996`}, {24.235268586524356`, 3.6806079660838646`, 
       2.1249999999999996`}, {24.235268586524356`, 3.0052038200428273`, 
       3.005203820042827}, {22.364731413475646`, 3.0052038200428273`, 
       3.005203820042827}, {22.364731413475646`, 3.6806079660838646`, 
       2.1249999999999996`}}], 
      Line3DBox[{{22.364731413475646`, 3.0052038200428273`, 
       3.005203820042827}, {24.235268586524356`, 3.0052038200428273`, 
       3.005203820042827}, {24.235268586524356`, 2.1250000000000004`, 
       3.680607966083864}, {22.364731413475646`, 2.1250000000000004`, 
       3.680607966083864}, {22.364731413475646`, 3.0052038200428273`, 
       3.005203820042827}}], 
      Line3DBox[{{22.364731413475646`, 2.1250000000000004`, 
       3.680607966083864}, {24.235268586524356`, 2.1250000000000004`, 
       3.680607966083864}, {24.235268586524356`, 1.099980941685714, 
       4.10518476172854}, {22.364731413475646`, 1.099980941685714, 
       4.10518476172854}, {22.364731413475646`, 2.1250000000000004`, 
       3.680607966083864}}], 
      Line3DBox[{{22.364731413475646`, 1.099980941685714, 4.10518476172854}, {
       24.235268586524356`, 1.099980941685714, 4.10518476172854}, {
       24.235268586524356`, 1.2039270157501956`*^-15, 4.25}, {
       22.364731413475646`, 1.2039270157501956`*^-15, 4.25}, {
       22.364731413475646`, 1.099980941685714, 4.10518476172854}}], 
      Line3DBox[{{22.364731413475646`, 2.6023744481881253`*^-16, 4.25}, {
       24.235268586524356`, 2.6023744481881253`*^-16, 4.25}, {
       24.235268586524356`, -1.0999809416857127`, 4.10518476172854}, {
       22.364731413475646`, -1.0999809416857127`, 4.10518476172854}, {
       22.364731413475646`, 2.6023744481881253`*^-16, 4.25}}], 
      Line3DBox[{{22.364731413475646`, -1.0999809416857127`, 
       4.10518476172854}, {24.235268586524356`, -1.0999809416857127`, 
       4.10518476172854}, {24.235268586524356`, -2.124999999999999, 
       3.680607966083865}, {22.364731413475646`, -2.124999999999999, 
       3.680607966083865}, {22.364731413475646`, -1.0999809416857127`, 
       4.10518476172854}}], 
      Line3DBox[{{22.364731413475646`, -2.124999999999999, 
       3.680607966083865}, {24.235268586524356`, -2.124999999999999, 
       3.680607966083865}, {24.235268586524356`, -3.005203820042827, 
       3.0052038200428273`}, {22.364731413475646`, -3.005203820042827, 
       3.0052038200428273`}, {22.364731413475646`, -2.124999999999999, 
       3.680607966083865}}], 
      Line3DBox[{{22.364731413475646`, -3.005203820042827, 
       3.0052038200428273`}, {24.235268586524356`, -3.005203820042827, 
       3.0052038200428273`}, {24.235268586524356`, -3.6806079660838646`, 
       2.1249999999999996`}, {22.364731413475646`, -3.6806079660838646`, 
       2.1249999999999996`}, {22.364731413475646`, -3.005203820042827, 
       3.0052038200428273`}}], 
      Line3DBox[{{22.364731413475646`, -3.6806079660838638`, 
       2.1250000000000013`}, {24.235268586524356`, -3.6806079660838638`, 
       2.1250000000000013`}, {24.235268586524356`, -4.10518476172854, 
       1.0999809416857143`}, {22.364731413475646`, -4.10518476172854, 
       1.0999809416857143`}, {22.364731413475646`, -3.6806079660838638`, 
       2.1250000000000013`}}], 
      Line3DBox[{{22.364731413475646`, -4.10518476172854, 
       1.0999809416857143`}, {24.235268586524356`, -4.10518476172854, 
       1.0999809416857143`}, {24.235268586524356`, -4.25, 
       5.204748896376251*^-16}, {22.364731413475646`, -4.25, 
       5.204748896376251*^-16}, {22.364731413475646`, -4.10518476172854, 
       1.0999809416857143`}}], 
      Line3DBox[{{22.364731413475646`, -4.25, 5.204748896376251*^-16}, {
       24.235268586524356`, -4.25, 5.204748896376251*^-16}, {
       24.235268586524356`, -4.10518476172854, -1.0999809416857134`}, {
       22.364731413475646`, -4.10518476172854, -1.0999809416857134`}, {
       22.364731413475646`, -4.25, 5.204748896376251*^-16}}], 
      Line3DBox[{{
       22.364731413475646`, -4.105184761728541, -1.0999809416857116`}, {
       24.235268586524356`, -4.105184761728541, -1.0999809416857116`}, {
       24.235268586524356`, -3.680607966083865, -2.124999999999999}, {
       22.364731413475646`, -3.680607966083865, -2.124999999999999}, {
       22.364731413475646`, -4.105184761728541, -1.0999809416857116`}}], 
      Line3DBox[{{
       22.364731413475646`, -3.680607966083865, -2.124999999999999}, {
       24.235268586524356`, -3.680607966083865, -2.124999999999999}, {
       24.235268586524356`, -3.0052038200428277`, -3.005203820042827}, {
       22.364731413475646`, -3.0052038200428277`, -3.005203820042827}, {
       22.364731413475646`, -3.680607966083865, -2.124999999999999}}], 
      Line3DBox[{{
       22.364731413475646`, -3.0052038200428286`, -3.0052038200428255`}, {
       24.235268586524356`, -3.0052038200428286`, -3.0052038200428255`}, {
       24.235268586524356`, -2.1250000000000018`, -3.680607966083863}, {
       22.364731413475646`, -2.1250000000000018`, -3.680607966083863}, {
       22.364731413475646`, -3.0052038200428286`, -3.0052038200428255`}}], 
      Line3DBox[{{
       22.364731413475646`, -2.1250000000000018`, -3.680607966083863}, {
       24.235268586524356`, -2.1250000000000018`, -3.680607966083863}, {
       24.235268586524356`, -1.0999809416857163`, -4.105184761728539}, {
       22.364731413475646`, -1.0999809416857163`, -4.105184761728539}, {
       22.364731413475646`, -2.1250000000000018`, -3.680607966083863}}], 
      Line3DBox[{{
       22.364731413475646`, -1.0999809416857163`, -4.105184761728539}, {
       24.235268586524356`, -1.0999809416857163`, -4.105184761728539}, {
       24.235268586524356`, -4.5554706181819696`*^-15, -4.25}, {
       22.364731413475646`, -4.5554706181819696`*^-15, -4.25}, {
       22.364731413475646`, -1.0999809416857163`, -4.105184761728539}}], 
      Line3DBox[{{22.364731413475646`, -7.807123344564377*^-16, -4.25}, {
       24.235268586524356`, -7.807123344564377*^-16, -4.25}, {
       24.235268586524356`, 1.0999809416857111`, -4.105184761728541}, {
       22.364731413475646`, 1.0999809416857111`, -4.105184761728541}, {
       22.364731413475646`, -7.807123344564377*^-16, -4.25}}], 
      Line3DBox[{{22.364731413475646`, 
       1.0999809416857111`, -4.105184761728541}, {24.235268586524356`, 
       1.0999809416857111`, -4.105184761728541}, {24.235268586524356`, 
       2.124999999999997, -3.680607966083866}, {22.364731413475646`, 
       2.124999999999997, -3.680607966083866}, {22.364731413475646`, 
       1.0999809416857111`, -4.105184761728541}}], 
      Line3DBox[{{22.364731413475646`, 
       2.124999999999997, -3.680607966083866}, {24.235268586524356`, 
       2.124999999999997, -3.680607966083866}, {24.235268586524356`, 
       3.0052038200428233`, -3.0052038200428304`}, {22.364731413475646`, 
       3.0052038200428233`, -3.0052038200428304`}, {22.364731413475646`, 
       2.124999999999997, -3.680607966083866}}], 
      Line3DBox[{{22.364731413475646`, 
       3.005203820042827, -3.0052038200428277`}, {24.235268586524356`, 
       3.005203820042827, -3.0052038200428277`}, {24.235268586524356`, 
       3.680607966083863, -2.1250000000000018`}, {22.364731413475646`, 
       3.680607966083863, -2.1250000000000018`}, {22.364731413475646`, 
       3.005203820042827, -3.0052038200428277`}}], 
      Line3DBox[{{22.364731413475646`, 
       3.680607966083863, -2.1250000000000018`}, {24.235268586524356`, 
       3.680607966083863, -2.1250000000000018`}, {24.235268586524356`, 
       4.105184761728539, -1.0999809416857165`}, {22.364731413475646`, 
       4.105184761728539, -1.0999809416857165`}, {22.364731413475646`, 
       3.680607966083863, -2.1250000000000018`}}], 
      Line3DBox[{{22.364731413475646`, 
       4.105184761728539, -1.0999809416857165`}, {24.235268586524356`, 
       4.105184761728539, -1.0999809416857165`}, {24.235268586524356`, 
       4.25, -4.8157080630007826`*^-15}, {22.364731413475646`, 
       4.25, -4.8157080630007826`*^-15}, {22.364731413475646`, 
       4.105184761728539, -1.0999809416857165`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{24.235268586524356`, 4.25, 0.}, {25.533315826311217`, 4.25, 
       0.}, {25.533315826311217`, 4.10518476172854, 1.0999809416857131`}, {
       24.235268586524356`, 4.10518476172854, 1.0999809416857131`}, {
       24.235268586524356`, 4.25, 0.}}], 
      Line3DBox[{{24.235268586524356`, 4.10518476172854, 
       1.0999809416857131`}, {25.533315826311217`, 4.10518476172854, 
       1.0999809416857131`}, {25.533315826311217`, 3.6806079660838646`, 
       2.1249999999999996`}, {24.235268586524356`, 3.6806079660838646`, 
       2.1249999999999996`}, {24.235268586524356`, 4.10518476172854, 
       1.0999809416857131`}}], 
      Line3DBox[{{24.235268586524356`, 3.6806079660838646`, 
       2.1249999999999996`}, {25.533315826311217`, 3.6806079660838646`, 
       2.1249999999999996`}, {25.533315826311217`, 3.0052038200428273`, 
       3.005203820042827}, {24.235268586524356`, 3.0052038200428273`, 
       3.005203820042827}, {24.235268586524356`, 3.6806079660838646`, 
       2.1249999999999996`}}], 
      Line3DBox[{{24.235268586524356`, 3.0052038200428273`, 
       3.005203820042827}, {25.533315826311217`, 3.0052038200428273`, 
       3.005203820042827}, {25.533315826311217`, 2.1250000000000004`, 
       3.680607966083864}, {24.235268586524356`, 2.1250000000000004`, 
       3.680607966083864}, {24.235268586524356`, 3.0052038200428273`, 
       3.005203820042827}}], 
      Line3DBox[{{24.235268586524356`, 2.1250000000000004`, 
       3.680607966083864}, {25.533315826311217`, 2.1250000000000004`, 
       3.680607966083864}, {25.533315826311217`, 1.099980941685714, 
       4.10518476172854}, {24.235268586524356`, 1.099980941685714, 
       4.10518476172854}, {24.235268586524356`, 2.1250000000000004`, 
       3.680607966083864}}], 
      Line3DBox[{{24.235268586524356`, 1.099980941685714, 4.10518476172854}, {
       25.533315826311217`, 1.099980941685714, 4.10518476172854}, {
       25.533315826311217`, 1.2039270157501956`*^-15, 4.25}, {
       24.235268586524356`, 1.2039270157501956`*^-15, 4.25}, {
       24.235268586524356`, 1.099980941685714, 4.10518476172854}}], 
      Line3DBox[{{24.235268586524356`, 2.6023744481881253`*^-16, 4.25}, {
       25.533315826311217`, 2.6023744481881253`*^-16, 4.25}, {
       25.533315826311217`, -1.0999809416857127`, 4.10518476172854}, {
       24.235268586524356`, -1.0999809416857127`, 4.10518476172854}, {
       24.235268586524356`, 2.6023744481881253`*^-16, 4.25}}], 
      Line3DBox[{{24.235268586524356`, -1.0999809416857127`, 
       4.10518476172854}, {25.533315826311217`, -1.0999809416857127`, 
       4.10518476172854}, {25.533315826311217`, -2.124999999999999, 
       3.680607966083865}, {24.235268586524356`, -2.124999999999999, 
       3.680607966083865}, {24.235268586524356`, -1.0999809416857127`, 
       4.10518476172854}}], 
      Line3DBox[{{24.235268586524356`, -2.124999999999999, 
       3.680607966083865}, {25.533315826311217`, -2.124999999999999, 
       3.680607966083865}, {25.533315826311217`, -3.005203820042827, 
       3.0052038200428273`}, {24.235268586524356`, -3.005203820042827, 
       3.0052038200428273`}, {24.235268586524356`, -2.124999999999999, 
       3.680607966083865}}], 
      Line3DBox[{{24.235268586524356`, -3.005203820042827, 
       3.0052038200428273`}, {25.533315826311217`, -3.005203820042827, 
       3.0052038200428273`}, {25.533315826311217`, -3.6806079660838646`, 
       2.1249999999999996`}, {24.235268586524356`, -3.6806079660838646`, 
       2.1249999999999996`}, {24.235268586524356`, -3.005203820042827, 
       3.0052038200428273`}}], 
      Line3DBox[{{24.235268586524356`, -3.6806079660838638`, 
       2.1250000000000013`}, {25.533315826311217`, -3.6806079660838638`, 
       2.1250000000000013`}, {25.533315826311217`, -4.10518476172854, 
       1.0999809416857143`}, {24.235268586524356`, -4.10518476172854, 
       1.0999809416857143`}, {24.235268586524356`, -3.6806079660838638`, 
       2.1250000000000013`}}], 
      Line3DBox[{{24.235268586524356`, -4.10518476172854, 
       1.0999809416857143`}, {25.533315826311217`, -4.10518476172854, 
       1.0999809416857143`}, {25.533315826311217`, -4.25, 
       5.204748896376251*^-16}, {24.235268586524356`, -4.25, 
       5.204748896376251*^-16}, {24.235268586524356`, -4.10518476172854, 
       1.0999809416857143`}}], 
      Line3DBox[{{24.235268586524356`, -4.25, 5.204748896376251*^-16}, {
       25.533315826311217`, -4.25, 5.204748896376251*^-16}, {
       25.533315826311217`, -4.10518476172854, -1.0999809416857134`}, {
       24.235268586524356`, -4.10518476172854, -1.0999809416857134`}, {
       24.235268586524356`, -4.25, 5.204748896376251*^-16}}], 
      Line3DBox[{{
       24.235268586524356`, -4.105184761728541, -1.0999809416857116`}, {
       25.533315826311217`, -4.105184761728541, -1.0999809416857116`}, {
       25.533315826311217`, -3.680607966083865, -2.124999999999999}, {
       24.235268586524356`, -3.680607966083865, -2.124999999999999}, {
       24.235268586524356`, -4.105184761728541, -1.0999809416857116`}}], 
      Line3DBox[{{
       24.235268586524356`, -3.680607966083865, -2.124999999999999}, {
       25.533315826311217`, -3.680607966083865, -2.124999999999999}, {
       25.533315826311217`, -3.0052038200428277`, -3.005203820042827}, {
       24.235268586524356`, -3.0052038200428277`, -3.005203820042827}, {
       24.235268586524356`, -3.680607966083865, -2.124999999999999}}], 
      Line3DBox[{{
       24.235268586524356`, -3.0052038200428286`, -3.0052038200428255`}, {
       25.533315826311217`, -3.0052038200428286`, -3.0052038200428255`}, {
       25.533315826311217`, -2.1250000000000018`, -3.680607966083863}, {
       24.235268586524356`, -2.1250000000000018`, -3.680607966083863}, {
       24.235268586524356`, -3.0052038200428286`, -3.0052038200428255`}}], 
      Line3DBox[{{
       24.235268586524356`, -2.1250000000000018`, -3.680607966083863}, {
       25.533315826311217`, -2.1250000000000018`, -3.680607966083863}, {
       25.533315826311217`, -1.0999809416857163`, -4.105184761728539}, {
       24.235268586524356`, -1.0999809416857163`, -4.105184761728539}, {
       24.235268586524356`, -2.1250000000000018`, -3.680607966083863}}], 
      Line3DBox[{{
       24.235268586524356`, -1.0999809416857163`, -4.105184761728539}, {
       25.533315826311217`, -1.0999809416857163`, -4.105184761728539}, {
       25.533315826311217`, -4.5554706181819696`*^-15, -4.25}, {
       24.235268586524356`, -4.5554706181819696`*^-15, -4.25}, {
       24.235268586524356`, -1.0999809416857163`, -4.105184761728539}}], 
      Line3DBox[{{24.235268586524356`, -7.807123344564377*^-16, -4.25}, {
       25.533315826311217`, -7.807123344564377*^-16, -4.25}, {
       25.533315826311217`, 1.0999809416857111`, -4.105184761728541}, {
       24.235268586524356`, 1.0999809416857111`, -4.105184761728541}, {
       24.235268586524356`, -7.807123344564377*^-16, -4.25}}], 
      Line3DBox[{{24.235268586524356`, 
       1.0999809416857111`, -4.105184761728541}, {25.533315826311217`, 
       1.0999809416857111`, -4.105184761728541}, {25.533315826311217`, 
       2.124999999999997, -3.680607966083866}, {24.235268586524356`, 
       2.124999999999997, -3.680607966083866}, {24.235268586524356`, 
       1.0999809416857111`, -4.105184761728541}}], 
      Line3DBox[{{24.235268586524356`, 
       2.124999999999997, -3.680607966083866}, {25.533315826311217`, 
       2.124999999999997, -3.680607966083866}, {25.533315826311217`, 
       3.0052038200428233`, -3.0052038200428304`}, {24.235268586524356`, 
       3.0052038200428233`, -3.0052038200428304`}, {24.235268586524356`, 
       2.124999999999997, -3.680607966083866}}], 
      Line3DBox[{{24.235268586524356`, 
       3.005203820042827, -3.0052038200428277`}, {25.533315826311217`, 
       3.005203820042827, -3.0052038200428277`}, {25.533315826311217`, 
       3.680607966083863, -2.1250000000000018`}, {24.235268586524356`, 
       3.680607966083863, -2.1250000000000018`}, {24.235268586524356`, 
       3.005203820042827, -3.0052038200428277`}}], 
      Line3DBox[{{24.235268586524356`, 
       3.680607966083863, -2.1250000000000018`}, {25.533315826311217`, 
       3.680607966083863, -2.1250000000000018`}, {25.533315826311217`, 
       4.105184761728539, -1.0999809416857165`}, {24.235268586524356`, 
       4.105184761728539, -1.0999809416857165`}, {24.235268586524356`, 
       3.680607966083863, -2.1250000000000018`}}], 
      Line3DBox[{{24.235268586524356`, 
       4.105184761728539, -1.0999809416857165`}, {25.533315826311217`, 
       4.105184761728539, -1.0999809416857165`}, {25.533315826311217`, 
       4.25, -4.8157080630007826`*^-15}, {24.235268586524356`, 
       4.25, -4.8157080630007826`*^-15}, {24.235268586524356`, 
       4.105184761728539, -1.0999809416857165`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhhwcYDQKgcYUICLw+pVICCFIb4GLM6FIc6AFbg4
rICod8AuLoUhDnUP0eKrcZizBoe9BNx5AIc7McSh7iEoDgCNXzFc
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhhwcWBAASoH0MVXrwIBKQzxNWBxLgxxVIAQXwFR
74BdXApDHOoeosVX4zBnDQ57CbjzAA53YohD3YNTHABOQDFc
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhhwcYDQKg4MKMDFIbe816crUNnB5MR3w7lbWBxg
4q/1zS/yBCk6/AcDYbj4AS55hmMeMg77oTRMnBFMizi8guqDiVtCzc2B2gMT
5yy+uX89/zEbVHe5OBhB1B/IRVP/D+KOA2/QzIe648ABNPdA3XGABeoumDjU
HQes0PwLdccBiLuu2cDE86DqtaHugolD3XEA5i6Y+BGoe3ZDaZg4K8QdB15C
9cHEXaDmwtwFE3cTe3z+cPeDPTB3wcS1oO7OQ1P/AxpPb9HMh8XTITT3QN0B
dxda+Di4ofkXFk+Q8Hm2BwA5SKag
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{50., 25., -25}, {50., -25., -25}, {50., -25., 25}, {
        50., 25., 25}, {50., 25., -25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{50., -25., -25}, {0., -25., -25}, {0., -25., 25}, {
        50., -25., 25}, {50., -25., -25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0, -25, -25}, {0, 25, -25}, {0, 25, 25}, {0, -25, 25}, {
       0, -25, -25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 25., -25}, {50., 25., -25}, {50., 25., 25}, {
        0., 25., 25}, {0., 25., -25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{50., -25, -25.}, {50., 25, -25.}, {0., 25, -25.}, {
        0., -25, -25.}, {50., -25, -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{50., 25., 25.}, {50., -25., 25.}, {0., -25., 25.}, {0., 25.,
        25.}, {50., 25., 25.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGCQAmImIAaxUYHIAVS+igN2cRjggItP8Zww80iziQO6OCr4
sB/GWsNqYuTCB1OPEEdTb49DvT129RwOONzjgFU5gwiaONy/uMw5ABOv3hdx
f2WYqUPUrV8r7ITY4eK4/MW+MIrr0VoTBze56xLxku9xhYM9DvVwcVz+QnMP
LnG4O/XqUwVOlFs6fK5Sm8B/mBkujsud7d/3p3h/snS4GvCosHD6S1z+sseh
Hi6Oy51o7sElDndniyBD0X5nK4cl+x9pb6hAiONy5/p383x2TLBy0NkyReqp
00tc/rLHoR4ujsudaO7BJQ53JwS4OLy6uMrMds4PXPbuR1cvEF62KLb7JkF3
oqmHm4PLnWjuwbAX3Z0Q4OmgoXtPMniHIIY56O6EqZ9XW2XY3PWFoDvR1ONy
D4Z6qHsOwEQAffwQNQ==
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAmJmBhhQcYDQIgdgIlM8J8w80mwCFeeAi69hNTFy4YOJ
f9iPQ9wehzkODCgAbi9cvHpfxP2VYaYOUbd+rbATYofby74wiuvRWhMHN7nr
EvGS7/fjELfHYQ7cfL36VIET5ZYOn6vUJvAfZoab3/59f4r3J0uHqwGPCgun
v9yPQ9wehzlw81sEGYr2O1s5LNn/SHtDBcL89e/m+eyYYOWgs2WK1FMnhPlo
4vY4zEELNxeHVxdXmdnO+WGPLi4QXrYotvsmLvH96OJQc9DEPR00dO9JBu8Q
dEAXn1dbZdjc9cUehzguc+DhAAB7W4+j
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{360., 394.99050461274373`},
  PlotLabel:>FormBox["\"Hastings Triplet Achromat\"", TraditionalForm],
  PlotRange:>All,
  ViewPoint->{0.9403080095912858, -2.600827126964691, 1.9497484716606566`},
  ViewVertical->{-0.04992711358286602, -0.038874418928347004`, 
   0.9979960234801875}]], "Print",
 CellChangeTimes->{3.4083318091174726`*^9, 3.544879555354888*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"DrawSystem", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"LineOfRays", "[", 
           RowBox[{"10", ",", 
            RowBox[{"NumberOfRays", "\[Rule]", "6"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"x0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"y0", ",", "0"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Theta]0", ",", "0.`"}], "}"}], ",", 
          RowBox[{"SymbolicValues", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"\[Theta]0", "\[Rule]", "0"}], ",", 
             RowBox[{"x0", "\[Rule]", "0"}], ",", 
             RowBox[{"y0", "\[Rule]", "0"}]}], "}"}]}]}], "]"}], ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"BaffleWithHole", "[", 
           RowBox[{"20", ",", "9"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"xb", ",", "10.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"yb", ",", "0"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Theta]b", ",", "0.`"}], "}"}]}], "]"}], ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"LensTriplet", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"ro", ",", "9.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"ri", ",", "6.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "ri"}], ",", 
              RowBox[{"-", "6.`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "ro"}], ",", 
              RowBox[{"-", "9.`"}]}], "}"}], ",", "8.5`", ",", 
            RowBox[{"{", 
             RowBox[{"to", ",", "0.6`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"ti", ",", "5.4`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"to", ",", "0.6`"}], "}"}], ",", "SF5", ",", "BK7", ",", 
            "SF5", ",", 
            RowBox[{"{", 
             RowBox[{"SymbolicValues", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\[Theta]1", "\[Rule]", "0"}], ",", 
                RowBox[{"x1", "\[Rule]", "20"}], ",", 
                RowBox[{"y1", "\[Rule]", "0"}], ",", 
                RowBox[{"ro", "\[Rule]", "9"}], ",", 
                RowBox[{"ri", "\[Rule]", "6"}], ",", 
                RowBox[{"to", "\[Rule]", "0.6`"}], ",", 
                RowBox[{"ti", "\[Rule]", "5.4`"}]}], "}"}]}], "}"}]}], "]"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"x1", ",", "20.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"y1", ",", "0"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Theta]1", ",", "0.`"}], "}"}], ",", 
          RowBox[{"SymbolicValues", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"\[Theta]1", "\[Rule]", "0"}], ",", 
             RowBox[{"x1", "\[Rule]", "20"}], ",", 
             RowBox[{"y1", "\[Rule]", "0"}]}], "}"}]}]}], "]"}], ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", "20", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"XS", ",", "40.`"}], "}"}]}], "]"}], ",", 
        RowBox[{"Boundary", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "25"}], ",", 
            RowBox[{"-", "25"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"50", ",", "25", ",", "25"}], "}"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"SymbolicValues", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Theta]0", "\[Rule]", "0"}], ",", 
         RowBox[{"x0", "\[Rule]", "0"}], ",", 
         RowBox[{"y0", "\[Rule]", "0"}], ",", 
         RowBox[{"\[Theta]b", "\[Rule]", "0"}], ",", 
         RowBox[{"xb", "\[Rule]", "10"}], ",", 
         RowBox[{"yb", "\[Rule]", "0"}], ",", 
         RowBox[{"\[Theta]1", "\[Rule]", "0"}], ",", 
         RowBox[{"x1", "\[Rule]", "20"}], ",", 
         RowBox[{"y1", "\[Rule]", "0"}], ",", 
         RowBox[{"ro", "\[Rule]", "9"}], ",", 
         RowBox[{"ri", "\[Rule]", "6"}], ",", 
         RowBox[{"to", "\[Rule]", "0.6`"}], ",", 
         RowBox[{"ti", "\[Rule]", "5.4`"}], ",", 
         RowBox[{"XS", "\[Rule]", "40"}]}], "}"}]}], ",", 
      RowBox[{"UpdateNumericParameters", "\[Rule]", "False"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Print",
 CellChangeTimes->{3.4083318091174726`*^9, 3.5448795554432993`*^9}]
}, Open  ]],

Cell[BoxData["\<\"-26 ray/surface intersections-\"\>"], "Output",
 CellChangeTimes->{3.408331809223761*^9, 3.5448795554464912`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ManipulateSystem", "[", 
  RowBox[{"mysystem2", ",", " ", 
   RowBox[{"Axes", " ", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{
   "PlotLabel", " ", "\[Rule]", " ", "\"\<Hastings Triplet Achromat\>\""}], 
   ",", " ", 
   RowBox[{"Row", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"DynamicFrame", "[", " ", 
       RowBox[{"PlotType", " ", "\[Rule]", " ", "TopView"}], "]"}], ",", " ", 
      
      RowBox[{"DynamicFrame", "[", " ", 
       RowBox[{
        RowBox[{"PlotType", " ", "\[Rule]", " ", "Full3D"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], "}"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4083300608507767`*^9, 3.408330072559238*^9}, {
   3.408330268497261*^9, 3.408330274935484*^9}, {3.408330385265143*^9, 
   3.4083304388077507`*^9}, {3.408330492073798*^9, 3.4083304943197727`*^9}, {
   3.408330832057513*^9, 3.408330869439836*^9}, {3.408330922577608*^9, 
   3.408330922751848*^9}, {3.408331001706408*^9, 3.408331014935824*^9}, {
   3.408331839178439*^9, 3.408331846723185*^9}, 3.408379258745113*^9, {
   3.40837929201598*^9, 3.408379319604464*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`lastlocpos\[Theta]0$$ = {1.25, 
    0.}, $CellContext`lastlocpos\[Theta]1$$ = {21.25, 
    0.}, $CellContext`lastlocpos\[Theta]b$$ = {11.25, 
    0.}, $CellContext`laststartpos\[Theta]0$$ = {0., 
    0.}, $CellContext`laststartpos\[Theta]1$$ = {20., 
    0.}, $CellContext`laststartpos\[Theta]b$$ = {10., 
    0.}, $CellContext`last\[Theta]0$$ = 0., $CellContext`last\[Theta]1$$ = 
    0., $CellContext`last\[Theta]b$$ = 0., $CellContext`maxri$$ = 
    12, $CellContext`maxro$$ = 18, $CellContext`maxti$$ = 
    11, $CellContext`maxto$$ = 0.9, $CellContext`maxx0$$ = 
    10, $CellContext`maxx1$$ = 40, $CellContext`maxxb$$ = 
    20, $CellContext`maxXS$$ = 80, $CellContext`maxy0$$ = 
    10, $CellContext`maxy1$$ = 10, $CellContext`maxyb$$ = 
    10, $CellContext`max\[Theta]0$$ = 180., $CellContext`max\[Theta]1$$ = 
    180., $CellContext`max\[Theta]b$$ = 180., $CellContext`minri$$ = 
    0.06, $CellContext`minro$$ = 0.09, $CellContext`minti$$ = 
    0.054, $CellContext`minto$$ = 
    0.1, $CellContext`minx0$$ = -10, $CellContext`minx1$$ = 
    0.2, $CellContext`minxb$$ = 0.1, $CellContext`minXS$$ = 
    0.4, $CellContext`miny0$$ = -10, $CellContext`miny1$$ = -10, \
$CellContext`minyb$$ = -10, $CellContext`min\[Theta]0$$ = -180., \
$CellContext`min\[Theta]1$$ = -180., $CellContext`min\[Theta]b$$ = -180., \
$CellContext`radius\[Theta]0$$ = 1.25, $CellContext`radius\[Theta]1$$ = 
    1.25, $CellContext`radius\[Theta]b$$ = 1.25, $CellContext`ri$$ = 
    6., $CellContext`ro$$ = 
    9., $CellContext`staticpolygons1184086201251114555749860$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxd019Ik1EYBvA59WIpqVPCC0Gco4uw0nURgdawmjYVTSF1E5yrNMKUMKc5
sYsEZToMvAlEIfFayYYiGVv+YxASUpCGF6WQOA1ChDTF/uz9vkd6Duzbfnyc
s/c85z1pzsbSu5EajUb795OlfP8/9Gb116dfIzv9ywlw+1Zy66Hz2C2NvSPZ
L+Jh863b161n42Cjbqaqpy8WzksvvjD+SAffm+iqqwhFwxHhpxZ+1tF5MOQ9
uKK6tm7+sXd4B84st7+cfLcGd2+49kOfX2WrNsh7v2qHzIc9sj589PvfiAio
viP1wRapHzbI/uDLsn9YyQd2S36wki8sQw8v0/t2mt9K6+fS/5+m+qxU/33a
X1T4qYUHKJ+HlF8J5VtgN7kcwcVp1Sl0PpV0fk/pfPclf7PqauoPC/WPgfor
h/rPRf3ppv7l/pahJxvhmrcfBkwf0+EHLd5Cz81jFz5/UnO1zQBvnb+4FFua
Bk98zzj343UqHDiRqlnIT4G/VbT1TVYmw3IfkuA3ZbYS++BJ+FLwZ9agLwr2
xNwos63tIk9d04p/LG4B98Et73FeJpkfQH2yPiz3IRH+KvXBfqkf9sn+4JDs
H1bygeslP1jJF5ZhhJ30voHmF9H62/T/U1TfHNW/QfuLDj+T4CDlc43yG6V8
LafW38/2fMF9aKbzOUPnN0rnuyf5w6vUH37qHx/11yb1n5X6s57610H9LcNo
/gPNv1zi
      "]]}, $CellContext`staticpolygons1384086201251114555789622$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAcqB2Cs1atAQAGNL3UAVb0InL8GLM8F528A
83/tx7ACClZA5O1R+VwOMP6//yAg7IAqLwXnr4K4D86Huh8nfzWa+tVo5kH9
A+evQXPPBjT34vDPflQ+Ijyg/jmAKo8Iz1Vo4Q11PwYfAJoRYDs=
      
      "]]}, $CellContext`staticpolygons1484086201251114555791267$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAFPBwht6YDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ApPwf+A==
      
      "]]}, $CellContext`staticpolygons2184086201251114557609625$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxdlEtIVVEUhq+vgSWZGeFAMB80sKcWRGW5MVMzJVMoH0F6KxVJpZdvapBQ
aKLQoMAMCseJZUp45a60RIqIMMqiQSkoaUJIUGZU5v7/A64D1yMf6+zzr2/t
fSLdldmn/Vwul+/iL27x9///5dcao8m7X51zN8ZCTOyxgu6+F+OJ5A0zYTW/
3SHGXfKstuXenMOrK693JtxdbVovNS7caVlwuDl68kD65mDzd+nycd4TEzh4
vLk1yBT3Xi3JnQ5weGr04e0PLgSaFNzJS1EXjefIfZb++ppEvIe8DTmYi7wY
uevRB/k29Mm+ya9NVc1Pf3iYoD1F2XrvmKovtOt7G9T6TTaPt0bl+WO9SJLK
f8r2KxtUv/AiqcpPlK2TMuVzn11X/OCJHF6kTc0LXqRUzRdeZI/aD/Ai1tNQ
Agm8yHp4IocXyYcncniRRngihxehJ3J4EXoiT4efJNzJ4UXoidzfepG9eA95
O3JUIRf5WeSmJ/Is9ElP5IcK4qsKR1566Ik8HB7HVH0evDeo9a9gTjUqzzzO
VbLKfwL7IFb1y3OVpvzAiylTPuHF0BM5vJjbal48V+fUfHmustV+gBdj98+o
ZzmPMS51FT0ZbY9/E20aVx7MyR//7uzD8uqWjKYj0WbHyI+4jh5/57mMW5eL
9tdFGU9OflZBxyqHz2zd+TooOxLfpVCH985u2vKtP8JM5Na19uWFOVxWRLiG
08KNF3fySdQ9wnPk9ru01kzjPeQDyMFc5LuQ+wz6IG9Cn+ybPPD8e29X8HCC
9lRv671uVR9v15dytX6vzSM6jz1vofJV5f9s+5XHql94EVF+emydTCmf8CL+
8ESOHDKg5gUvslvNF17kptoP8CLW01vnuwQvUgtP5BVYfyM8kWciTxc8kcOL
0BM5vAg9kT+Fn37cyeFF6Ik8wHqRL3gP+QhypCMXeTJy0xP5ffRZiL7JU9ZN
vBpq/uShJ/KL8OhW9bHwXqHXx5wyVZ6fOFezKv9H7IMB1S/P1aDyAy9mSvmE
F0NP5PBinqt58VylqPnCi+lW+wFejN0/k55/a7W5fQ==
      
      "]]}, $CellContext`staticpolygons2384086201251114558049314$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmJmBnSgcgBdZPUqEFDAIS6FIQ4BIhjia8DquTDEN4DF
f+3Hbg4mWAFRb49dnMsBXfzffxAQxhCHqJfCEF8F8S+GOASoEC2+Goc5q3HY
CwEiGOJrcPhrA45wwAVW4AjnFTjiBRpuGOIrcMT7KhzpBAIw0xW6OABkrmA6

       "], CompressedData["
1:eJxTTMoPSmViYGCQBmJmBlxA5QC6yOpVIKCAQ1wKQxwCRDDE14DVc2GIbwCL
/9qP00loYAVEvT12cS4HdPF//0FAGEMcol4KQ3wVxL8Y4hCgQrT4ahzmrMZh
LwSIYIivweGvDTjCARdYgSOcV+CIF2i4YYivwBHvq3CkEwjATFcwcQBxAWA6

       "], CompressedData["
1:eJxdk71LQmEUh29lQx/UUERDIGZTRaEEUQi9UEiFQulStqTQljZERDa0NBnR
WBD+C0lgRqh4+kCkJaIIgoZKUPoQGoKa+sD3dxzOhXsvPJz73t95zvtaAkue
hWrDMGz/d40hry4lif/0Zt9+a1WbDRNe3/PnCPPg6rYrMm1VA7kvWzRuqnzn
2tvwj4Y7Vcrrm5qLNlX4W//gdaPHon7LV0uFJ0q9fR9Js8rPhHeOZ9srnOrN
Rna8Q2XwZl5A3RG+Y15VfraqV/yHeRo5OBfzIeReRB/MI+iT+2Zet3yfiTVn
HdLTuq7PBES9Xa9PQbF+QuchmedHe6F3kf9J90snol94IRJ+4rqOisInvJAJ
npgjB6XFvOCFhsV84YV2xX6AF9Ke7hxM4IXW4Il5COv3wBNzN/LE4Ik5vBB7
Yg4vxJ6YX8BPEm/m8ELsiXmt9kIv+A/zHHJMIhfzMeRmT8wP0Oc8+mbubMtf
nW89ptgT8xV4DIj6bngPyfUxJ7fI841zVRL5H7AP0qJfPldnwg+8qKLwCS+K
PTGHF3Up5sXnyinmCy/qUOwHeFF6/xRSfy2XT3Q=
       
       "]}]}, $CellContext`staticpolygons2484086201251114558050801$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIAaxIcDTAUJbwugDaOIHCIg74DAHlzgB82GAoDi6
+YTEiTXfgYC4A373kGo+wfDBZS8hcXRzDuAQR5PHZQ5cHJc5hMx3wKHeAYf5
6OK4zIHTANcrNqc=
      "]]}, $CellContext`ti$$ = 5.4, $CellContext`to$$ = 
    0.595, $CellContext`x0$$ = 0., $CellContext`x1$$ = 
    20., $CellContext`xb$$ = 10., $CellContext`xoff\[Theta]0$$ = 
    1.25, $CellContext`xoff\[Theta]1$$ = 1.25, $CellContext`xoff\[Theta]b$$ = 
    1.25, $CellContext`XS$$ = 40., $CellContext`x\[Theta]0$$ = 
    1.25, $CellContext`x\[Theta]1$$ = 21.25, $CellContext`x\[Theta]b$$ = 
    11.25, $CellContext`y0$$ = 0., $CellContext`y1$$ = 0., $CellContext`yb$$ =
     0., $CellContext`yoff\[Theta]0$$ = 0., $CellContext`yoff\[Theta]1$$ = 
    0., $CellContext`yoff\[Theta]b$$ = 0., $CellContext`y\[Theta]0$$ = 
    0., $CellContext`y\[Theta]1$$ = 0., $CellContext`y\[Theta]b$$ = 
    0., $CellContext`\[Theta]0$$ = 0., $CellContext`\[Theta]1$$ = 
    0., $CellContext`\[Theta]b$$ = 0., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`x0$$], 0.}, -10, 10}, {{
       Hold[$CellContext`y0$$], 0.}, -10, 10}, {{
       Hold[$CellContext`\[Theta]0$$], 0.}, -180., 180.}, {{
       Hold[$CellContext`ri$$], 6.}, 0.06, 12}, {{
       Hold[$CellContext`ro$$], 9.}, 0.09, 18}, {{
       Hold[$CellContext`ti$$], 5.4}, 0.054, 11}, {{
       Hold[$CellContext`to$$], 0.6}, 0.1, 0.8999999999999999}, {{
       Hold[$CellContext`x1$$], 20.}, 0.2, 40}, {{
       Hold[$CellContext`xb$$], 10.}, 0.1, 20}, {{
       Hold[$CellContext`XS$$], 40.}, 0.4, 80}, {{
       Hold[$CellContext`y1$$], 0.}, -10, 10}, {{
       Hold[$CellContext`yb$$], 0.}, -10, 10}, {{
       Hold[$CellContext`\[Theta]1$$], 0.}, -180., 180.}, {{
       Hold[$CellContext`\[Theta]b$$], 0.}, -180., 180.}, {
      Hold[
       Style[
        Grid[{{"ri", 
           InputField[
            Dynamic[$CellContext`minri$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567223; $CellContext`ri$$, \
($CellContext`ri$$ = #)& ], {
             Dynamic[$CellContext`minri$$], 
             Dynamic[$CellContext`maxri$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxri$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567223; $CellContext`ri$$, \
($CellContext`ri$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minri$$], 0.06}}, {{
       Hold[$CellContext`maxri$$], 12}}, {
      Hold[
       Style[
        Grid[{{"ro", 
           InputField[
            Dynamic[$CellContext`minro$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567441; $CellContext`ro$$, \
($CellContext`ro$$ = #)& ], {
             Dynamic[$CellContext`minro$$], 
             Dynamic[$CellContext`maxro$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxro$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567441; $CellContext`ro$$, \
($CellContext`ro$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minro$$], 0.09}}, {{
       Hold[$CellContext`maxro$$], 18}}, {
      Hold[
       Style[
        Grid[{{"ti", 
           InputField[
            Dynamic[$CellContext`minti$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567616; $CellContext`ti$$, \
($CellContext`ti$$ = #)& ], {
             Dynamic[$CellContext`minti$$], 
             Dynamic[$CellContext`maxti$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxti$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567616; $CellContext`ti$$, \
($CellContext`ti$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minti$$], 0.054}}, {{
       Hold[$CellContext`maxti$$], 11}}, {
      Hold[
       Style[
        Grid[{{"to", 
           InputField[
            Dynamic[$CellContext`minto$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567795; $CellContext`to$$, \
($CellContext`to$$ = #)& ], {
             Dynamic[$CellContext`minto$$], 
             Dynamic[$CellContext`maxto$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxto$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567795; $CellContext`to$$, \
($CellContext`to$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minto$$], 0.1}}, {{
       Hold[$CellContext`maxto$$], 0.8999999999999999}}, {{
       Hold[$CellContext`minx0$$], -10}}, {{
       Hold[$CellContext`maxx0$$], 10}}, {{
       Hold[$CellContext`miny0$$], -10}}, {{
       Hold[$CellContext`maxy0$$], 10}}, {{
       Hold[$CellContext`min\[Theta]0$$], -180.}}, {{
       Hold[$CellContext`max\[Theta]0$$], 180.}}, {{
       Hold[$CellContext`minx1$$], 0.2}}, {{
       Hold[$CellContext`maxx1$$], 40}}, {{
       Hold[$CellContext`minxb$$], 0.1}}, {{
       Hold[$CellContext`maxxb$$], 20}}, {{
       Hold[$CellContext`minXS$$], 0.4}}, {{
       Hold[$CellContext`maxXS$$], 80}}, {{
       Hold[$CellContext`miny1$$], -10}}, {{
       Hold[$CellContext`maxy1$$], 10}}, {{
       Hold[$CellContext`minyb$$], -10}}, {{
       Hold[$CellContext`maxyb$$], 10}}, {{
       Hold[$CellContext`min\[Theta]1$$], -180.}}, {{
       Hold[$CellContext`max\[Theta]1$$], 180.}}, {{
       Hold[$CellContext`min\[Theta]b$$], -180.}}, {{
       Hold[$CellContext`max\[Theta]b$$], 180.}}, {{
       Hold[$CellContext`minri$$], 0.06}}, {{
       Hold[$CellContext`maxri$$], 12}}, {{
       Hold[$CellContext`minro$$], 0.09}}, {{
       Hold[$CellContext`maxro$$], 18}}, {{
       Hold[$CellContext`minti$$], 0.054}}, {{
       Hold[$CellContext`maxti$$], 11}}, {{
       Hold[$CellContext`minto$$], 0.1}}, {{
       Hold[$CellContext`maxto$$], 0.8999999999999999}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{
              "ri", "ro", "ti", "to", "x0", "x1", "xb", "XS", "y0", "y1", 
               "yb", "\[Theta]0", "\[Theta]1", 
               "\[Theta]b"}, {$CellContext`ri$$, $CellContext`ro$$, \
$CellContext`ti$$, $CellContext`to$$, $CellContext`x0$$, $CellContext`x1$$, \
$CellContext`xb$$, $CellContext`XS$$, $CellContext`y0$$, $CellContext`y1$$, \
$CellContext`yb$$, $CellContext`\[Theta]0$$, $CellContext`\[Theta]1$$, \
$CellContext`\[Theta]b$$}}], 
           Optica`Optica`SymbolicRanges -> {$CellContext`x0$$ -> {-10, 
              10}, $CellContext`y0$$ -> {-10, 
              10}, $CellContext`\[Theta]0$$ -> {-180., 
              180.}, $CellContext`ri$$ -> {0.06, 12}, $CellContext`ro$$ -> {
              0.09, 18}, $CellContext`ti$$ -> {
              0.054, 11}, $CellContext`to$$ -> {0.1, 
              0.8999999999999999}, $CellContext`x1$$ -> {
              0.2, 40}, $CellContext`xb$$ -> {0.1, 20}, $CellContext`XS$$ -> {
              0.4, 80}, $CellContext`y1$$ -> {-10, 
              10}, $CellContext`yb$$ -> {-10, 
              10}, $CellContext`\[Theta]1$$ -> {-180., 
              180.}, $CellContext`\[Theta]b$$ -> {-180., 180.}}}; 
        Optica`Optica`$OpticalSystemScript = 
         "{Move[LineOfRays[10, NumberOfRays -> 6], {{x0, 0}, {y0, 0}}, {\
\[Theta]0, 0.}, SymbolicValues -> {\[Theta]0 -> 0, x0 -> 0, y0 -> 0}], \
Move[BaffleWithHole[20, 9], {{xb, 10.}, {yb, 0}}, {\[Theta]b, 0.}, \
SymbolicValues -> {\[Theta]b -> 0, xb -> 10, yb -> 0}], Move[LensTriplet[{ro, \
9.}, {ri, 6.}, {-ri, -6.}, {-ro, -9.}, 8.5, {to, 0.6}, {ti, 5.4}, {to, 0.6}, \
SF5, BK7, SF5, {SymbolicValues -> {\[Theta]1 -> 0, x1 -> 20, y1 -> 0, ro -> \
9, ri -> 6, to -> 0.6, ti -> 5.4}}], {{x1, 20.}, {y1, 0}}, {\[Theta]1, 0.}, \
SymbolicValues -> {\[Theta]1 -> 0, x1 -> 20, y1 -> 0}], Move[Screen[20], {XS, \
40.}, SymbolicValues -> {XS -> 40}], Boundary[{0, -25, -25}, {50, 25, 25}]}"; 
        Print[
          InputForm[
           StringJoin["SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "ri", "ro", "ti", "to", "x0", "x1", "xb", "XS", "y0", "y1", 
                "yb", "\[Theta]0", "\[Theta]1", 
                "\[Theta]b"}, {$CellContext`ri$$, $CellContext`ro$$, \
$CellContext`ti$$, $CellContext`to$$, $CellContext`x0$$, $CellContext`x1$$, \
$CellContext`xb$$, $CellContext`XS$$, $CellContext`y0$$, $CellContext`y1$$, \
$CellContext`yb$$, $CellContext`\[Theta]0$$, $CellContext`\[Theta]1$$, \
$CellContext`\[Theta]b$$}}]]]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`x\[Theta]0$$], 1.25}}, {{
       Hold[$CellContext`y\[Theta]0$$], 0.}}, {{
       Hold[$CellContext`radius\[Theta]0$$], 1.25}}, {{
       Hold[$CellContext`xoff\[Theta]0$$], 1.25}}, {{
       Hold[$CellContext`yoff\[Theta]0$$], 0.}}, {{
       Hold[$CellContext`laststartpos\[Theta]0$$], {0., 0.}}}, {{
       Hold[$CellContext`lastlocpos\[Theta]0$$], {1.25, 0.}}}, {{
       Hold[$CellContext`last\[Theta]0$$], 0}}, {{
       Hold[$CellContext`x\[Theta]b$$], 11.25}}, {{
       Hold[$CellContext`y\[Theta]b$$], 0.}}, {{
       Hold[$CellContext`radius\[Theta]b$$], 1.25}}, {{
       Hold[$CellContext`xoff\[Theta]b$$], 1.25}}, {{
       Hold[$CellContext`yoff\[Theta]b$$], 0.}}, {{
       Hold[$CellContext`laststartpos\[Theta]b$$], {10., 0.}}}, {{
       Hold[$CellContext`lastlocpos\[Theta]b$$], {11.25, 0.}}}, {{
       Hold[$CellContext`last\[Theta]b$$], 0}}, {{
       Hold[$CellContext`x\[Theta]1$$], 21.25}}, {{
       Hold[$CellContext`y\[Theta]1$$], 0.}}, {{
       Hold[$CellContext`radius\[Theta]1$$], 1.25}}, {{
       Hold[$CellContext`xoff\[Theta]1$$], 1.25}}, {{
       Hold[$CellContext`yoff\[Theta]1$$], 0.}}, {{
       Hold[$CellContext`laststartpos\[Theta]1$$], {20., 0.}}}, {{
       Hold[$CellContext`lastlocpos\[Theta]1$$], {21.25, 0.}}}, {{
       Hold[$CellContext`last\[Theta]1$$], 0}}, {{
       Hold[$CellContext`staticpolygons1184086201251114555749860$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxd019Ik1EYBvA59WIpqVPCC0Gco4uw0nURgdawmjYVTSF1E5yrNMKUMKc5
sYsEZToMvAlEIfFayYYiGVv+YxASUpCGF6WQOA1ChDTF/uz9vkd6Duzbfnyc
s/c85z1pzsbSu5EajUb795OlfP8/9Gb116dfIzv9ywlw+1Zy66Hz2C2NvSPZ
L+Jh863b161n42Cjbqaqpy8WzksvvjD+SAffm+iqqwhFwxHhpxZ+1tF5MOQ9
uKK6tm7+sXd4B84st7+cfLcGd2+49kOfX2WrNsh7v2qHzIc9sj589PvfiAio
viP1wRapHzbI/uDLsn9YyQd2S36wki8sQw8v0/t2mt9K6+fS/5+m+qxU/33a
X1T4qYUHKJ+HlF8J5VtgN7kcwcVp1Sl0PpV0fk/pfPclf7PqauoPC/WPgfor
h/rPRf3ppv7l/pahJxvhmrcfBkwf0+EHLd5Cz81jFz5/UnO1zQBvnb+4FFua
Bk98zzj343UqHDiRqlnIT4G/VbT1TVYmw3IfkuA3ZbYS++BJ+FLwZ9agLwr2
xNwos63tIk9d04p/LG4B98Et73FeJpkfQH2yPiz3IRH+KvXBfqkf9sn+4JDs
H1bygeslP1jJF5ZhhJ30voHmF9H62/T/U1TfHNW/QfuLDj+T4CDlc43yG6V8
LafW38/2fMF9aKbzOUPnN0rnuyf5w6vUH37qHx/11yb1n5X6s57610H9LcNo
/gPNv1zi
         "]]}}}, {{
       Hold[$CellContext`staticpolygons1384086201251114555789622$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAcqB2Cs1atAQAGNL3UAVb0InL8GLM8F528A
83/tx7ACClZA5O1R+VwOMP6//yAg7IAqLwXnr4K4D86Huh8nfzWa+tVo5kH9
A+evQXPPBjT34vDPflQ+Ijyg/jmAKo8Iz1Vo4Q11PwYfAJoRYDs=
         "]]}}}, {{
       Hold[$CellContext`staticpolygons1484086201251114555791267$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAFPBwht6YDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ApPwf+A==
         "]]}}}, {{
       Hold[$CellContext`staticpolygons2184086201251114557609625$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxdlEtIVVEUhq+vgSWZGeFAMB80sKcWRGW5MVMzJVMoH0F6KxVJpZdvapBQ
aKLQoMAMCseJZUp45a60RIqIMMqiQSkoaUJIUGZU5v7/A64D1yMf6+zzr2/t
fSLdldmn/Vwul+/iL27x9///5dcao8m7X51zN8ZCTOyxgu6+F+OJ5A0zYTW/
3SHGXfKstuXenMOrK693JtxdbVovNS7caVlwuDl68kD65mDzd+nycd4TEzh4
vLk1yBT3Xi3JnQ5weGr04e0PLgSaFNzJS1EXjefIfZb++ppEvIe8DTmYi7wY
uevRB/k29Mm+ya9NVc1Pf3iYoD1F2XrvmKovtOt7G9T6TTaPt0bl+WO9SJLK
f8r2KxtUv/AiqcpPlK2TMuVzn11X/OCJHF6kTc0LXqRUzRdeZI/aD/Ai1tNQ
Agm8yHp4IocXyYcncniRRngihxehJ3J4EXoiT4efJNzJ4UXoidzfepG9eA95
O3JUIRf5WeSmJ/Is9ElP5IcK4qsKR1566Ik8HB7HVH0evDeo9a9gTjUqzzzO
VbLKfwL7IFb1y3OVpvzAiylTPuHF0BM5vJjbal48V+fUfHmustV+gBdj98+o
ZzmPMS51FT0ZbY9/E20aVx7MyR//7uzD8uqWjKYj0WbHyI+4jh5/57mMW5eL
9tdFGU9OflZBxyqHz2zd+TooOxLfpVCH985u2vKtP8JM5Na19uWFOVxWRLiG
08KNF3fySdQ9wnPk9ru01kzjPeQDyMFc5LuQ+wz6IG9Cn+ybPPD8e29X8HCC
9lRv671uVR9v15dytX6vzSM6jz1vofJV5f9s+5XHql94EVF+emydTCmf8CL+
8ESOHDKg5gUvslvNF17kptoP8CLW01vnuwQvUgtP5BVYfyM8kWciTxc8kcOL
0BM5vAg9kT+Fn37cyeFF6Ik8wHqRL3gP+QhypCMXeTJy0xP5ffRZiL7JU9ZN
vBpq/uShJ/KL8OhW9bHwXqHXx5wyVZ6fOFezKv9H7IMB1S/P1aDyAy9mSvmE
F0NP5PBinqt58VylqPnCi+lW+wFejN0/k55/a7W5fQ==
         "]]}}}, {{
       Hold[$CellContext`staticpolygons2384086201251114558049314$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmJmBnSgcgBdZPUqEFDAIS6FIQ4BIhjia8DquTDEN4DF
f+3Hbg4mWAFRb49dnMsBXfzffxAQxhCHqJfCEF8F8S+GOASoEC2+Goc5q3HY
CwEiGOJrcPhrA45wwAVW4AjnFTjiBRpuGOIrcMT7KhzpBAIw0xW6OABkrmA6

          "], CompressedData["
1:eJxTTMoPSmViYGCQBmJmBlxA5QC6yOpVIKCAQ1wKQxwCRDDE14DVc2GIbwCL
/9qP00loYAVEvT12cS4HdPF//0FAGEMcol4KQ3wVxL8Y4hCgQrT4ahzmrMZh
LwSIYIivweGvDTjCARdYgSOcV+CIF2i4YYivwBHvq3CkEwjATFcwcQBxAWA6

          "], CompressedData["
1:eJxdk71LQmEUh29lQx/UUERDIGZTRaEEUQi9UEiFQulStqTQljZERDa0NBnR
WBD+C0lgRqh4+kCkJaIIgoZKUPoQGoKa+sD3dxzOhXsvPJz73t95zvtaAkue
hWrDMGz/d40hry4lif/0Zt9+a1WbDRNe3/PnCPPg6rYrMm1VA7kvWzRuqnzn
2tvwj4Y7Vcrrm5qLNlX4W//gdaPHon7LV0uFJ0q9fR9Js8rPhHeOZ9srnOrN
Rna8Q2XwZl5A3RG+Y15VfraqV/yHeRo5OBfzIeReRB/MI+iT+2Zet3yfiTVn
HdLTuq7PBES9Xa9PQbF+QuchmedHe6F3kf9J90snol94IRJ+4rqOisInvJAJ
npgjB6XFvOCFhsV84YV2xX6AF9Ke7hxM4IXW4Il5COv3wBNzN/LE4Ik5vBB7
Yg4vxJ6YX8BPEm/m8ELsiXmt9kIv+A/zHHJMIhfzMeRmT8wP0Oc8+mbubMtf
nW89ptgT8xV4DIj6bngPyfUxJ7fI841zVRL5H7AP0qJfPldnwg+8qKLwCS+K
PTGHF3Up5sXnyinmCy/qUOwHeFF6/xRSfy2XT3Q=
          "]}]}}}, {{
       Hold[$CellContext`staticpolygons2484086201251114558050801$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIAaxIcDTAUJbwugDaOIHCIg74DAHlzgB82GAoDi6
+YTEiTXfgYC4A373kGo+wfDBZS8hcXRzDuAQR5PHZQ5cHJc5hMx3wKHeAYf5
6OK4zIHTANcrNqc=
         "]]}}}}, Typeset`size$$ = {
    815., {662.34375, 667.65625}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`x0$66424$$ = 
    0, $CellContext`y0$66425$$ = 0, $CellContext`\[Theta]0$66426$$ = 
    0, $CellContext`ri$66427$$ = 0, $CellContext`ro$66428$$ = 
    0, $CellContext`ti$66429$$ = 0, $CellContext`to$66430$$ = 
    0, $CellContext`x1$66431$$ = 0, $CellContext`xb$66432$$ = 
    0, $CellContext`XS$66433$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`lastlocpos\[Theta]0$$ = {1.25, 
         0.}, $CellContext`lastlocpos\[Theta]1$$ = {21.25, 
         0.}, $CellContext`lastlocpos\[Theta]b$$ = {11.25, 
         0.}, $CellContext`laststartpos\[Theta]0$$ = {0., 
         0.}, $CellContext`laststartpos\[Theta]1$$ = {20., 
         0.}, $CellContext`laststartpos\[Theta]b$$ = {10., 
         0.}, $CellContext`last\[Theta]0$$ = 0, $CellContext`last\[Theta]1$$ = 
        0, $CellContext`last\[Theta]b$$ = 0, $CellContext`maxri$$ = 
        12, $CellContext`maxro$$ = 18, $CellContext`maxti$$ = 
        11, $CellContext`maxto$$ = 0.8999999999999999, $CellContext`maxx0$$ = 
        10, $CellContext`maxx1$$ = 40, $CellContext`maxxb$$ = 
        20, $CellContext`maxXS$$ = 80, $CellContext`maxy0$$ = 
        10, $CellContext`maxy1$$ = 10, $CellContext`maxyb$$ = 
        10, $CellContext`max\[Theta]0$$ = 180., $CellContext`max\[Theta]1$$ = 
        180., $CellContext`max\[Theta]b$$ = 180., $CellContext`minri$$ = 
        0.06, $CellContext`minro$$ = 0.09, $CellContext`minti$$ = 
        0.054, $CellContext`minto$$ = 
        0.1, $CellContext`minx0$$ = -10, $CellContext`minx1$$ = 
        0.2, $CellContext`minxb$$ = 0.1, $CellContext`minXS$$ = 
        0.4, $CellContext`miny0$$ = -10, $CellContext`miny1$$ = -10, \
$CellContext`minyb$$ = -10, $CellContext`min\[Theta]0$$ = -180., \
$CellContext`min\[Theta]1$$ = -180., $CellContext`min\[Theta]b$$ = -180., \
$CellContext`radius\[Theta]0$$ = 1.25, $CellContext`radius\[Theta]1$$ = 
        1.25, $CellContext`radius\[Theta]b$$ = 1.25, $CellContext`ri$$ = 
        6., $CellContext`ro$$ = 
        9., $CellContext`staticpolygons1184086201251114555749860$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxd019Ik1EYBvA59WIpqVPCC0Gco4uw0nURgdawmjYVTSF1E5yrNMKUMKc5
sYsEZToMvAlEIfFayYYiGVv+YxASUpCGF6WQOA1ChDTF/uz9vkd6Duzbfnyc
s/c85z1pzsbSu5EajUb795OlfP8/9Gb116dfIzv9ywlw+1Zy66Hz2C2NvSPZ
L+Jh863b161n42Cjbqaqpy8WzksvvjD+SAffm+iqqwhFwxHhpxZ+1tF5MOQ9
uKK6tm7+sXd4B84st7+cfLcGd2+49kOfX2WrNsh7v2qHzIc9sj589PvfiAio
viP1wRapHzbI/uDLsn9YyQd2S36wki8sQw8v0/t2mt9K6+fS/5+m+qxU/33a
X1T4qYUHKJ+HlF8J5VtgN7kcwcVp1Sl0PpV0fk/pfPclf7PqauoPC/WPgfor
h/rPRf3ppv7l/pahJxvhmrcfBkwf0+EHLd5Cz81jFz5/UnO1zQBvnb+4FFua
Bk98zzj343UqHDiRqlnIT4G/VbT1TVYmw3IfkuA3ZbYS++BJ+FLwZ9agLwr2
xNwos63tIk9d04p/LG4B98Et73FeJpkfQH2yPiz3IRH+KvXBfqkf9sn+4JDs
H1bygeslP1jJF5ZhhJ30voHmF9H62/T/U1TfHNW/QfuLDj+T4CDlc43yG6V8
LafW38/2fMF9aKbzOUPnN0rnuyf5w6vUH37qHx/11yb1n5X6s57610H9LcNo
/gPNv1zi
           
           "]]}, $CellContext`staticpolygons1384086201251114555789622$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAcqB2Cs1atAQAGNL3UAVb0InL8GLM8F528A
83/tx7ACClZA5O1R+VwOMP6//yAg7IAqLwXnr4K4D86Huh8nfzWa+tVo5kH9
A+evQXPPBjT34vDPflQ+Ijyg/jmAKo8Iz1Vo4Q11PwYfAJoRYDs=
           
           "]]}, $CellContext`staticpolygons1484086201251114555791267$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAFPBwht6YDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ApPwf+A==
           
           "]]}, $CellContext`staticpolygons2184086201251114557609625$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxdlEtIVVEUhq+vgSWZGeFAMB80sKcWRGW5MVMzJVMoH0F6KxVJpZdvapBQ
aKLQoMAMCseJZUp45a60RIqIMMqiQSkoaUJIUGZU5v7/A64D1yMf6+zzr2/t
fSLdldmn/Vwul+/iL27x9///5dcao8m7X51zN8ZCTOyxgu6+F+OJ5A0zYTW/
3SHGXfKstuXenMOrK693JtxdbVovNS7caVlwuDl68kD65mDzd+nycd4TEzh4
vLk1yBT3Xi3JnQ5weGr04e0PLgSaFNzJS1EXjefIfZb++ppEvIe8DTmYi7wY
uevRB/k29Mm+ya9NVc1Pf3iYoD1F2XrvmKovtOt7G9T6TTaPt0bl+WO9SJLK
f8r2KxtUv/AiqcpPlK2TMuVzn11X/OCJHF6kTc0LXqRUzRdeZI/aD/Ai1tNQ
Agm8yHp4IocXyYcncniRRngihxehJ3J4EXoiT4efJNzJ4UXoidzfepG9eA95
O3JUIRf5WeSmJ/Is9ElP5IcK4qsKR1566Ik8HB7HVH0evDeo9a9gTjUqzzzO
VbLKfwL7IFb1y3OVpvzAiylTPuHF0BM5vJjbal48V+fUfHmustV+gBdj98+o
ZzmPMS51FT0ZbY9/E20aVx7MyR//7uzD8uqWjKYj0WbHyI+4jh5/57mMW5eL
9tdFGU9OflZBxyqHz2zd+TooOxLfpVCH985u2vKtP8JM5Na19uWFOVxWRLiG
08KNF3fySdQ9wnPk9ru01kzjPeQDyMFc5LuQ+wz6IG9Cn+ybPPD8e29X8HCC
9lRv671uVR9v15dytX6vzSM6jz1vofJV5f9s+5XHql94EVF+emydTCmf8CL+
8ESOHDKg5gUvslvNF17kptoP8CLW01vnuwQvUgtP5BVYfyM8kWciTxc8kcOL
0BM5vAg9kT+Fn37cyeFF6Ik8wHqRL3gP+QhypCMXeTJy0xP5ffRZiL7JU9ZN
vBpq/uShJ/KL8OhW9bHwXqHXx5wyVZ6fOFezKv9H7IMB1S/P1aDyAy9mSvmE
F0NP5PBinqt58VylqPnCi+lW+wFejN0/k55/a7W5fQ==
           
           "]]}, $CellContext`staticpolygons2384086201251114558049314$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmJmBnSgcgBdZPUqEFDAIS6FIQ4BIhjia8DquTDEN4DF
f+3Hbg4mWAFRb49dnMsBXfzffxAQxhCHqJfCEF8F8S+GOASoEC2+Goc5q3HY
CwEiGOJrcPhrA45wwAVW4AjnFTjiBRpuGOIrcMT7KhzpBAIw0xW6OABkrmA6

            "], CompressedData["
1:eJxTTMoPSmViYGCQBmJmBlxA5QC6yOpVIKCAQ1wKQxwCRDDE14DVc2GIbwCL
/9qP00loYAVEvT12cS4HdPF//0FAGEMcol4KQ3wVxL8Y4hCgQrT4ahzmrMZh
LwSIYIivweGvDTjCARdYgSOcV+CIF2i4YYivwBHvq3CkEwjATFcwcQBxAWA6

            "], CompressedData["
1:eJxdk71LQmEUh29lQx/UUERDIGZTRaEEUQi9UEiFQulStqTQljZERDa0NBnR
WBD+C0lgRqh4+kCkJaIIgoZKUPoQGoKa+sD3dxzOhXsvPJz73t95zvtaAkue
hWrDMGz/d40hry4lif/0Zt9+a1WbDRNe3/PnCPPg6rYrMm1VA7kvWzRuqnzn
2tvwj4Y7Vcrrm5qLNlX4W//gdaPHon7LV0uFJ0q9fR9Js8rPhHeOZ9srnOrN
Rna8Q2XwZl5A3RG+Y15VfraqV/yHeRo5OBfzIeReRB/MI+iT+2Zet3yfiTVn
HdLTuq7PBES9Xa9PQbF+QuchmedHe6F3kf9J90snol94IRJ+4rqOisInvJAJ
npgjB6XFvOCFhsV84YV2xX6AF9Ke7hxM4IXW4Il5COv3wBNzN/LE4Ik5vBB7
Yg4vxJ6YX8BPEm/m8ELsiXmt9kIv+A/zHHJMIhfzMeRmT8wP0Oc8+mbubMtf
nW89ptgT8xV4DIj6bngPyfUxJ7fI841zVRL5H7AP0qJfPldnwg+8qKLwCS+K
PTGHF3Up5sXnyinmCy/qUOwHeFF6/xRSfy2XT3Q=
            
            "]}]}, $CellContext`staticpolygons2484086201251114558050801$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIAaxIcDTAUJbwugDaOIHCIg74DAHlzgB82GAoDi6
+YTEiTXfgYC4A373kGo+wfDBZS8hcXRzDuAQR5PHZQ5cHJc5hMx3wKHeAYf5
6OK4zIHTANcrNqc=
           "]]}, $CellContext`ti$$ = 5.4, $CellContext`to$$ = 
        0.6, $CellContext`x0$$ = 0., $CellContext`x1$$ = 
        20., $CellContext`xb$$ = 10., $CellContext`xoff\[Theta]0$$ = 
        1.25, $CellContext`xoff\[Theta]1$$ = 
        1.25, $CellContext`xoff\[Theta]b$$ = 1.25, $CellContext`XS$$ = 
        40., $CellContext`x\[Theta]0$$ = 1.25, $CellContext`x\[Theta]1$$ = 
        21.25, $CellContext`x\[Theta]b$$ = 11.25, $CellContext`y0$$ = 
        0., $CellContext`y1$$ = 0., $CellContext`yb$$ = 
        0., $CellContext`yoff\[Theta]0$$ = 0., $CellContext`yoff\[Theta]1$$ = 
        0., $CellContext`yoff\[Theta]b$$ = 0., $CellContext`y\[Theta]0$$ = 
        0., $CellContext`y\[Theta]1$$ = 0., $CellContext`y\[Theta]b$$ = 
        0., $CellContext`\[Theta]0$$ = 0., $CellContext`\[Theta]1$$ = 
        0., $CellContext`\[Theta]b$$ = 0.}, "ControllerVariables" :> {
        Hold[$CellContext`x0$$, $CellContext`x0$66424$$, 0], 
        Hold[$CellContext`y0$$, $CellContext`y0$66425$$, 0], 
        Hold[$CellContext`\[Theta]0$$, $CellContext`\[Theta]0$66426$$, 0], 
        Hold[$CellContext`ri$$, $CellContext`ri$66427$$, 0], 
        Hold[$CellContext`ro$$, $CellContext`ro$66428$$, 0], 
        Hold[$CellContext`ti$$, $CellContext`ti$66429$$, 0], 
        Hold[$CellContext`to$$, $CellContext`to$66430$$, 0], 
        Hold[$CellContext`x1$$, $CellContext`x1$66431$$, 0], 
        Hold[$CellContext`xb$$, $CellContext`xb$66432$$, 0], 
        Hold[$CellContext`XS$$, $CellContext`XS$66433$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         Row[{
           OpenerView[{"Hastings Triplet Achromat", 
             Show[{
               Graphics[{{
                  Opacity[0.8], 
                  
                  GeometricTransformation[$CellContext`\
staticpolygons1184086201251114555749860$$, 
                   Dynamic[BesselJ[1., 3.]; {{{
                    Cos[Degree $CellContext`\[Theta]b$$], -
                    Sin[Degree $CellContext`\[Theta]b$$]}, {
                    Sin[Degree $CellContext`\[Theta]b$$], 
                    Cos[
                    Degree $CellContext`\[Theta]b$$]}}, {$CellContext`xb$$, \
$CellContext`yb$$}}]], 
                  GeometricTransformation[{
                    AbsoluteThickness[1], 
                    AbsolutePointSize[1], 
                    EdgeForm[], 
                    RGBColor[0.4, 0.6, 0.8], 
                    Polygon[
                    Dynamic[
                    (Map[
                    Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], {{1, 27}, {28, 54}, {55, 
                    81}}]& )[
                    $CellContext`polygons1284086201251114555787525[$\
CellContext`ro$$, $CellContext`ri$$, $CellContext`to$$, \
$CellContext`ti$$]]]]}, 
                   Dynamic[BesselJ[1., 3.]; {{{
                    Cos[Degree $CellContext`\[Theta]1$$], -
                    Sin[Degree $CellContext`\[Theta]1$$]}, {
                    Sin[Degree $CellContext`\[Theta]1$$], 
                    Cos[
                    Degree $CellContext`\[Theta]1$$]}}, {$CellContext`x1$$, \
$CellContext`y1$$}}]], 
                  
                  GeometricTransformation[$CellContext`\
staticpolygons1384086201251114555789622$$, 
                   Dynamic[
                   BesselJ[
                    1., 3.]; {{{1, 0}, {0, 
                    1}}, {$CellContext`XS$$, 
                    0}}]], $CellContext`\
staticpolygons1484086201251114555791267$$, 
                  Opacity[1], 
                  RGBColor[
                  0.038747429704798886`, 0.9161617552424038, 
                   0.039847212269181365`], 
                  AbsoluteThickness[Medium], 
                  Line[
                   Dynamic[
                    Refresh[
                    Map[{
                    Part[#, {1, 2}], 
                    Part[#, {4, 5}]}& , 
                    Select[
                    $CellContext`raytracefunction184086201251114555803588[$\
CellContext`x0$$, $CellContext`y0$$, $CellContext`\[Theta]0$$, \
$CellContext`ri$$, $CellContext`ro$$, $CellContext`ti$$, $CellContext`to$$, \
$CellContext`x1$$, $CellContext`xb$$, $CellContext`XS$$, $CellContext`y1$$, \
$CellContext`yb$$, $CellContext`\[Theta]1$$, $CellContext`\[Theta]b$$], And[
                    Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]], 
                    TrackedSymbols :> {$CellContext`x0$$, $CellContext`y0$$, \
$CellContext`\[Theta]0$$, $CellContext`ri$$, $CellContext`ro$$, \
$CellContext`ti$$, $CellContext`to$$, $CellContext`x1$$, $CellContext`xb$$, \
$CellContext`XS$$, $CellContext`y1$$, $CellContext`yb$$, \
$CellContext`\[Theta]1$$, $CellContext`\[Theta]b$$}], SynchronousUpdating -> 
                    False]], 
                  Arrowheads[Large], 
                  Thickness[Large], 
                  Dashing[{Small, Small}], 
                  RGBColor[1, 1, 0], 
                  Arrow[
                   Dynamic[If[
                    
                    Or[$CellContext`laststartpos\[Theta]0$$ != \
{$CellContext`x0$$, $CellContext`y0$$}, $CellContext`last\[Theta]0$$ =!= \
$CellContext`\[Theta]0$$], $CellContext`laststartpos\[Theta]0$$ = \
{$CellContext`x0$$, $CellContext`y0$$}; $CellContext`last\[Theta]0$$ = \
$CellContext`\[Theta]0$$; {$CellContext`x\[Theta]0$$, \
$CellContext`y\[Theta]0$$} = $CellContext`laststartpos\[Theta]0$$ + \
$CellContext`radius\[Theta]0$$ {
                    Cos[$CellContext`\[Theta]0$$ Degree], 
                    
                    Sin[$CellContext`\[Theta]0$$ 
                    Degree]}]; {$CellContext`laststartpos\[Theta]0$$, \
{$CellContext`x\[Theta]0$$, $CellContext`y\[Theta]0$$}}, \
({$CellContext`laststartpos\[Theta]0$$, {$CellContext`x\[Theta]0$$, \
$CellContext`y\[Theta]0$$}} = #)& ]], 
                  Tooltip[
                   Locator[
                    Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`x\[Theta]0$$, $CellContext`y\[Theta]0$$} != \
$CellContext`lastlocpos\[Theta]0$$, $CellContext`last\[Theta]0$$ != \
$CellContext`\[Theta]0$$], $CellContext`lastlocpos\[Theta]0$$ = \
{$CellContext`x\[Theta]0$$, $CellContext`y\[Theta]0$$}; $CellContext`last\
\[Theta]0$$ = $CellContext`\[Theta]0$$; {$CellContext`x\[Theta]0$$, \
$CellContext`y\[Theta]0$$} = $CellContext`laststartpos\[Theta]0$$ + \
$CellContext`radius\[Theta]0$$ {
                    Cos[$CellContext`\[Theta]0$$ Degree], 
                    Sin[$CellContext`\[Theta]0$$ 
                    Degree]}]; {$CellContext`x\[Theta]0$$, $CellContext`y\
\[Theta]0$$}), ({$CellContext`x\[Theta]0$$, $CellContext`y\[Theta]0$$} = #; \
$CellContext`xoff\[Theta]0$$ = $CellContext`x\[Theta]0$$ - $CellContext`x0$$; \
$CellContext`yoff\[Theta]0$$ = $CellContext`y\[Theta]0$$ - $CellContext`y0$$; \
$CellContext`radius\[Theta]0$$ = 
                    Sqrt[$CellContext`xoff\[Theta]0$$^2 + $CellContext`yoff\
\[Theta]0$$^2]; $CellContext`\[Theta]0$$ = 
                    Chop[ArcTan[$CellContext`xoff\[Theta]0$$, \
$CellContext`yoff\[Theta]0$$]/
                    Degree]; {$CellContext`x\[Theta]0$$, $CellContext`y\
\[Theta]0$$})& ], 
                    Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                   Dynamic[
                    StringJoin["\[Theta]0 = ", 
                    ToString[$CellContext`\[Theta]0$$]]]], 
                  Arrowheads[Large], 
                  Thickness[Large], 
                  Dashing[{Small, Small}], 
                  RGBColor[1, 1, 0], 
                  Arrow[
                   Dynamic[If[
                    
                    Or[$CellContext`laststartpos\[Theta]b$$ != \
{$CellContext`xb$$, $CellContext`yb$$}, $CellContext`last\[Theta]b$$ =!= \
$CellContext`\[Theta]b$$], $CellContext`laststartpos\[Theta]b$$ = \
{$CellContext`xb$$, $CellContext`yb$$}; $CellContext`last\[Theta]b$$ = \
$CellContext`\[Theta]b$$; {$CellContext`x\[Theta]b$$, \
$CellContext`y\[Theta]b$$} = $CellContext`laststartpos\[Theta]b$$ + \
$CellContext`radius\[Theta]b$$ {
                    Cos[$CellContext`\[Theta]b$$ Degree], 
                    
                    Sin[$CellContext`\[Theta]b$$ 
                    Degree]}]; {$CellContext`laststartpos\[Theta]b$$, \
{$CellContext`x\[Theta]b$$, $CellContext`y\[Theta]b$$}}, \
({$CellContext`laststartpos\[Theta]b$$, {$CellContext`x\[Theta]b$$, \
$CellContext`y\[Theta]b$$}} = #)& ]], 
                  Tooltip[
                   Locator[
                    Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`x\[Theta]b$$, $CellContext`y\[Theta]b$$} != \
$CellContext`lastlocpos\[Theta]b$$, $CellContext`last\[Theta]b$$ != \
$CellContext`\[Theta]b$$], $CellContext`lastlocpos\[Theta]b$$ = \
{$CellContext`x\[Theta]b$$, $CellContext`y\[Theta]b$$}; $CellContext`last\
\[Theta]b$$ = $CellContext`\[Theta]b$$; {$CellContext`x\[Theta]b$$, \
$CellContext`y\[Theta]b$$} = $CellContext`laststartpos\[Theta]b$$ + \
$CellContext`radius\[Theta]b$$ {
                    Cos[$CellContext`\[Theta]b$$ Degree], 
                    
                    Sin[$CellContext`\[Theta]b$$ 
                    Degree]}]; {$CellContext`x\[Theta]b$$, $CellContext`y\
\[Theta]b$$}), ({$CellContext`x\[Theta]b$$, $CellContext`y\[Theta]b$$} = #; \
$CellContext`xoff\[Theta]b$$ = $CellContext`x\[Theta]b$$ - $CellContext`xb$$; \
$CellContext`yoff\[Theta]b$$ = $CellContext`y\[Theta]b$$ - $CellContext`yb$$; \
$CellContext`radius\[Theta]b$$ = 
                    Sqrt[$CellContext`xoff\[Theta]b$$^2 + $CellContext`yoff\
\[Theta]b$$^2]; $CellContext`\[Theta]b$$ = 
                    Chop[ArcTan[$CellContext`xoff\[Theta]b$$, \
$CellContext`yoff\[Theta]b$$]/
                    Degree]; {$CellContext`x\[Theta]b$$, $CellContext`y\
\[Theta]b$$})& ], 
                    Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                   Dynamic[
                    StringJoin["\[Theta]b = ", 
                    ToString[$CellContext`\[Theta]b$$]]]], 
                  Arrowheads[Large], 
                  Thickness[Large], 
                  Dashing[{Small, Small}], 
                  RGBColor[1, 1, 0], 
                  Arrow[
                   Dynamic[If[
                    
                    Or[$CellContext`laststartpos\[Theta]1$$ != \
{$CellContext`x1$$, $CellContext`y1$$}, $CellContext`last\[Theta]1$$ =!= \
$CellContext`\[Theta]1$$], $CellContext`laststartpos\[Theta]1$$ = \
{$CellContext`x1$$, $CellContext`y1$$}; $CellContext`last\[Theta]1$$ = \
$CellContext`\[Theta]1$$; {$CellContext`x\[Theta]1$$, \
$CellContext`y\[Theta]1$$} = $CellContext`laststartpos\[Theta]1$$ + \
$CellContext`radius\[Theta]1$$ {
                    Cos[$CellContext`\[Theta]1$$ Degree], 
                    
                    Sin[$CellContext`\[Theta]1$$ 
                    Degree]}]; {$CellContext`laststartpos\[Theta]1$$, \
{$CellContext`x\[Theta]1$$, $CellContext`y\[Theta]1$$}}, \
({$CellContext`laststartpos\[Theta]1$$, {$CellContext`x\[Theta]1$$, \
$CellContext`y\[Theta]1$$}} = #)& ]], 
                  Tooltip[
                   Locator[
                    Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`x\[Theta]1$$, $CellContext`y\[Theta]1$$} != \
$CellContext`lastlocpos\[Theta]1$$, $CellContext`last\[Theta]1$$ != \
$CellContext`\[Theta]1$$], $CellContext`lastlocpos\[Theta]1$$ = \
{$CellContext`x\[Theta]1$$, $CellContext`y\[Theta]1$$}; $CellContext`last\
\[Theta]1$$ = $CellContext`\[Theta]1$$; {$CellContext`x\[Theta]1$$, \
$CellContext`y\[Theta]1$$} = $CellContext`laststartpos\[Theta]1$$ + \
$CellContext`radius\[Theta]1$$ {
                    Cos[$CellContext`\[Theta]1$$ Degree], 
                    
                    Sin[$CellContext`\[Theta]1$$ 
                    Degree]}]; {$CellContext`x\[Theta]1$$, $CellContext`y\
\[Theta]1$$}), ({$CellContext`x\[Theta]1$$, $CellContext`y\[Theta]1$$} = #; \
$CellContext`xoff\[Theta]1$$ = $CellContext`x\[Theta]1$$ - $CellContext`x1$$; \
$CellContext`yoff\[Theta]1$$ = $CellContext`y\[Theta]1$$ - $CellContext`y1$$; \
$CellContext`radius\[Theta]1$$ = 
                    Sqrt[$CellContext`xoff\[Theta]1$$^2 + $CellContext`yoff\
\[Theta]1$$^2]; $CellContext`\[Theta]1$$ = 
                    Chop[ArcTan[$CellContext`xoff\[Theta]1$$, \
$CellContext`yoff\[Theta]1$$]/
                    Degree]; {$CellContext`x\[Theta]1$$, $CellContext`y\
\[Theta]1$$})& ], 
                    Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                   Dynamic[
                    StringJoin["\[Theta]1 = ", 
                    ToString[$CellContext`\[Theta]1$$]]]], 
                  Tooltip[
                   Locator[
                    Dynamic[
                    BesselJ[
                    1., 3.]; {$CellContext`x0$$, $CellContext`y0$$}, \
({$CellContext`x0$$, $CellContext`y0$$} = Chop[#])& ], 
                    Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                   Dynamic[
                    StringJoin["{x0, y0} = ", 
                    ToString[
                    Chop[{$CellContext`x0$$, $CellContext`y0$$}]]]]], 
                  Tooltip[
                   Locator[
                    Dynamic[
                    BesselJ[
                    1., 3.]; {$CellContext`xb$$, $CellContext`yb$$}, \
({$CellContext`xb$$, $CellContext`yb$$} = Chop[#])& ], 
                    Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                   Dynamic[
                    StringJoin["{xb, yb} = ", 
                    ToString[
                    Chop[{$CellContext`xb$$, $CellContext`yb$$}]]]]], 
                  Tooltip[
                   Locator[
                    Dynamic[
                    BesselJ[
                    1., 3.]; {$CellContext`x1$$, $CellContext`y1$$}, \
({$CellContext`x1$$, $CellContext`y1$$} = Chop[#])& ], 
                    Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                   Dynamic[
                    StringJoin["{x1, y1} = ", 
                    ToString[
                    Chop[{$CellContext`x1$$, $CellContext`y1$$}]]]]], 
                  Tooltip[
                   Locator[
                    Dynamic[
                    BesselJ[
                    1., 3.]; {$CellContext`XS$$, 0}, ($CellContext`XS$$ = Chop[
                    Part[#, 1]])& ], 
                    Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                   Dynamic[
                    StringJoin["XS = ", 
                    ToString[$CellContext`XS$$]]]]}}]}, {
              PlotLabel -> "Hastings Triplet Achromat", Axes -> True, 
               ImageSize -> 800, AspectRatio -> Automatic}]}, True], 
           OpenerView[{"Hastings Triplet Achromat", 
             Show[{
               Graphics3D[{{
                  Opacity[1], 
                  Dynamic[
                   
                   GeometricTransformation[$CellContext`\
staticpolygons2184086201251114557609625$$, {{{
                    Cos[Degree $CellContext`\[Theta]b$$], -
                    Sin[Degree $CellContext`\[Theta]b$$], 0}, {
                    Sin[Degree $CellContext`\[Theta]b$$], 
                    Cos[Degree $CellContext`\[Theta]b$$], 0}, {0, 0, 
                    1}}, {$CellContext`xb$$, $CellContext`yb$$, 0}}]], 
                  Dynamic[{
                    AbsoluteThickness[1], 
                    AbsolutePointSize[1], 
                    EdgeForm[], 
                    RGBColor[0.4, 0.6, 0.8], 
                    Polygon[
                    (Map[
                    Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], CompressedData["
1:eJwl0b0rJgAAwOGXUF51FArF5aO44gp1FArlI5SPuDrqXD6KG7wDAwMDAwMD
AwMDAwMDAwMDAwMDAwPD3XAGBgY3MDDwyPD0+wN+6V2hloHwQCBQy3vDiCSK
IDHEEkcCiSSTQhqfySSLHL6Qx1cKKKSIYkopo4JKqqmhngaaaKaN77TTQSe/
6KGXfn4zQIhBhhhmhFHGGGeCSaaYZoZZ5phngUWWWGaFVdZYZ4NNtthmh132
2OeAQ4445oRTzjjngkuu+MNf/nHNDbfccc8D/3nkiWdeeA18jIkgkmiCfCKW
eBJIIplU0sggk2xyyCWPfAr4RhEllFJOBVVUU0c9jTTRShs/aOcnnXTTQx9v
mqQ9sQ==
                    "]]& )[
                    $CellContext`polygons2284086201251114558005575[$\
CellContext`\[Theta]1$$, $CellContext`x1$$, $CellContext`y1$$, \
$CellContext`ro$$, $CellContext`ri$$, $CellContext`to$$, $CellContext`ti$$]]], 
                    GrayLevel[0], 
                    AbsoluteThickness[0.5], 
                    Line[
                    (Map[
                    Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], CompressedData["
1:eJwl02loDgAABuBvzpgc2eSeM0dMRhs5YrLJkW3Z5Ihhkw2bmEKhUKZQKBTK
kSNHTDbZ5MiRTY5sssnIiMkmm5iMeL78eHp/v/W+vRdnJ2U1CQQC+wlmCN3o
TjQxJJLEClaynVyOc4LTnOE8F8jjMgVcpYjr3OI297hPCQ95wlPKeE4FL3nN
G97xnmo+UcsX6vlGAz/5zZ9gByWa0IKWhNKG9nQgnE50pRsR9KIf/RnEYCIZ
xghGMorRjGM8sUwinilMZwaJJJHCbOYxn1QWkc5SMllONqvIYS3r2cAmNrOV
beSyg13sZi/7OMBBDnOEYxznFKc5x3kukUc+BRRSxE1ucZd7FFPCY55QShnl
VFDJa6p4x0eqqaGWOur5QQON/A75P7AQmtOC1oTSjvaEEU4XutKTCPrSj4EM
YiiRRDGCGEYxlnFMJJY44pnGdBJIJJkU5jKPhaSSRjoZZBI8RjZryGEd69nI
Jrawle3kspNd7GEv+znAIQ5zlGOc5BRnOcdFLnGFfK5RyA1ucoe7PKCYRzzm
GaW8oJxXVPKWKj7wkc/U8JU6vvODXzTyN3j8poFAM5rTita0pR0dCaMzXehB
T/rQlwEMZAhDGU4U0cQwhrFMYCKTiWMq05hJArNIZg5zWcBClpDGMjJYSRar
+Qfgo5Wt
                    "]]& )[
                    $CellContext`lines2284086201251114558016518[$CellContext`\
\[Theta]1$$, $CellContext`x1$$, $CellContext`y1$$, $CellContext`ro$$, \
$CellContext`ri$$, $CellContext`to$$, $CellContext`ti$$]]]}], 
                  Dynamic[
                   
                   GeometricTransformation[$CellContext`\
staticpolygons2384086201251114558049314$$, {{{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}, {$CellContext`XS$$, 0, 
                    0}}]], $CellContext`\
staticpolygons2484086201251114558050801$$, 
                  Opacity[1], 
                  RGBColor[
                  0.038747429704798886`, 0.9161617552424038, 
                   0.039847212269181365`], 
                  AbsoluteThickness[Medium], 
                  Line[
                   Dynamic[
                    Refresh[
                    Map[{
                    Part[#, {1, 2, 3}], 
                    Part[#, {4, 5, 6}]}& , 
                    Select[
                    $CellContext`raytracefunction284086201251114558088881[$\
CellContext`x0$$, $CellContext`y0$$, $CellContext`\[Theta]0$$, \
$CellContext`ri$$, $CellContext`ro$$, $CellContext`ti$$, $CellContext`to$$, \
$CellContext`x1$$, $CellContext`xb$$, $CellContext`XS$$, $CellContext`y1$$, \
$CellContext`yb$$, $CellContext`\[Theta]1$$, $CellContext`\[Theta]b$$], And[
                    Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]], 
                    TrackedSymbols :> {$CellContext`x0$$, $CellContext`y0$$, \
$CellContext`\[Theta]0$$, $CellContext`ri$$, $CellContext`ro$$, \
$CellContext`ti$$, $CellContext`to$$, $CellContext`x1$$, $CellContext`xb$$, \
$CellContext`XS$$, $CellContext`y1$$, $CellContext`yb$$, \
$CellContext`\[Theta]1$$, $CellContext`\[Theta]b$$}], SynchronousUpdating -> 
                    False]]}}]}, {
              PlotLabel -> "Hastings Triplet Achromat", ImageSize -> 400, 
               Axes -> True, ImageSize -> 800, AspectRatio -> Automatic}]}, 
            True]}], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`x0$$, 0.}, -10, 10, ControlType -> 
         None}, {{$CellContext`y0$$, 0.}, -10, 10, ControlType -> 
         None}, {{$CellContext`\[Theta]0$$, 0.}, -180., 180., ControlType -> 
         None}, {{$CellContext`ri$$, 6.}, 0.06, 12, ControlType -> 
         None}, {{$CellContext`ro$$, 9.}, 0.09, 18, ControlType -> 
         None}, {{$CellContext`ti$$, 5.4}, 0.054, 11, ControlType -> 
         None}, {{$CellContext`to$$, 0.6}, 0.1, 0.8999999999999999, 
         ControlType -> None}, {{$CellContext`x1$$, 20.}, 0.2, 40, 
         ControlType -> None}, {{$CellContext`xb$$, 10.}, 0.1, 20, 
         ControlType -> None}, {{$CellContext`XS$$, 40.}, 0.4, 80, 
         ControlType -> None}, {{$CellContext`y1$$, 0.}, -10, 10, ControlType -> 
         None}, {{$CellContext`yb$$, 0.}, -10, 10, ControlType -> 
         None}, {{$CellContext`\[Theta]1$$, 0.}, -180., 180., ControlType -> 
         None}, {{$CellContext`\[Theta]b$$, 0.}, -180., 180., ControlType -> 
         None}, 
        Style[
         Grid[{{"ri", 
            InputField[
             Dynamic[$CellContext`minri$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567223; $CellContext`ri$$, \
($CellContext`ri$$ = #)& ], {
              Dynamic[$CellContext`minri$$], 
              Dynamic[$CellContext`maxri$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxri$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567223; $CellContext`ri$$, \
($CellContext`ri$$ = #)& ]}}]], {{$CellContext`minri$$, 0.06}, ControlType -> 
         None}, {{$CellContext`maxri$$, 12}, ControlType -> None}, 
        Style[
         Grid[{{"ro", 
            InputField[
             Dynamic[$CellContext`minro$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567441; $CellContext`ro$$, \
($CellContext`ro$$ = #)& ], {
              Dynamic[$CellContext`minro$$], 
              Dynamic[$CellContext`maxro$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxro$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567441; $CellContext`ro$$, \
($CellContext`ro$$ = #)& ]}}]], {{$CellContext`minro$$, 0.09}, ControlType -> 
         None}, {{$CellContext`maxro$$, 18}, ControlType -> None}, 
        Style[
         Grid[{{"ti", 
            InputField[
             Dynamic[$CellContext`minti$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567616; $CellContext`ti$$, \
($CellContext`ti$$ = #)& ], {
              Dynamic[$CellContext`minti$$], 
              Dynamic[$CellContext`maxti$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxti$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567616; $CellContext`ti$$, \
($CellContext`ti$$ = #)& ]}}]], {{$CellContext`minti$$, 0.054}, ControlType -> 
         None}, {{$CellContext`maxti$$, 11}, ControlType -> None}, 
        Style[
         Grid[{{"to", 
            InputField[
             Dynamic[$CellContext`minto$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567795; $CellContext`to$$, \
($CellContext`to$$ = #)& ], {
              Dynamic[$CellContext`minto$$], 
              Dynamic[$CellContext`maxto$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxto$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable159384086201251114559567795; $CellContext`to$$, \
($CellContext`to$$ = #)& ]}}]], {{$CellContext`minto$$, 0.1}, ControlType -> 
         None}, {{$CellContext`maxto$$, 0.8999999999999999}, ControlType -> 
         None}, {{$CellContext`minx0$$, -10}, ControlType -> 
         None}, {{$CellContext`maxx0$$, 10}, ControlType -> 
         None}, {{$CellContext`miny0$$, -10}, ControlType -> 
         None}, {{$CellContext`maxy0$$, 10}, ControlType -> 
         None}, {{$CellContext`min\[Theta]0$$, -180.}, ControlType -> 
         None}, {{$CellContext`max\[Theta]0$$, 180.}, ControlType -> 
         None}, {{$CellContext`minx1$$, 0.2}, ControlType -> 
         None}, {{$CellContext`maxx1$$, 40}, ControlType -> 
         None}, {{$CellContext`minxb$$, 0.1}, ControlType -> 
         None}, {{$CellContext`maxxb$$, 20}, ControlType -> 
         None}, {{$CellContext`minXS$$, 0.4}, ControlType -> 
         None}, {{$CellContext`maxXS$$, 80}, ControlType -> 
         None}, {{$CellContext`miny1$$, -10}, ControlType -> 
         None}, {{$CellContext`maxy1$$, 10}, ControlType -> 
         None}, {{$CellContext`minyb$$, -10}, ControlType -> 
         None}, {{$CellContext`maxyb$$, 10}, ControlType -> 
         None}, {{$CellContext`min\[Theta]1$$, -180.}, ControlType -> 
         None}, {{$CellContext`max\[Theta]1$$, 180.}, ControlType -> 
         None}, {{$CellContext`min\[Theta]b$$, -180.}, ControlType -> 
         None}, {{$CellContext`max\[Theta]b$$, 180.}, ControlType -> 
         None}, {{$CellContext`minri$$, 0.06}, ControlType -> 
         None}, {{$CellContext`maxri$$, 12}, ControlType -> 
         None}, {{$CellContext`minro$$, 0.09}, ControlType -> 
         None}, {{$CellContext`maxro$$, 18}, ControlType -> 
         None}, {{$CellContext`minti$$, 0.054}, ControlType -> 
         None}, {{$CellContext`maxti$$, 11}, ControlType -> 
         None}, {{$CellContext`minto$$, 0.1}, ControlType -> 
         None}, {{$CellContext`maxto$$, 0.8999999999999999}, ControlType -> 
         None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{
               "ri", "ro", "ti", "to", "x0", "x1", "xb", "XS", "y0", "y1", 
                "yb", "\[Theta]0", "\[Theta]1", 
                "\[Theta]b"}, {$CellContext`ri$$, $CellContext`ro$$, \
$CellContext`ti$$, $CellContext`to$$, $CellContext`x0$$, $CellContext`x1$$, \
$CellContext`xb$$, $CellContext`XS$$, $CellContext`y0$$, $CellContext`y1$$, \
$CellContext`yb$$, $CellContext`\[Theta]0$$, $CellContext`\[Theta]1$$, \
$CellContext`\[Theta]b$$}}], 
            Optica`Optica`SymbolicRanges -> {$CellContext`x0$$ -> {-10, 
               10}, $CellContext`y0$$ -> {-10, 
               10}, $CellContext`\[Theta]0$$ -> {-180., 
               180.}, $CellContext`ri$$ -> {0.06, 12}, $CellContext`ro$$ -> {
               0.09, 18}, $CellContext`ti$$ -> {
               0.054, 11}, $CellContext`to$$ -> {0.1, 
               0.8999999999999999}, $CellContext`x1$$ -> {
               0.2, 40}, $CellContext`xb$$ -> {
               0.1, 20}, $CellContext`XS$$ -> {
               0.4, 80}, $CellContext`y1$$ -> {-10, 
               10}, $CellContext`yb$$ -> {-10, 
               10}, $CellContext`\[Theta]1$$ -> {-180., 
               180.}, $CellContext`\[Theta]b$$ -> {-180., 180.}}}; 
         Optica`Optica`$OpticalSystemScript = 
          "{Move[LineOfRays[10, NumberOfRays -> 6], {{x0, 0}, {y0, 0}}, {\
\[Theta]0, 0.}, SymbolicValues -> {\[Theta]0 -> 0, x0 -> 0, y0 -> 0}], \
Move[BaffleWithHole[20, 9], {{xb, 10.}, {yb, 0}}, {\[Theta]b, 0.}, \
SymbolicValues -> {\[Theta]b -> 0, xb -> 10, yb -> 0}], Move[LensTriplet[{ro, \
9.}, {ri, 6.}, {-ri, -6.}, {-ro, -9.}, 8.5, {to, 0.6}, {ti, 5.4}, {to, 0.6}, \
SF5, BK7, SF5, {SymbolicValues -> {\[Theta]1 -> 0, x1 -> 20, y1 -> 0, ro -> \
9, ri -> 6, to -> 0.6, ti -> 5.4}}], {{x1, 20.}, {y1, 0}}, {\[Theta]1, 0.}, \
SymbolicValues -> {\[Theta]1 -> 0, x1 -> 20, y1 -> 0}], Move[Screen[20], {XS, \
40.}, SymbolicValues -> {XS -> 40}], Boundary[{0, -25, -25}, {50, 25, 25}]}"; 
         Print[
           InputForm[
            StringJoin["SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "ri", "ro", "ti", "to", "x0", "x1", "xb", "XS", "y0", "y1", 
                 "yb", "\[Theta]0", "\[Theta]1", 
                 "\[Theta]b"}, {$CellContext`ri$$, $CellContext`ro$$, \
$CellContext`ti$$, $CellContext`to$$, $CellContext`x0$$, $CellContext`x1$$, \
$CellContext`xb$$, $CellContext`XS$$, $CellContext`y0$$, $CellContext`y1$$, \
$CellContext`yb$$, $CellContext`\[Theta]0$$, $CellContext`\[Theta]1$$, \
$CellContext`\[Theta]b$$}}]]]]], ImageSize -> 
         Automatic], {{$CellContext`x\[Theta]0$$, 1.25}, ControlType -> 
         None}, {{$CellContext`y\[Theta]0$$, 0.}, ControlType -> 
         None}, {{$CellContext`radius\[Theta]0$$, 1.25}, ControlType -> 
         None}, {{$CellContext`xoff\[Theta]0$$, 1.25}, ControlType -> 
         None}, {{$CellContext`yoff\[Theta]0$$, 0.}, ControlType -> 
         None}, {{$CellContext`laststartpos\[Theta]0$$, {0., 0.}}, 
         ControlType -> 
         None}, {{$CellContext`lastlocpos\[Theta]0$$, {1.25, 0.}}, 
         ControlType -> None}, {{$CellContext`last\[Theta]0$$, 0}, 
         ControlType -> None}, {{$CellContext`x\[Theta]b$$, 11.25}, 
         ControlType -> None}, {{$CellContext`y\[Theta]b$$, 0.}, ControlType -> 
         None}, {{$CellContext`radius\[Theta]b$$, 1.25}, ControlType -> 
         None}, {{$CellContext`xoff\[Theta]b$$, 1.25}, ControlType -> 
         None}, {{$CellContext`yoff\[Theta]b$$, 0.}, ControlType -> 
         None}, {{$CellContext`laststartpos\[Theta]b$$, {10., 0.}}, 
         ControlType -> 
         None}, {{$CellContext`lastlocpos\[Theta]b$$, {11.25, 0.}}, 
         ControlType -> None}, {{$CellContext`last\[Theta]b$$, 0}, 
         ControlType -> None}, {{$CellContext`x\[Theta]1$$, 21.25}, 
         ControlType -> None}, {{$CellContext`y\[Theta]1$$, 0.}, ControlType -> 
         None}, {{$CellContext`radius\[Theta]1$$, 1.25}, ControlType -> 
         None}, {{$CellContext`xoff\[Theta]1$$, 1.25}, ControlType -> 
         None}, {{$CellContext`yoff\[Theta]1$$, 0.}, ControlType -> 
         None}, {{$CellContext`laststartpos\[Theta]1$$, {20., 0.}}, 
         ControlType -> 
         None}, {{$CellContext`lastlocpos\[Theta]1$$, {21.25, 0.}}, 
         ControlType -> None}, {{$CellContext`last\[Theta]1$$, 0}, 
         ControlType -> 
         None}, {{$CellContext`staticpolygons1184086201251114555749860$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxd019Ik1EYBvA59WIpqVPCC0Gco4uw0nURgdawmjYVTSF1E5yrNMKUMKc5
sYsEZToMvAlEIfFayYYiGVv+YxASUpCGF6WQOA1ChDTF/uz9vkd6Duzbfnyc
s/c85z1pzsbSu5EajUb795OlfP8/9Gb116dfIzv9ywlw+1Zy66Hz2C2NvSPZ
L+Jh863b161n42Cjbqaqpy8WzksvvjD+SAffm+iqqwhFwxHhpxZ+1tF5MOQ9
uKK6tm7+sXd4B84st7+cfLcGd2+49kOfX2WrNsh7v2qHzIc9sj589PvfiAio
viP1wRapHzbI/uDLsn9YyQd2S36wki8sQw8v0/t2mt9K6+fS/5+m+qxU/33a
X1T4qYUHKJ+HlF8J5VtgN7kcwcVp1Sl0PpV0fk/pfPclf7PqauoPC/WPgfor
h/rPRf3ppv7l/pahJxvhmrcfBkwf0+EHLd5Cz81jFz5/UnO1zQBvnb+4FFua
Bk98zzj343UqHDiRqlnIT4G/VbT1TVYmw3IfkuA3ZbYS++BJ+FLwZ9agLwr2
xNwos63tIk9d04p/LG4B98Et73FeJpkfQH2yPiz3IRH+KvXBfqkf9sn+4JDs
H1bygeslP1jJF5ZhhJ30voHmF9H62/T/U1TfHNW/QfuLDj+T4CDlc43yG6V8
LafW38/2fMF9aKbzOUPnN0rnuyf5w6vUH37qHx/11yb1n5X6s57610H9LcNo
/gPNv1zi
            "]]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons1384086201251114555789622$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAcqB2Cs1atAQAGNL3UAVb0InL8GLM8F528A
83/tx7ACClZA5O1R+VwOMP6//yAg7IAqLwXnr4K4D86Huh8nfzWa+tVo5kH9
A+evQXPPBjT34vDPflQ+Ijyg/jmAKo8Iz1Vo4Q11PwYfAJoRYDs=
            "]]}}, 
         ControlType -> 
         None}, {{$CellContext`staticpolygons1484086201251114555791267$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAFPBwht6YDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ApPwf+A==
            "]]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons2184086201251114557609625$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxdlEtIVVEUhq+vgSWZGeFAMB80sKcWRGW5MVMzJVMoH0F6KxVJpZdvapBQ
aKLQoMAMCseJZUp45a60RIqIMMqiQSkoaUJIUGZU5v7/A64D1yMf6+zzr2/t
fSLdldmn/Vwul+/iL27x9///5dcao8m7X51zN8ZCTOyxgu6+F+OJ5A0zYTW/
3SHGXfKstuXenMOrK693JtxdbVovNS7caVlwuDl68kD65mDzd+nycd4TEzh4
vLk1yBT3Xi3JnQ5weGr04e0PLgSaFNzJS1EXjefIfZb++ppEvIe8DTmYi7wY
uevRB/k29Mm+ya9NVc1Pf3iYoD1F2XrvmKovtOt7G9T6TTaPt0bl+WO9SJLK
f8r2KxtUv/AiqcpPlK2TMuVzn11X/OCJHF6kTc0LXqRUzRdeZI/aD/Ai1tNQ
Agm8yHp4IocXyYcncniRRngihxehJ3J4EXoiT4efJNzJ4UXoidzfepG9eA95
O3JUIRf5WeSmJ/Is9ElP5IcK4qsKR1566Ik8HB7HVH0evDeo9a9gTjUqzzzO
VbLKfwL7IFb1y3OVpvzAiylTPuHF0BM5vJjbal48V+fUfHmustV+gBdj98+o
ZzmPMS51FT0ZbY9/E20aVx7MyR//7uzD8uqWjKYj0WbHyI+4jh5/57mMW5eL
9tdFGU9OflZBxyqHz2zd+TooOxLfpVCH985u2vKtP8JM5Na19uWFOVxWRLiG
08KNF3fySdQ9wnPk9ru01kzjPeQDyMFc5LuQ+wz6IG9Cn+ybPPD8e29X8HCC
9lRv671uVR9v15dytX6vzSM6jz1vofJV5f9s+5XHql94EVF+emydTCmf8CL+
8ESOHDKg5gUvslvNF17kptoP8CLW01vnuwQvUgtP5BVYfyM8kWciTxc8kcOL
0BM5vAg9kT+Fn37cyeFF6Ik8wHqRL3gP+QhypCMXeTJy0xP5ffRZiL7JU9ZN
vBpq/uShJ/KL8OhW9bHwXqHXx5wyVZ6fOFezKv9H7IMB1S/P1aDyAy9mSvmE
F0NP5PBinqt58VylqPnCi+lW+wFejN0/k55/a7W5fQ==
            "]]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons2384086201251114558049314$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmJmBnSgcgBdZPUqEFDAIS6FIQ4BIhjia8DquTDEN4DF
f+3Hbg4mWAFRb49dnMsBXfzffxAQxhCHqJfCEF8F8S+GOASoEC2+Goc5q3HY
CwEiGOJrcPhrA45wwAVW4AjnFTjiBRpuGOIrcMT7KhzpBAIw0xW6OABkrmA6

             "], CompressedData["
1:eJxTTMoPSmViYGCQBmJmBlxA5QC6yOpVIKCAQ1wKQxwCRDDE14DVc2GIbwCL
/9qP00loYAVEvT12cS4HdPF//0FAGEMcol4KQ3wVxL8Y4hCgQrT4ahzmrMZh
LwSIYIivweGvDTjCARdYgSOcV+CIF2i4YYivwBHvq3CkEwjATFcwcQBxAWA6

             "], CompressedData["
1:eJxdk71LQmEUh29lQx/UUERDIGZTRaEEUQi9UEiFQulStqTQljZERDa0NBnR
WBD+C0lgRqh4+kCkJaIIgoZKUPoQGoKa+sD3dxzOhXsvPJz73t95zvtaAkue
hWrDMGz/d40hry4lif/0Zt9+a1WbDRNe3/PnCPPg6rYrMm1VA7kvWzRuqnzn
2tvwj4Y7Vcrrm5qLNlX4W//gdaPHon7LV0uFJ0q9fR9Js8rPhHeOZ9srnOrN
Rna8Q2XwZl5A3RG+Y15VfraqV/yHeRo5OBfzIeReRB/MI+iT+2Zet3yfiTVn
HdLTuq7PBES9Xa9PQbF+QuchmedHe6F3kf9J90snol94IRJ+4rqOisInvJAJ
npgjB6XFvOCFhsV84YV2xX6AF9Ke7hxM4IXW4Il5COv3wBNzN/LE4Ik5vBB7
Yg4vxJ6YX8BPEm/m8ELsiXmt9kIv+A/zHHJMIhfzMeRmT8wP0Oc8+mbubMtf
nW89ptgT8xV4DIj6bngPyfUxJ7fI841zVRL5H7AP0qJfPldnwg+8qKLwCS+K
PTGHF3Up5sXnyinmCy/qUOwHeFF6/xRSfy2XT3Q=
             "]}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons2484086201251114558050801$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIAaxIcDTAUJbwugDaOIHCIg74DAHlzgB82GAoDi6
+YTEiTXfgYC4A373kGo+wfDBZS8hcXRzDuAQR5PHZQ5cHJc5hMx3wKHeAYf5
6OK4zIHTANcrNqc=
            "]]}}, ControlType -> None}}, 
      "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 
        SynchronousInitialization -> False, SynchronousUpdating -> False, 
        BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{858., {765., 771.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`raytracefunction184086201251114555803588 = 
       Compile[{{$CellContext`x0$$, 
           Blank[Real]}, {$CellContext`y0$$, 
           Blank[Real]}, {$CellContext`\[Theta]0$$, 
           Blank[Real]}, {$CellContext`ri$$, 
           Blank[Real]}, {$CellContext`ro$$, 
           Blank[Real]}, {$CellContext`ti$$, 
           Blank[Real]}, {$CellContext`to$$, 
           Blank[Real]}, {$CellContext`x1$$, 
           Blank[Real]}, {$CellContext`xb$$, 
           Blank[Real]}, {$CellContext`XS$$, 
           Blank[Real]}, {$CellContext`y1$$, 
           Blank[Real]}, {$CellContext`yb$$, 
           Blank[Real]}, {$CellContext`\[Theta]1$$, 
           Blank[Real]}, {$CellContext`\[Theta]b$$, 
           Blank[Real]}}, 
         Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
           Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`activeregion$ = 
           1.; $CellContext`allcreatedamplitudes$ = {{
             0. + 0. I, 0. + 0. I, 0. + 
              0. I}}; $CellContext`allcreatedrays$ = {{
            1.}}; $CellContext`allowzeroraylength$ = 
           True; $CellContext`alternateindex$ = 
           1.; $CellContext`amplitude$ = {
            1. + 0. I, 0. + 0. I, 0. + 0. I}; $CellContext`axismagnitude$ = 
           1.; $CellContext`axismatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}; $CellContext`clonedata$ = {{
            1.}}; $CellContext`clonegenerationnumber$ = 
           1.; $CellContext`cloneinput$ = {1.}; $CellContext`clonenumber$ = 
           1; $CellContext`cloneposition$ = {0., 0., 
            0.}; $CellContext`clonereportedrays$ = {{
            1.}}; $CellContext`clonerotation$ = {{
            1.}}; $CellContext`clonescale$ = 
           1.; $CellContext`clonescalevector$ = {
            1.}; $CellContext`clonesorthistogram$ = {
            1}; $CellContext`clonetraceinput$ = {{
            1.}}; $CellContext`clonetraceoutput$ = {{
            1.}}; $CellContext`closestdistances$ = {
            1.}; $CellContext`closestposition$ = 
           0; $CellContext`closestpositions$ = {
            0}; $CellContext`closestraylength$ = 
           1.; $CellContext`completedray$ = {
            1.}; $CellContext`componentnumber$ = -1.; $CellContext`cosangle$ = 
           1.; $CellContext`crossmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}; $CellContext`deflecteddummyrayspresent$ = 
           False; $CellContext`deflectedlocalrays$ = {{
            1.}}; $CellContext`deflectedrays$ = {{
            1.}}; $CellContext`deflectedrayspresent$ = 
           False; $CellContext`dummymatrix$ = {{
            1.}}; $CellContext`dummymatrixlist$ = {{{
            1.}}}; $CellContext`dummyvector$ = {1.}; $CellContext`frontid$ = 
           1.; $CellContext`generationlimit$ = 
           200.; $CellContext`generationnumber$ = 
           1.; $CellContext`holeintersections$ = {{-1., 0., 
            0.}}; $CellContext`holeQ$ = 
           False; $CellContext`holeQlist$ = {0}; $CellContext`hor$ = 
           1. + 0. I; $CellContext`index$ = 1.; $CellContext`index1$ = 
           1.; $CellContext`index2$ = 
           1.; $CellContext`inrays$ = {{1.}}; $CellContext`intensity$ = 
           1.; $CellContext`intensityscale$ = 
           1.; $CellContext`intersectionnumber$ = 
           1.; $CellContext`intersections$ = {{-1., 0., 
            0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
            0.}}}; $CellContext`intersectionspresent$ = 
           False; $CellContext`localdummyoutrayspresent$ = 
           False; $CellContext`localoutrays$ = {{
            1.}}; $CellContext`localoutrayspresent$ = 
           False; $CellContext`magnitude$ = 
           1.; $CellContext`maxclonegenerationnumber$ = 
           1.; $CellContext`maximumposition$ = 
           1; $CellContext`minimumraylength$ = 
           0.0001; $CellContext`minresonateraylength$ = 1.; $CellContext`n12$ = 
           1.; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newdeflectedrays$ = {{1.}}; $CellContext`newdistance$ = 
           1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`nonintersectingrays$ = {{
            1.}}; $CellContext`normalizedpolarization$ = {1., 
            1.}; $CellContext`oldgenerationnumber$ = 
           1.; $CellContext`opticallength$ = 
           1.; $CellContext`originalray$ = {
            1.}; $CellContext`originalraytilt$ = {
            1.}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 1., 
            0.}, {0., 0., 1.}}; $CellContext`originalsurfnorm$ = {{
            1.}}; $CellContext`outrays$ = {{
            1.}}; $CellContext`parallelamplitude$ = 
           1. + 0. I; $CellContext`PAxis$ = {1., 0., 
            0.}; $CellContext`perpendicularamplitude$ = 
           1. + 0. I; $CellContext`phaseshift$ = 0.; $CellContext`pol1$ = 
           1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
           1.; $CellContext`previoustilt$ = {1., 0., 
            0.}; $CellContext`propagate$ = 
           True; $CellContext`propagatedrays$ = {{1.}}; $CellContext`r1$ = 
           1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 1.; $CellContext`r4$ = 
           1.; $CellContext`r5$ = 1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
           1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
           1.; $CellContext`ray1$ = 1.; $CellContext`ray2$ = 
           1.; $CellContext`ray3$ = 1.; $CellContext`LocRayL$ = 
           1.; $CellContext`rayslot$ = 1.; $CellContext`raysreported$ = 
           False; $CellContext`raytiltx$ = 1.; $CellContext`raytiltz$ = 
           1.; $CellContext`reporteddummyrayspresent$ = 
           False; $CellContext`reportedlocalrays$ = {{
            1.}}; $CellContext`reportedrays$ = {{
            1.}}; $CellContext`reportedrayspresent$ = 
           False; $CellContext`resonateintersections$ = {{-1., 0., 
            0.}}; $CellContext`resonatenumber$ = 
           0; $CellContext`resonateraylength$ = 1.; $CellContext`rex$ = 
           1.; $CellContext`rey$ = 1.; $CellContext`rez$ = 
           1.; $CellContext`rsx$ = 1.; $CellContext`LocRSx$ = 
           1.; $CellContext`rsy$ = 1.; $CellContext`LocRSy$ = 
           1.; $CellContext`rsz$ = 1.; $CellContext`LocRSz$ = 1.; 
          Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
           1.; $CellContext`LocRTz$ = 1.; $CellContext`rx$ = 
           1.; $CellContext`rxhlp$ = 1.; $CellContext`ry$ = 
           1.; $CellContext`ryhlp$ = 1.; $CellContext`rz$ = 
           1.; $CellContext`rzhlp$ = 1.; $CellContext`LocSCx$ = 
           1.; $CellContext`LocSCy$ = 1.; $CellContext`sid$ = 
           1.; $CellContext`sinangle$ = 1.; $CellContext`sno1$ = 
           1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
           1.; $CellContext`sno4$ = 
           1.; $CellContext`surfaceid$ = -1.; $CellContext`surfacenumber$ = \
-1.; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}; $CellContext`surfacetranslationvector$ = {0., 0., 
            0.}; $CellContext`surfnorm$ = {{1.}}; $CellContext`symr1$ = 
           1.; $CellContext`symr2$ = 1.; $CellContext`symr3$ = 
           1.; $CellContext`symr4$ = 1.; $CellContext`symr5$ = 
           1.; $CellContext`symr6$ = 1.; $CellContext`symr7$ = 
           1.; $CellContext`symr8$ = 1.; $CellContext`symr9$ = 
           1.; $CellContext`tempclonedata$ = {{
            1.}}; $CellContext`terminatedeflection$ = 
           False; $CellContext`thresholdintensity$ = 
           1.; $CellContext`tiltmagnitude$ = 
           1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}}; $CellContext`LocTV1$ = 1.; $CellContext`LocTV10$ = 
           1.; $CellContext`LocTV2$ = 1.; $CellContext`LocTV3$ = 
           1.; $CellContext`LocTV4$ = 1.; $CellContext`LocTV5$ = 
           1.; $CellContext`LocTV6$ = 1.; $CellContext`LocTV7$ = 
           1.; $CellContext`LocTV8$ = 1.; $CellContext`LocTV9$ = 
           1.; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
            0.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`ver$ = 0. + 0. I; $CellContext`wavelength$ = 
           1.; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`xunit$ = 
           1.; $CellContext`YAxis$ = {1., 0., 0.}; $CellContext`yunit$ = 
           1.; $CellContext`ZAxis$ = {1., 0., 0.}; $CellContext`zunit$ = 
           1.; $CellContext`propagatedrays$ = 
           Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                 Cos[Degree $CellContext`\[Theta]0$$], 
                 Sin[Degree $CellContext`\[Theta]0$$], 0, -
                 Sin[Degree $CellContext`\[Theta]0$$], 
                 Cos[Degree $CellContext`\[Theta]0$$], 0, 0, 0, 1}]; 
             Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`x0$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`y0$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`x0$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`y0$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + \
$CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ $CellContext`symr2$ + \
$CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ $CellContext`symr8$, \
$CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ $CellContext`symr6$ + \
$CellContext`r3$ $CellContext`symr9$}; {$CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$} = {$CellContext`r4$ \
$CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + $CellContext`r6$ \
$CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + $CellContext`r5$ \
$CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, $CellContext`r4$ \
$CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + $CellContext`r6$ \
$CellContext`symr9$}; {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$} = {$CellContext`r7$ $CellContext`symr1$ + \
$CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ $CellContext`symr7$, \
$CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ $CellContext`symr5$ + \
$CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ $CellContext`symr3$ + \
$CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ $CellContext`symr9$}; \
{{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}} = {{$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}, {$CellContext`LocTV4$, $CellContext`LocTV5$, \
$CellContext`LocTV6$}, {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$}}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJxTTMoPSmViYGBgA2J1BnQgcgBDCKv4B3vs6oiXXyClf1eF7SFUXaRDWCgI
HIXre6IU3CXFiMscQuZDwAbeDw7INEKfBBqfeHdjF+c4QJz4UA03BigtgcYn
3t04xPcTJz5Uw40DSkug8Yl3N2XiQzXcBKC0BBqfeHdjF0cPf1ziQzXcRKC0
BBqfeHdjF0c3B5f4UA03CRw08e6GsQC8KJBJ
               
               "]]]; $CellContext`propagatedrays$ = 
           Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
              1.; $CellContext`frontid$ = 
              1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
           200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 0.; (
           AddTo[$CellContext`generationnumber$, 
             1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
               0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
             False; $CellContext`reportedrayspresent$ = 
             False; $CellContext`deflecteddummyrayspresent$ = 
             False; $CellContext`reporteddummyrayspresent$ = 
             False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
               
               Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]b$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]b$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]b$$]] - 
                   1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]b$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                   Re[Cos[0.017453292519943295` $CellContext`\[Theta]b$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]b$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                  Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                  Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
($CellContext`rex$ - 1. Re[$CellContext`xb$$]) Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]b$$]] + \
($CellContext`rey$ - 1. Re[$CellContext`yb$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]b$$]]; \
$CellContext`ry$ = ($CellContext`rey$ - 1. Re[$CellContext`yb$$]) Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]b$$]] - 
                   1. ($CellContext`rex$ - 1. Re[$CellContext`xb$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]b$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                   Re[Cos[0.017453292519943295` $CellContext`\[Theta]b$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]b$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                  Chop[$CellContext`ry$]; $CellContext`rz$ = 
                  Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                  False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                   True; ($CellContext`intersections$ = Block[{Compile`$2877}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 100.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2877 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2877), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2877, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2877}]}, {{-1., 0., 0.}}]]; 
                   AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 65794.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                   Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                   If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; $CellContext`intersections$ = Union[
                    Map[
                    If[Part[#, 2]^2 + Part[#, 3]^2 <= 
                    20.25, $CellContext`holeQ$ = True; {-1., 0., 
                    0.}, #]& , $CellContext`unfilteredintersections$]]; 
                   If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                  If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    65794.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 1., 
                    65794.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    Re[$CellContext`xb$$] + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]b$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]b$$]]; \
$CellContext`rey$ = Re[$CellContext`yb$$] + $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]b$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]b$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]b$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]b$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]b$$]], -
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]b$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]b$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]b$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]b$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]b$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]b$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]b$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`xb$$], 
                    Re[$CellContext`yb$$], 0.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                   True; $CellContext`deflecteddummyrayspresent$ = 
                   True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                   "]])& , $CellContext`propagatedrays$]]; If[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
               Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
              1., 1.]; If[
              
              And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
               Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
              1., 1.]); (
            If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
               Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                 
                 "], $CellContext`reportedlocalrays$]; 1., 
              1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 
           1.); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

             "]; $CellContext`deflectedrayspresent$ = 
            True; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = True; While[
             And[$CellContext`deflectedrayspresent$, $CellContext`propagate$],
              AddTo[$CellContext`generationnumber$, 
               1.]; ($CellContext`deflecteddummyrayspresent$ = 
               False; $CellContext`deflectedrayspresent$ = 
               False; $CellContext`reportedrayspresent$ = 
               False; $CellContext`reporteddummyrayspresent$ = 
               True; $CellContext`localdummyoutrayspresent$ = 
               False; $CellContext`localoutrayspresent$ = 
               False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
               Map[Flatten[#, 1]& , 
                 Transpose[
                  
                  Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
($CellContext`rex$ - 1. Re[$CellContext`x1$$]) Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
($CellContext`rey$ - 1. Re[$CellContext`y1$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`ry$ = ($CellContext`rey$ - 1. Re[$CellContext`y1$$]) Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. ($CellContext`rex$ - 1. Re[$CellContext`x1$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`ro$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`ro$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`ro$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`ro$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ro$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`ro$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`ro$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ro$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66013.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x1$$ + $CellContext`to$$ 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + $CellContext`to$$ 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + $CellContext`to$$ 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + $CellContext`to$$ 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`ri$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`ri$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`ri$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`ri$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ri$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`ri$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`ri$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ri$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66014.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) + 
                    Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. 
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. 
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - (-$CellContext`ri$$) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ (-$CellContext`ri$$); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[$CellContext`ri$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    Sqrt[$CellContext`ri$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ri$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[$CellContext`ri$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    Sqrt[$CellContext`ri$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ri$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66015.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - (-$CellContext`ro$$) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ (-$CellContext`ro$$); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[$CellContext`ro$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    Sqrt[$CellContext`ro$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ro$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[$CellContext`ro$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    Sqrt[$CellContext`ro$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ro$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66016.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
($CellContext`rex$ - 1. Re[$CellContext`x1$$]) Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
($CellContext`rey$ - 1. Re[$CellContext`y1$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`ry$ = ($CellContext`rey$ - 1. Re[$CellContext`y1$$]) Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. ($CellContext`rex$ - 1. Re[$CellContext`x1$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    66013.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 1., 
                    66013.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    Re[$CellContext`x1$$] + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rey$ = Re[$CellContext`y1$$] + $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`ro$$] \
$CellContext`ray2$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`ro$$] \
$CellContext`ray3$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`ro$$] \
$CellContext`ray2$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`ro$$] \
$CellContext`ray3$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], -
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`x1$$], 
                    Re[$CellContext`y1$$], 0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x1$$ + $CellContext`to$$ 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + $CellContext`to$$ 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + $CellContext`to$$ 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + $CellContext`to$$ 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    66014.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 2., 
                    66014.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[$CellContext`x1$$ + $CellContext`to$$ 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[$CellContext`y1$$ + $CellContext`to$$ 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`ri$$] \
$CellContext`ray2$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`ri$$] \
$CellContext`ray3$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`ri$$] \
$CellContext`ray2$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`ri$$] \
$CellContext`ray3$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], -
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    
                    Re[$CellContext`x1$$ + $CellContext`to$$ 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    
                    Re[$CellContext`y1$$ + $CellContext`to$$ 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) + 
                    Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. 
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. 
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    66015.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 3., 
                    66015.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -(((-
                    Sign[$CellContext`ri$$]) \
$CellContext`ray2$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -(((-
                    Sign[$CellContext`ri$$]) \
$CellContext`ray3$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {((-
                    Sign[$CellContext`ri$$]) \
$CellContext`ray2$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {((-
                    Sign[$CellContext`ri$$]) \
$CellContext`ray3$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], -
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    66016.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 4., 
                    66016.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -(((-
                    Sign[$CellContext`ro$$]) \
$CellContext`ray2$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -(((-
                    Sign[$CellContext`ro$$]) \
$CellContext`ray3$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {((-
                    Sign[$CellContext`ro$$]) \
$CellContext`ray2$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {((-
                    Sign[$CellContext`ro$$]) \
$CellContext`ray3$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], -
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                
                And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                 1., 1.]; 
              If[$CellContext`localoutrayspresent$, 
                If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                   Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 1.,
                   1.]; $CellContext`outrays$ = 
                 Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1., 
                1.]; If[
                
                And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                 Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                1., 1.]); 
             If[$CellContext`reportedrayspresent$, $CellContext`raysreported$ = 
                True; $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
            If[Length[$CellContext`outrays$] > 1, 
              Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
             
             And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
              
              Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); (
           AddTo[$CellContext`generationnumber$, 
             1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
               0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
             False; $CellContext`reportedrayspresent$ = 
             False; $CellContext`deflecteddummyrayspresent$ = 
             False; $CellContext`reporteddummyrayspresent$ = 
             False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
               
               Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                  Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                  Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                  Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                   Re[$CellContext`XS$$]; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                  Chop[$CellContext`rx$]; $CellContext`ry$ = 
                  Chop[$CellContext`ry$]; $CellContext`rz$ = 
                  Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                  False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                   True; ($CellContext`intersections$ = Block[{Compile`$2955}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 100.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2955 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2955), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2955, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2955}]}, {{-1., 0., 0.}}]]; 
                   AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66051.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                   Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                   If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                  If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 1., 
                    66051.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {3., 1., 
                    66051.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ + 
                    Re[$CellContext`XS$$]; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`XS$$], 0., 
                    0.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                   True; $CellContext`deflecteddummyrayspresent$ = 
                   True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                   "]])& , $CellContext`propagatedrays$]]; If[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
               Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
              1., 1.]; If[
              
              And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
               Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
              1., 1.]); (
            If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
               Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                 
                 "], $CellContext`reportedlocalrays$]; 1., 
              1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 
           1.); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

             "]; $CellContext`deflectedrayspresent$ = 
            True; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = True; While[
             And[$CellContext`deflectedrayspresent$, $CellContext`propagate$],
              AddTo[$CellContext`generationnumber$, 
               1.]; ($CellContext`deflecteddummyrayspresent$ = 
               False; $CellContext`deflectedrayspresent$ = 
               False; $CellContext`reportedrayspresent$ = 
               False; $CellContext`reporteddummyrayspresent$ = 
               True; $CellContext`localdummyoutrayspresent$ = 
               False; $CellContext`localoutrayspresent$ = 
               False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
               Map[Flatten[#, 1]& , 
                 Transpose[
                  
                  Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-50. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2958}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 25., Part[#, 2] >= -25., Part[#, 3] >= -25.,
                     Part[#, 3] <= 25.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2958 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2958), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2958, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2958}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66152.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    25. + $CellContext`rey$; $CellContext`ry$ = -(-25. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2974}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 25., Part[#, 2] >= -25., Part[#, 3] >= -25.,
                     Part[#, 3] <= 25.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2974 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2974), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2974, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2974}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66153.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2958}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 25., Part[#, 2] >= -25., Part[#, 3] >= -25.,
                     Part[#, 3] <= 25.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2958 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2958), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2958, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2958}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66154.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-25. + \
$CellContext`rey$); $CellContext`ry$ = -25. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2974}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 25., Part[#, 2] >= -25., Part[#, 3] >= -25.,
                     Part[#, 3] <= 25.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2974 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2974), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2974, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2974}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66155.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    25. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-25. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2961}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 25., Part[#, 2] >= -25., Part[#, 3] >= -25.,
                     Part[#, 3] <= 25.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2961 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2961), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2961, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2961}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66156.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-25. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-25. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2961}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 25., Part[#, 2] >= -25., Part[#, 3] >= -25.,
                     Part[#, 3] <= 25.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2961 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2961), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2961, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2961}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66157.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-50. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {4., 1., 
                    66152.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {4., 1., 
                    66152.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    50. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    50., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    25. + $CellContext`rey$; $CellContext`ry$ = -(-25. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {4., 2., 
                    66153.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {4., 2., 
                    66153.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    25. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -25. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    25., -25., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {4., 3., 
                    66154.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {4., 3., 
                    66154.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-25. + \
$CellContext`rey$); $CellContext`ry$ = -25. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {4., 4., 
                    66155.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {4., 4., 
                    66155.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    25. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    25. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    25., 25., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    25. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-25. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {4., 5., 
                    66156.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {4., 5., 
                    66156.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    25. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -25. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    25., 0, -25.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-25. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-25. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {4., 6., 
                    66157.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {4., 6., 
                    66157.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    25. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    25. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    25., 0, 25.}; $CellContext`activeregion$ = 
                    
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                
                And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                 1., 1.]; 
              If[$CellContext`localoutrayspresent$, 
                If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                   Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 1.,
                   1.]; $CellContext`outrays$ = 
                 Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1., 
                1.]; If[
                
                And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                 Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                1., 1.]); 
             If[$CellContext`reportedrayspresent$, $CellContext`raysreported$ = 
                True; $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
            If[Length[$CellContext`outrays$] > 1, 
              Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
             
             And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
              Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
          If[Length[$CellContext`reportedrays$] > 
            2, $CellContext`reportedrays$ = 
            Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
          Map[{
             Part[#, 1], 
             Part[#, 2], 
             Part[#, 3], 
             Part[#, 4], 
             Part[#, 5], 
             Part[#, 6]}& , $CellContext`reportedrays$]], {
         CompilationTarget -> "MVM", RuntimeAttributes -> {Listable}, 
          Parallelization -> False, 
          RuntimeOptions -> {}}]; \
$CellContext`raytracefunction284086201251114558088881 = 
       Compile[{{$CellContext`x0$$, 
           Blank[Real]}, {$CellContext`y0$$, 
           Blank[Real]}, {$CellContext`\[Theta]0$$, 
           Blank[Real]}, {$CellContext`ri$$, 
           Blank[Real]}, {$CellContext`ro$$, 
           Blank[Real]}, {$CellContext`ti$$, 
           Blank[Real]}, {$CellContext`to$$, 
           Blank[Real]}, {$CellContext`x1$$, 
           Blank[Real]}, {$CellContext`xb$$, 
           Blank[Real]}, {$CellContext`XS$$, 
           Blank[Real]}, {$CellContext`y1$$, 
           Blank[Real]}, {$CellContext`yb$$, 
           Blank[Real]}, {$CellContext`\[Theta]1$$, 
           Blank[Real]}, {$CellContext`\[Theta]b$$, 
           Blank[Real]}}, 
         Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
           Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`activeregion$ = 
           1.; $CellContext`allcreatedamplitudes$ = {{
             0. + 0. I, 0. + 0. I, 0. + 
              0. I}}; $CellContext`allcreatedrays$ = {{
            1.}}; $CellContext`allowzeroraylength$ = 
           True; $CellContext`alternateindex$ = 
           1.; $CellContext`amplitude$ = {
            1. + 0. I, 0. + 0. I, 0. + 0. I}; $CellContext`axismagnitude$ = 
           1.; $CellContext`axismatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}; $CellContext`clonedata$ = {{
            1.}}; $CellContext`clonegenerationnumber$ = 
           1.; $CellContext`cloneinput$ = {1.}; $CellContext`clonenumber$ = 
           1; $CellContext`cloneposition$ = {0., 0., 
            0.}; $CellContext`clonereportedrays$ = {{
            1.}}; $CellContext`clonerotation$ = {{
            1.}}; $CellContext`clonescale$ = 
           1.; $CellContext`clonescalevector$ = {
            1.}; $CellContext`clonesorthistogram$ = {
            1}; $CellContext`clonetraceinput$ = {{
            1.}}; $CellContext`clonetraceoutput$ = {{
            1.}}; $CellContext`closestdistances$ = {
            1.}; $CellContext`closestposition$ = 
           0; $CellContext`closestpositions$ = {
            0}; $CellContext`closestraylength$ = 
           1.; $CellContext`completedray$ = {
            1.}; $CellContext`componentnumber$ = -1.; $CellContext`cosangle$ = 
           1.; $CellContext`crossmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}; $CellContext`deflecteddummyrayspresent$ = 
           False; $CellContext`deflectedlocalrays$ = {{
            1.}}; $CellContext`deflectedrays$ = {{
            1.}}; $CellContext`deflectedrayspresent$ = 
           False; $CellContext`dummymatrix$ = {{
            1.}}; $CellContext`dummymatrixlist$ = {{{
            1.}}}; $CellContext`dummyvector$ = {1.}; $CellContext`frontid$ = 
           1.; $CellContext`generationlimit$ = 
           200.; $CellContext`generationnumber$ = 
           1.; $CellContext`holeintersections$ = {{-1., 0., 
            0.}}; $CellContext`holeQ$ = 
           False; $CellContext`holeQlist$ = {0}; $CellContext`hor$ = 
           1. + 0. I; $CellContext`index$ = 1.; $CellContext`index1$ = 
           1.; $CellContext`index2$ = 
           1.; $CellContext`inrays$ = {{1.}}; $CellContext`intensity$ = 
           1.; $CellContext`intensityscale$ = 
           1.; $CellContext`intersectionnumber$ = 
           1.; $CellContext`intersections$ = {{-1., 0., 
            0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
            0.}}}; $CellContext`intersectionspresent$ = 
           False; $CellContext`localdummyoutrayspresent$ = 
           False; $CellContext`localoutrays$ = {{
            1.}}; $CellContext`localoutrayspresent$ = 
           False; $CellContext`magnitude$ = 
           1.; $CellContext`maxclonegenerationnumber$ = 
           1.; $CellContext`maximumposition$ = 
           1; $CellContext`minimumraylength$ = 
           0.0001; $CellContext`minresonateraylength$ = 1.; $CellContext`n12$ = 
           1.; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newdeflectedrays$ = {{1.}}; $CellContext`newdistance$ = 
           1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`nonintersectingrays$ = {{
            1.}}; $CellContext`normalizedpolarization$ = {1., 
            1.}; $CellContext`oldgenerationnumber$ = 
           1.; $CellContext`opticallength$ = 
           1.; $CellContext`originalray$ = {
            1.}; $CellContext`originalraytilt$ = {
            1.}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 1., 
            0.}, {0., 0., 1.}}; $CellContext`originalsurfnorm$ = {{
            1.}}; $CellContext`outrays$ = {{
            1.}}; $CellContext`parallelamplitude$ = 
           1. + 0. I; $CellContext`PAxis$ = {1., 0., 
            0.}; $CellContext`perpendicularamplitude$ = 
           1. + 0. I; $CellContext`phaseshift$ = 0.; $CellContext`pol1$ = 
           1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
           1.; $CellContext`previoustilt$ = {1., 0., 
            0.}; $CellContext`propagate$ = 
           True; $CellContext`propagatedrays$ = {{1.}}; $CellContext`r1$ = 
           1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 1.; $CellContext`r4$ = 
           1.; $CellContext`r5$ = 1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
           1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
           1.; $CellContext`ray1$ = 1.; $CellContext`ray2$ = 
           1.; $CellContext`ray3$ = 1.; $CellContext`LocRayL$ = 
           1.; $CellContext`rayslot$ = 1.; $CellContext`raysreported$ = 
           False; $CellContext`raytiltx$ = 1.; $CellContext`raytiltz$ = 
           1.; $CellContext`reporteddummyrayspresent$ = 
           False; $CellContext`reportedlocalrays$ = {{
            1.}}; $CellContext`reportedrays$ = {{
            1.}}; $CellContext`reportedrayspresent$ = 
           False; $CellContext`resonateintersections$ = {{-1., 0., 
            0.}}; $CellContext`resonatenumber$ = 
           0; $CellContext`resonateraylength$ = 1.; $CellContext`rex$ = 
           1.; $CellContext`rey$ = 1.; $CellContext`rez$ = 
           1.; $CellContext`rsx$ = 1.; $CellContext`LocRSx$ = 
           1.; $CellContext`rsy$ = 1.; $CellContext`LocRSy$ = 
           1.; $CellContext`rsz$ = 1.; $CellContext`LocRSz$ = 1.; 
          Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
           1.; $CellContext`LocRTz$ = 1.; $CellContext`rx$ = 
           1.; $CellContext`rxhlp$ = 1.; $CellContext`ry$ = 
           1.; $CellContext`ryhlp$ = 1.; $CellContext`rz$ = 
           1.; $CellContext`rzhlp$ = 1.; $CellContext`LocSCx$ = 
           1.; $CellContext`LocSCy$ = 1.; $CellContext`sid$ = 
           1.; $CellContext`sinangle$ = 1.; $CellContext`sno1$ = 
           1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
           1.; $CellContext`sno4$ = 
           1.; $CellContext`surfaceid$ = -1.; $CellContext`surfacenumber$ = \
-1.; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}; $CellContext`surfacetranslationvector$ = {0., 0., 
            0.}; $CellContext`surfnorm$ = {{1.}}; $CellContext`symr1$ = 
           1.; $CellContext`symr2$ = 1.; $CellContext`symr3$ = 
           1.; $CellContext`symr4$ = 1.; $CellContext`symr5$ = 
           1.; $CellContext`symr6$ = 1.; $CellContext`symr7$ = 
           1.; $CellContext`symr8$ = 1.; $CellContext`symr9$ = 
           1.; $CellContext`tempclonedata$ = {{
            1.}}; $CellContext`terminatedeflection$ = 
           False; $CellContext`thresholdintensity$ = 
           1.; $CellContext`tiltmagnitude$ = 
           1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}}; $CellContext`LocTV1$ = 1.; $CellContext`LocTV10$ = 
           1.; $CellContext`LocTV2$ = 1.; $CellContext`LocTV3$ = 
           1.; $CellContext`LocTV4$ = 1.; $CellContext`LocTV5$ = 
           1.; $CellContext`LocTV6$ = 1.; $CellContext`LocTV7$ = 
           1.; $CellContext`LocTV8$ = 1.; $CellContext`LocTV9$ = 
           1.; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
            0.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`ver$ = 0. + 0. I; $CellContext`wavelength$ = 
           1.; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`xunit$ = 
           1.; $CellContext`YAxis$ = {1., 0., 0.}; $CellContext`yunit$ = 
           1.; $CellContext`ZAxis$ = {1., 0., 0.}; $CellContext`zunit$ = 
           1.; $CellContext`propagatedrays$ = 
           Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                 Cos[Degree $CellContext`\[Theta]0$$], 
                 Sin[Degree $CellContext`\[Theta]0$$], 0, -
                 Sin[Degree $CellContext`\[Theta]0$$], 
                 Cos[Degree $CellContext`\[Theta]0$$], 0, 0, 0, 1}]; 
             Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`x0$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`y0$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`x0$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`y0$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + \
$CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ $CellContext`symr2$ + \
$CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ $CellContext`symr8$, \
$CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ $CellContext`symr6$ + \
$CellContext`r3$ $CellContext`symr9$}; {$CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$} = {$CellContext`r4$ \
$CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + $CellContext`r6$ \
$CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + $CellContext`r5$ \
$CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, $CellContext`r4$ \
$CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + $CellContext`r6$ \
$CellContext`symr9$}; {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$} = {$CellContext`r7$ $CellContext`symr1$ + \
$CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ $CellContext`symr7$, \
$CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ $CellContext`symr5$ + \
$CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ $CellContext`symr3$ + \
$CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ $CellContext`symr9$}; \
{{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}} = {{$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}, {$CellContext`LocTV4$, $CellContext`LocTV5$, \
$CellContext`LocTV6$}, {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$}}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJxTTMoPSmViYGBgA2J1BnQgcgBDCKv4B3vs6oiXXyClf1eF7SFUXaRDWCgI
HIXre6IU3CXFiMscQuZDwAbeDw7INEKfBBqfeHdjF+c4QJz4UA03BigtgcYn
3t04xPcTJz5Uw40DSkug8Yl3N2XiQzXcBKC0BBqfeHdjF0cPf1ziQzXcRKC0
BBqfeHdjF0c3B5f4UA03CRw08e6GsQC8KJBJ
               
               "]]]; $CellContext`propagatedrays$ = 
           Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
              1.; $CellContext`frontid$ = 
              1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
           200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 0.; (
           AddTo[$CellContext`generationnumber$, 
             1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
               0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
             False; $CellContext`reportedrayspresent$ = 
             False; $CellContext`deflecteddummyrayspresent$ = 
             False; $CellContext`reporteddummyrayspresent$ = 
             False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
               
               Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]b$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]b$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]b$$]] - 
                   1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]b$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                   Re[Cos[0.017453292519943295` $CellContext`\[Theta]b$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]b$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                  Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                  Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
($CellContext`rex$ - 1. Re[$CellContext`xb$$]) Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]b$$]] + \
($CellContext`rey$ - 1. Re[$CellContext`yb$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]b$$]]; \
$CellContext`ry$ = ($CellContext`rey$ - 1. Re[$CellContext`yb$$]) Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]b$$]] - 
                   1. ($CellContext`rex$ - 1. Re[$CellContext`xb$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]b$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                   Re[Cos[0.017453292519943295` $CellContext`\[Theta]b$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]b$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                  Chop[$CellContext`ry$]; $CellContext`rz$ = 
                  Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                  False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                   True; ($CellContext`intersections$ = Block[{Compile`$2877}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 100.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2877 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2877), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2877, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2877}]}, {{-1., 0., 0.}}]]; 
                   AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 65794.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                   Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                   If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; $CellContext`intersections$ = Union[
                    Map[
                    If[Part[#, 2]^2 + Part[#, 3]^2 <= 
                    20.25, $CellContext`holeQ$ = True; {-1., 0., 
                    0.}, #]& , $CellContext`unfilteredintersections$]]; 
                   If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                  If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    65794.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 1., 
                    65794.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 1]; $CellContext`rsx$ = $\
CellContext`rex$; $CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = \
$CellContext`rez$; $CellContext`rxhlp$ = $CellContext`rx$ + \
$CellContext`ray1$ $CellContext`xunit$; $CellContext`ryhlp$ = \
$CellContext`ry$ + $CellContext`ray1$ $CellContext`yunit$; \
$CellContext`rzhlp$ = $CellContext`rz$ + $CellContext`ray1$ \
$CellContext`zunit$; $CellContext`rex$ = 
                    Re[$CellContext`xb$$] + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]b$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]b$$]]; \
$CellContext`rey$ = Re[$CellContext`yb$$] + $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]b$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]b$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]b$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]b$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]b$$]], -
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]b$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]b$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]b$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]b$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]b$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]b$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]b$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`xb$$], 
                    Re[$CellContext`yb$$], 0.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                   True; $CellContext`deflecteddummyrayspresent$ = 
                   True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                   "]])& , $CellContext`propagatedrays$]]; If[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
               Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
              1., 1.]; If[
              
              And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
               Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
              1., 1.]); (
            If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
               Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                 
                 "], $CellContext`reportedlocalrays$]; 1., 
              1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 
           1.); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

             "]; $CellContext`deflectedrayspresent$ = 
            True; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = True; While[
             And[$CellContext`deflectedrayspresent$, $CellContext`propagate$],
              AddTo[$CellContext`generationnumber$, 
               1.]; ($CellContext`deflecteddummyrayspresent$ = 
               False; $CellContext`deflectedrayspresent$ = 
               False; $CellContext`reportedrayspresent$ = 
               False; $CellContext`reporteddummyrayspresent$ = 
               True; $CellContext`localdummyoutrayspresent$ = 
               False; $CellContext`localoutrayspresent$ = 
               False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
               Map[Flatten[#, 1]& , 
                 Transpose[
                  
                  Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
($CellContext`rex$ - 1. Re[$CellContext`x1$$]) Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
($CellContext`rey$ - 1. Re[$CellContext`y1$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`ry$ = ($CellContext`rey$ - 1. Re[$CellContext`y1$$]) Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. ($CellContext`rex$ - 1. Re[$CellContext`x1$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`ro$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`ro$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`ro$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`ro$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ro$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`ro$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`ro$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ro$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66013.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x1$$ + $CellContext`to$$ 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + $CellContext`to$$ 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + $CellContext`to$$ 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + $CellContext`to$$ 
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`ri$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`ri$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`ri$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`ri$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ri$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`ri$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`ri$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ri$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66014.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) + 
                    Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. 
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. 
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - (-$CellContext`ri$$) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ (-$CellContext`ri$$); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[$CellContext`ri$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    Sqrt[$CellContext`ri$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ri$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[$CellContext`ri$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    Sqrt[$CellContext`ri$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ri$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66015.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - (-$CellContext`ro$$) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ (-$CellContext`ro$$); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[$CellContext`ro$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    Sqrt[$CellContext`ro$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ro$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    18.0625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[$CellContext`ro$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    Sqrt[$CellContext`ro$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`ro$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66016.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
($CellContext`rex$ - 1. Re[$CellContext`x1$$]) Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
($CellContext`rey$ - 1. Re[$CellContext`y1$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`ry$ = ($CellContext`rey$ - 1. Re[$CellContext`y1$$]) Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. ($CellContext`rex$ - 1. Re[$CellContext`x1$$]) Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    66013.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 1., 
                    66013.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    Re[$CellContext`x1$$] + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rey$ = Re[$CellContext`y1$$] + $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`ro$$] \
$CellContext`ray2$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`ro$$] \
$CellContext`ray3$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`ro$$] \
$CellContext`ray2$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`ro$$] \
$CellContext`ray3$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], -
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`x1$$], 
                    Re[$CellContext`y1$$], 0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x1$$ + $CellContext`to$$ 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + $CellContext`to$$ 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + $CellContext`to$$ 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + $CellContext`to$$ 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    66014.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 2., 
                    66014.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[$CellContext`x1$$ + $CellContext`to$$ 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[$CellContext`y1$$ + $CellContext`to$$ 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`ri$$] \
$CellContext`ray2$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    
                    Sign[$CellContext`ri$$] \
$CellContext`ray3$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`ri$$] \
$CellContext`ray2$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`ri$$] \
$CellContext`ray3$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], -
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    
                    Re[$CellContext`x1$$ + $CellContext`to$$ 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    
                    Re[$CellContext`y1$$ + $CellContext`to$$ 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) + 
                    Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. 
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. 
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    66015.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 3., 
                    66015.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -(((-
                    Sign[$CellContext`ri$$]) \
$CellContext`ray2$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -(((-
                    Sign[$CellContext`ri$$]) \
$CellContext`ray3$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {((-
                    Sign[$CellContext`ri$$]) \
$CellContext`ray2$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {((-
                    Sign[$CellContext`ri$$]) \
$CellContext`ray3$)/($CellContext`ri$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], -
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + \
$CellContext`to$$) Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}; $CellContext`activeregion$ = 
                    
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 
                    1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`r1$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rex$ - 1. Re[$CellContext`x1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) + Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`ry$ = -($CellContext`rex$ - 1. 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]]) Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] \
($CellContext`rey$ - 1. Re[$CellContext`y1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]); \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    66016.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 4., 
                    66016.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]] - 
                    1. $CellContext`ryhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`\[Theta]1$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]] + 
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`\[Theta]1$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -(((-
                    Sign[$CellContext`ro$$]) \
$CellContext`ray2$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -(((-
                    Sign[$CellContext`ro$$]) \
$CellContext`ray3$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {((-
                    Sign[$CellContext`ro$$]) \
$CellContext`ray2$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {((-
                    Sign[$CellContext`ro$$]) \
$CellContext`ray3$)/($CellContext`ro$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], -
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    
                    Re[$CellContext`x1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Cos[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    Re[$CellContext`y1$$ + ($CellContext`ti$$ + 
                    2. $CellContext`to$$) 
                    Sin[0.017453292519943295` $CellContext`\[Theta]1$$]], 
                    0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.7105646 - 
                    0.009121199600000001 $CellContext`wavelength$^2 + 
                    0.027760538/$CellContext`wavelength$^2 + 
                    0.0012739656/$CellContext`wavelength$^4 - 
                    0.000047889342/$CellContext`wavelength$^6 + 
                    8.0562028*^-6/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                
                And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                 1., 1.]; 
              If[$CellContext`localoutrayspresent$, 
                If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                   Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 1.,
                   1.]; $CellContext`outrays$ = 
                 Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1., 
                1.]; If[
                
                And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                 Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                1., 1.]); 
             If[$CellContext`reportedrayspresent$, $CellContext`raysreported$ = 
                True; $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
            If[Length[$CellContext`outrays$] > 1, 
              Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
             
             And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
              Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); (
           AddTo[$CellContext`generationnumber$, 
             1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
               0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
             False; $CellContext`reportedrayspresent$ = 
             False; $CellContext`deflecteddummyrayspresent$ = 
             False; $CellContext`reporteddummyrayspresent$ = 
             False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
               
               Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                  Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                  Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                  Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                   Re[$CellContext`XS$$]; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                  Chop[$CellContext`rx$]; $CellContext`ry$ = 
                  Chop[$CellContext`ry$]; $CellContext`rz$ = 
                  Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                  False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                   True; ($CellContext`intersections$ = Block[{Compile`$2955}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 100.], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2955 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2955), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2955, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2955}]}, {{-1., 0., 0.}}]]; 
                   AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66051.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                   Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                   If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                  If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 1., 
                    66051.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {3., 1., 
                    66051.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ + 
                    Re[$CellContext`XS$$]; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`XS$$], 0., 
                    0.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                   True; $CellContext`deflecteddummyrayspresent$ = 
                   True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                   "]])& , $CellContext`propagatedrays$]]; If[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
               Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
              1., 1.]; If[
              
              And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
               Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
              1., 1.]); (
            If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
               Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                 
                 "], $CellContext`reportedlocalrays$]; 1., 
              1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 
           1.); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

             "]; $CellContext`deflectedrayspresent$ = 
            True; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = True; While[
             And[$CellContext`deflectedrayspresent$, $CellContext`propagate$],
              AddTo[$CellContext`generationnumber$, 
               1.]; ($CellContext`deflecteddummyrayspresent$ = 
               False; $CellContext`deflectedrayspresent$ = 
               False; $CellContext`reportedrayspresent$ = 
               False; $CellContext`reporteddummyrayspresent$ = 
               True; $CellContext`localdummyoutrayspresent$ = 
               False; $CellContext`localoutrayspresent$ = 
               False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
               Map[Flatten[#, 1]& , 
                 Transpose[
                  
                  Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-50. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2958}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 25., Part[#, 2] >= -25., Part[#, 3] >= -25.,
                     Part[#, 3] <= 25.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2958 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2958), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2958, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2958}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66152.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    25. + $CellContext`rey$; $CellContext`ry$ = -(-25. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2974}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 25., Part[#, 2] >= -25., Part[#, 3] >= -25.,
                     Part[#, 3] <= 25.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2974 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2974), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2974, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2974}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66153.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2958}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 25., Part[#, 2] >= -25., Part[#, 3] >= -25.,
                     Part[#, 3] <= 25.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2958 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2958), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2958, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2958}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66154.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-25. + \
$CellContext`rey$); $CellContext`ry$ = -25. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2974}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 25., Part[#, 2] >= -25., Part[#, 3] >= -25.,
                     Part[#, 3] <= 25.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2974 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2974), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2974, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2974}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66155.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    25. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-25. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2961}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 25., Part[#, 2] >= -25., Part[#, 3] >= -25.,
                     Part[#, 3] <= 25.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2961 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2961), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2961, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2961}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66156.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-25. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-25. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$2961}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 25., Part[#, 2] >= -25., Part[#, 3] >= -25.,
                     Part[#, 3] <= 25.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$2961 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$2961), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$2961, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$2961}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 66157.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-50. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {4., 1., 
                    66152.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {4., 1., 
                    66152.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    50. - 
                    1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    50., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    25. + $CellContext`rey$; $CellContext`ry$ = -(-25. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {4., 2., 
                    66153.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {4., 2., 
                    66153.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    25. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -25. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    25., -25., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {4., 3., 
                    66154.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {4., 3., 
                    66154.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-25. + \
$CellContext`rey$); $CellContext`ry$ = -25. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {4., 4., 
                    66155.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {4., 4., 
                    66155.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    25. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    25. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    25., 25., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    25. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-25. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {4., 5., 
                    
                    66156.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {4., 5., 
                    66156.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    25. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -25. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    25., 0, -25.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-25. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-25. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {4., 6., 
                    66157.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {4., 6., 
                    66157.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    25. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    25. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    25., 0, 25.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                
                And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                 1., 1.]; 
              If[$CellContext`localoutrayspresent$, 
                If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                   Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 1.,
                   1.]; $CellContext`outrays$ = 
                 Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1., 
                1.]; If[
                
                And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                 Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                1., 1.]); 
             If[$CellContext`reportedrayspresent$, $CellContext`raysreported$ = 
                True; $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
            If[Length[$CellContext`outrays$] > 1, 
              Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
             
             And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
              Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
          If[Length[$CellContext`reportedrays$] > 
            2, $CellContext`reportedrays$ = 
            Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
          Map[{
             Part[#, 1], 
             Part[#, 2], 
             Part[#, 3], 
             Part[#, 4], 
             Part[#, 5], 
             Part[#, 6]}& , $CellContext`reportedrays$]], {
         CompilationTarget -> "MVM", RuntimeAttributes -> {Listable}, 
          Parallelization -> False, 
          RuntimeOptions -> {}}]; \
$CellContext`polygons1284086201251114555787525 = 
       Compile[{$CellContext`ro, $CellContext`ri, $CellContext`to, \
$CellContext`ti}, {{$CellContext`ro - 1. Sqrt[-18.0625 + $CellContext`ro^2] 
           Sign[$CellContext`ro], -4.25}, {$CellContext`ro - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] 
           Sign[$CellContext`ro], -3.541666666666667}, {$CellContext`ro - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] 
           Sign[$CellContext`ro], -2.8333333333333335`}, {$CellContext`ro - 
           1. Sqrt[-4.515625 + $CellContext`ro^2] 
           Sign[$CellContext`ro], -2.125}, {$CellContext`ro - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] 
           Sign[$CellContext`ro], -1.416666666666667}, {$CellContext`ro - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
           Sign[$CellContext`ro], -0.7083333333333339}, {$CellContext`ro - 1. 
           Sqrt[0. + $CellContext`ro^2] Sign[$CellContext`ro], 
           0.}, {$CellContext`ro - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
           Sign[$CellContext`ro], 0.708333333333333}, {$CellContext`ro - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] Sign[$CellContext`ro],
            1.416666666666666}, {$CellContext`ro - 1. 
           Sqrt[-4.5156249999999964` + $CellContext`ro^2] 
           Sign[$CellContext`ro], 2.124999999999999}, {$CellContext`ro - 1. 
           Sqrt[-8.027777777777771 + $CellContext`ro^2] Sign[$CellContext`ro],
            2.833333333333332}, {$CellContext`ro - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Sign[$CellContext`ro], 3.541666666666666}, {$CellContext`ro - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro], 
           4.25}, {$CellContext`ri + $CellContext`to - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri], 
           4.25}, {$CellContext`ri + $CellContext`to - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri],
            3.541666666666667}, {$CellContext`ri + $CellContext`to - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri],
            2.8333333333333335`}, {$CellContext`ri + $CellContext`to - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri], 
           2.125}, {$CellContext`ri + $CellContext`to - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri],
            1.416666666666667}, {$CellContext`ri + $CellContext`to - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Sign[$CellContext`ri], 
           0.7083333333333339}, {$CellContext`ri + $CellContext`to - 1. 
           Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri], 
           0.}, {$CellContext`ri + $CellContext`to - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Sign[$CellContext`ri], -0.708333333333333}, {$CellContext`ri + \
$CellContext`to - 1. Sqrt[-2.006944444444443 + $CellContext`ri^2] 
           Sign[$CellContext`ri], -1.416666666666666}, {$CellContext`ri + \
$CellContext`to - 1. Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
           Sign[$CellContext`ri], -2.124999999999999}, {$CellContext`ri + \
$CellContext`to - 1. Sqrt[-8.027777777777771 + $CellContext`ri^2] 
           Sign[$CellContext`ri], -2.833333333333332}, {$CellContext`ri + \
$CellContext`to - 1. Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri], -3.541666666666666}, {$CellContext`ri + \
$CellContext`to - 1. Sqrt[-18.0625 + $CellContext`ri^2] 
           Sign[$CellContext`ri], -4.25}, {$CellContext`ro - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Sign[$CellContext`ro], -4.25}, {$CellContext`ri + $CellContext`to - 
           1. Sqrt[-18.0625 + $CellContext`ri^2] 
           Sign[$CellContext`ri], -4.25}, {$CellContext`ri + $CellContext`to - 
           1. Sqrt[-12.54340277777778 + $CellContext`ri^2] 
           Sign[$CellContext`ri], -3.541666666666667}, {$CellContext`ri + \
$CellContext`to - 1. Sqrt[-8.027777777777779 + $CellContext`ri^2] 
           Sign[$CellContext`ri], -2.8333333333333335`}, {$CellContext`ri + \
$CellContext`to - 1. Sqrt[-4.515625 + $CellContext`ri^2] 
           Sign[$CellContext`ri], -2.125}, {$CellContext`ri + $CellContext`to - 
           1. Sqrt[-2.006944444444445 + $CellContext`ri^2] 
           Sign[$CellContext`ri], -1.416666666666667}, {$CellContext`ri + \
$CellContext`to - 1. Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Sign[$CellContext`ri], -0.7083333333333339}, {$CellContext`ri + \
$CellContext`to - 1. Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri], 
           0.}, {$CellContext`ri + $CellContext`to - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Sign[$CellContext`ri], 
           0.708333333333333}, {$CellContext`ri + $CellContext`to - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri],
            1.416666666666666}, {$CellContext`ri + $CellContext`to - 1. 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
           Sign[$CellContext`ri], 
           2.124999999999999}, {$CellContext`ri + $CellContext`to - 1. 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] Sign[$CellContext`ri],
            2.833333333333332}, {$CellContext`ri + $CellContext`to - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri], 
           3.541666666666666}, {$CellContext`ri + $CellContext`to - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri], 
           4.25}, {-$CellContext`ri + $CellContext`ti + $CellContext`to + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri], 
           4.25}, {-$CellContext`ri + $CellContext`ti + $CellContext`to + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri],
            3.541666666666667}, {-$CellContext`ri + $CellContext`ti + \
$CellContext`to + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri],
            2.8333333333333335`}, {-$CellContext`ri + $CellContext`ti + \
$CellContext`to + Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri], 
           2.125}, {-$CellContext`ri + $CellContext`ti + $CellContext`to + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri],
            1.416666666666667}, {-$CellContext`ri + $CellContext`ti + \
$CellContext`to + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Sign[$CellContext`ri], 
           0.7083333333333339}, {-$CellContext`ri + $CellContext`ti + \
$CellContext`to + Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri], 
           0.}, {-$CellContext`ri + $CellContext`ti + $CellContext`to + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Sign[$CellContext`ri], -0.708333333333333}, {-$CellContext`ri + \
$CellContext`ti + $CellContext`to + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
            Sign[$CellContext`ri], -1.416666666666666}, {-$CellContext`ri + \
$CellContext`ti + $CellContext`to + 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
            Sign[$CellContext`ri], -2.124999999999999}, {-$CellContext`ri + \
$CellContext`ti + $CellContext`to + 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] 
            Sign[$CellContext`ri], -2.833333333333332}, {-$CellContext`ri + \
$CellContext`ti + $CellContext`to + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri], -3.541666666666666}, {-$CellContext`ri + \
$CellContext`ti + $CellContext`to + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Sign[$CellContext`ri], -4.25}, {$CellContext`ri + $CellContext`to - 
           1. Sqrt[-18.0625 + $CellContext`ri^2] 
           Sign[$CellContext`ri], -4.25}, {-$CellContext`ri + $CellContext`ti + \
$CellContext`to + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Sign[$CellContext`ri], -4.25}, {-$CellContext`ri + \
$CellContext`ti + $CellContext`to + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
            Sign[$CellContext`ri], -3.541666666666667}, {-$CellContext`ri + \
$CellContext`ti + $CellContext`to + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
            Sign[$CellContext`ri], -2.8333333333333335`}, {-$CellContext`ri + \
$CellContext`ti + $CellContext`to + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Sign[$CellContext`ri], -2.125}, {-$CellContext`ri + \
$CellContext`ti + $CellContext`to + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
            Sign[$CellContext`ri], -1.416666666666667}, {-$CellContext`ri + \
$CellContext`ti + $CellContext`to + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Sign[$CellContext`ri], -0.7083333333333339}, {-$CellContext`ri + \
$CellContext`ti + $CellContext`to + 
           Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri], 
           0.}, {-$CellContext`ri + $CellContext`ti + $CellContext`to + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Sign[$CellContext`ri], 
           0.708333333333333}, {-$CellContext`ri + $CellContext`ti + \
$CellContext`to + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri],
            1.416666666666666}, {-$CellContext`ri + $CellContext`ti + \
$CellContext`to + 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
            Sign[$CellContext`ri], 
           2.124999999999999}, {-$CellContext`ri + $CellContext`ti + \
$CellContext`to + 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] Sign[$CellContext`ri],
            2.833333333333332}, {-$CellContext`ri + $CellContext`ti + \
$CellContext`to + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri], 
           3.541666666666666}, {-$CellContext`ri + $CellContext`ti + \
$CellContext`to + Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri], 
           4.25}, {-$CellContext`ro + $CellContext`ti + 2. $CellContext`to + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro], 
           4.25}, {-$CellContext`ro + $CellContext`ti + 2. $CellContext`to + 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] Sign[$CellContext`ro],
            3.541666666666667}, {-$CellContext`ro + $CellContext`ti + 
           2. $CellContext`to + 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] Sign[$CellContext`ro],
            2.8333333333333335`}, {-$CellContext`ro + $CellContext`ti + 
           2. $CellContext`to + 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro], 
           2.125}, {-$CellContext`ro + $CellContext`ti + 2. $CellContext`to + 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] Sign[$CellContext`ro],
            1.416666666666667}, {-$CellContext`ro + $CellContext`ti + 
           2. $CellContext`to + 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
            Sign[$CellContext`ro], 
           0.7083333333333339}, {-$CellContext`ro + $CellContext`ti + 
           2. $CellContext`to + 
           Sqrt[0. + $CellContext`ro^2] Sign[$CellContext`ro], 
           0.}, {-$CellContext`ro + $CellContext`ti + 2. $CellContext`to + 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
            Sign[$CellContext`ro], -0.708333333333333}, {-$CellContext`ro + \
$CellContext`ti + 2. $CellContext`to + 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] 
            
            Sign[$CellContext`ro], -1.416666666666666}, {-$CellContext`ro + \
$CellContext`ti + 2. $CellContext`to + 
           Sqrt[-4.5156249999999964` + $CellContext`ro^2] 
            Sign[$CellContext`ro], -2.124999999999999}, {-$CellContext`ro + \
$CellContext`ti + 2. $CellContext`to + 
           Sqrt[-8.027777777777771 + $CellContext`ro^2] 
            Sign[$CellContext`ro], -2.833333333333332}, {-$CellContext`ro + \
$CellContext`ti + 2. $CellContext`to + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Sign[$CellContext`ro], -3.541666666666666}, {-$CellContext`ro + \
$CellContext`ti + 2. $CellContext`to + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Sign[$CellContext`ro], -4.25}, {-$CellContext`ri + \
$CellContext`ti + $CellContext`to + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Sign[$CellContext`ri], -4.25}}]; \
$CellContext`polygons2284086201251114558005575 = 
       Compile[{$CellContext`\[Theta]1, $CellContext`x1, $CellContext`y1, \
$CellContext`ro, $CellContext`ri, $CellContext`to, $CellContext`ti}, \
{{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0409497792752501`*^-15 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0409497792752501`*^-15 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666666 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           9.542039643356459*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           9.542039643356459*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.541666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.541666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666666 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           9.542039643356459*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           9.542039643356459*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.833333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.833333333333333 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           8.674581493960418*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           8.674581493960418*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.8333333333333335` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.8333333333333335` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.541666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.8333333333333335` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.8333333333333335` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.833333333333334 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.833333333333334 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           8.674581493960419*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           8.674581493960419*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           7.807123344564377*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           7.807123344564377*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.8333333333333335` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.8333333333333335` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           7.807123344564377*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           7.807123344564377*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666666 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           6.939665195168334*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           6.939665195168334*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           6.939665195168335*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           6.939665195168335*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.7083333333333339 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333339 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           6.072207045772293*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           6.072207045772293*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           0.7083333333333335 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333335 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           0.7083333333333335 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333335 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.7083333333333339 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333339 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           6.072207045772293*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           6.072207045772293*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.70894110743298*^-31 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.70894110743298*^-31 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           5.204748896376251*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-7.888609052210118*^-31 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           8.881784197001252*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 8.881784197001252*^-16 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-7.888609052210118*^-31 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           0.7083333333333335 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333335 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.70894110743298*^-31 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.70894110743298*^-31 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           5.204748896376251*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.708333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.3372907469802096`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.3372907469802096`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 0.7083333333333339 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.7083333333333339 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 0.708333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.50173611111111 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.7083333333333326 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.7083333333333326 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.50173611111111 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.33729074698021*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.33729074698021*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.469832597584168*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.469832597584168*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 0.708333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444444 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.4166666666666665` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.4166666666666665` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444444 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.4698325975841675`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.4698325975841675`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515624999999998 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.1249999999999996` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515624999999998 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.6023744481881263`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.6023744481881263`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.125 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.125 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.125 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.6023744481881253`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.833333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.7349162987920837`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.7349162987920837`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.02777777777778 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.833333333333334 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.833333333333334 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.02777777777778 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.125 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.833333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777773 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.8333333333333326` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.8333333333333326` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777773 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.7349162987920847`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.7349162987920847`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           8.674581493960427*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           8.674581493960427*^-17 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.833333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           8.674581493960424*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           8.674581493960424*^-17 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.333824046611965*^-32 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.333824046611965*^-32 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 5.204748896376251*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           5.204748896376251*^-16 
            Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.771019821678229*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.771019821678229*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666666) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.337290746980209*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.337290746980209*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.771019821678229*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.771019821678229*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666666) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.337290746980209*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.833333333333333) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.833333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 8.674581493960417*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           8.674581493960417*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.8333333333333335`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.8333333333333335` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.337290746980209*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 8.674581493960417*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           8.674581493960417*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.8333333333333335`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.8333333333333335` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.3372907469802096`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.3372907469802096`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.833333333333334) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.833333333333334 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.9035616722821883`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9035616722821883`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.3011872240940627`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.3011872240940627`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 8.674581493960417*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           8.674581493960417*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.8333333333333335`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.8333333333333335` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.3011872240940627`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.3011872240940627`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.9035616722821883`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9035616722821883`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.469832597584167*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.469832597584167*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666666) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.7349162987920835`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.7349162987920835`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.3011872240940627`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.3011872240940627`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.7349162987920835`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.7349162987920835`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.4698325975841675`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.4698325975841675`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.0361035228861467`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0361035228861467`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333339) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333339 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.1686453734901045`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1686453734901045`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333335) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333335 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.7349162987920835`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.7349162987920835`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.1686453734901045`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1686453734901045`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333335) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333335 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.0361035228861467`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0361035228861467`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333339) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333339 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.565844329068363*^-31 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.602374448188125*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.602374448188125*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.565844329068363*^-31 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-8.881784197001252*^-16) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           8.881784197001252*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.1686453734901045`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1686453734901045`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333335) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333335 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.1686453734901048`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1686453734901048`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.708333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.0361035228861467`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0361035228861467`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.7083333333333339 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.7083333333333339 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.036103522886146*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.036103522886146*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.708333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.50173611111111 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.168645373490105*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.168645373490105*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.50173611111111 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.7083333333333326 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.7083333333333326 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.734916298792084*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.734916298792084*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.469832597584167*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.469832597584167*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.036103522886146*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.036103522886146*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.708333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.469832597584167*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.469832597584167*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444444 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.7349162987920837`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.7349162987920837`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444444 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.4166666666666665` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.4166666666666665` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515624999999998 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.3011872240940632`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.3011872240940632`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515624999999998 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.9035616722821883`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9035616722821883`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.125 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.469832597584167*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.469832597584167*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.9035616722821883`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9035616722821883`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.125 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.3011872240940627`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.3011872240940627`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.125 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 8.674581493960419*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           8.674581493960419*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.833333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.02777777777778 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.3372907469802096`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.3372907469802096`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.02777777777778 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.833333333333334 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.833333333333334 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.9035616722821883`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9035616722821883`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.125 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.337290746980209*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.833333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777773 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 8.674581493960424*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           8.674581493960424*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777773 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.8333333333333326` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.8333333333333326` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.3372907469802136`*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.3372907469802136`*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.771019821678229*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.771019821678229*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.337290746980209*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.833333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.771019821678229*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.771019821678229*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.337290746980212*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980212*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.1669120233059826`*^-32 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1669120233059826`*^-32 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 5.204748896376251*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.771019821678229*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.771019821678229*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0409497792752501`*^-15 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0409497792752501`*^-15 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666666 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           9.542039643356459*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           9.542039643356459*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.541666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.541666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666666 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           9.542039643356459*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           9.542039643356459*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.833333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.833333333333333 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           8.674581493960418*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           8.674581493960418*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.8333333333333335` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.8333333333333335` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.541666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.8333333333333335` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.8333333333333335` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.833333333333334 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.833333333333334 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           8.674581493960419*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           8.674581493960419*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           7.807123344564377*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           7.807123344564377*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.8333333333333335` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.8333333333333335` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           7.807123344564377*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           7.807123344564377*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666666 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           6.939665195168334*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           6.939665195168334*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           6.939665195168335*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           6.939665195168335*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.7083333333333339 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333339 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           6.072207045772293*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           6.072207045772293*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.7083333333333335 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333335 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.7083333333333335 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333335 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.7083333333333339 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333339 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           6.072207045772293*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           6.072207045772293*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.70894110743298*^-31 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.70894110743298*^-31 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           5.204748896376251*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-7.888609052210118*^-31 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           8.881784197001252*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 8.881784197001252*^-16 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-7.888609052210118*^-31 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.7083333333333335 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333335 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.70894110743298*^-31 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.70894110743298*^-31 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           5.204748896376251*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.708333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.3372907469802096`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.3372907469802096`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.7083333333333339 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.7083333333333339 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.708333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.50173611111111 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.7083333333333326 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.7083333333333326 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.50173611111111 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.33729074698021*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.33729074698021*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.469832597584168*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.469832597584168*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.708333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444444 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.4166666666666665` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.4166666666666665` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444444 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.4698325975841675`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.4698325975841675`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515624999999998 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.1249999999999996` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515624999999998 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.6023744481881263`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.6023744481881263`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.125 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.125 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.6023744481881253`*^-16 
            Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.833333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.7349162987920837`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.7349162987920837`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.833333333333334 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.833333333333334 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.125 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.833333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777773 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.8333333333333326` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.8333333333333326` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777773 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.7349162987920847`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.7349162987920847`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           8.674581493960427*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           8.674581493960427*^-17 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.833333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           8.674581493960424*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           8.674581493960424*^-17 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.333824046611965*^-32 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.333824046611965*^-32 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 5.204748896376251*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.771019821678229*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.771019821678229*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666666) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.337290746980209*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.337290746980209*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.771019821678229*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.771019821678229*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666666) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.337290746980209*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.833333333333333) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.833333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 8.674581493960417*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           8.674581493960417*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.8333333333333335`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.8333333333333335` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.337290746980209*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[
            0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 8.674581493960417*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           8.674581493960417*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.8333333333333335`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.8333333333333335` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.3372907469802096`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.3372907469802096`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.833333333333334) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.833333333333334 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.9035616722821883`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9035616722821883`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.3011872240940627`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.3011872240940627`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 8.674581493960417*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           8.674581493960417*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.8333333333333335`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.8333333333333335` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.3011872240940627`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.3011872240940627`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.9035616722821883`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9035616722821883`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.469832597584167*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.469832597584167*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666666) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.7349162987920835`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.7349162987920835`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.3011872240940627`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.3011872240940627`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.7349162987920835`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.7349162987920835`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.4698325975841675`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.4698325975841675`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.0361035228861467`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0361035228861467`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333339) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333339 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.1686453734901045`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1686453734901045`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333335) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333335 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.7349162987920835`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.7349162987920835`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.1686453734901045`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1686453734901045`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333335) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333335 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.0361035228861467`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0361035228861467`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333339) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333339 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.565844329068363*^-31 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.602374448188125*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.602374448188125*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.565844329068363*^-31 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-8.881784197001252*^-16) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           8.881784197001252*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.1686453734901045`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1686453734901045`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333335) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333335 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.1686453734901048`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1686453734901048`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.708333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.0361035228861467`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0361035228861467`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.7083333333333339 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.7083333333333339 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.036103522886146*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.036103522886146*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.708333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.50173611111111 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.168645373490105*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.168645373490105*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.50173611111111 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.7083333333333326 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.7083333333333326 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.734916298792084*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.734916298792084*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.469832597584167*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.469832597584167*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.036103522886146*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.036103522886146*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.708333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.469832597584167*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.469832597584167*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444444 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.7349162987920837`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.7349162987920837`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444444 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.4166666666666665` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.4166666666666665` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515624999999998 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.3011872240940632`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.3011872240940632`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515624999999998 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.9035616722821883`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9035616722821883`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.125 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.469832597584167*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.469832597584167*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.9035616722821883`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9035616722821883`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.125 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.3011872240940627`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.3011872240940627`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.125 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 8.674581493960419*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           8.674581493960419*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.833333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.3372907469802096`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.3372907469802096`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.833333333333334 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.833333333333334 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.9035616722821883`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9035616722821883`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.125 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.337290746980209*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.833333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777773 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 8.674581493960424*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           8.674581493960424*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777773 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.8333333333333326` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.8333333333333326` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.3372907469802136`*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.3372907469802136`*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.771019821678229*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.771019821678229*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.337290746980209*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.833333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.771019821678229*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.771019821678229*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.337290746980212*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980212*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.1669120233059826`*^-32 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1669120233059826`*^-32 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 5.204748896376251*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.771019821678229*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.771019821678229*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0409497792752501`*^-15 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0409497792752501`*^-15 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666666 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           9.542039643356459*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           9.542039643356459*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.541666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.541666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666666 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           9.542039643356459*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           9.542039643356459*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           2.833333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.833333333333333 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           8.674581493960418*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           8.674581493960418*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.8333333333333335` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.8333333333333335` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.541666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.8333333333333335` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.8333333333333335` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.02777777777778 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           2.833333333333334 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.833333333333334 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.02777777777778 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           8.674581493960419*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           8.674581493960419*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           7.807123344564377*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           7.807123344564377*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.8333333333333335` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.8333333333333335` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           7.807123344564377*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           7.807123344564377*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666666 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           6.939665195168334*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           6.939665195168334*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           6.939665195168335*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           6.939665195168335*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           0.7083333333333339 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333339 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           6.072207045772293*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           6.072207045772293*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.7083333333333335 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333335 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.7083333333333335 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333335 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           0.7083333333333339 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333339 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           6.072207045772293*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           6.072207045772293*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.70894110743298*^-31 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.70894110743298*^-31 + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           5.204748896376251*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-7.888609052210118*^-31 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           8.881784197001252*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 8.881784197001252*^-16 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-7.888609052210118*^-31 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.7083333333333335 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333335 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.70894110743298*^-31 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.70894110743298*^-31 + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           5.204748896376251*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 0.708333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.3372907469802096`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.3372907469802096`*^-16 
            Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.7083333333333339 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.7083333333333339 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.708333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.50173611111111 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 0.7083333333333326 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.7083333333333326 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.50173611111111 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.33729074698021*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.33729074698021*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.469832597584168*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.469832597584168*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.708333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444444 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 1.4166666666666665` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.4166666666666665` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444444 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.4698325975841675`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.4698325975841675`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515624999999998 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.1249999999999996` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515624999999998 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.6023744481881263`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.6023744481881263`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.6023744481881253`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.833333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.7349162987920837`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.7349162987920837`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.833333333333334 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.833333333333334 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.833333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777773 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.8333333333333326` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.8333333333333326` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777773 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.7349162987920847`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.7349162987920847`*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           8.674581493960427*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           8.674581493960427*^-17 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.833333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           8.674581493960424*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           8.674581493960424*^-17 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.333824046611965*^-32 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.333824046611965*^-32 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 5.204748896376251*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.771019821678229*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.771019821678229*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[
             0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666666) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.337290746980209*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.337290746980209*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.771019821678229*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.771019821678229*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666666) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.337290746980209*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.833333333333333) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.833333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 8.674581493960417*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           8.674581493960417*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.8333333333333335`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.8333333333333335` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.337290746980209*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 8.674581493960417*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           8.674581493960417*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.8333333333333335`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.8333333333333335` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.02777777777778 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.3372907469802096`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.3372907469802096`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.02777777777778 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.833333333333334) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.833333333333334 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.9035616722821883`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9035616722821883`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.3011872240940627`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.3011872240940627`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 8.674581493960417*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           8.674581493960417*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.8333333333333335`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.8333333333333335` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.3011872240940627`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.3011872240940627`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.9035616722821883`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9035616722821883`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.469832597584167*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.469832597584167*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666666) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.7349162987920835`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.7349162987920835`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.3011872240940627`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.3011872240940627`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.7349162987920835`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.7349162987920835`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.4698325975841675`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.4698325975841675`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.0361035228861467`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0361035228861467`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333339) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333339 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.1686453734901045`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1686453734901045`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333335) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333335 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.7349162987920835`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.7349162987920835`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.1686453734901045`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1686453734901045`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333335) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333335 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.0361035228861467`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0361035228861467`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333339) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333339 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.565844329068363*^-31 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.602374448188125*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.602374448188125*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.565844329068363*^-31 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-8.881784197001252*^-16) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           8.881784197001252*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.1686453734901045`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1686453734901045`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111113 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333335) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333335 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.1686453734901048`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1686453734901048`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.708333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.0361035228861467`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0361035228861467`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.7083333333333339 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.7083333333333339 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-6.77235276858245*^-32 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.036103522886146*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.036103522886146*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.708333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.50173611111111 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.168645373490105*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.168645373490105*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.50173611111111 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.7083333333333326 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.7083333333333326 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 1.734916298792084*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.734916298792084*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.469832597584167*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.469832597584167*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.036103522886146*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.036103522886146*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.708333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.469832597584167*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.469832597584167*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444444 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 1.7349162987920837`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.7349162987920837`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444444 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.4166666666666665` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.4166666666666665` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515624999999998 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 1.3011872240940632`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.3011872240940632`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515624999999998 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.9035616722821883`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9035616722821883`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.125 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.469832597584167*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.469832597584167*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.9035616722821883`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9035616722821883`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.125 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 1.3011872240940627`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.3011872240940627`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.125 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 8.674581493960419*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           8.674581493960419*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.833333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.3372907469802096`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.3372907469802096`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.02777777777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.833333333333334 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.833333333333334 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.9035616722821883`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9035616722821883`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.125 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.337290746980209*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.833333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777773 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 8.674581493960424*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           8.674581493960424*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777773 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.8333333333333326` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.8333333333333326` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.3372907469802136`*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.3372907469802136`*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.771019821678229*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.771019821678229*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.337290746980209*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980209*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777777 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.833333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.833333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.771019821678229*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.771019821678229*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.337290746980212*^-17 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.337290746980212*^-17 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.1669120233059826`*^-32 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1669120233059826`*^-32 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 5.204748896376251*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.771019821678229*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.771019821678229*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}}]; \
$CellContext`lines2284086201251114558016518 = 
       Compile[{$CellContext`\[Theta]1, $CellContext`x1, $CellContext`y1, \
$CellContext`ro, $CellContext`ri, $CellContext`to, $CellContext`ti}, \
{{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.541666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.8333333333333335` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.8333333333333335` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           0.7083333333333339 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333339 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 0.708333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.5156249999999964` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.124999999999999 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999999 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.5156249999999964` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777771 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.833333333333332 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.833333333333332 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777771 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.541666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666667 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.8333333333333335` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.8333333333333335` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.125 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666667 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.7083333333333339 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.7083333333333339 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.708333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.708333333333333 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666666 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.833333333333332 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.833333333333332 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666666 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.8333333333333335`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.8333333333333335` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333339) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333339 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.708333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.5156249999999964` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.5156249999999964` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.124999999999999 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777771 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777771 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.833333333333332 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.833333333333332 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666667 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.8333333333333335` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.8333333333333335` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.125 Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666667 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.7083333333333339 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.7083333333333339 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.708333333333333) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.708333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666666) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.124999999999999) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.124999999999999 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.833333333333332) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.833333333333332 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666666) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro], 
           0. + $CellContext`y1 + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.541666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.8333333333333335` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.8333333333333335` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.7083333333333339 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333339 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.708333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.124999999999999 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999999 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.833333333333332 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.833333333333332 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.541666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666667 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.8333333333333335` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.8333333333333335` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666667 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.7083333333333339 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.7083333333333339 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.708333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.708333333333333 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666666 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.833333333333332 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.833333333333332 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666666 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.8333333333333335`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.8333333333333335` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333339) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333339 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.708333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.124999999999999 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.833333333333332 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.833333333333332 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666667 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.8333333333333335` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.8333333333333335` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.125 Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666667 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.7083333333333339 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.7083333333333339 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.708333333333333) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.708333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666666) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.124999999999999) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.124999999999999 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.833333333333332) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.833333333333332 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666666) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri], 
           0. + $CellContext`y1 + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.541666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.8333333333333335` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.8333333333333335` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.125 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666667 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.7083333333333339 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.7083333333333339 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.708333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.124999999999999 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999999 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.833333333333332 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.833333333333332 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.541666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.541666666666667 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.8333333333333335` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.8333333333333335` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.416666666666667 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 0.7083333333333339 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.7083333333333339 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           0.708333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.708333333333333 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.416666666666666 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.5156249999999964` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.5156249999999964` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777771 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           2.833333333333332 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.833333333333332 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777771 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.541666666666666 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.8333333333333335`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.8333333333333335` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-2.125) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 2.125 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666667) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666667 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.7083333333333339) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.7083333333333339 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.708333333333333 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.708333333333333 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.5156249999999964` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.124999999999999 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777771 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.833333333333332 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.833333333333332 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666666 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666666 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.54340277777778 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.541666666666667 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.541666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777779 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.8333333333333335` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.8333333333333335` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.515625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.125 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.125 Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444445 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.416666666666667 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.416666666666667 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111119 + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.7083333333333339 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.7083333333333339 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[0. + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 0.}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-0.5017361111111107 + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.708333333333333) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.708333333333333 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-2.006944444444443 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.416666666666666) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.416666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.5156249999999964` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-4.5156249999999964` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.124999999999999) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.124999999999999 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777771 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-8.027777777777771 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.833333333333332) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.833333333333332 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-12.543402777777773` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.541666666666666) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.541666666666666 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro], 0. + $CellContext`y1 - 1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, {
          0. + $CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri], 0. + $CellContext`y1 - 1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.5547363169352192 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.5547363169352192 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.5547363169352192 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.5547363169352192 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.5547363169352192 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.5547363169352192 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.5547363169352192 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.5547363169352192 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.10518476172854 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857131` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.10518476172854 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857131` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.5547363169352192 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.5547363169352192 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.10518476172854 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857131` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.10518476172854 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857131` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.9264880131729685` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729685` 
            Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516315` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516315` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.9264880131729685` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516315` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516315` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.10518476172854 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857131` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.9264880131729685` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516315` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516315` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.9264880131729685` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516315` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516315` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.6806079660838646` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.6806079660838646` 
            Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.6806079660838646` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.6806079660838646` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.9264880131729685` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516315` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516315` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.6806079660838646` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.6806079660838646` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.6806079660838646` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.6806079660838646` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.3717516962377494` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377494` 
            Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.5872360732870625` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.5872360732870625` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.3717516962377494` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377494` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.5872360732870625` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.5872360732870625` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.6806079660838646` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.6806079660838646` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.3717516962377494` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377494` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.5872360732870625` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.5872360732870625` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.3717516962377494` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377494` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.5872360732870625` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.5872360732870625` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.0052038200428277` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428277` 
            Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.0052038200428277` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428277` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.3717516962377494` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377494` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.5872360732870625` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.5872360732870625` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.0052038200428273` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.0052038200428273` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.5872360732870634` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870634` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.371751696237749 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.371751696237749 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.5872360732870634` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870634` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.371751696237749 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.371751696237749 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.0052038200428273` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.5872360732870634` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870634` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.371751696237749 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.371751696237749 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.5872360732870634` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870634` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.371751696237749 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.371751696237749 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.1250000000000004` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1250000000000004` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083864 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083864 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.1250000000000004` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1250000000000004` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083864 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083864 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.5872360732870634` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870634` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.371751696237749 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.371751696237749 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.1250000000000004` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1250000000000004` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083864 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083864 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.1250000000000004` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1250000000000004` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083864 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083864 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.6264045875516318` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.6264045875516318` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.1250000000000004` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1250000000000004` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083864 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083864 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.6264045875516318` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.6264045875516318` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.0999809416857131` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.0999809416857131` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.6264045875516318` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.099980941685714 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.099980941685714 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.099980941685714 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.099980941685714 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.5547363169352197 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352197 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 0.5547363169352197 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352197 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.099980941685714 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.099980941685714 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 0.5547363169352197 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352197 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.5547363169352197 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352197 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 0.5547363169352197 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352197 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.5547363169352193 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352193 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           0.5547363169352193 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352193 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           0.5547363169352184 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352184 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838695 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.5547363169352184 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352184 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838695 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.0999809416857127` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857127` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.0999809416857127` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857127` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           0.5547363169352184 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352184 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838695 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.0999809416857127` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857127` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.0999809416857127` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857127` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.6264045875516313` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.6264045875516313` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.6264045875516313` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.6264045875516313` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.0999809416857127` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857127` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.6264045875516304` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.6264045875516304` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.926488013172969 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.926488013172969 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.6264045875516304` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.6264045875516304` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.926488013172969 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.926488013172969 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083865 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083865 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.6264045875516304` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.6264045875516304` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.926488013172969 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.926488013172969 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083865 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083865 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.587236073287061 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287061 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.3717516962377503` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.587236073287061 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287061 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.3717516962377503` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083865 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.587236073287061 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287061 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.3717516962377503` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.587236073287061 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287061 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.3717516962377503` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.0052038200428255` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428255` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.0052038200428286` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.0052038200428255` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428255` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.0052038200428286` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.587236073287061 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287061 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.3717516962377503` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.005203820042827 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.0052038200428273` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.005203820042827 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.0052038200428273` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.3717516962377485` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377485` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.587236073287064 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.3717516962377485` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377485` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.587236073287064 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.005203820042827 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.0052038200428273` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.3717516962377485` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377485` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.587236073287064 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.3717516962377485` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377485` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.587236073287064 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.6806079660838638` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.6806079660838638` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1250000000000013` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1250000000000013` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.6806079660838638` 
            Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           3.6806079660838638` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1250000000000013` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1250000000000013` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.3717516962377485` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377485` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.587236073287064 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.6806079660838638` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.6806079660838638` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1250000000000013` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1250000000000013` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.6806079660838638` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.6806079660838638` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1250000000000013` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1250000000000013` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.9264880131729676` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729676` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516338` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516338` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.9264880131729676` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729676` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516338` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516338` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.6806079660838638` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.6806079660838638` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1250000000000013` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1250000000000013` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729685` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516318` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729685` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516318` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.10518476172854 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857143` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857143` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.10518476172854 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857143` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857143` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729685` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516318` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.10518476172854 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857143` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857143` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.10518476172854 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857143` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857143` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838694 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.554736316935221 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.554736316935221 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838694 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.554736316935221 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.554736316935221 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.10518476172854 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857143` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857143` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838694 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.554736316935221 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.554736316935221 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838694 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.554736316935221 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.554736316935221 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.4078540315003913`*^-15 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.4078540315003913`*^-15 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.4078540315003913`*^-15 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.4078540315003913`*^-15 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838694 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.554736316935221 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.554736316935221 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           5.204748896376251*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           5.204748896376251*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838695 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352181) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352181 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838695 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352181) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352181 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           5.204748896376251*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838695 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352181) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352181 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838695 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352181) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352181 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.105184761728541 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.105184761728541 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857116`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857116` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.105184761728541 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.105184761728541 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857116`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857116` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838695 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352181) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352181 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.105184761728541 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.105184761728541 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857116`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857116` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.105184761728541 
            Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.105184761728541 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857116`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857116` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.9264880131729694` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729694` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516293`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516293` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.9264880131729694` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729694` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[
            0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516293`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516293` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.105184761728541 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.105184761728541 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857116`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857116` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.9264880131729694` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729694` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516293`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516293` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.9264880131729694` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729694` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516293`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516293` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.680607966083866 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.680607966083866 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1249999999999973`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1249999999999973` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.680607966083866 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.680607966083866 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[
            0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1249999999999973`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1249999999999973` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.9264880131729694` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729694` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516293`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516293` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.680607966083865 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.124999999999999) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.124999999999999 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.680607966083865 
            Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           3.680607966083865 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.124999999999999) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.124999999999999 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377503` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287061) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287061 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377503` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287061) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287061 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.680607966083865 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.124999999999999) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.124999999999999 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377503` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287061) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287061 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377503` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287061) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287061 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428286` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428255`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428255` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428286` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428255`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428255` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377503` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287061) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287061 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428286` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428255`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428255` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428286` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428255`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428255` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287064 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377485`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287064 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377485`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428286` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428255`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428255` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287064 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377485`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287064 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377485`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.1250000000000018` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.1250000000000018` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083863) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.1250000000000018` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.1250000000000018` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083863) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287064 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377485`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.1250000000000018` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.1250000000000018` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083863) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.1250000000000018` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.1250000000000018` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083863) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.626404587551634 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.626404587551634 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729676`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.626404587551634 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.626404587551634 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729676`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           2.1250000000000018` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.1250000000000018` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083863) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.626404587551634 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.626404587551634 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729676`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.626404587551634 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.626404587551634 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729676`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.0999809416857163` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857163` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728539) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.0999809416857163` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857163` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728539) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.626404587551634 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.626404587551634 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729676`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.0999809416857163` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857163` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728539) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.0999809416857163` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857163` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728539) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.5547363169352232 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352232 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838694) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           0.5547363169352232 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352232 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838694) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           1.0999809416857163` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857163` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728539) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           0.5547363169352232 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352232 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838694) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.5547363169352232 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352232 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838694) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.5554706181819696`*^-15 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.5554706181819696`*^-15 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           4.5554706181819696`*^-15 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.5554706181819696`*^-15 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           0.5547363169352232 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352232 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838694) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           7.807123344564377*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 7.807123344564377*^-16 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           7.807123344564377*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 7.807123344564377*^-16 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.5547363169352177 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352177 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838695) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838695 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 0.5547363169352177 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352177 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838695) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838695 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] + 
           7.807123344564377*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 7.807123344564377*^-16 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 0.5547363169352177 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352177 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838695) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838695 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.5547363169352177 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352177 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838695) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838695 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.0999809416857111` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857111` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728541) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728541 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.0999809416857111` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857111` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728541) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728541 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 0.5547363169352177 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352177 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838695) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838695 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.0999809416857111` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857111` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728541) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728541 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.0999809416857111` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857111` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728541) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728541 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.626404587551629 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.626404587551629 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729694`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729694` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.626404587551629 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.626404587551629 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729694`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729694` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.0999809416857111` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857111` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728541) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728541 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.626404587551629 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.626404587551629 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729694`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729694` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.626404587551629 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.626404587551629 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729694`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729694` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.124999999999997 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999997 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083866) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083866 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.124999999999997 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999997 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083866) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083866 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 1.626404587551629 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.626404587551629 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729694`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729694` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.124999999999997 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999997 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083866) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083866 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.124999999999997 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999997 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083866) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083866 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.5872360732870594` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870594` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377516`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377516` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.5872360732870594` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870594` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377516`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377516` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.124999999999997 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999997 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083866) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083866 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.5872360732870594` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870594` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377516`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377516` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.5872360732870594` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870594` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377516`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377516` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.0052038200428233` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428233` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428304`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428304` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.0052038200428233` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428233` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428304`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428304` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 2.5872360732870594` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870594` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377516`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377516` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.005203820042827 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428277`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428277` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.005203820042827 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428277`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428277` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377485` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287064) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287064 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377485` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287064) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287064 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.005203820042827 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428277`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428277` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377485` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287064) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287064 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377485` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287064) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287064 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.680607966083863 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1250000000000018`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1250000000000018` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.680607966083863 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1250000000000018`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1250000000000018` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377485` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287064) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287064 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.680607966083863 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1250000000000018`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1250000000000018` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.680607966083863 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1250000000000018`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1250000000000018` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729676` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516342`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516342` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729676` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516342`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516342` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.680607966083863 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1250000000000018`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1250000000000018` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729676` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516342`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516342` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729676` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516342`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516342` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.105184761728539 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857165`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857165` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.105184761728539 
            Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857165`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857165` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729676` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516342`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516342` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.105184761728539 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857165`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857165` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.105184761728539 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857165`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857165` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352234) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352234 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352234) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352234 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.105184761728539 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857165`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857165` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352234) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352234 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352234) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352234 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.8157080630007826`*^-15) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.8157080630007826`*^-15 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ro 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.8157080630007826`*^-15) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.8157080630007826`*^-15 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ro 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ro] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ro Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
           Sign[$CellContext`ro] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352234) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352234 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.5547363169352192 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.5547363169352192 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.5547363169352192 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.5547363169352192 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.5547363169352192 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.5547363169352192 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.5547363169352192 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.5547363169352192 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.10518476172854 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.10518476172854 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857131` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.10518476172854 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857131` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.5547363169352192 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.5547363169352192 
            Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.10518476172854 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857131` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.10518476172854 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.10518476172854 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857131` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.9264880131729685` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516315` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516315` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.9264880131729685` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516315` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516315` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.10518476172854 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857131` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.9264880131729685` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516315` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516315` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.9264880131729685` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516315` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516315` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.6806079660838646` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.6806079660838646` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.6806079660838646` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.6806079660838646` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.9264880131729685` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516315` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516315` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.6806079660838646` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.6806079660838646` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.6806079660838646` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.6806079660838646` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.3717516962377494` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377494` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.5872360732870625` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.5872360732870625` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.3717516962377494` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377494` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.5872360732870625` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.5872360732870625` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.6806079660838646` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.6806079660838646` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.3717516962377494` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377494` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.5872360732870625` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.5872360732870625` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.3717516962377494` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377494` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.5872360732870625` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.5872360732870625` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.0052038200428277` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428277` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.0052038200428277` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428277` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.3717516962377494` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377494` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.5872360732870625` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.5872360732870625` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.0052038200428273` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.0052038200428273` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.5872360732870634` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870634` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.371751696237749 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.371751696237749 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.5872360732870634` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870634` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.371751696237749 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.371751696237749 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.0052038200428273` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.5872360732870634` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870634` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.371751696237749 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.371751696237749 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.5872360732870634` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870634` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.371751696237749 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.371751696237749 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.1250000000000004` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1250000000000004` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083864 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083864 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.1250000000000004` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1250000000000004` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083864 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083864 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.5872360732870634` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870634` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.371751696237749 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.371751696237749 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.1250000000000004` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1250000000000004` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083864 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083864 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.1250000000000004` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1250000000000004` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083864 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083864 
            Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.6264045875516318` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.6264045875516318` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.1250000000000004` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1250000000000004` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083864 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083864 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.6264045875516318` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.6264045875516318` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.0999809416857131` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.0999809416857131` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.6264045875516318` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.099980941685714 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.099980941685714 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.099980941685714 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.099980941685714 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.5547363169352197 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352197 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.5547363169352197 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352197 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.099980941685714 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.099980941685714 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.5547363169352197 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352197 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.5547363169352197 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352197 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.5547363169352197 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352197 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.5547363169352193 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352193 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.5547363169352193 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352193 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.5547363169352184 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352184 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838695 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.5547363169352184 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352184 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838695 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.0999809416857127` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857127` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.0999809416857127` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857127` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.5547363169352184 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352184 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838695 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838695 
            Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.0999809416857127` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857127` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.0999809416857127` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857127` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.6264045875516313` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.6264045875516313` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.6264045875516313` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.6264045875516313` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.0999809416857127` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857127` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.6264045875516304` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.6264045875516304` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.926488013172969 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.926488013172969 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.6264045875516304` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.6264045875516304` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.926488013172969 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.926488013172969 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083865 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083865 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.6264045875516304` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.6264045875516304` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.926488013172969 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.926488013172969 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083865 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083865 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.587236073287061 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287061 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.3717516962377503` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.587236073287061 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287061 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.3717516962377503` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083865 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.587236073287061 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287061 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.3717516962377503` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.587236073287061 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287061 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.3717516962377503` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.0052038200428255` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428255` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.0052038200428286` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.0052038200428255` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428255` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.0052038200428286` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.587236073287061 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287061 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.3717516962377503` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.005203820042827 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.0052038200428273` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.005203820042827 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.0052038200428273` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.3717516962377485` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377485` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.587236073287064 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.3717516962377485` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377485` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.587236073287064 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.005203820042827 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.0052038200428273` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.3717516962377485` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377485` 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.587236073287064 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.3717516962377485` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377485` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.587236073287064 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.6806079660838638` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.6806079660838638` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1250000000000013` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1250000000000013` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.6806079660838638` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.6806079660838638` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1250000000000013` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1250000000000013` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.3717516962377485` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377485` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.587236073287064 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.6806079660838638` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.6806079660838638` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1250000000000013` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1250000000000013` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.6806079660838638` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.6806079660838638` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1250000000000013` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1250000000000013` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.9264880131729676` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729676` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516338` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516338` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.9264880131729676` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729676` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516338` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516338` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.6806079660838638` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.6806079660838638` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1250000000000013` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1250000000000013` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729685` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516318` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729685` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516318` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.10518476172854 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857143` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857143` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.10518476172854 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857143` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857143` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729685` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516318` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.10518476172854 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857143` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857143` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.10518476172854 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857143` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857143` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838694 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.554736316935221 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.554736316935221 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838694 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.554736316935221 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.554736316935221 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.10518476172854 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857143` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857143` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838694 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.554736316935221 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.554736316935221 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838694 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.554736316935221 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.554736316935221 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.4078540315003913`*^-15 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.4078540315003913`*^-15 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.4078540315003913`*^-15 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.4078540315003913`*^-15 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838694 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.554736316935221 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.554736316935221 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           5.204748896376251*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           5.204748896376251*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838695 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352181) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352181 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838695 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352181) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352181 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           5.204748896376251*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838695 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352181) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352181 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838695 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352181) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352181 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.105184761728541 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.105184761728541 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857116`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857116` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.105184761728541 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.105184761728541 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857116`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857116` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838695 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352181) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352181 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.105184761728541 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.105184761728541 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857116`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857116` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.105184761728541 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.105184761728541 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857116`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857116` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.9264880131729694` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729694` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516293`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516293` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.9264880131729694` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729694` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516293`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516293` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.105184761728541 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.105184761728541 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857116`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857116` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.9264880131729694` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729694` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516293`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516293` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.9264880131729694` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729694` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516293`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516293` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.680607966083866 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.680607966083866 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1249999999999973`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1249999999999973` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.680607966083866 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.680607966083866 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1249999999999973`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1249999999999973` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.9264880131729694` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729694` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516293`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516293` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.680607966083865 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.124999999999999) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.124999999999999 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.680607966083865 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.124999999999999) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.124999999999999 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377503` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287061) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287061 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377503` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287061) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287061 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.680607966083865 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.124999999999999) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.124999999999999 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377503` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287061) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287061 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377503` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287061) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287061 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428286` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428255`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428255` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428286` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428255`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428255` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377503` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287061) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287061 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428286` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428255`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428255` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428286` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428255`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428255` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287064 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[
             0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377485`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287064 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377485`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428286` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428255`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428255` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287064 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377485`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287064 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377485`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.1250000000000018` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.1250000000000018` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083863) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.1250000000000018` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.1250000000000018` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083863) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287064 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377485`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.1250000000000018` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.1250000000000018` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083863) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.1250000000000018` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.1250000000000018` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083863) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.626404587551634 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.626404587551634 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729676`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.626404587551634 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.626404587551634 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729676`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           2.1250000000000018` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.1250000000000018` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083863) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.626404587551634 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.626404587551634 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729676`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.626404587551634 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.626404587551634 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729676`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.0999809416857163` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857163` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728539) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.0999809416857163` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857163` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728539) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.626404587551634 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.626404587551634 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729676`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.0999809416857163` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857163` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728539) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.0999809416857163` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857163` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728539) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.5547363169352232 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352232 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838694) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.5547363169352232 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352232 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838694) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           1.0999809416857163` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857163` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728539) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.5547363169352232 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352232 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838694) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.5547363169352232 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352232 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838694) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.5554706181819696`*^-15 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.5554706181819696`*^-15 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           4.5554706181819696`*^-15 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.5554706181819696`*^-15 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           0.5547363169352232 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352232 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838694) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           7.807123344564377*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 7.807123344564377*^-16 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           7.807123344564377*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 7.807123344564377*^-16 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.5547363169352177 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352177 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838695) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838695 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.5547363169352177 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352177 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838695) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838695 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] + 
           7.807123344564377*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 7.807123344564377*^-16 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.5547363169352177 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352177 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838695) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838695 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.5547363169352177 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352177 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[
             0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838695) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838695 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.0999809416857111` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857111` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728541) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728541 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.0999809416857111` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857111` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728541) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728541 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 0.5547363169352177 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352177 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838695) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838695 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.0999809416857111` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857111` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728541) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728541 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.0999809416857111` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857111` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728541) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728541 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.626404587551629 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.626404587551629 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729694`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729694` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.626404587551629 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.626404587551629 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729694`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729694` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.0999809416857111` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857111` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728541) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728541 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.626404587551629 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.626404587551629 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729694`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729694` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.626404587551629 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.626404587551629 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729694`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729694` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.124999999999997 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999997 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083866) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083866 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.124999999999997 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999997 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083866) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083866 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 1.626404587551629 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.626404587551629 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729694`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729694` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.124999999999997 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999997 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083866) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083866 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.124999999999997 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999997 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083866) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083866 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.5872360732870594` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870594` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377516`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377516` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.5872360732870594` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870594` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377516`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377516` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.124999999999997 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999997 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083866) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083866 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.5872360732870594` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870594` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377516`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377516` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.5872360732870594` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870594` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377516`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377516` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.0052038200428233` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428233` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428304`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428304` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.0052038200428233` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428233` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428304`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428304` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 2.5872360732870594` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870594` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377516`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377516` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.005203820042827 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428277`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428277` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.005203820042827 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428277`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428277` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377485` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287064) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287064 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377485` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287064) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287064 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.005203820042827 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428277`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428277` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377485` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287064) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287064 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377485` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287064) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287064 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.680607966083863 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1250000000000018`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1250000000000018` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.680607966083863 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1250000000000018`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1250000000000018` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377485` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287064) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287064 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.680607966083863 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1250000000000018`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1250000000000018` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.680607966083863 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1250000000000018`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1250000000000018` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729676` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516342`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516342` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729676` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516342`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516342` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.680607966083863 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1250000000000018`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1250000000000018` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729676` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516342`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516342` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729676` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516342`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516342` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.105184761728539 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857165`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857165` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.105184761728539 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[
            0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857165`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857165` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729676` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516342`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516342` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.105184761728539 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857165`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857165` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.105184761728539 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857165`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857165` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352234) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352234 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352234) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352234 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.105184761728539 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857165`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857165` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352234) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352234 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352234) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352234 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.8157080630007826`*^-15) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.8157080630007826`*^-15 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[
             0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.8157080630007826`*^-15) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.8157080630007826`*^-15 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 + $CellContext`ri 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] 
           Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ri 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] - 1. 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
           Sign[$CellContext`ri] 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352234) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352234 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.5547363169352192 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.5547363169352192 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.5547363169352192 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.5547363169352192 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.}, {$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.5547363169352192 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.5547363169352192 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.5547363169352192 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.5547363169352192 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.10518476172854 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.10518476172854 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857131` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.10518476172854 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.10518476172854 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857131` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.5547363169352192 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.5547363169352192 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.10518476172854 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.10518476172854 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857131` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.10518476172854 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.10518476172854 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857131` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.9264880131729685` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516315` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516315` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.9264880131729685` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516315` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516315` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.10518476172854 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.10518476172854 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857131` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.9264880131729685` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516315` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516315` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.9264880131729685` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516315` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516315` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.6806079660838646` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.6806079660838646` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.6806079660838646` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.6806079660838646` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.9264880131729685` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516315` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516315` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.6806079660838646` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.6806079660838646` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.6806079660838646` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.6806079660838646` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.3717516962377494` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377494` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.5872360732870625` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.5872360732870625` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.3717516962377494` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377494` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.5872360732870625` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.5872360732870625` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.6806079660838646` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.6806079660838646` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1249999999999996` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1249999999999996` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.3717516962377494` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377494` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.5872360732870625` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.5872360732870625` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.3717516962377494` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377494` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.5872360732870625` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.5872360732870625` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.0052038200428277` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428277` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.0052038200428277` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428277` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.3717516962377494` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377494` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.5872360732870625` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.5872360732870625` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.0052038200428273` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.0052038200428273` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.5872360732870634` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870634` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.371751696237749 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.371751696237749 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.5872360732870634` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870634` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.371751696237749 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.371751696237749 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.0052038200428273` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.5872360732870634` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870634` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.371751696237749 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.371751696237749 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.5872360732870634` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870634` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.371751696237749 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.371751696237749 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.1250000000000004` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1250000000000004` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083864 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083864 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.1250000000000004` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1250000000000004` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083864 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083864 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.5872360732870634` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870634` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.371751696237749 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.371751696237749 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.1250000000000004` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1250000000000004` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083864 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083864 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.1250000000000004` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1250000000000004` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083864 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083864 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 1.6264045875516318` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.6264045875516318` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.1250000000000004` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.1250000000000004` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083864 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083864 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.6264045875516318` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 1.6264045875516318` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 1.0999809416857131` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.0999809416857131` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857131` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.6264045875516318` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.099980941685714 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.099980941685714 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 1.099980941685714 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.099980941685714 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 0.5547363169352197 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352197 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.5547363169352197 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352197 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.099980941685714 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.099980941685714 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.5547363169352197 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352197 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 0.5547363169352197 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352197 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.5547363169352197 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352197 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           0.5547363169352193 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352193 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.5547363169352193 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352193 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.6023744481881253`*^-16 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.6023744481881253`*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.25 Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.5547363169352184 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352184 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838695 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           0.5547363169352184 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352184 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838695 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           1.0999809416857127` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857127` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.0999809416857127` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857127` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.5547363169352184 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352184 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.213640660838695 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.0999809416857127` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857127` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           1.0999809416857127` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857127` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           1.6264045875516313` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.6264045875516313` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.6264045875516313` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.6264045875516313` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.9264880131729685` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.0999809416857127` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857127` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           4.10518476172854 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.6264045875516304` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.6264045875516304` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.926488013172969 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.926488013172969 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           1.6264045875516304` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.6264045875516304` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.926488013172969 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.926488013172969 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083865 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083865 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.6264045875516304` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.6264045875516304` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.926488013172969 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.926488013172969 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083865 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083865 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           2.587236073287061 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287061 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.3717516962377503` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.587236073287061 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287061 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.3717516962377503` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.124999999999999 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.124999999999999 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.680607966083865 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.587236073287061 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287061 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.3717516962377503` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.3717516962377503` 
            Sin[
              0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           2.587236073287061 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287061 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.3717516962377503` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.0052038200428255` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428255` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.0052038200428286` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.0052038200428255` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428255` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.0052038200428286` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.587236073287061 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287061 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.3717516962377503` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.005203820042827 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.0052038200428273` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.005203820042827 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.0052038200428273` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.3717516962377485` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377485` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.587236073287064 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.3717516962377485` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377485` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.587236073287064 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.005203820042827 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.005203820042827 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           3.0052038200428273` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           3.0052038200428273` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.3717516962377485` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377485` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.587236073287064 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.3717516962377485` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377485` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.587236073287064 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.6806079660838638` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.6806079660838638` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1250000000000013` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1250000000000013` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.6806079660838638` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.6806079660838638` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1250000000000013` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1250000000000013` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.3717516962377485` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377485` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.587236073287064 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.6806079660838638` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.6806079660838638` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1250000000000013` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1250000000000013` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.6806079660838638` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.6806079660838638` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1250000000000013` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1250000000000013` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.9264880131729676` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729676` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516338` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516338` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.9264880131729676` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729676` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516338` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516338` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.6806079660838638` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.6806079660838638` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.1250000000000013` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.1250000000000013` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729685` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516318` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.9264880131729685` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729685` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516318` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           4.10518476172854 Sin[0.017453292519943295` $CellContext`\[Theta]1],
            $CellContext`y1 - 4.10518476172854 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857143` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857143` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.10518476172854 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857143` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857143` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.9264880131729685` 
            Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           3.9264880131729685` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.6264045875516318` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.6264045875516318` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.10518476172854 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857143` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857143` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.10518476172854 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857143` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857143` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838694 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.554736316935221 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.554736316935221 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838694 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.554736316935221 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.554736316935221 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.10518476172854 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.10518476172854 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           1.0999809416857143` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           1.0999809416857143` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838694 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.554736316935221 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.554736316935221 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838694 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.554736316935221 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.554736316935221 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.4078540315003913`*^-15 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.4078540315003913`*^-15 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           2.4078540315003913`*^-15 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           2.4078540315003913`*^-15 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.213640660838694 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838694 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           0.554736316935221 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           0.554736316935221 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           5.204748896376251*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           5.204748896376251*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838695 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352181) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352181 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838695 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352181) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352181 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.25 Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], 
           5.204748896376251*^-16 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 + 
           5.204748896376251*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838695 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352181) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352181 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838695 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352181) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352181 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           4.105184761728541 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.105184761728541 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857116`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857116` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.105184761728541 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.105184761728541 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857116`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857116` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.213640660838695 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.213640660838695 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352181) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352181 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.105184761728541 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.105184761728541 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857116`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857116` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           4.105184761728541 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.105184761728541 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857116`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857116` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.9264880131729694` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729694` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516293`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516293` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.9264880131729694` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729694` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516293`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516293` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.105184761728541 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.105184761728541 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857116`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857116` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.9264880131729694` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729694` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516293`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516293` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.9264880131729694` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729694` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516293`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516293` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.680607966083866 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.680607966083866 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1249999999999973`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1249999999999973` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.680607966083866 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.680607966083866 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1249999999999973`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1249999999999973` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.9264880131729694` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.9264880131729694` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516293`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516293` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.680607966083865 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.124999999999999) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.124999999999999 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.680607966083865 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.124999999999999) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.124999999999999 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377503` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287061) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287061 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377503` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287061) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287061 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.680607966083865 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.680607966083865 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.124999999999999) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.124999999999999 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377503` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287061) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287061 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377503` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287061) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287061 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428286` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428255`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428255` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428286` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428255`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428255` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.3717516962377503` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.3717516962377503` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287061) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287061 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428286` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428255`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428255` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428286` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428255`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428255` 
           Sin[
             0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287064 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377485`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287064 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377485`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           3.0052038200428286` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 3.0052038200428286` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428255`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428255` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287064 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377485`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287064 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377485`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           2.1250000000000018` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.1250000000000018` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083863) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.1250000000000018` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.1250000000000018` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083863) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.587236073287064 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.587236073287064 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377485`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.1250000000000018` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.1250000000000018` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083863) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           2.1250000000000018` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.1250000000000018` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083863) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           1.626404587551634 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.626404587551634 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729676`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.626404587551634 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.626404587551634 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729676`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           2.1250000000000018` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 2.1250000000000018` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083863) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.626404587551634 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.626404587551634 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729676`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           1.626404587551634 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.626404587551634 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729676`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           1.0999809416857163` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857163` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728539) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.0999809416857163` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857163` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728539) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.626404587551634 
            Sin[
             0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 - 
           1.626404587551634 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729676`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.0999809416857163` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857163` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728539) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           1.0999809416857163` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857163` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728539) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           0.5547363169352232 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352232 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838694) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.5547363169352232 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352232 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838694) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           1.0999809416857163` 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 1.0999809416857163` 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728539) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.5547363169352232 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352232 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838694) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           0.5547363169352232 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352232 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838694) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           4.5554706181819696`*^-15 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.5554706181819696`*^-15 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           4.5554706181819696`*^-15 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 4.5554706181819696`*^-15 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           0.5547363169352232 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 0.5547363169352232 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838694) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           7.807123344564377*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 7.807123344564377*^-16 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[
            0.017453292519943295` $CellContext`\[Theta]1] + $CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] + 
           7.807123344564377*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 7.807123344564377*^-16 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 0.5547363169352177 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352177 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838695) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838695 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.5547363169352177 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352177 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838695) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838695 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] + 
           7.807123344564377*^-16 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
$CellContext`y1 - 7.807123344564377*^-16 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], (-4.25) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 4.25 
           Sin[
             0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.5547363169352177 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352177 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838695) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838695 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 0.5547363169352177 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352177 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838695) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838695 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 1.0999809416857111` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857111` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728541) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728541 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.0999809416857111` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857111` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728541) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728541 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 0.5547363169352177 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           0.5547363169352177 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.213640660838695) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.213640660838695 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.0999809416857111` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857111` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728541) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728541 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 1.0999809416857111` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857111` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728541) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728541 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 1.626404587551629 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.626404587551629 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729694`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729694` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.626404587551629 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.626404587551629 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729694`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729694` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.0999809416857111` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.0999809416857111` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.105184761728541) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.105184761728541 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.626404587551629 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.626404587551629 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729694`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729694` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 1.626404587551629 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.626404587551629 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729694`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729694` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.124999999999997 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999997 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083866) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083866 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.124999999999997 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999997 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083866) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083866 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 1.626404587551629 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           1.626404587551629 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.9264880131729694`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.9264880131729694` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.124999999999997 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999997 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083866) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083866 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.124999999999997 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999997 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083866) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083866 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.5872360732870594` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870594` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377516`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377516` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.5872360732870594` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870594` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377516`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377516` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.124999999999997 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.124999999999997 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.680607966083866) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.680607966083866 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.5872360732870594` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870594` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377516`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377516` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 2.5872360732870594` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870594` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377516`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377516` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.0052038200428233` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428233` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428304`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428304` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.0052038200428233` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.0052038200428233` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428304`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428304` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 2.5872360732870594` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           2.5872360732870594` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.3717516962377516`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.3717516962377516` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.005203820042827 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428277`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428277` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.005203820042827 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428277`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428277` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377485` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287064) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287064 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377485` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[
             0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287064) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287064 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.005203820042827 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.005203820042827 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-3.0052038200428277`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           3.0052038200428277` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377485` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287064) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287064 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377485` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287064) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287064 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.680607966083863 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1250000000000018`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1250000000000018` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.680607966083863 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1250000000000018`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1250000000000018` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.3717516962377485` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.3717516962377485` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.587236073287064) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.587236073287064 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.680607966083863 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1250000000000018`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1250000000000018` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.680607966083863 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1250000000000018`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1250000000000018` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729676` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516342`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516342` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729676` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516342`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516342` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.680607966083863 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.680607966083863 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062499999999996` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-2.1250000000000018`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           2.1250000000000018` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729676` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516342`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516342` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729676` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516342`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516342` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.105184761728539 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857165`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857165` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.105184761728539 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857165`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857165` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 3.9264880131729676` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           3.9264880131729676` 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.6264045875516342`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.6264045875516342` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.105184761728539 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857165`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857165` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.105184761728539 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857165`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857165` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352234) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352234 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352234) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352234 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.105184761728539 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.105184761728539 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-1.0999809416857165`) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           1.0999809416857165` 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352234) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352234 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ro^2] 
            Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352234) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352234 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ro 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ro] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ro 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           2. $CellContext`to 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ro^2] Sign[$CellContext`ro] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.8157080630007826`*^-15) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.8157080630007826`*^-15 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.25 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.25 Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.0625 + $CellContext`ri^2] Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-4.8157080630007826`*^-15) 
            Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           4.8157080630007826`*^-15 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}, \
{$CellContext`x1 - 1. $CellContext`ri 
           Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Cos[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] 
            Sign[$CellContext`ri] - 4.213640660838694 
           Sin[0.017453292519943295` $CellContext`\[Theta]1], $CellContext`y1 + 
           4.213640660838694 
            Cos[0.017453292519943295` $CellContext`\[Theta]1] - 
           1. $CellContext`ri 
           Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`ti 
            Sin[0.017453292519943295` $CellContext`\[Theta]1] + \
$CellContext`to Sin[0.017453292519943295` $CellContext`\[Theta]1] + 
           Sqrt[-18.062500000000004` + $CellContext`ri^2] 
            Sign[$CellContext`ri] 
            Sin[0.017453292519943295` $CellContext`\[Theta]1], \
(-0.5547363169352234) Cos[0.017453292519943295` $CellContext`\[Theta]1]^2 - 
           0.5547363169352234 
           Sin[0.017453292519943295` $CellContext`\[Theta]1]^2}}]); 
     Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5448795644912443`*^9}]
}, Open  ]]
},
WindowSize->{1359, 1011},
WindowMargins->{{Automatic, 123}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 5, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3544861552-7689995"->{
  Cell[754, 28, 1228, 17, 130, "Print",
   CellTags->"Info3544861552-7689995"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3544861552-7689995", 2022631, 35914}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 184, 4, 58, "Input"],
Cell[754, 28, 1228, 17, 130, "Print",
 CellTags->"Info3544861552-7689995"]
}, Open  ]],
Cell[1997, 48, 3154, 82, 103, "Input"],
Cell[CellGroupData[{
Cell[5176, 134, 477, 11, 58, "Input"],
Cell[CellGroupData[{
Cell[5678, 149, 64054, 1047, 403, "Print"],
Cell[69735, 1198, 4792, 122, 81, "Print"]
}, Open  ]],
Cell[74542, 1323, 131, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74710, 1329, 1134, 24, 27, "Input"],
Cell[75847, 1355, 1946426, 34544, 1553, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
