(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      6487,        179]
NotebookOptionsPosition[      5493,        141]
NotebookOutlinePosition[      6179,        167]
CellTagsIndexPosition[      6095,        162]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Optica`Optica`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.407177934160603*^9, 3.4071779528777437`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "DynamicFrame"}]], "Input",
 CellChangeTimes->{{3.407177998318359*^9, 3.407178007282166*^9}}],

Cell[BoxData[
 StyleBox["\<\"DynamicFrame[actions] takes series of options that define the \
dynamic presentation of an optical model. \\n\\nDynamicFrame works within the \
ManipulateSystem function. Two examples DynamicFrame models are: \
DynamicFrame[{OpticalSystem->{WedgeOfRays[10],Move[PlanoConvexLens[{f,100},50,\
10],{x,50}], Boundary[150]}, PlotType->TopView}] and \
DynamicFrame[{NewSource->WedgeOfRays[10], OpticaFunction->TurboPlot, \
PlotType->Full3D}]. DynamicFrame can accept up to four different modes of \
operation (LocalMode, DynamicMode, StaticMode, and ButtonMode) in response to \
types of events present. These different modes can be used to modify the \
default behavior of the Dynamic for the particular mode of operation. If no \
mode of operation has been specified, then the default behaviors of each mode \
is given by Options[ManipulateSystem]. In particular, LocalMode is used to \
specify a local-driven event that originates from the corresponding sliders \
and graphics windows to a particular DynamicFrame instance. DynamicMode \
relates to an input originating from sliders and graphics windows of other \
DynamicFrame instances present. StaticMode is triggered when a slider or \
locator has been released. Finally, ButtonMode is only triggered when a \
corresponding button has been intentionally pressed. See also: LocalMode, \
DynamicMode, StaticMode, ButtonMode, MeasureTools, FrameDescription, \
ButtonLabel, SliderLabelReplacements, CustomFrameFunction, \
CustomFrameSettings, $RayTraceFunction, $RayTraceSymbols, and \
ManipulateSystem.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.614748515242288*^9},
 CellTags->"Info3614730515-5945536"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "DynamicWindow"}]], "Input",
 CellChangeTimes->{{3.407255939082312*^9, 3.407255941593092*^9}}],

Cell[BoxData[
 StyleBox["\<\"DynamicWindow[\\\"label\\\",contents] creates a new window for \
its contents.\\n \\nA button is generated with the provided label. \
DynamicWindow works within the ManipulateSystem function and accepts multiple \
DynamicFrame objects. See also: NewWindow, LocalMode, DynamicMode, \
StaticMode, ButtonMode, MeasureTools, FrameDescription, ButtonLabel, \
SliderLabelReplacements, and ManipulateSystem.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.614748515482613*^9},
 CellTags->"Info3614730515-5945536"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ManipulateSystem", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"LineOfRays", "[", 
        RowBox[{"40", ",", 
         RowBox[{"NumberOfRays", "\[Rule]", "11"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"xs", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"ys", ",", "0"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ths", ",", "0"}], "}"}]}], "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"PlanoConvexLens", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"f", ",", "100"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"a", ",", "50"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "10"}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"xlns", ",", "50"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"ylns", ",", "0"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"thlns", ",", "0"}], "}"}]}], "]"}], ",", 
     RowBox[{"Boundary", "[", 
      RowBox[{"150", ",", "75"}], "]"}]}], "}"}], ",", 
   RowBox[{"Row", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"DynamicWindow", "[", 
       RowBox[{"\"\<Top View\>\"", ",", 
        RowBox[{"PlotType", "\[Rule]", "TopView"}]}], "]"}], ",", 
      RowBox[{"DynamicWindow", "[", 
       RowBox[{"\"\<Front View\>\"", ",", 
        RowBox[{"PlotType", "\[Rule]", "FrontView"}]}], "]"}], ",", 
      RowBox[{"DynamicWindow", "[", 
       RowBox[{"\"\<Three-Dimensional View\>\"", ",", 
        RowBox[{"PlotType", "\[Rule]", "Full3D"}]}], "]"}]}], "}"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.407251450661965*^9, 3.407251620552144*^9}, 
   3.407251668928987*^9, {3.407251967576571*^9, 3.407251998342314*^9}, {
   3.407253026638958*^9, 3.407253046985269*^9}}],

Cell[BoxData[
 TemplateBox[{FrontEndObject[
    LinkObject["q9p_shm", 3, 1]],50,
   "FrontEndObject[LinkObject[\"q9p_shm\", 3, 1]]","50","\"Optical System\""},
  
  "NotebookObjectUnsaved"]], "Output",
 CellChangeTimes->{3.614748523564548*^9}]
}, Open  ]]
},
WindowSize->{1462, 989},
WindowMargins->{{131, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3614730515-5945536"->{
  Cell[841, 30, 1696, 24, 167, "Print",
   CellTags->"Info3614730515-5945536"],
  Cell[2699, 63, 548, 9, 95, "Print",
   CellTags->"Info3614730515-5945536"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3614730515-5945536", 5913, 154}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 147, 2, 28, "Input"],
Cell[CellGroupData[{
Cell[717, 26, 121, 2, 28, "Input"],
Cell[841, 30, 1696, 24, 167, "Print",
 CellTags->"Info3614730515-5945536"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2574, 59, 122, 2, 28, "Input"],
Cell[2699, 63, 548, 9, 95, "Print",
 CellTags->"Info3614730515-5945536"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3284, 77, 1947, 53, 63, "Input"],
Cell[5234, 132, 243, 6, 75, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
