(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1440869,      37986]*)
(*NotebookOutlinePosition[   1446916,      38143]*)
(*  CellTagsIndexPosition[   1446670,      38133]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CustomPrism and Stellated Icosahedron", "Subsection",
  CellTags->"CustomPrism"],

Cell[TextData[{
  "You can use ",
  StyleBox["CustomPrism", "Input"],
  " to turn ordinary ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics into a optical component. However, this only works for graphics \
that are based on ",
  StyleBox["Polygon", "Input"],
  " and ",
  StyleBox["Line", "Input"],
  " primatives. Here we will use a Stellated Icosahedron."
}], "Text",
  CellTags->"CustomPrism"],

Cell["<<Graphics`Polyhedra`", "Input",
  CellTags->"CustomPrism"],

Cell["stel = Stellate[Icosahedron[ ]];", "Input",
  CellTags->"CustomPrism"],

Cell[CellGroupData[{

Cell["?CustomPrism", "Input",
  CellTags->"CustomPrism"],

Cell[BoxData[
    \("CustomPrism[facetpointlisting, options] creates a multi-faceted prism \
with user-specified optical properties.\n\nAs its first parameter, \
CustomPrism accepts either a Graphics3D object or a nested list of \
three-dimensional points to describe the facet vertices. The optical \
properties of CustomPrism are specified by the SurfaceType option. See also: \
SurfaceType and SurfaceFacet."\)], "Print",
  CellTags->"CustomPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["show = Show[Graphics3D[stel],Axes->True];", "Input",
  CellTags->"CustomPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00162 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0206914 1.08755 0 1.08755 [
[.19758 .1856 -11.4908 -9 ]
[.19758 .1856 .50925 0 ]
[.35212 .12216 -5.44839 -9 ]
[.35212 .12216 .55161 0 ]
[.5164 .05478 -5.1514 -9 ]
[.5164 .05478 .8486 0 ]
[.10066 .80545 -6.72912 0 ]
[.10066 .80545 5.27088 9 ]
[.21156 .887 -3.26269 0 ]
[.21156 .887 2.73731 9 ]
[.31085 .96001 -3.17537 0 ]
[.31085 .96001 2.82463 9 ]
[.04788 .32955 -12 -2.72392 ]
[.04788 .32955 0 6.27608 ]
[.02586 .4711 -6 -2.84609 ]
[.02586 .4711 0 6.15391 ]
[.00165 .6267 -6 -2.98166 ]
[.00165 .6267 0 6.01834 ]
[ 0 0 0 0 ]
[ 1 1.00162 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07192 .25073 m
.68538 0 L
s
.20676 .19562 m
.21134 .20064 L
s
[(-1)] .19758 .1856 .91513 1 Mshowa
.36072 .1327 m
.36502 .13796 L
s
[(0)] .35212 .12216 .81613 1 Mshowa
.52432 .06583 m
.52828 .07135 L
s
[(1)] .5164 .05478 .71713 1 Mshowa
.125 Mabswid
.23682 .18334 m
.23954 .18638 L
s
.26724 .1709 m
.26993 .17397 L
s
.29803 .15832 m
.30068 .16142 L
s
.32918 .14559 m
.3318 .14871 L
s
.39264 .11965 m
.39518 .12284 L
s
.42495 .10644 m
.42746 .10966 L
s
.45767 .09307 m
.46013 .09632 L
s
.49079 .07954 m
.49321 .08282 L
s
.17704 .20777 m
.17983 .21075 L
s
.14768 .21977 m
.15049 .22272 L
s
.11865 .23163 m
.1215 .23455 L
s
.08996 .24336 m
.09284 .24625 L
s
.55828 .05195 m
.56061 .0553 L
s
.59266 .0379 m
.59495 .04127 L
s
.62749 .02366 m
.62973 .02707 L
s
.66276 .00925 m
.66495 .01268 L
s
.25 Mabswid
0 .71646 m
.38643 1.00162 L
s
.1023 .79195 m
.10312 .7852 L
s
[(-1)] .10066 .80545 .12152 -1 Mshowa
.21274 .87345 m
.21334 .86668 L
s
[(0)] .21156 .887 .08756 -1 Mshowa
.31164 .94644 m
.31204 .93965 L
s
[(1)] .31085 .96001 .05846 -1 Mshowa
.125 Mabswid
.12541 .809 m
.12587 .80495 L
s
.14799 .82567 m
.14842 .82161 L
s
.17006 .84196 m
.17047 .8379 L
s
.19164 .85788 m
.19202 .85382 L
s
.23339 .88869 m
.23372 .88462 L
s
.25359 .90359 m
.25389 .89953 L
s
.27335 .91818 m
.27363 .91411 L
s
.2927 .93246 m
.29296 .92839 L
s
.07864 .77449 m
.07917 .77045 L
s
.05442 .75662 m
.05498 .75258 L
s
.02962 .73832 m
.0302 .73428 L
s
.0042 .71956 m
.00482 .71553 L
s
.3302 .96013 m
.33041 .95605 L
s
.34837 .97354 m
.34856 .96946 L
s
.36617 .98667 m
.36635 .9826 L
s
.38362 .99955 m
.38377 .99547 L
s
.25 Mabswid
.07192 .25073 m
0 .71646 L
s
.06052 .32456 m
.06684 .32207 L
s
[(-1)] .04788 .32955 1 -0.39468 Mshowa
.03862 .46641 m
.045 .46406 L
s
[(0)] .02586 .4711 1 -0.36754 Mshowa
.01453 .62235 m
.02097 .62018 L
s
[(1)] .00165 .6267 1 -0.33741 Mshowa
.125 Mabswid
.0563 .3519 m
.0601 .35042 L
s
.052 .37973 m
.05581 .37827 L
s
.04762 .40809 m
.05144 .40664 L
s
.04316 .43697 m
.04698 .43555 L
s
.03398 .4964 m
.03782 .49501 L
s
.02926 .52698 m
.0331 .52561 L
s
.02445 .55815 m
.0283 .5568 L
s
.01954 .58993 m
.0234 .58861 L
s
.06467 .29772 m
.06845 .29621 L
s
.06874 .27135 m
.07252 .26982 L
s
.00943 .65542 m
.0133 .65414 L
s
.00422 .68916 m
.0081 .6879 L
s
.25 Mabswid
.07192 .25073 m
0 .71646 L
s
0 .71646 m
.38643 1.00162 L
s
.38643 1.00162 m
.40217 .57872 L
s
.40217 .57872 m
.07192 .25073 L
s
.68538 0 m
.93948 .40631 L
s
.93948 .40631 m
1 .85355 L
s
1 .85355 m
.71506 .4883 L
s
.71506 .4883 m
.68538 0 L
s
.07192 .25073 m
0 .71646 L
s
0 .71646 m
.71506 .4883 L
s
.71506 .4883 m
.68538 0 L
s
.68538 0 m
.07192 .25073 L
s
.40217 .57872 m
.93948 .40631 L
s
.93948 .40631 m
1 .85355 L
s
1 .85355 m
.38643 1.00162 L
s
.38643 1.00162 m
.40217 .57872 L
s
0 0 m
1 0 L
1 1.00162 L
0 1.00162 L
closepath
clip
newpath
.5 Mabswid
.44491 .44907 m .52308 .38117 L .55473 .57484 L closepath p .37 .395 .757 r
F P
0 g
s
.44491 .44907 m .55473 .57484 L .36477 .52184 L closepath p .786 .442 .405 r
F P
0 g
s
.44491 .44907 m .36477 .52184 L .52308 .38117 L closepath p 0 0 0 r
F P
0 g
s
.39521 .65616 m .36477 .52184 L .55473 .57484 L closepath p .702 .725 .868 r
F P
0 g
s
.39521 .65616 m .55473 .57484 L .44391 .71565 L closepath p .366 .042 .277 r
F P
0 g
s
.39521 .65616 m .44391 .71565 L .36477 .52184 L closepath p 0 0 .535 r
F P
0 g
s
.65615 .42467 m .55473 .57484 L .52308 .38117 L closepath p .859 .738 .729 r
F P
0 g
s
.65615 .42467 m .70544 .48388 L .55473 .57484 L closepath p .299 .033 .331 r
F P
0 g
s
.65615 .42467 m .52308 .38117 L .70544 .48388 L closepath p .641 .082 0 r
F P
0 g
s
.57791 .76621 m .55473 .57484 L .65788 .69455 L closepath p .311 .298 .683 r
F P
0 g
s
.57791 .76621 m .44391 .71565 L .55473 .57484 L closepath p .873 .707 .674 r
F P
0 g
s
.57791 .76621 m .65788 .69455 L .44391 .71565 L closepath p .6 .813 .982 r
F P
0 g
s
.74263 .62049 m .55473 .57484 L .70544 .48388 L closepath p .643 .687 .876 r
F P
0 g
s
.74263 .62049 m .65788 .69455 L .55473 .57484 L closepath p .721 .348 .342 r
F P
0 g
s
.74263 .62049 m .70544 .48388 L .65788 .69455 L closepath p .971 .845 .659 r
F P
0 g
s
.33115 .32429 m .52308 .38117 L .36477 .52184 L closepath p .698 .565 .701 r
F P
0 g
s
.33115 .32429 m .38251 .38653 L .52308 .38117 L closepath p .608 .076 0 r
F P
0 g
s
.33115 .32429 m .36477 .52184 L .38251 .38653 L closepath p 0 0 .52 r
F P
0 g
s
.19481 .46702 m .38251 .38653 L .36477 .52184 L closepath p .712 .79 .912 r
F P
0 g
s
.24235 .68284 m .36477 .52184 L .44391 .71565 L closepath p .706 .538 .659 r
F P
0 g
s
.24235 .68284 m .32852 .60768 L .36477 .52184 L closepath p 0 0 0 r
F P
0 g
s
.19481 .46702 m .36477 .52184 L .32852 .60768 L closepath p .817 .41 .277 r
F P
0 g
s
.69731 .27878 m .70544 .48388 L .52308 .38117 L closepath p .654 .533 .704 r
F P
0 g
s
.69731 .27878 m .52308 .38117 L .60797 .35949 L closepath p 0 0 0 r
F P
0 g
s
.48589 .20782 m .52308 .38117 L .38251 .38653 L closepath p .899 .805 .747 r
F P
0 g
s
.48589 .20782 m .60797 .35949 L .52308 .38117 L closepath p .217 .339 .774 r
F P
0 g
s
.24235 .68284 m .44391 .71565 L .32852 .60768 L closepath p .559 .729 .954 r
F P
0 g
s
.56015 .87859 m .44391 .71565 L .65788 .69455 L closepath p .666 .487 .633 r
F P
0 g
s
.56015 .87859 m .52308 .72469 L .44391 .71565 L closepath p .079 .258 .746 r
F P
0 g
s
.33664 .82736 m .44391 .71565 L .52308 .72469 L closepath p .145 0 0 r
F P
0 g
s
.33664 .82736 m .32852 .60768 L .44391 .71565 L closepath p .927 .746 .637 r
F P
0 g
s
.69731 .27878 m .60797 .35949 L .70544 .48388 L closepath p .952 .764 .613 r
F P
0 g
s
.82611 .39367 m .70544 .48388 L .60797 .35949 L closepath p .593 .717 .93 r
F P
0 g
s
.85199 .62068 m .65788 .69455 L .70544 .48388 L closepath p .633 .483 .662 r
F P
0 g
s
.85199 .62068 m .70544 .48388 L .69976 .56825 L closepath p .804 .349 .159 r
F P
0 g
s
.82611 .39367 m .69976 .56825 L .70544 .48388 L closepath p 0 0 .084 r
F P
0 g
s
.85199 .62068 m .69976 .56825 L .65788 .69455 L closepath p .702 .816 .936 r
F P
0 g
s
.56015 .87859 m .65788 .69455 L .52308 .72469 L closepath p .92 .834 .744 r
F P
0 g
s
.73868 .79032 m .65788 .69455 L .69976 .56825 L closepath p .065 .115 .604 r
F P
0 g
s
.73868 .79032 m .52308 .72469 L .65788 .69455 L closepath p .67 .196 .118 r
F P
0 g
s
.19481 .46702 m .32852 .60768 L .38251 .38653 L closepath p .624 .472 .656 r
F P
0 g
s
.48589 .20782 m .38251 .38653 L .60797 .35949 L closepath p .661 .476 .624 r
F P
0 g
s
.45664 .27423 m .60797 .35949 L .38251 .38653 L closepath p .635 .791 .957 r
F P
0 g
s
.45664 .27423 m .38251 .38653 L .48535 .50673 L closepath p .22 .231 .659 r
F P
0 g
s
.25792 .45112 m .38251 .38653 L .32852 .60768 L closepath p .947 .817 .683 r
F P
0 g
s
.25792 .45112 m .48535 .50673 L .38251 .38653 L closepath p .707 .293 .259 r
F P
0 g
s
.25792 .45112 m .32852 .60768 L .48535 .50673 L closepath p .628 .699 .896 r
F P
0 g
s
.33664 .82736 m .52308 .72469 L .32852 .60768 L closepath p .648 .528 .703 r
F P
0 g
s
.35521 .69402 m .32852 .60768 L .52308 .72469 L closepath p .722 .218 .033 r
F P
0 g
s
.35521 .69402 m .48535 .50673 L .32852 .60768 L closepath p .184 0 .222 r
F P
0 g
s
.82611 .39367 m .60797 .35949 L .69976 .56825 L closepath p .705 .534 .654 r
F P
0 g
s
.45664 .27423 m .48535 .50673 L .60797 .35949 L closepath p .892 .722 .664 r
F P
0 g
s
.68527 .40123 m .69976 .56825 L .60797 .35949 L closepath p 0 .115 .646 r
F P
0 g
s
.68527 .40123 m .60797 .35949 L .48535 .50673 L closepath p .266 0 .159 r
F P
0 g
s
.73868 .79032 m .69976 .56825 L .52308 .72469 L closepath p .697 .564 .701 r
F P
0 g
s
.62474 .66693 m .52308 .72469 L .69976 .56825 L closepath p 0 0 0 r
F P
0 g
s
.62474 .66693 m .48535 .50673 L .52308 .72469 L closepath p .296 .351 .75 r
F P
0 g
s
.35521 .69402 m .52308 .72469 L .48535 .50673 L closepath p .876 .757 .728 r
F P
0 g
s
.68527 .40123 m .48535 .50673 L .69976 .56825 L closepath p .697 .742 .886 r
F P
0 g
s
.62474 .66693 m .69976 .56825 L .48535 .50673 L closepath p .786 .409 .341 r
F P
0 g
s
.25 Mabswid
.68538 0 m
.93948 .40631 L
s
.93948 .40631 m
1 .85355 L
s
1 .85355 m
.71506 .4883 L
s
.71506 .4883 m
.68538 0 L
s
.07192 .25073 m
0 .71646 L
s
0 .71646 m
.71506 .4883 L
s
.71506 .4883 m
.68538 0 L
s
.68538 0 m
.07192 .25073 L
s
.07192 .25073 m
.68538 0 L
s
.20676 .19562 m
.21134 .20064 L
s
[(-1)] .19758 .1856 .91513 1 Mshowa
.36072 .1327 m
.36502 .13796 L
s
[(0)] .35212 .12216 .81613 1 Mshowa
.52432 .06583 m
.52828 .07135 L
s
[(1)] .5164 .05478 .71713 1 Mshowa
.125 Mabswid
.23682 .18334 m
.23954 .18638 L
s
.26724 .1709 m
.26993 .17397 L
s
.29803 .15832 m
.30068 .16142 L
s
.32918 .14559 m
.3318 .14871 L
s
.39264 .11965 m
.39518 .12284 L
s
.42495 .10644 m
.42746 .10966 L
s
.45767 .09307 m
.46013 .09632 L
s
.49079 .07954 m
.49321 .08282 L
s
.17704 .20777 m
.17983 .21075 L
s
.14768 .21977 m
.15049 .22272 L
s
.11865 .23163 m
.1215 .23455 L
s
.08996 .24336 m
.09284 .24625 L
s
.55828 .05195 m
.56061 .0553 L
s
.59266 .0379 m
.59495 .04127 L
s
.62749 .02366 m
.62973 .02707 L
s
.66276 .00925 m
.66495 .01268 L
s
.25 Mabswid
0 .71646 m
.38643 1.00162 L
s
.1023 .79195 m
.10312 .7852 L
s
[(-1)] .10066 .80545 .12152 -1 Mshowa
.21274 .87345 m
.21334 .86668 L
s
[(0)] .21156 .887 .08756 -1 Mshowa
.31164 .94644 m
.31204 .93965 L
s
[(1)] .31085 .96001 .05846 -1 Mshowa
.125 Mabswid
.12541 .809 m
.12587 .80495 L
s
.14799 .82567 m
.14842 .82161 L
s
.17006 .84196 m
.17047 .8379 L
s
.19164 .85788 m
.19202 .85382 L
s
.23339 .88869 m
.23372 .88462 L
s
.25359 .90359 m
.25389 .89953 L
s
.27335 .91818 m
.27363 .91411 L
s
.2927 .93246 m
.29296 .92839 L
s
.07864 .77449 m
.07917 .77045 L
s
.05442 .75662 m
.05498 .75258 L
s
.02962 .73832 m
.0302 .73428 L
s
.0042 .71956 m
.00482 .71553 L
s
.3302 .96013 m
.33041 .95605 L
s
.34837 .97354 m
.34856 .96946 L
s
.36617 .98667 m
.36635 .9826 L
s
.38362 .99955 m
.38377 .99547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{287.5, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004O00017b000`400?l00000o`00003oo`3ooolP
0?ooo`00o`3ooolP0?ooo`00a@3oool2000005P0oooo00320?ooo`<0000000<0oooo0000003oool0
E`3oool00<00oooo0P0000040?ooo`800000E`3oool00;d0oooo0`0000060?ooo`030000003oool0
000005H0oooo002k0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
05H0oooo002i0?ooo`8000002`3oool010000000oooo0?ooo`00001E0?ooo`00]P3oool3000000d0
oooo00@000000?ooo`3oool00000E@3oool00;@0oooo0P00000@0?ooo`050000003oool0oooo0?oo
o`000000E03oool00980oooo0`00000L0?ooo`<000000P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0D@3oool009<0oooo00<000000?ooo`3oool0
6@3oool2000001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1A0?ooo`00T`3o
ool00`000000oooo0?ooo`0F0?ooo`<00000603oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0500oooo002C0?ooo`030000003oool0oooo01@0oooo0`00000J0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0C`3oool009<0oooo00<000000?ooo`3oool04P3oool20000
0080oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
04l0oooo002B0?ooo`8000004@3oool3000001l0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1>0?ooo`00T`3oool00`000000oooo0?ooo`0=0?ooo`8000008P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo04h0oooo002P0?ooo`<00000903oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo04d0oooo002N0?ooo`8000000`3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0C03oool009/0oooo0`00000Y0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0C03oool009T0oooo0P00000/0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0B`3oool009H0oooo0`00000^0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0BP3oool009@0oooo0P0000030?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1:0?ooo`00TP3oool2
000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`190?ooo`00S`3oool30000
03D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`190?ooo`00S@3oool3000003L0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`180?ooo`00RP3oool3000000<0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04L0oooo
00280?ooo`800000?@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04L0oooo0025
0?ooo`<00000?`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04H0oooo001T0?oo
o`8000007@3oool2000000030?ooo`000000oooo0400oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`150?ooo`00H`3oool010000000oooo0?ooo`00000J0?ooo`800000A@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo04D0oooo001S0?ooo`040000003oool0oooo0000
01L0oooo0`0000170?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0A03oool006<0
oooo00@000000?ooo`3oool000005@3oool2000004X0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`140?ooo`00H`3oool010000000oooo0?ooo`00000B0?ooo`<0000000<0oooo0000
003oool0B@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04<0oooo001S0?ooo`04
0000003oool0oooo00000100oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0@P3oool006@0oooo0P00000>0?ooo`<00000D@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0480oooo001b0?ooo`800000E03oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0440oooo001_0?ooo`<000000P3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0@@3oool006d0oooo0P00001I0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0@03oool006/0oooo0P00001K0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0?`3oool006P0oooo1000001L0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0?`3oool006H0oooo0P0000040?ooo`030000003oool0oooo05T0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0n0?ooo`00H`3oool300000680oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0m0?ooo`00H@3oool2000006D0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0m0?ooo`00GP3oool3000000030?ooo`000000oooo
06@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0l0?ooo`00G03oool2000006X0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0l0?ooo`00>03oool3000001l0oooo
0P00001]0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>`3oool003T0oooo00<0
00000?ooo`3oool06`3oool3000006l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0j0?ooo`00<@3oool5000000<0oooo00<000000?ooo`3oool06@3oool2000000<0oooo00<00000
0?ooo`3oool0K03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03X0oooo000i0?oo
o`030000003oool0oooo01H0oooo0`00001d0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0>@3oool003T0oooo00<000000?ooo`3oool0503oool2000007L0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0h0?ooo`00>03oool2000001<0oooo0`0000000`3oool00000
0?ooo`1f0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0>03oool003T0oooo00<0
00000?ooo`3oool03`3oool2000007`0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0g0?ooo`00B@3oool2000007h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0g
0?ooo`00AP3oool300000800oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0f0?oo
o`00A03oool200000080oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo03D0oooo00110?ooo`<00000Q@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo03D0oooo000o0?ooo`800000R03oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo03@0oooo000l0?ooo`@00000R@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo03<0oooo000j0?ooo`800000103oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0<`3oool003L0oooo0`00002?0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0<P3oool003D0oooo0`00001F0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0b0?ooo`00<`3oool2000000<0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0<@3oool00300oooo0`00001J0?ooo`030000002YNIl0000003X0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0`0?ooo`00;P3oool2000005d0oooo00@000000:Ui
W`2YNIl00000>@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0300oooo000[0?oo
o`<0000000<0oooo0000003oool0F`3oool00`000000ZGVO0:UiW`020:UiW`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0_0?ooo`00:@3oool200000600
oooo00<000000:UiW`2YNIl0102YNIl00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0;P3oool002H0oooo0`00001R0?ooo`030000002YNIl0ZGVO00@0ZGVO
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02h0oooo
000T0?ooo`80000000<0oooo0000003oool0H@3oool00`000000ZGVO0:UiW`060:UiW`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0]0?ooo`008P3oool2
000006H0oooo00<000000:UiW`2YNIl01`2YNIl00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0;@3oool001l0oooo0`00001W0?ooo`030000002YNIl0ZGVO
00T0ZGVO00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
02`0oooo000M0?ooo`800000J@3oool00`000000ZGVO0:UiW`0;0:UiW`030000003oool0oooo0340
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0[0?ooo`006P3oool300000080oooo
00<000000?ooo`3oool0IP3oool00`000000ZGVO0:UiW`0<0:UiW`030000003oool0oooo0300oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0[0?ooo`006@3oool2000006`0oooo00<0
00000:UiW`2YNIl03@2YNIl00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0:P3oool001T0oooo00<000000?ooo`000000J`3oool00`000000ZGVO0:UiW`0>
0:UiW`030000003oool0oooo02l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y
0?ooo`006@3oool010000000oooo0?ooo`00001Y0?ooo`030000002YNIl0ZGVO0100ZGVO00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02T0oooo000I0?oo
o`050000003oool0oooo0?ooo`000000J03oool00`000000ZGVO0:UiW`0A0:UiW`030000003oool0
oooo02d0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0X0?ooo`00603oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo06@0oooo00<000000:UiW`2YNIl04`2YNIl00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0:03oool001P0
oooo0P0000050?ooo`030000003oool0oooo0680oooo00<000000:UiW`2YNIl0502YNIl00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool09`3oool001P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1Q0?ooo`<000005@2YNIl00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool09P3oool001P0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1O0?ooo`040000002YNIl000000>BhZ@800000
502YNIl00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
9P3oool001P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1N0?ooo`<000000`3T
^:T00`000000ZGVO0:UiW`0B0:UiW`030000003oool0oooo02L0oooo0P0000000`3oool000000?oo
o`0Z0?ooo`030000003oool0oooo02D0oooo000H0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0G03oool20000000303PkZ0000000i;RY00<0i;RY0P00000C0:UiW`030000003oool0
oooo02@0oooo0P000000103c`i`000000?ooo`00000/0?ooo`030000003oool0oooo02@0oooo000H
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0F`3oool20000000303PkZ0000000
i;RY00D0i;RY0P00000A0:UiW`030000003oool0oooo02<0oooo0P0000020??3W0030000003oool0
000002`0oooo00<000000?ooo`3oool0903oool001L0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1I0?ooo`8000000`0h>jP00`000000i;RY0>BhZ@050>BhZ@800000402YNIl00`00
0000oooo0?ooo`0P0?ooo`<000000`3c`i`00`000000oooo0000000]0?ooo`030000003oool0oooo
02<0oooo000G0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0E`3oool00`000000
ZGVO0000000303PkZ0030000003T^:T0i;RY00L0i;RY0P00000?0:UiW`030000003oool0oooo01d0
oooo100000040??3W0030000003oool0000002d0oooo00<000000?ooo`3oool08`3oool001L0oooo
0P00000>0?ooo`030000003oool0oooo05H0oooo0P00000403PkZ0030000003T^:T0i;RY00T0i;RY
00<000000:UiW`2YNIl03@2YNIl00`000000oooo0?ooo`0J0?ooo`D000001@3c`i`00`000000oooo
0000000^0?ooo`030000003oool0oooo0280oooo000G0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0E03oool2000000D0>3^X00<000000>BhZ@3T^:T02P3T^:T2000000h0ZGVO00<0
00000?ooo`3oool0603oool5000000H0ll>L00<000000?ooo`000000;`3oool00`000000oooo0?oo
o`0Q0?ooo`005`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05<0oooo0P000005
03PkZ0030000003T^:T0i;RY00`0i;RY0P00000<0:UiW`030000003oool0oooo01H0oooo1P000007
0??3W0030000003oool0000002l0oooo00<000000?ooo`3oool08@3oool001L0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`1A0?ooo`8000001P0h>jP00`000000i;RY0>BhZ@0>0>Bh
Z@8000002`2YNIl00`000000oooo0?ooo`0C0?ooo`H000002@3c`i`00`000000oooo0000000`0?oo
o`030000003oool0oooo0200oooo000F0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0C`3oool2000000L0>3^X00<000000>BhZ@3T^:T0403T^:T2000000X0ZGVO00<000000?ooo`3o
ool0403oool7000000X0ll>L00<000000?ooo`000000<03oool00`000000oooo0?ooo`0P0?ooo`00
5P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04h0oooo0P00000703PkZ0030000
003T^:T0i;RY0180i;RY00<000000:UiW`2YNIl0202YNIl00`000000oooo0?ooo`0>0?ooo`L00000
2`3c`i`00`000000oooo0000000a0?ooo`030000003oool0oooo01l0oooo000F0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0C03oool2000000T0>3^X00<000000>BhZ@3T^:T04P3T
^:T2000000T0ZGVO00<000000?ooo`3oool02`3oool8000000`0ll>L00<000000?ooo`000000<P3o
ool00`000000oooo0?ooo`0N0?ooo`005P3oool3000001D0oooo00<000000?ooo`3oool0<@3oool3
000001L0oooo0P00000903PkZ0030000003T^:T0i;RY01@0i;RY0P0000080:UiW`030000003oool0
oooo00P0oooo2@00000=0??3W0030000003oool000000380oooo00<000000?ooo`3oool07P3oool0
01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0`0?ooo`030000002K4`00Va<0
00<000004`3oool2000000X0>3^X00<000000>BhZ@3T^:T05P3T^:T2000000H0ZGVO00<000000?oo
o`3oool01P3oool:000000h0ll>L00<000000?ooo`000000<`3oool00`000000oooo0?ooo`0M0?oo
o`003@3oool3000000H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0_0?ooo`80
0000102K4`0300000100oooo00<0000003PkZ00h>jP02@0h>jP00`000000i;RY0>BhZ@0H0>BhZ@80
00001@2YNIl00`000000oooo0?ooo`040?ooo`X000003`3c`i`00`000000oooo0000000d0?ooo`03
0000003oool0oooo01`0oooo000>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0^0?ooo`030000000008D0000000H0Va<01000000;0?ooo`800000
2`0h>jP00`000000i;RY0>BhZ@0J0>BhZ@030000002YNIl0ZGVO00<0ZGVO00@000000?ooo`3oool0
oooo2`00000A0??3W0800000=03oool00`000000oooo0?ooo`0L0?ooo`001P3oool5000000<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02h0oooo
00<000000000Q@0000002@2K4`03000000L0oooo0P00000<03PkZ0030000003T^:T0i;RY01/0i;RY
0P0000040:UiW``000004`3c`i`2000003D0oooo00<000000?ooo`3oool06`3oool000h0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02d0oooo00@0
00000000Q@0008D000002`2K4`04000000<0oooo00<0000003PkZ00h>jP02`0h>jP00`000000i;RY
0>BhZ@0M0>BhZ@8000000`2YNIl:000001@0ll>L00<000000?ooo`000000=03oool00`000000oooo
0?ooo`0K0?ooo`003P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0;03oool01@00000000250000Q@0008D0000000h0Va<01000000=03PkZ0030000
003T^:T0i;RY01l0i;RY0P0000000`2YNIl0000000000007000001D0ll>L00<000000?ooo`000000
=@3oool00`000000oooo0?ooo`0J0?ooo`003@3oool2000000H0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0[0?ooo`050000000008D000250000Q@000000402K4`000`000000>3^X
03PkZ00<03PkZ0030000003T^:T0i;RY0240i;RY2@00000F0??3W0030000003oool0000003H0oooo
00<000000?ooo`3oool06@3oool000h0oooo00<000000?ooo`3oool0103oool2000001l0oooo00<0
00000?ooo`3oool0:P3oool00`00000000250000Q@020000Q@030000002K4`00Va<000`0Va<00P00
000?03PkZ0030000003T^:T0i;RY0280i;RY1P00000G0??3W0030000003oool0000003H0oooo00<0
00000?ooo`3oool06@3oool001D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Z
0?ooo`030000000008D000250080002500<0000009/C002K4`002`2K4`000`000000>3^X03PkZ00>
03PkZ0030000003T^:T0i;RY02<0i;RY1000000H0??3W0030000003oool0000003L0oooo00<00000
0?ooo`3oool0603oool001@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Y0?oo
o`030000000008D0002500<0002500<0000009/C002K4`002@2K4`000`000000>3^X03PkZ00?03Pk
Z0030000003T^:T0i;RY02D0i;RY1000000F0??3W0030000003oool0000003P0oooo00<000000?oo
o`3oool05`3oool001@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0X0?ooo`03
0000000008D0002500@0002500<0000009/C002K4`001`2K4`0200000140>3^X00<000000>BhZ@3T
^:T09@3T^:T00`000000A00X0000000700000100ll>L00<000000?ooo`000000>03oool00`000000
oooo0?ooo`0G0?ooo`00503oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02L0oooo
00<000000000Q@0008D01@0008D00`000000Va<009/C000609/C00030000000h>jP0>3^X0100>3^X
00<000000>BhZ@3T^:T0903T^:T00`000000A00X04@0:00204@0:0800000102dR:L6000000X0ll>L
00<000000?ooo`000000>@3oool00`000000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo02H0oooo00<000000000Q@0008D01@0008D00`000000Va<009/C
000509/C00030000000h>jP0>3^X0140>3^X00<000000>BhZ@3T^:T08`3T^:T00`000000A00X04@0
:00504@0:0030000002dR:L0]8RW00L0]8RW1P0000040??3W0030000003oool0000003T0oooo00<0
00000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U
0?ooo`030000000008D0002500H0002500<0000009/C002K4`00102K4`000`000000>3^X03PkZ00A
03PkZ0030000003T^:T0i;RY0280i;RY00<0000004@0:01402P01`1402P2000000d0]8RW1`00000j
0?ooo`030000003oool0oooo01D0oooo000D0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool09@3oool00`00000000250000Q@060000Q@030000002K4`00Va<00080Va<000<0000003Pk
Z00h>jP04P0h>jP00`000000i;RY0>BhZ@0Q0>BhZ@030000001402P0A00X00X0A00X0P00000A0;B8
Y`L00000=@3oool00`000000oooo0?ooo`0D0?ooo`00503oool2000002P0oooo00<000000?ooo`3o
ool0903oool00`00000000250000Q@070000Q@030000002K4`00Va<0008000005@0h>jP00`000000
i;RY0>BhZ@0O0>BhZ@030000001402P0A00X00d0A00X0P00000?0;B8Y`030000002dR:L0]8RW00@0
]8RW1P00000_0?ooo`030000003oool0oooo01@0oooo000C0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool08`3oool00`00000000250000Q@080000Q@030000002K4`00000001H0>3^X
00<000000>BhZ@3T^:T07`3T^:T00`000000A00X04@0:00?04@0:08000003@2dR:L00`000000]8RW
0;B8Y`0:0;B8Y`H00000:P3oool00`000000oooo0?ooo`0C0?ooo`004`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo0280oooo00<000000000Q@0008D0200008D2000001L0>3^X00<0
00000>BhZ@3T^:T07P3T^:T00`000000A00X04@0:00B04@0:08000002`2dR:L00`000000]8RW0;B8
Y`0@0;B8Y`H000009@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0240oooo00<000000000Q@0008D01P0008D2000000030;A;@P000000
>3^X01H0>3^X00<000000>BhZ@3T^:T07@3T^:T00`000000A00X04@0:00E04@0:0030000002dR:L0
]8RW00P0]8RW00<000000;B8Y`2dR:L05P2dR:L6000001l0oooo00<000000?ooo`3oool04P3oool0
01<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0P0?ooo`030000000008D00025
00<000250`0000040;A;@P030000000h>jP0>3^X01@0>3^X00<000000>BhZ@3T^:T0703T^:T00`00
0000A00X04@0:00G04@0:0800000202dR:L00`000000]8RW0;B8Y`0L0;B8Y`<000007@3oool00`00
0000oooo0?ooo`0A0?ooo`004`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0200
oooo00<000000000Q@0008D00`0000070;A;@P030000000h>jP0>3^X01<0>3^X00<000000>BhZ@3T
^:T06`3T^:T00`000000A00X04@0:00J04@0:08000001P2dR:L00`000000]8RW0;B8Y`0N0;B8Y`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool04@3oool001<0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0O0?ooo`@000002P2dBd800`000000>3^X03PkZ00B03PkZ0030000
003T^:T0i;RY01X0i;RY00<0000004@0:01402P0701402P2000000H0]8RW00<000000;B8Y`2dR:L0
702dR:L00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0100oooo000C0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0703oool4000000d0]4]200<0000003PkZ00h>jP04@0h
>jP00`000000i;RY0>BhZ@0J0>BhZ@030000001402P0A00X01X0A00X0P0000000`2b_N8000000;B8
Y`050;B8Y`030000002dR:L0]8RW01/0]8RW00<000000?ooo`3oool07@3oool300000140oooo000B
0?ooo`800000<P3oool00`000000oooo0?ooo`0I0?ooo`@00000402dBd800`000000>3^X03PkZ00A
03PkZ0030000003T^:T0i;RY01P0i;RY00<0000004@0:01402P06@1402P2000000<0/[gR00<00000
0;B8Y`2dR:L0102dR:L00`000000]8RW0;B8Y`0J0;B8Y`030000003oool0oooo01/0oooo0`000002
0?ooo`030000003oool0oooo00l0oooo000B0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool05P3oool400000180]4]200<0000003PkZ00h>jP04@0h>jP00`000000i;RY0>BhZ@0G0>Bh
Z@030000001402P0A00X01P0A00X0P0000050;:mhP030000002dR:L0]8RW00@0]8RW00<000000;B8
Y`2dR:L06P2dR:L00`000000oooo0?ooo`0H0?ooo`<000001@3oool00`000000oooo0?ooo`0?0?oo
o`004P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0180oooo1@00000E0;A;@P03
0000000h>jP0>3^X0100>3^X00<000000>BhZ@3T^:T05P3T^:T00`000000A00X04@0:00G04@0:080
00001`2b_N800`000000]8RW0;B8Y`040;B8Y`030000002dR:L0]8RW01T0]8RW00<000000?ooo`3o
ool05P3oool3000000P0oooo00<000000?ooo`3oool03`3oool00180oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0?0?ooo`8000000P2ON:L00`000000]4]20;A;@P0F0;A;@P030000
000h>jP0>3^X00l0>3^X00<000000>BhZ@3T^:T05@3T^:T00`000000A00X04@0:00G04@0:0030000
002b_N80/[gR00L0/[gR00<000000;B8Y`2dR:L0102dR:L00`000000]8RW0;B8Y`0H0;B8Y`030000
003oool0oooo01@0oooo0`00000;0?ooo`030000003oool0oooo00l0oooo000B0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0303oool200000080WgRW0P00000J0;A;@P030000000h
>jP0>3^X00h0>3^X00<000000>BhZ@3T^:T0503T^:T00`000000A00X04@0:00F04@0:08000002P2b
_N800`000000]8RW0;B8Y`040;B8Y`030000002dR:L0]8RW01P0]8RW00<000000?ooo`3oool04@3o
ool3000000l0oooo00<000000?ooo`3oool03P3oool00180oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`080?ooo`<000000P2ON:L2000001d0]4]200<0000003PkZ00h>jP03@0h>jP0
0`000000i;RY0>BhZ@0D0>BhZ@030000001402P0A00X01@0A00X0P00000=0;:mhP030000002dR:L0
]8RW00<0]8RW00<000000;B8Y`2dR:L05`2dR:L00`000000oooo0?ooo`0?0?ooo`<000004P3oool0
0`000000oooo0?ooo`0>0?ooo`004@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
00D0oooo0P00000309mhY`8000007`2dBd800`000000>3^X03PkZ00=03PkZ0030000003T^:T0i;RY
01<0i;RY00<0000004@0:01402P04`1402P2000000l0/[gR00<000000;B8Y`2dR:L00`2dR:L00`00
0000]8RW0;B8Y`0F0;B8Y`030000003oool0oooo00d0oooo0`00000E0?ooo`030000003oool0oooo
00h0oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00P3oool2000000<0
WgRW0P00000R0;A;@P030000000h>jP0>3^X00`0>3^X00<000000>BhZ@3T^:T04P3T^:T00`000000
A00X04@0:00B04@0:08000004@2b_N800`000000]8RW0;B8Y`030;B8Y`030000002dR:L0]8RW01D0
]8RW00<000000?ooo`3oool02`3oool3000001P0oooo00<000000?ooo`3oool03P3oool00140oooo
0P00000k0?ooo`040000003oool00000000000<0WgRW0P00000U0;A;@P030000000h>jP0>3^X00`0
>3^X00<000000>BhZ@3T^:T0403T^:T00`000000A00X04@0:00A04@0:08000004`2b_N800`000000
]8RW0;B8Y`030;B8Y`030000002dR:L0]8RW01D0]8RW00<000000?ooo`3oool0203oool3000001/0
oooo00<000000?ooo`3oool03P3oool00140oooo00<000000?ooo`3oool0>@3oool3000000<0WgRW
0P00000X0;A;@P030000000h>jP0>3^X00/0>3^X00<000000>BhZ@3T^:T03`3T^:T00`000000A00X
04@0:00@04@0:08000005@2b_N800`000000]8RW0;B8Y`030;B8Y`030000002dR:L0]8RW01@0]8RW
00<000000?ooo`3oool01P3oool3000001h0oooo00<000000?ooo`3oool03P3oool00140oooo00<0
00000?ooo`3oool0=`3oool2000000@0WgRW0P00000[0;A;@P030000000h>jP0>3^X00X0>3^X00<0
00000>BhZ@3T^:T03P3T^:T00`000000A00X04@0:00?04@0:08000005`2b_N800`000000]8RW0;B8
Y`030;B8Y`030000002dR:L0]8RW01<0]8RW00<000000?ooo`3oool0103oool300000240oooo00<0
00000?ooo`3oool03P3oool00140oooo00<000000?ooo`3oool0=@3oool2000000@0WgRW0P00000^
0;A;@P030000000h>jP0>3^X00T0>3^X00<000000>BhZ@3T^:T03P3T^:T00`000000A00X04@0:00=
04@0:08000006@2b_N800`000000]8RW0;B8Y`030;B8Y`030000002dR:L0]8RW01<0]8RW00<00000
0?ooo`3oool01000000U0?ooo`030000003oool0oooo00d0oooo000A0?ooo`030000003oool0oooo
0380oooo0`00000509mhY`<00000;P2dBd800`000000>3^X03PkZ00903PkZ0030000003T^:T0i;RY
00d0i;RY00<0000004@0:01402P0301402P2000001/0/[gR00<000000;B8Y`2dR:L00`2dR:L00`00
0000]8RW0;B8Y`0B0;B8Y`@00000:@3oool00`000000oooo0?ooo`0=0?ooo`00403oool00`000000
oooo0?ooo`0a0?ooo`800000202ON:L00`000000X;;U0:2bi@04000002/0]4]200<0000003PkZ00h
>jP0200h>jP00`000000i;RY0>BhZ@0<0>BhZ@030000001402P0A00X00`0A00X00<000000;:mhP2b
_N806`2b_N800`000000]8RW0;B8Y`030;B8Y`030000002dR:L0]8RW0140]8RW0P00000/0?ooo`03
0000003oool0oooo00d0oooo000@0?ooo`030000003oool0oooo02l0oooo0P00000;09mhY`030000
002P/^D0X;;U00<0X;;U1000000X0;A;@P030000000h>jP0>3^X00L0>3^X00<000000>BhZ@3T^:T0
2`3T^:T00`000000A00X04@0:00;04@0:08000007P2b_N800`000000]8RW0;B8Y`030;B8Y`030000
002dR:L0]8RW0100]8RW00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0=0?ooo`00403o
ool00`000000oooo0?ooo`0/0?ooo`<000003@2ON:L00`000000X;;U0:2bi@070:2bi@@000009@2d
Bd800`000000>3^X03PkZ00603PkZ0030000003T^:T0i;RY00X0i;RY00<0000004@0:01402P02P14
02P200000200/[gR00<000000;B8Y`2dR:L0102dR:L00`000000]8RW0;B8Y`0?0;B8Y`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool03@3oool00100oooo0`00000Z0?ooo`8000004@2ON:L0
0`000000X;;U0:2bi@0:0:2bi@@000008P2dBd800`000000>3^X03PkZ00503PkZ0030000003T^:T0
i;RY00T0i;RY00<0000004@0:01402P02@1402P200000280/[gR00<000000;B8Y`2dR:L0102dR:L0
0`000000]8RW0;B8Y`0>0;B8Y`030000003oool0oooo02d0oooo00<000000?ooo`3oool03@3oool0
00P0oooo0P0000060?ooo`030000003oool0oooo02T0oooo00<0000009mhY`2ON:L04@2ON:L00`00
0000X;;U0:2bi@0>0:2bi@@000007`2dBd800`000000>3^X03PkZ00503PkZ0030000003T^:T0i;RY
00P0i;RY00<0000004@0:01402P01`1402P2000002D0/[gR00<000000;B8Y`2dR:L00`2dR:L00`00
0000]8RW0;B8Y`0=0;B8Y`030000003oool0oooo02h0oooo00<000000?ooo`3oool03@3oool000L0
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0Y0?ooo`030000002ON:L0WgRW
0140WgRW00<000000:2bi@2P/^D04P2P/^D4000001/0]4]200<0000003PkZ00h>jP01@0h>jP00`00
0000i;RY0>BhZ@070>BhZ@030000001402P0A00X00H0A00X0P00000W0;:mhP030000002dR:L0]8RW
00<0]8RW00<000000;B8Y`2dR:L03@2dR:L00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
00d0oooo00070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0:`3oool00`00
0000WgRW09mhY`0A09mhY`030000002P/^D0X;;U01D0X;;U1000000H0;A;@P030000000h>jP0>3^X
00@0>3^X00<000000>BhZ@3T^:T01P3T^:T00`000000A00X04@0:00504@0:0800000:@2b_N800`00
0000]8RW0;B8Y`030;B8Y`030000002dR:L0]8RW00`0]8RW00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0<0?ooo`001`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
02`0oooo00<0000009mhY`2ON:L0402ON:L00`000000X;;U0:2bi@0I0:2bi@<000005P2dBd800`00
0000>3^X03PkZ00303PkZ0030000003T^:T0i;RY00D0i;RY00<0000004@0:01402P0101402P20000
02/0/[gR00<000000;B8Y`2dR:L00`2dR:L00`000000]8RW0;B8Y`0;0;B8Y`030000003oool0oooo
0340oooo00<000000?ooo`3oool0303oool000L0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0]0?ooo`030000002ON:L0WgRW0100WgRW00<000000:2bi@2P/^D06`2P/^D40000
01<0]4]200<0000003PkZ00h>jP00P0h>jP00`000000i;RY0>BhZ@040>BhZ@030000001402P0A00X
00<0A00X0P00000]0;:mhP030000002dR:L0]8RW00<0]8RW00<000000;B8Y`2dR:L02P2dR:L00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo00`0oooo00070?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0;P3oool00`000000WgRW09mhY`0?09mhY`030000002P/^D0X;;U
01l0X;;U1000000@0;A;@P050000000h>jP0>3^X03PkZ00000001@3T^:T00`000000A00X04@0:002
04@0:0800000;`2b_N800`000000]8RW0;B8Y`030;B8Y`030000002dR:L0]8RW00X0]8RW00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0<0?ooo`00203oool2000000D0oooo00<000000?oo
o`3oool0;`3oool00`000000WgRW09mhY`0?09mhY`030000002P/^D0X;;U0280X;;U1000000<0;A;
@P050000000h>jP0>3^X03PkZ00000001@3T^:T01@000000A00X04@0:01402P000000340/[gR00@0
00000;B8Y`2dR:L0]8RW0`00000;0;B8Y`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
303oool000l0oooo0P00000a0?ooo`030000002ON:L0WgRW00h0WgRW00<000000:2bi@2P/^D09P2P
/^D4000000T0]4]200@0000003PkZ00h>jP00000103T^:T00`000000A00X04@0:00200000380/[gR
100000020;B8Y`030000002dR:L0]8RW00P0]8RW00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0<0?ooo`003`3oool00`000000oooo0?ooo`0a0?ooo`030000002ON:L0WgRW00d0WgRW00<0
00000:2bi@2P/^D0:P2P/^D4000000H0]4]200@0000003PkZ00h>jP000000P3T^:T010000000A00X
00000000000b0;:mhP<000001P2dR:L00`000000]8RW0;B8Y`070;B8Y`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool0<`3oool00`000000WgRW
09mhY`0=09mhY`030000002P/^D0X;;U02d0X;;U100000030;A;@P040000000h>jP000000>BhZ@<0
0000<@2b_N8300000080/[gR00<000000;B8Y`2dR:L01@2dR:L00`000000]8RW0;B8Y`050;B8Y`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool000h0oooo00<000000?ooo`3oool0
=03oool00`000000WgRW09mhY`0<09mhY`030000002P/^D0X;;U0340X;;U2000000`0;:mhP<00000
1@2b_N800`000000]8RW0;B8Y`060;B8Y`030000002dR:L0]8RW00<0]8RW00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0;0?ooo`003P3oool00`000000oooo0?ooo`0e0?ooo`030000002O
N:L0WgRW00`0WgRW00<000000:2bi@2P/^D0=02P/^D4000002d0/[gR0`0000090;:mhP030000002d
R:L0]8RW00H0]8RW00D000000;B8Y`2dR:L0]8RW0000000j0?ooo`030000003oool0oooo00/0oooo
000>0?ooo`030000003oool0oooo03H0oooo00<0000009mhY`2ON:L02`2ON:L00`000000X;;U0:2b
i@0c0:2bi@030000000_03P000000080bFQG0`00000W0;:mhP<00000302b_N800`000000]8RW0;B8
Y`060;B8Y`050000002dR:L0]8RW0;B8Y`000000>P3oool00`000000oooo0?ooo`0;0?ooo`003P3o
ool00`000000oooo0?ooo`0g0?ooo`030000002ON:L0WgRW00/0WgRW00<000000:2bi@2P/^D0<02P
/^D20000000402l0>00000000000000000@0bFQG1000000O0;:mhP@000003`2b_N800`000000]8RW
0;B8Y`070;B8Y`030000002dR:L0000003/0oooo00<000000?ooo`3oool02`3oool000h0oooo00<0
00000?ooo`3oool0>03oool00`000000WgRW09mhY`0:09mhY`030000002P/^D0X;;U02h0X;;U0P00
000202l0>0050000003P`KX0000004]I_`0000001`39J5L4000001P0/[gR0`00000C0;:mhP030000
002dR:L0]8RW00P0]8RW00<000000<eI:0000000>P3oool00`000000oooo0?ooo`0;0?ooo`003@3o
ool00`000000oooo0?ooo`0j0?ooo`030000002ON:L0WgRW00T0WgRW00<000000:2bi@2P/^D0;@2P
/^D00`000000;`0h02l0>00202l0>0060000003P`KX0h<6j0000001;FKl000002P39J5L300000180
/[gR0`00000F0;:mhP030000002dR:L0]8RW00P0]8RW0P0000000`3=FBP000000?ooo`0h0?ooo`03
0000003oool0oooo00/0oooo000=0?ooo`800000?03oool00`000000WgRW09mhY`0909mhY`030000
002P/^D0X;;U02X0X;;U0P00000402l0>0050000003P`KX0h<6j0>31^P0000000P1;FKl00`000000
bFQG0<UXE`0:0<UXE`@000002`2b_N83000001T0/[gR00<000000;B8Y`2dR:L01`2dR:L00`000000
cETX000000020<eI:0030000003oool0oooo03L0oooo00<000000?ooo`3oool02P3oool000d0oooo
00<000000?ooo`3oool0?03oool00`000000WgRW09mhY`0809mhY`030000002P/^D0X;;U02T0X;;U
00<0000002l0>00_03P00`0_03P00`000000h<6j0>31^P020>31^P050000001;FKl0BeVo04]I_`00
00003`39J5L3000000D0/[gR0`00000L0;:mhP030000002dR:L0]8RW00H0]8RW00D000000<eI:03=
FBP0cETX000000020<eI:0030000003oool0oooo03H0oooo00<000000?ooo`3oool02P3oool000d0
oooo00<000000?ooo`3oool0?@3oool00`000000WgRW09mhY`0809mhY`030000002P/^D0X;;U02H0
X;;U0P00000502l0>0030000003P`KX0h<6j00<0h<6j00<0000004]I_`1;FKl00P1;FKl00`000000
bFQG0<UXE`0?0<UXE`D000007`2b_N800`000000]8RW0;B8Y`050;B8Y`030000003=FBP0cETX00<0
cETX00@000000<eI:03=FBP00000=`3oool00`000000oooo0?ooo`0:0?ooo`003@3oool00`000000
oooo0?ooo`0n0?ooo`030000002ON:L0WgRW00L0WgRW00<000000:2bi@2P/^D09@2P/^D00`000000
;`0h02l0>00502l0>0030000003P`KX0h<6j00<0h<6j00<0000004]I_`1;FKl00`1;FKl00`000000
bFQG0<UXE`0=0<UXE`<000000P39J5L4000001`0/[gR00<000000;B8Y`2dR:L01@2dR:L00`000000
cETX0<eI:0040<eI:0040000003=FBP0cETX000003H0oooo00<000000?ooo`3oool02P3oool000d0
oooo00<000000?ooo`3oool0?`3oool00`000000WgRW09mhY`0709mhY`030000002P/^D0X;;U0280
X;;U0P00000702l0>0030000003P`KX0h<6j00D0h<6j00<0000004]I_`1;FKl00`1;FKl00`000000
bFQG0<UXE`080<UXE`@000002@39J5L3000001T0/[gR00<000000;B8Y`2dR:L0102dR:L00`000000
cETX0<eI:0060<eI:0040000003=FBP0cETX000003D0oooo00<000000?ooo`3oool02P3oool000d0
oooo00<000000?ooo`3oool0?`3oool00`000000WgRW09mhY`0709mhY`030000002P/^D0X;;U0200
X;;U0P00000802l0>0030000003P`KX0h<6j00H0h<6j00<0000004]I_`1;FKl00`1;FKl00`000000
bFQG0<UXE`050<UXE`<000004039J5L4000001D0/[gR00<000000;B8Y`2dR:L00`2dR:L00`000000
cETX0<eI:0070<eI:0050000003=FBP0cETX0<eI:0000000=03oool00`000000oooo0?ooo`0:0?oo
o`00303oool00`000000oooo0?ooo`110?ooo`030000002ON:L0WgRW00H0WgRW00<000000:2bi@2P
/^D07`2P/^D00`000000;`0h02l0>00802l0>0030000003P`KX0h<6j00H0h<6j00<0000004]I_`1;
FKl0101;FKl010000000bFQG0<UXE`39J5L3000001L0bFQG0`00000B0;:mhP030000002dR:L0]8RW
00<0]8RW00<000000<eI:03=FBP0203=FBP01@000000cETX0<eI:03=FBP0000003<0oooo00<00000
0?ooo`3oool02P3oool000`0oooo00<000000?ooo`3oool0@P3oool00`000000WgRW09mhY`0609mh
Y`030000002P/^D0X;;U01`0X;;U0P00000:02l0>0030000003P`KX0h<6j00L0h<6j00<0000004]I
_`1;FKl01@1;FKl3000001d0bFQG1000000?0;:mhP050000002dR:L0]8RW0;B8Y`000000303=FBP0
10000000cETX0<eI:03=FBP200000340oooo00<000000?ooo`3oool02P3oool000`0oooo00<00000
0?ooo`3oool0@`3oool00`000000WgRW09mhY`0509mhY`030000002P/^D0X;;U01/0X;;U00<00000
02l0>00_03P02@0_03P00`000000h<6j0>31^P080>31^P030000001;FKl0BeVo0080BeVo0`000000
0`1;FKl000000<UXE`0Q0<UXE`<00000302b_N8010000000]8RW0;B8Y`00000>0<eI:0030000003=
FBP0cETX0080cETX00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`090?ooo`00303oool2
000004D0oooo00<0000009mhY`2ON:L01@2ON:L00`000000X;;U0:2bi@0H0:2bi@800000300_03P0
0`000000h<6j0>31^P080>31^P030000001;FKl00000008000001@1;FKl00`000000bFQG0<UXE`0R
0<UXE`@00000202b_N800`000000]8RW0000000@0<eI:0030000003=FBP0cETX0080cETX00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`090?ooo`00303oool00`000000oooo0?ooo`150?oo
o`030000002ON:L0WgRW00@0WgRW00<000000:2bi@2P/^D05`2P/^D00`000000;`0h02l0>00;02l0
>0030000003P`KX0h<6j00P0h<6j0`00000904]I_`0300000039J5L0bFQG02D0bFQG100000040;:m
hP030000002dR:L000000100cETX00<000000<eI:03=FBP00`3=FBP00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00T0oooo000<0?ooo`030000003oool0oooo04H0oooo00<0000009mhY`2O
N:L0102ON:L00`000000X;;U0:2bi@0D0:2bi@8000003@0_03P00`000000h<6j0>31^P050>31^P@0
00000P3P`KX00`000000BeVo04]I_`0804]I_`0300000039J5L0bFQG02P0bFQG0`0000000`2b_N80
00000000000B0<eI:0030000003=FBP0cETX00<0cETX00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`090?ooo`002`3oool00`000000oooo0?ooo`180?ooo`030000002ON:L0WgRW00<0WgRW
00<000000:2bi@2P/^D04P2P/^D2000000l0;`0h00<000000>31^P3P`KX00P3P`KX3000000H0h<6j
00<0000004]I_`1;FKl02@1;FKl00`000000bFQG0<UXE`0Z0<UXE`<000004`3=FBP00`000000cETX
0<eI:0030<eI:0030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool000/0oooo00<0
00000?ooo`3oool0B@3oool00`000000WgRW09mhY`0209mhY`030000002P/^D0X;;U0140X;;U00<0
000002l0>00_03P03P0_03P00`000000h<6j0>31^P03000000T0h<6j00<0000004]I_`1;FKl02P1;
FKl00`000000bFQG0<UXE`0Z0<UXE`030000002cd>l00000008000004@3=FBP00`000000cETX0<eI
:0030<eI:0030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool000/0oooo00<00000
0?ooo`3oool0BP3oool00`000000WgRW09mhY`0209mhY`030000002P/^D0X;;U00h0X;;U0P00000@
02l0>0@00000303P`KX00`000000BeVo04]I_`0:04]I_`0300000039J5L0bFQG02T0bFQG0P000004
0;?@k`<000003P3=FBP00`000000cETX0<eI:0040<eI:0030000003oool0oooo02T0oooo00<00000
0?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool0B`3oool01@000000WgRW09mhY`2ON:L0
000000l0X;;U00<0000002l0>00_03P03P0_03P300000100h<6j00<0000004]I_`1;FKl02P1;FKl0
0`000000bFQG0<UXE`0W0<UXE`030000002bT;<0000000L0/m3_0`00000<0<eI:0030000003=FBP0
cETX00@0cETX00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`080?ooo`002`3oool00`00
0000oooo0?ooo`1<0?ooo`050000002ON:L0WgRW09mhY`000000302P/^D2000000h0;`0h0`000000
0`0_03P000000>31^P0@0>31^P030000001;FKl0BeVo00/0BeVo00<000000<UXE`39J5L09@39J5L0
1@000000/Y2c0;:@/`2bT;<0000000T0/m3_0`00000:0<eI:0030000003=FBP0cETX00@0cETX00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`1=
0?ooo`040000002ON:L0WgRW000000/0X;;U00<0000002l0>00_03P02`0_03P3000000<0;`0h00<0
00000>31^P3P`KX0403P`KX00`000000BeVo04]I_`0<04]I_`0300000039J5L0bFQG02@0bFQG00D0
00000;:@/`2bT;<0/Y2c0000000<0;?@k`8000002@3=FBP00`000000cETX0<eI:0040<eI:0030000
003oool0oooo02L0oooo00<000000?ooo`3oool0203oool000/0oooo0P00001?0?ooo`040000002O
N:L0WgRW000000P0X;;U0P00000:02l0>0@000001@0_03P00`000000h<6j0>31^P0A0>31^P030000
001;FKl0BeVo00d0BeVo00<000000<UXE`39J5L08P39J5L00`000000/Y2c0;:@/`020;:@/`030000
002cd>l0/m3_00`0/m3_0`0000070<eI:0030000003=FBP0cETX00@0cETX00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`1@0?ooo`030000002O
N:L0000000H0X;;U0P00000902l0>0<000002@0_03P00`000000h<6j0>31^P0A0>31^P030000001;
FKl0BeVo00h0BeVo00<000000<UXE`39J5L08039J5L00`000000/Y2c0;:@/`030;:@/`030000002c
d>l0/m3_00l0/m3_0`0000040<eI:0030000003=FBP0cETX00D0cETX00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`1?0?ooo`@000001@2P/^D0
0`000000;`0h02l0>00602l0>0<000002`0_03P00`000000h<6j0>31^P0B0>31^P030000001;FKl0
BeVo00l0BeVo00<000000<UXE`39J5L07P39J5L00`000000/Y2c0;:@/`040;:@/`030000002cd>l0
/m3_0180/m3_0`0000020<eI:0030000003=FBP0cETX00D0cETX00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`1>0?ooo`H000000P2P/^D20000
00H0;`0h0`00000=02l0>0030000003P`KX0h<6j01@0h<6j00<0000004]I_`1;FKl03`1;FKl00`00
0000bFQG0<UXE`0M0<UXE`030000002bT;<0/Y2c00D0/Y2c00<000000;?@k`2cd>l0502cd>l40000
00L0cETX00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000
oooo0?ooo`1=0?ooo`L0000000<0X;;U0000000_03P0100_03P300000100;`0h00<000000>31^P3P
`KX0503P`KX00`000000BeVo04]I_`0@04]I_`0300000039J5L0bFQG01/0bFQG00<000000;:@/`2b
T;<01P2bT;<00`000000/m3_0;?@k`0G0;?@k`8000001`3=FBP00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo04d0oooo2000000302l0>0<00000
4P0_03P00`000000h<6j0>31^P0E0>31^P030000001;FKl0BeVo0100BeVo00<000000<UXE`39J5L0
6P39J5L00`000000/Y2c0;:@/`070;:@/`030000002cd>l0/m3_01P0/m3_100000050<eI:0030000
003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000X0oooo00<000000?ooo`3oool0C03o
ool70000000308njm0000000000000800000500_03P00`000000h<6j0>31^P0F0>31^P030000001;
FKl0BeVo0140BeVo00<000000<UXE`39J5L06039J5L00`000000/Y2c0;:@/`080;:@/`030000002c
d>l0/m3_01T0/m3_00<000000;?@k`2cd>l00`0000030<eI:0030000003oool0oooo0240oooo00<0
00000?ooo`3oool01`3oool000X0oooo00<000000?ooo`3oool0B`3oool;000001H0;`0h00<00000
0>31^P3P`KX05P3P`KX00`000000BeVo04]I_`0B04]I_`0300000039J5L0bFQG01L0bFQG00<00000
0;:@/`2bT;<0202bT;<00`000000/m3_0;?@k`0J0;?@k`030000002cd>l0/m3_0080/m3_0`000000
0`3=FBP000000?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo
04/0oooo2000000208njm08000005@0_03P00`000000h<6j0>31^P0H0>31^P030000001;FKl0BeVo
0180BeVo00<000000<UXE`39J5L05@39J5L00`000000/Y2c0;:@/`090;:@/`030000002cd>l0/m3_
01/0/m3_00<000000;?@k`2cd>l0102cd>l300000240oooo00<000000?ooo`3oool01`3oool000T0
oooo0`00001;0?ooo`H00000102?^_@2000001@0;`0h00<000000>31^P3P`KX06@3P`KX00`000000
BeVo04]I_`0C04]I_`0300000039J5L0bFQG01<0bFQG00<000000;:@/`2bT;<02`2bT;<00`000000
/m3_0;?@k`0K0;?@k`030000002cd>l0/m3_00D0/m3_0P00000P0?ooo`030000003oool0oooo00L0
oooo0000103oool000000000000000050?ooo`030000003oool0oooo04T0oooo1`00000508njm003
0000002UQk<000000180;`0h00<000000>31^P3P`KX06P3P`KX00`000000BeVo04]I_`0D04]I_`03
00000039J5L0bFQG0140bFQG00<000000;:@/`2bT;<0302bT;<00`000000/m3_0;?@k`0K0;?@k`03
0000002cd>l0/m3_0080/m3_0`00000R0?ooo`030000003oool0oooo00L0oooo00020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0AP3oool9000000H0Sk[d00<000000:F7/`000000
4P0_03P00`000000h<6j0>31^P0J0>31^P030000001;FKl0BeVo01D0BeVo00<000000<UXE`39J5L0
4039J5L00`000000/Y2c0;:@/`0<0;:@/`030000002cd>l0/m3_01`0/m3_1000000U0?ooo`030000
003oool0oooo00L0oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3o
ool300000080oooo1P00000708njm0030000002UQk<000000140;`0h00<000000>31^P3P`KX06`3P
`KX00`000000BeVo04]I_`0F04]I_`0300000039J5L0bFQG00h0bFQG00<000000;:@/`2bT;<03@2b
T;<00`000000/m3_0;?@k`0K0;?@k`<00000:03oool00`000000oooo0?ooo`060?ooo`000P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0400oooo0`0000040?ooo`D000002@2?^_@0
10000000YHNc0:F7/`00000?02l0>0030000003P`KX0h<6j01`0h<6j00<0000004]I_`1;FKl05`1;
FKl00`000000bFQG0<UXE`0<0<UXE`030000002bT;<0/Y2c00h0/Y2c00<000000;?@k`2cd>l0602c
d>l3000000<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`060?ooo`000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03h0oooo0`0000070?ooo`@000002P2?^_@0
10000000YHNc0:F7/`00000?02l0>0030000003P`KX0h<6j01d0h<6j00<0000004]I_`1;FKl05P1;
FKl00`000000bFQG0<UXE`0;0<UXE`030000002bT;<0/Y2c00l0/Y2c00<000000;?@k`2cd>l05@2c
d>l3000000L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`060?ooo`0000<0oooo
0000000000001@3oool00`000000oooo0?ooo`0j0?ooo`@000002@3oool4000000/0Sk[d00@00000
0:F7/`2UQk<000003P0_03P00`000000h<6j0>31^P0N0>31^P030000001;FKl0BeVo01L0BeVo00<0
00000<UXE`39J5L02P39J5L00`000000/Y2c0;:@/`0@0;:@/`030000002cd>l0/m3_0140/m3_0`00
000:0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01P3oool00080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0g0?ooo`<00000303oool4000000d0Sk[d00@00000
0:F7/`2UQk<00000300_03P00`000000h<6j0>31^P0O0>31^P030000001;FKl0BeVo01P0BeVo00<0
00000<UXE`39J5L02039J5L00`000000/Y2c0;:@/`0A0;:@/`030000002cd>l0/m3_00l0/m3_0P00
000>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool000P0oooo00<00000
0?ooo`3oool0=03oool3000000h0oooo1000000>08njm0040000002UQk<0YHNc000000`0;`0h00<0
00000>31^P3P`KX07`3P`KX00`000000BeVo04]I_`0I04]I_`0300000039J5L0bFQG00H0bFQG00<0
00000;:@/`2bT;<04P2bT;<00`000000/m3_0;?@k`0<0;?@k`<000004@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00H0oooo00080?ooo`800000<P3oool300000140oooo0`00000?
08njm0040000002UQk<0YHNc000000/0;`0h00<000000>31^P3P`KX0803P`KX00`000000BeVo04]I
_`0J04]I_`0300000039J5L0bFQG00@0bFQG00<000000;:@/`2bT;<04`2bT;<00`000000/m3_0;?@
k`090;?@k`<000005@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo0008
0?ooo`030000003oool0oooo02h0oooo0`00000C0?ooo`<00000402?^_@01@000000YHNc0:F7/`2U
Qk<0000000T0;`0h00<000000>31^P3P`KX08@3P`KX00`000000BeVo04]I_`0K04]I_`0300000039
J5L0bFQG00<0bFQG00<000000;:@/`2bT;<04`2bT;<00`000000/m3_0;?@k`070;?@k`800000603o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00080?ooo`030000003oool0
oooo02/0oooo0`00000E0?ooo`8000004P2?^_@01@000000YHNc0:F7/`2UQk<0000000T0;`0h00<0
00000>31^P3P`KX08P3P`KX00`000000BeVo04]I_`0K04]I_`0500000039J5L0bFQG0<UXE`000000
5`2bT;<00`000000/m3_0;?@k`030;?@k`<000006`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02T0oooo0`00000G0?ooo`8000004`2?
^_@01@000000YHNc0:F7/`2UQk<0000000P0;`0h00<000000>31^P3P`KX08`3P`KX00`000000BeVo
04]I_`0L04]I_`0300000039J5L0000001P0/Y2c00<000000;?@k`2cd>l00`00000O0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool09@3o
ool4000001T0oooo0P00000D08njm0030000002UQk<0YHNc0080YHNc00<0000002l0>00_03P0100_
03P00`000000h<6j0>31^P0T0>31^P030000001;FKl0BeVo01`0BeVo0P00000I0;:@/`<000008`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo0280oooo0`00000M0?ooo`030000002?^_@0Sk[d01<0Sk[d00<000000:F7/`2UQk<00P2UQk<0
0`000000;`0h02l0>00302l0>0030000003P`KX0h<6j02D0h<6j00<0000004]I_`1;FKl06P1;FKl2
000001/0/Y2c00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo01l0oooo0`00000O0?ooo`030000002?^_@0Sk[d
01@0Sk[d00<000000:F7/`2UQk<00P2UQk<00`000000;`0h02l0>00302l0>0030000003P`KX0h<6j
02D0h<6j00<0000004]I_`1;FKl0601;FKl2000001d0/Y2c00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo01`0
oooo0`00000Q0?ooo`030000002?^_@0Sk[d01D0Sk[d00<000000:F7/`2UQk<00`2UQk<01@000000
;`0h02l0>00_03P0000002T0h<6j00<0000004]I_`1;FKl05P1;FKl00`000000/Y2c0;:@/`0M0;:@
/`030000003oool0oooo02D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0I0?ooo`<000008`3oool4000001D0Sk[d00<000000:F7/`2U
Qk<00`2UQk<010000000;`0h02l0>000000Z0>31^P030000001;FKl0BeVo01@0BeVo0P00000Q0;:@
/`030000003oool0oooo02D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`0G0?ooo`<00000:P3oool7000000h0Sk[d00<000000:F7/`2U
Qk<00`2UQk<010000000;`0h02l0>000000Z0>31^P030000001;FKl0BeVo0180BeVo0P00000S0;:@
/`030000003oool0oooo02H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`040?oo
o`001P3oool2000001D0oooo0`00000d0?ooo`H00000202?^_@00`000000YHNc0:F7/`040:F7/`80
0000:`3P`KX00`000000BeVo04]I_`0@04]I_`8000009@2bT;<00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0
403oool4000003d0oooo1P00000208njm0030000002UQk<0YHNc00@0YHNc1000000Y0>31^P030000
001;FKl0BeVo00h0BeVo0P00000W0;:@/`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0=0?ooo`<00000A`3o
ool3000000X0YHNc1@00000T0>31^P030000001;FKl0BeVo00d0BeVo00<000000;:@/`2bT;<09`2b
T;<00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0103o
ool000H0oooo00<000000?ooo`3oool02P3oool3000004`0oooo00<000000:F7/`2UQk<03@2UQk<5
00000200h<6j00<0000004]I_`1;FKl02P1;FKl2000002X0/Y2c00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo
00L0oooo0`00001?0?ooo`030000002UQk<0YHNc0180YHNc1@00000K0>31^P030000001;FKl0BeVo
00P0BeVo0P00000]0;:@/`030000003oool0oooo02T0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`040?ooo`<00000DP3oool00`000000
YHNc0:F7/`0G0:F7/`H000005@3P`KX00`000000BeVo04]I_`0604]I_`800000;`2bT;<00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool000D0oooo
00<000000?ooo`3oool00P3oool3000005D0oooo00<000000:F7/`2UQk<07@2UQk<500000100h<6j
00<0000004]I_`1;FKl0101;FKl200000340/Y2c00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00<0oooo00050?ooo`D00000F03oool00`000000YHNc0:F7
/`0R0:F7/`D000002`3P`KX00`000000BeVo04]I_`0304]I_`030000002bT;<0/Y2c0340/Y2c00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo0005
0?ooo`800000F`3oool00`000000YHNc0:F7/`0W0:F7/`D000001`3P`KX00`000000BeVo04]I_`02
000003@0/Y2c00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00<0oooo00070?ooo`030000003oool0oooo05T0oooo00<000000:F7/`2UQk<0:`2UQk<50000
0080h<6j0`00000g0;:@/`030000003oool0oooo02`0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`030?ooo`00203oool00`000000oooo0?ooo`1H0?ooo`030000002UQk<0YHNc0300
YHNc1@00000g0;:@/`030000003oool0oooo02`0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`030?ooo`002@3oool2000005P0oooo00<000000:F7/`2UQk<0;`2UQk<20000000401A2
_P000000jmFn0>_E_P<00000=02bT;<00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool00`3oool000/0oooo00<000000?ooo`3oool0E@3oool00`000000YHNc
0:F7/`0^0:F7/`050000000D@[h054:n01A2_P0000001@3[eKh300000340/Y2c00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo000<0?ooo`030000
003oool0000005@0oooo00<000000:F7/`2UQk<0;02UQk<2000000D054:n00<000000>_E_P3[eKh0
1@3[eKh4000002d0/Y2c00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00<0oooo000=0?ooo`800000E03oool00`000000YHNc0:F7/`0Z0:F7/`8000001`0D
@[h00`000000jmFn0>_E_P090>_E_P<00000:P2bT;<00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool00P3oool000l0oooo00<000000?ooo`3oool0D@3oool0
0`000000YHNc0:F7/`0X0:F7/`8000002@0D@[h00`000000jmFn0>_E_P0<0>_E_P@000009`2bT;<0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool0
0100oooo0P00001A0?ooo`030000002UQk<0YHNc02H0YHNc0P00000;01A2_P030000003[eKh0jmFn
0100jmFn0`00000T0;:@/`030000003oool0oooo0300oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1>0?ooo`030000002UQk<0YHNc02D0
YHNc00<0000001A2_P0D@[h0300D@[h00`000000jmFn0>_E_P0B0>_E_P<000008@2bT;<00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool001<0oooo
0P00001>0?ooo`030000002UQk<0YHNc02<0YHNc0P00000?01A2_P030000003[eKh0jmFn01D0jmFn
1000000M0;:@/`030000003oool0oooo0380oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`020?ooo`00503oool2000004d0oooo00<000000:F7/`2UQk<08@2UQk<2000000030?ooo`00
000054:n00h054:n00<000000>_E_P3[eKh0603[eKh4000001X0/Y2c00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo000F0?ooo`030000003oool0
oooo04X0oooo00<000000:F7/`2UQk<07`2UQk<2000000@0oooo00<0000001A2_P0D@[h0300D@[h0
0`000000jmFn0>_E_P0G0>_E_P030000003oool0oooo0080oooo1000000F0;:@/`030000003oool0
oooo03<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`005`3oool00`00
0000oooo0?ooo`190?ooo`030000002UQk<0YHNc01d0YHNc0P0000060?ooo`030000000D@[h054:n
00`054:n00<000000>_E_P3[eKh05P3[eKh00`000000oooo0?ooo`070?ooo`<00000502bT;<00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00@3oool001P0
oooo0P0000190?ooo`030000002UQk<0YHNc01`0YHNc00<000000?ooo`3oool01`3oool00`000000
54:n01A2_P0<01A2_P030000003[eKh0jmFn01D0jmFn00<000000?ooo`3oool02P3oool300000140
/Y2c00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0040
oooo000J0?ooo`800000A`3oool00`000000YHNc0:F7/`0J0:F7/`8000002`3oool00`00000054:n
01A2_P0;01A2_P030000003[eKh0jmFn01@0jmFn00<000000?ooo`3oool03P3oool4000000d0/Y2c
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0040oooo
000K0?ooo`030000003oool0oooo04D0oooo00<000000:F7/`2UQk<0602UQk<2000000d0oooo00<0
000001A2_P0D@[h02`0D@[h00`000000jmFn0>_E_P0D0>_E_P030000003oool0oooo0180oooo0`00
000:0;:@/`030000003oool0oooo03D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`010?ooo`00703oool2000004D0oooo00<000000:F7/`2UQk<05P2UQk<200000100oooo00<00000
01A2_P0D@[h02P0D@[h00`000000jmFn0>_E_P0C0>_E_P030000003oool0oooo01H0oooo10000006
0;:@/`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`01
0?ooo`007P3oool00`000000oooo0?ooo`120?ooo`030000002UQk<0YHNc01@0YHNc0P00000C0?oo
o`030000000D@[h054:n00X054:n00<000000>_E_P3[eKh04P3[eKh00`000000oooo0?ooo`0J0?oo
o`<00000102bT;<00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00@3oool001l0oooo0P0000000`3oool000000?ooo`0o0?ooo`030000002UQk<0YHNc01<0
YHNc00<000000?ooo`3oool0503oool00`00000054:n01A2_P0901A2_P030000003[eKh0jmFn0140
jmFn00<000000?ooo`3oool07P3oool3000000030;:@/`000000oooo03P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`010?ooo`008@3oool200000400oooo00<000000:F7/`2UQk<0
4@2UQk<2000001L0oooo00<0000001A2_P0D@[h02@0D@[h00`000000jmFn0>_E_P0A0>_E_P030000
003oool0oooo0240oooo0P00000i0?ooo`030000003oool0oooo00X0oooo0@0000010?ooo`40oooo
000R0?ooo`030000003oool0oooo03h0oooo00<000000:F7/`2UQk<03`2UQk<2000001X0oooo00<0
000001A2_P0D@[h0200D@[h00`000000jmFn0>_E_P0@0>_E_P030000003oool0oooo05h0oooo00<0
00000?ooo`3oool02@3oool100000040oooo0@3oool002<0oooo0P00000o0?ooo`030000002UQk<0
YHNc00`0YHNc0P00000M0?ooo`030000000D@[h054:n00P054:n00<000000>_E_P3[eKh03`3[eKh0
0`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`40oooo000U0?oo
o`030000003oool0oooo03`0oooo00<000000:F7/`2UQk<02P2UQk<2000000030?ooo`000000oooo
01`0oooo00<0000001A2_P0D@[h0200D@[h00`000000jmFn0>_E_P0>0>_E_P030000003oool0oooo
0640oooo00<000000?ooo`3oool01`3oool100000040oooo0@3oool002H0oooo00<000000?ooo`00
0000>`3oool00`000000YHNc0:F7/`090:F7/`050000003oool0oooo0?ooo`0000007P3oool00`00
000054:n01A2_P0701A2_P030000003[eKh0jmFn00h0jmFn00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`060?ooo`4000000@3oool10?ooo`009`3oool2000003/0oooo00<000000:F7/`2U
Qk<01`2UQk<2000000@0oooo00<000000?ooo`3oool07@3oool00`00000054:n01A2_P0601A2_P03
0000003[eKh0jmFn00d0jmFn00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`060?ooo`40
00000@3oool10?ooo`00:03oool2000003X0oooo00<000000:F7/`2UQk<01@2UQk<2000000H0oooo
00<000000?ooo`3oool07@3oool00`00000054:n01A2_P0601A2_P030000003[eKh0jmFn00`0jmFn
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00:P3o
ool00`000000oooo0?ooo`0g0?ooo`030000002UQk<0YHNc00<0YHNc0P0000080?ooo`030000003o
ool0oooo01h0oooo00<0000001A2_P0D@[h01P0D@[h00`000000jmFn0>_E_P0;0>_E_P030000003o
ool0oooo06H0oooo00<000000?ooo`3oool0103oool100000040oooo0@3oool00280oooo0`000006
0?ooo`800000=`3oool010000000YHNc0:F7/`2UQk<2000000X0oooo00<000000?ooo`3oool07`3o
ool00`00000054:n01A2_P0501A2_P030000003[eKh0jmFn00X0jmFn00<000000?ooo`3oool0J03o
ool00`000000oooo0?ooo`040?ooo`4000000@3oool002<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0000000d0?ooo`040000002UQk<0YHNc000000`0oooo00<000000?ooo`3oool0803o
ool00`00000054:n01A2_P0401A2_P030000003[eKh0jmFn00X0jmFn00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`030?ooo`4000000@3oool001/0oooo1@0000030?ooo`030000003oool0
oooo00P0oooo0P00000d0?ooo`<000003@3oool00`000000oooo0?ooo`0P0?ooo`030000000D@[h0
54:n00@054:n00<000000>_E_P3[eKh02@3[eKh00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo00<0oooo0@0000010?ooo`008`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Q0?ooo`030000000D@[h054:n
00@054:n00<000000>_E_P3[eKh0203[eKh00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
0080oooo0@0000010?ooo`008`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool08P3oool00`00000054:n01A2_P0301A2_P030000003[eKh0jmFn00L0
jmFn00<000000?ooo`3oool0K@3oool01@000000oooo0?ooo`3oool000000040oooo000R0?ooo`80
00003P3oool200000400oooo00<000000?ooo`3oool08P3oool00`00000054:n01A2_P0301A2_P03
0000003[eKh0jmFn00L0jmFn00<000000?ooo`3oool0KP3oool010000000oooo0?ooo`0000010?oo
o`008`3oool00`000000oooo0?ooo`0>0?ooo`800000?P3oool00`000000oooo0?ooo`0S0?ooo`03
0000000D@[h054:n008054:n00<000000>_E_P3[eKh01P3[eKh00`000000oooo0?ooo`1_0?ooo`04
0000003oool0oooo00000040oooo000e0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0903oool00`00000054:n01A2_P0201A2_P030000003[eKh0jmFn00D0jmFn00<000000?ooo`3o
ool0L03oool00`000000oooo0?ooo`0100000000=P3oool2000003/0oooo00<000000?ooo`3oool0
9@3oool00`00000054:n01A2_P0201A2_P030000003[eKh0jmFn00@0jmFn00<000000?ooo`3oool0
LP3oool100000040oooo0@00000003P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0V0?ooo`050000000D@[h054:n01A2_P0000001P3[eKh00`000000oooo0?ooo`1c0?ooo`800000
000i0?ooo`030000003oool0000003L0oooo00<000000?ooo`3oool09`3oool01000000054:n01A2
_P0000050>_E_P030000003oool0oooo07<0oooo0`00000003X0oooo0P00000g0?ooo`030000003o
ool0oooo02L0oooo00@0000001A2_P0D@[h00000103[eKh00`000000oooo0?ooo`1`0?ooo`@00000
0`3oool003`0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0X0?ooo`040000000D
@[h054:n000000<0jmFn00<000000?ooo`3oool0K03oool4000000L0oooo000m0?ooo`800000=03o
ool00`000000oooo0?ooo`0Y0?ooo`030000000D@[h000000080jmFn00<000000?ooo`3oool0J@3o
ool4000000/0oooo000o0?ooo`030000003oool000000340oooo00<000000?ooo`3oool0:P3oool2
00000080jmFn00<000000?ooo`3oool0I@3oool4000000l0oooo00100?ooo`800000<@3oool00`00
0000oooo0?ooo`0Z0?ooo`80000000<0jmFn0000003oool0HP3oool5000001<0oooo00110?ooo`80
0000<03oool00`000000oooo0?ooo`0[0?ooo`<00000G`3oool4000001P0oooo00130?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1J0?ooo`@00000
703oool004@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`250?ooo`@00000803o
ool004D0oooo0`00000[0?ooo`030000003oool0oooo0840oooo1000000T0?ooo`00A`3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo07d0oooo1000000X0?ooo`00B03oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo07T0oooo1000000/0?ooo`00B@3oool2000002P0oooo
00<000000?ooo`3oool0M@3oool400000300oooo000o0?ooo`8000002P3oool2000002H0oooo00<0
00000?ooo`3oool0L@3oool4000003@0oooo000n0?ooo`040000003oool0oooo000000X0oooo0P00
000U0?ooo`030000003oool0oooo06d0oooo1000000h0?ooo`00?P3oool010000000oooo0?ooo`00
000<0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0J@3oool4000003`0oooo000n
0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`1T0?ooo`D00000@03oool003h0oooo00@000000?ooo`3oool000003P3oool300000200oooo00<0
00000?ooo`3oool0H03oool4000004D0oooo000n0?ooo`040000003oool0oooo00000100oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1L0?ooo`@00000B@3oool003l0oooo0P00000B
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F03oool4000004d0oooo001D0?oo
o`8000007@3oool00`000000oooo0?ooo`1D0?ooo`@00000D@3oool005H0oooo0P00000K0?ooo`03
0000003oool0oooo0500oooo1000001E0?ooo`00E`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo04`0oooo1000001I0?ooo`00F03oool2000001T0oooo00<000000?ooo`3oool0B03o
ool4000005d0oooo001J0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool0A03o
ool400000640oooo001K0?ooo`<000005@3oool00`000000oooo0?ooo`100?ooo`@00000I@3oool0
05d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0k0?ooo`D00000J@3oool005h0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`@00000KP3oool005l0oooo
0P00000A0?ooo`030000003oool0oooo03@0oooo1000001b0?ooo`00H@3oool2000000l0oooo00<0
00000?ooo`3oool0<03oool4000007H0oooo001R0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0;03oool4000007X0oooo001S0?ooo`8000003@3oool00`000000oooo0?ooo`0X0?oo
o`@00000OP3oool006D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0T0?ooo`@0
0000PP3oool005X0oooo0`0000090?ooo`8000002P3oool00`000000oooo0?ooo`0P0?ooo`@00000
QP3oool005/0oooo00<000000?ooo`3oool02@3oool2000000T0oooo00<000000?ooo`3oool0703o
ool4000008X0oooo001K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0H0?ooo`@00000SP3oool005/0oooo00<000000?ooo`3oool0303oool30000
00D0oooo00<000000?ooo`3oool0503oool400000980oooo001K0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`D00000UP3oool005X0oooo
0P00000@0?ooo`800000103oool00`000000oooo0?ooo`0;0?ooo`@00000V`3oool005/0oooo00<0
00000?ooo`3oool0403oool200000080oooo00<000000?ooo`3oool01`3oool4000009l0oooo001`
0?ooo`<000001@3oool400000:<0oooo001a0?ooo`80000000<0oooo0000000000000P00002W0?oo
o`00LP3oool200000:/0oooo003o0?ooob00oooo003o0?ooob00oooo0000\
\>"],
  ImageRangeCache->{{{0, 286.5}, {286.938, 0}} -> {0.000902133, -0.00903519, \
0.00327269, 0.00327269}},
  CellTags->"CustomPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["solidstelprism = CustomPrism[show,GraphicDesign->Solid]", "Input",
  CellTags->"CustomPrism"],

Cell[BoxData[
    TagBox[
      RowBox[{"CustomPrism", "[", 
        RowBox[{
          TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
            False,
            Editable->False], ",", \({GraphicDesign \[Rule] Solid}\)}], "]"}],
      
      HoldForm]], "Output",
  CellTags->"CustomPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
solidstelprism = \
CustomPrism[stel,\"stelprism\",GraphicDesign->Solid]\
\>", "Input",
  CellTags->"CustomPrism"],

Cell[BoxData[
    TagBox["\<\"stelprism\"\>",
      HoldForm]], "Output",
  CellTags->"CustomPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[stelsys = 
\tTurboPlot[
\t\t{Move[LineOfRays[{1,1}],{-3,-.25}],
\t\tsolidstelprism,
\t\tBoundary[{-2,-2,-2},{2,2,2}]},
\t\tPlotType->TopView,
\t\tThresholdIntensity->.1,
\t\tShowArrows->True
\t]][[1]]\
\>", "Input",
  CellTags->"CustomPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.595238 0.190476 0.4 0.190476 [
[ 0 0 0 0 ]
[ 1 .8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.77002 .52698 m
.59524 .4 L
.65713 .59048 L
.77002 .52698 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.77002 .52698 m
.59524 .4 L
.65713 .59048 L
.77002 .52698 L
s
.5 g
.77002 .52698 m
.65713 .59048 L
.79552 .4 L
.77002 .52698 L
F
0 g
.77002 .52698 m
.65713 .59048 L
.79552 .4 L
.77002 .52698 L
s
.5 g
.77002 .52698 m
.79552 .4 L
.59524 .4 L
.77002 .52698 L
F
0 g
.77002 .52698 m
.79552 .4 L
.59524 .4 L
.77002 .52698 L
s
.5 g
.52848 .60546 m
.59524 .4 L
.43321 .51772 L
.52848 .60546 L
F
0 g
.52848 .60546 m
.59524 .4 L
.43321 .51772 L
.52848 .60546 L
s
.5 g
.52848 .60546 m
.43321 .51772 L
.65713 .59048 L
.52848 .60546 L
F
0 g
.52848 .60546 m
.43321 .51772 L
.65713 .59048 L
.52848 .60546 L
s
.5 g
.52848 .60546 m
.65713 .59048 L
.59524 .4 L
.52848 .60546 L
F
0 g
.52848 .60546 m
.65713 .59048 L
.59524 .4 L
.52848 .60546 L
s
.5 g
.3792 .4 m
.59524 .4 L
.43321 .28228 L
.3792 .4 L
F
0 g
.3792 .4 m
.59524 .4 L
.43321 .28228 L
.3792 .4 L
s
.5 g
.3792 .4 m
.43321 .28228 L
.43321 .51772 L
.3792 .4 L
F
0 g
.3792 .4 m
.43321 .28228 L
.43321 .51772 L
.3792 .4 L
s
.5 g
.3792 .4 m
.43321 .51772 L
.59524 .4 L
.3792 .4 L
F
0 g
.3792 .4 m
.43321 .51772 L
.59524 .4 L
.3792 .4 L
s
.5 g
.52848 .19454 m
.59524 .4 L
.65713 .20952 L
.52848 .19454 L
F
0 g
.52848 .19454 m
.59524 .4 L
.65713 .20952 L
.52848 .19454 L
s
.5 g
.52848 .19454 m
.65713 .20952 L
.43321 .28228 L
.52848 .19454 L
F
0 g
.52848 .19454 m
.65713 .20952 L
.43321 .28228 L
.52848 .19454 L
s
.5 g
.52848 .19454 m
.43321 .28228 L
.59524 .4 L
.52848 .19454 L
F
0 g
.52848 .19454 m
.43321 .28228 L
.59524 .4 L
.52848 .19454 L
s
.5 g
.77002 .27302 m
.59524 .4 L
.79552 .4 L
.77002 .27302 L
F
0 g
.77002 .27302 m
.59524 .4 L
.79552 .4 L
.77002 .27302 L
s
.5 g
.77002 .27302 m
.79552 .4 L
.65713 .20952 L
.77002 .27302 L
F
0 g
.77002 .27302 m
.79552 .4 L
.65713 .20952 L
.77002 .27302 L
s
.5 g
.77002 .27302 m
.65713 .20952 L
.59524 .4 L
.77002 .27302 L
F
0 g
.77002 .27302 m
.65713 .20952 L
.59524 .4 L
.77002 .27302 L
s
.5 g
.87804 .60546 m
.79552 .4 L
.65713 .59048 L
.87804 .60546 L
F
0 g
.87804 .60546 m
.79552 .4 L
.65713 .59048 L
.87804 .60546 L
s
.5 g
.87804 .60546 m
.65713 .59048 L
.75727 .51772 L
.87804 .60546 L
F
0 g
.87804 .60546 m
.65713 .59048 L
.75727 .51772 L
.87804 .60546 L
s
.5 g
.87804 .60546 m
.75727 .51772 L
.79552 .4 L
.87804 .60546 L
F
0 g
.87804 .60546 m
.75727 .51772 L
.79552 .4 L
.87804 .60546 L
s
.5 g
.48722 .73245 m
.65713 .59048 L
.43321 .51772 L
.48722 .73245 L
F
0 g
.48722 .73245 m
.65713 .59048 L
.43321 .51772 L
.48722 .73245 L
s
.5 g
.48722 .73245 m
.43321 .51772 L
.53335 .59048 L
.48722 .73245 L
F
0 g
.48722 .73245 m
.43321 .51772 L
.53335 .59048 L
.48722 .73245 L
s
.5 g
.48722 .73245 m
.53335 .59048 L
.65713 .59048 L
.48722 .73245 L
F
0 g
.48722 .73245 m
.53335 .59048 L
.65713 .59048 L
.48722 .73245 L
s
.5 g
.24568 .4 m
.43321 .51772 L
.43321 .28228 L
.24568 .4 L
F
0 g
.24568 .4 m
.43321 .51772 L
.43321 .28228 L
.24568 .4 L
s
.5 g
.24568 .4 m
.43321 .28228 L
.39496 .4 L
.24568 .4 L
F
0 g
.24568 .4 m
.43321 .28228 L
.39496 .4 L
.24568 .4 L
s
.5 g
.24568 .4 m
.39496 .4 L
.43321 .51772 L
.24568 .4 L
F
0 g
.24568 .4 m
.39496 .4 L
.43321 .51772 L
.24568 .4 L
s
.5 g
.48722 .06755 m
.43321 .28228 L
.65713 .20952 L
.48722 .06755 L
F
0 g
.48722 .06755 m
.43321 .28228 L
.65713 .20952 L
.48722 .06755 L
s
.5 g
.48722 .06755 m
.65713 .20952 L
.53335 .20952 L
.48722 .06755 L
F
0 g
.48722 .06755 m
.65713 .20952 L
.53335 .20952 L
.48722 .06755 L
s
.5 g
.48722 .06755 m
.53335 .20952 L
.43321 .28228 L
.48722 .06755 L
F
0 g
.48722 .06755 m
.53335 .20952 L
.43321 .28228 L
.48722 .06755 L
s
.5 g
.87804 .19454 m
.65713 .20952 L
.79552 .4 L
.87804 .19454 L
F
0 g
.87804 .19454 m
.65713 .20952 L
.79552 .4 L
.87804 .19454 L
s
.5 g
.87804 .19454 m
.79552 .4 L
.75727 .28228 L
.87804 .19454 L
F
0 g
.87804 .19454 m
.79552 .4 L
.75727 .28228 L
.87804 .19454 L
s
.5 g
.87804 .19454 m
.75727 .28228 L
.65713 .20952 L
.87804 .19454 L
F
0 g
.87804 .19454 m
.75727 .28228 L
.65713 .20952 L
.87804 .19454 L
s
.5 g
.70326 .73245 m
.75727 .51772 L
.65713 .59048 L
.70326 .73245 L
F
0 g
.70326 .73245 m
.75727 .51772 L
.65713 .59048 L
.70326 .73245 L
s
.5 g
.70326 .73245 m
.65713 .59048 L
.53335 .59048 L
.70326 .73245 L
F
0 g
.70326 .73245 m
.65713 .59048 L
.53335 .59048 L
.70326 .73245 L
s
.5 g
.70326 .73245 m
.53335 .59048 L
.75727 .51772 L
.70326 .73245 L
F
0 g
.70326 .73245 m
.53335 .59048 L
.75727 .51772 L
.70326 .73245 L
s
.5 g
.31244 .60546 m
.53335 .59048 L
.43321 .51772 L
.31244 .60546 L
F
0 g
.31244 .60546 m
.53335 .59048 L
.43321 .51772 L
.31244 .60546 L
s
.5 g
.31244 .60546 m
.43321 .51772 L
.39496 .4 L
.31244 .60546 L
F
0 g
.31244 .60546 m
.43321 .51772 L
.39496 .4 L
.31244 .60546 L
s
.5 g
.31244 .60546 m
.39496 .4 L
.53335 .59048 L
.31244 .60546 L
F
0 g
.31244 .60546 m
.39496 .4 L
.53335 .59048 L
.31244 .60546 L
s
.5 g
.31244 .19454 m
.39496 .4 L
.43321 .28228 L
.31244 .19454 L
F
0 g
.31244 .19454 m
.39496 .4 L
.43321 .28228 L
.31244 .19454 L
s
.5 g
.31244 .19454 m
.43321 .28228 L
.53335 .20952 L
.31244 .19454 L
F
0 g
.31244 .19454 m
.43321 .28228 L
.53335 .20952 L
.31244 .19454 L
s
.5 g
.31244 .19454 m
.53335 .20952 L
.39496 .4 L
.31244 .19454 L
F
0 g
.31244 .19454 m
.53335 .20952 L
.39496 .4 L
.31244 .19454 L
s
.5 g
.70326 .06755 m
.53335 .20952 L
.65713 .20952 L
.70326 .06755 L
F
0 g
.70326 .06755 m
.53335 .20952 L
.65713 .20952 L
.70326 .06755 L
s
.5 g
.70326 .06755 m
.65713 .20952 L
.75727 .28228 L
.70326 .06755 L
F
0 g
.70326 .06755 m
.65713 .20952 L
.75727 .28228 L
.70326 .06755 L
s
.5 g
.70326 .06755 m
.75727 .28228 L
.53335 .20952 L
.70326 .06755 L
F
0 g
.70326 .06755 m
.75727 .28228 L
.53335 .20952 L
.70326 .06755 L
s
.5 g
.9448 .4 m
.75727 .28228 L
.79552 .4 L
.9448 .4 L
F
0 g
.9448 .4 m
.75727 .28228 L
.79552 .4 L
.9448 .4 L
s
.5 g
.9448 .4 m
.79552 .4 L
.75727 .51772 L
.9448 .4 L
F
0 g
.9448 .4 m
.79552 .4 L
.75727 .51772 L
.9448 .4 L
s
.5 g
.9448 .4 m
.75727 .51772 L
.75727 .28228 L
.9448 .4 L
F
0 g
.9448 .4 m
.75727 .51772 L
.75727 .28228 L
.9448 .4 L
s
.5 g
.662 .60546 m
.75727 .51772 L
.53335 .59048 L
.662 .60546 L
F
0 g
.662 .60546 m
.75727 .51772 L
.53335 .59048 L
.662 .60546 L
s
.5 g
.662 .60546 m
.53335 .59048 L
.59524 .4 L
.662 .60546 L
F
0 g
.662 .60546 m
.53335 .59048 L
.59524 .4 L
.662 .60546 L
s
.5 g
.662 .60546 m
.59524 .4 L
.75727 .51772 L
.662 .60546 L
F
0 g
.662 .60546 m
.59524 .4 L
.75727 .51772 L
.662 .60546 L
s
.5 g
.42046 .52698 m
.53335 .59048 L
.39496 .4 L
.42046 .52698 L
F
0 g
.42046 .52698 m
.53335 .59048 L
.39496 .4 L
.42046 .52698 L
s
.5 g
.42046 .52698 m
.39496 .4 L
.59524 .4 L
.42046 .52698 L
F
0 g
.42046 .52698 m
.39496 .4 L
.59524 .4 L
.42046 .52698 L
s
.5 g
.42046 .52698 m
.59524 .4 L
.53335 .59048 L
.42046 .52698 L
F
0 g
.42046 .52698 m
.59524 .4 L
.53335 .59048 L
.42046 .52698 L
s
.5 g
.42046 .27302 m
.39496 .4 L
.53335 .20952 L
.42046 .27302 L
F
0 g
.42046 .27302 m
.39496 .4 L
.53335 .20952 L
.42046 .27302 L
s
.5 g
.42046 .27302 m
.53335 .20952 L
.59524 .4 L
.42046 .27302 L
F
0 g
.42046 .27302 m
.53335 .20952 L
.59524 .4 L
.42046 .27302 L
s
.5 g
.42046 .27302 m
.59524 .4 L
.39496 .4 L
.42046 .27302 L
F
0 g
.42046 .27302 m
.59524 .4 L
.39496 .4 L
.42046 .27302 L
s
.5 g
.662 .19454 m
.53335 .20952 L
.75727 .28228 L
.662 .19454 L
F
0 g
.662 .19454 m
.53335 .20952 L
.75727 .28228 L
.662 .19454 L
s
.5 g
.662 .19454 m
.75727 .28228 L
.59524 .4 L
.662 .19454 L
F
0 g
.662 .19454 m
.75727 .28228 L
.59524 .4 L
.662 .19454 L
s
.5 g
.662 .19454 m
.59524 .4 L
.53335 .20952 L
.662 .19454 L
F
0 g
.662 .19454 m
.59524 .4 L
.53335 .20952 L
.662 .19454 L
s
.5 g
.81128 .4 m
.75727 .28228 L
.75727 .51772 L
.81128 .4 L
F
0 g
.81128 .4 m
.75727 .28228 L
.75727 .51772 L
.81128 .4 L
s
.5 g
.81128 .4 m
.75727 .51772 L
.59524 .4 L
.81128 .4 L
F
0 g
.81128 .4 m
.75727 .51772 L
.59524 .4 L
.81128 .4 L
s
.5 g
.81128 .4 m
.59524 .4 L
.75727 .28228 L
.81128 .4 L
F
0 g
.81128 .4 m
.59524 .4 L
.75727 .28228 L
.81128 .4 L
s
.97619 .78095 m
.97619 .01905 L
.97619 .01905 L
.97619 .78095 L
.97619 .78095 L
s
.97619 .01905 m
.21429 .01905 L
.21429 .01905 L
.97619 .01905 L
.97619 .01905 L
s
.21429 .01905 m
.21429 .78095 L
.21429 .78095 L
.21429 .01905 L
.21429 .01905 L
s
.21429 .78095 m
.97619 .78095 L
.97619 .78095 L
.21429 .78095 L
.21429 .78095 L
s
.97619 .01905 m
.97619 .78095 L
.21429 .78095 L
.21429 .01905 L
.97619 .01905 L
s
.97619 .78095 m
.97619 .01905 L
.21429 .01905 L
.21429 .78095 L
.97619 .78095 L
s
.039 .916 .04 r
.02381 .25714 m
.37391 .25714 L
s
% Start of user PostScript
-3. -0.75 -1.16199 -0.75 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.37391 .25714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .35238 m
.39333 .35238 L
s
% Start of user PostScript
-3. -0.25 -1.06004 -0.25 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.39333 .35238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .44762 m
.39333 .44762 L
s
% Start of user PostScript
-3. 0.25 -1.06004 0.25 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.39333 .44762 Mdot
.039 .916 .04 r
.5 Mabswid
.37391 .25714 m
.48962 .23909 L
s
% Start of user PostScript
-1.16199 -0.75 -0.554488 -0.844801 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.48962 .23909 Mdot
.039 .916 .04 r
.5 Mabswid
.37391 .25714 m
.21429 .53565 L
s
% Start of user PostScript
-1.16199 -0.75 -2. 0.712148 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.21429 .53565 Mdot
.039 .916 .04 r
.5 Mabswid
.39333 .35238 m
.7789 .53492 L
s
% Start of user PostScript
-1.06004 -0.25 0.964231 0.708339 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.7789 .53492 Mdot
.039 .916 .04 r
.5 Mabswid
.39333 .35238 m
.40774 .3358 L
s
0 0 0 r
2 Mabswid
.40774 .3358 Mdot
.039 .916 .04 r
.5 Mabswid
.39333 .44762 m
.7789 .26508 L
s
% Start of user PostScript
-1.06004 0.25 0.964231 -0.708339 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.7789 .26508 Mdot
.039 .916 .04 r
.5 Mabswid
.39333 .44762 m
.40774 .4642 L
s
0 0 0 r
2 Mabswid
.40774 .4642 Mdot
.039 .916 .04 r
.5 Mabswid
.48962 .23909 m
.75918 .29985 L
s
% Start of user PostScript
-0.554488 -0.844801 0.860689 -0.5258 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.75918 .29985 Mdot
.039 .916 .04 r
.5 Mabswid
.7789 .53492 m
.84728 .56498 L
s
% Start of user PostScript
0.964231 0.708339 1.32323 0.866137 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.84728 .56498 Mdot
.039 .916 .04 r
.5 Mabswid
.40774 .3358 m
.5743 .19158 L
s
% Start of user PostScript
-0.984375 -0.337054 -0.109911 -1.09422 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5743 .19158 Mdot
.039 .916 .04 r
.5 Mabswid
.40774 .3358 m
.21429 .34154 L
s
% Start of user PostScript
-0.984375 -0.337054 -2. -0.3069 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.21429 .34154 Mdot
.039 .916 .04 r
.5 Mabswid
.7789 .26508 m
.84728 .23502 L
s
% Start of user PostScript
0.964231 -0.708339 1.32323 -0.866137 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.84728 .23502 Mdot
.039 .916 .04 r
.5 Mabswid
.40774 .4642 m
.5743 .60842 L
s
% Start of user PostScript
-0.984375 0.337054 -0.109911 1.09422 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5743 .60842 Mdot
.039 .916 .04 r
.5 Mabswid
.40774 .4642 m
.21429 .45846 L
s
% Start of user PostScript
-0.984375 0.337054 -2. 0.3069 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.21429 .45846 Mdot
.039 .916 .04 r
.5 Mabswid
.75918 .29985 m
.97619 .40599 L
s
% Start of user PostScript
0.860689 -0.5258 2. 0.0314342 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .40599 Mdot
.039 .916 .04 r
.5 Mabswid
.75918 .29985 m
.74058 .3062 L
s
0 0 0 r
2 Mabswid
.74058 .3062 Mdot
.039 .916 .04 r
.5 Mabswid
.84728 .56498 m
.83608 .58999 L
s
0 0 0 r
2 Mabswid
.83608 .58999 Mdot
.039 .916 .04 r
.5 Mabswid
.5743 .19158 m
.63589 .14963 L
s
% Start of user PostScript
-0.109911 -1.09422 0.213429 -1.31446 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.63589 .14963 Mdot
.039 .916 .04 r
.5 Mabswid
.84728 .23502 m
.83608 .21001 L
s
0 0 0 r
2 Mabswid
.83608 .21001 Mdot
.039 .916 .04 r
.5 Mabswid
.5743 .60842 m
.63589 .65037 L
s
% Start of user PostScript
-0.109911 1.09422 0.213429 1.31446 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.63589 .65037 Mdot
.039 .916 .04 r
.5 Mabswid
.74058 .3062 m
.6574 .43656 L
s
% Start of user PostScript
0.763057 -0.492459 0.326356 0.191928 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.6574 .43656 Mdot
.039 .916 .04 r
.5 Mabswid
.83608 .58999 m
.70353 .78095 L
s
% Start of user PostScript
1.2644 0.997441 0.568518 2. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70353 .78095 Mdot
.039 .916 .04 r
.5 Mabswid
.83608 .58999 m
.82621 .55687 L
s
0 0 0 r
2 Mabswid
.82621 .55687 Mdot
.039 .916 .04 r
.5 Mabswid
.63589 .14963 m
.6875 .13211 L
s
0 0 0 r
2 Mabswid
.6875 .13211 Mdot
.039 .916 .04 r
.5 Mabswid
.83608 .21001 m
.70353 .01905 L
s
% Start of user PostScript
1.2644 -0.997441 0.568518 -2. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70353 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.83608 .21001 m
.82621 .24313 L
s
0 0 0 r
2 Mabswid
.82621 .24313 Mdot
.039 .916 .04 r
.5 Mabswid
.63589 .65037 m
.6875 .66789 L
s
0 0 0 r
2 Mabswid
.6875 .66789 Mdot
.039 .916 .04 r
.5 Mabswid
.6574 .43656 m
.64673 .4479 L
s
0 0 0 r
2 Mabswid
.64673 .4479 Mdot
.039 .916 .04 r
.5 Mabswid
.6574 .43656 m
.56925 .1565 L
s
% Start of user PostScript
0.326356 0.191928 -0.136434 -1.27839 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.56925 .1565 Mdot
.039 .916 .04 r
.5 Mabswid
.82621 .55687 m
.68644 .25864 L
s
% Start of user PostScript
1.21259 0.823559 0.478789 -0.742127 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68644 .25864 Mdot
.039 .916 .04 r
.5 Mabswid
.6875 .13211 m
.9442 .01905 L
s
% Start of user PostScript
0.484358 -1.40644 1.83208 -2. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.9442 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.6875 .13211 m
.67135 .13298 L
s
0 0 0 r
2 Mabswid
.67135 .13298 Mdot
.039 .916 .04 r
.5 Mabswid
.82621 .24313 m
.68644 .54136 L
s
% Start of user PostScript
1.21259 -0.823559 0.478789 0.742127 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68644 .54136 Mdot
.039 .916 .04 r
.5 Mabswid
.6875 .66789 m
.9442 .78095 L
s
% Start of user PostScript
0.484358 1.40644 1.83208 2. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.9442 .78095 Mdot
.039 .916 .04 r
.5 Mabswid
.6875 .66789 m
.67135 .66702 L
s
0 0 0 r
2 Mabswid
.67135 .66702 Mdot
.039 .916 .04 r
.5 Mabswid
.64673 .4479 m
.5792 .50522 L
s
% Start of user PostScript
0.270312 0.251462 -0.0841886 0.552384 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5792 .50522 Mdot
.039 .916 .04 r
.5 Mabswid
.64673 .4479 m
.70101 .48697 L
s
% Start of user PostScript
0.270312 0.251462 0.5553 0.456576 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70101 .48697 Mdot
.039 .916 .04 r
.5 Mabswid
.56925 .1565 m
.52619 .01905 L
s
% Start of user PostScript
-0.136434 -1.27839 -0.362503 -2. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.52619 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.68644 .25864 m
.59794 .2689 L
s
% Start of user PostScript
0.478789 -0.742127 0.0141605 -0.688289 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59794 .2689 Mdot
.039 .916 .04 r
.5 Mabswid
.67135 .13298 m
.61825 .236 L
s
% Start of user PostScript
0.399601 -1.40184 0.120794 -0.861026 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.61825 .236 Mdot
.039 .916 .04 r
.5 Mabswid
.68644 .54136 m
.59794 .5311 L
s
% Start of user PostScript
0.478789 0.742127 0.0141605 0.688289 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59794 .5311 Mdot
.039 .916 .04 r
.5 Mabswid
.67135 .66702 m
.61825 .564 L
s
% Start of user PostScript
0.399601 1.40184 0.120794 0.861026 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.61825 .564 Mdot
.039 .916 .04 r
.5 Mabswid
.5792 .50522 m
.63937 .62627 L
s
% Start of user PostScript
-0.0841886 0.552384 0.231689 1.1879 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.63937 .62627 Mdot
.039 .916 .04 r
.5 Mabswid
.59794 .2689 m
.48307 .30591 L
s
% Start of user PostScript
0.0141605 -0.688289 -0.58887 -0.493952 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.48307 .30591 Mdot
.039 .916 .04 r
.5 Mabswid
.59794 .2689 m
.69463 .298 L
s
% Start of user PostScript
0.0141605 -0.688289 0.521815 -0.53548 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69463 .298 Mdot
.039 .916 .04 r
.5 Mabswid
.61825 .236 m
.46832 .54851 L
s
% Start of user PostScript
0.120794 -0.861026 -0.666344 0.779668 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.46832 .54851 Mdot
.039 .916 .04 r
.5 Mabswid
.59794 .5311 m
.48307 .49409 L
s
% Start of user PostScript
0.0141605 0.688289 -0.58887 0.493952 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.48307 .49409 Mdot
.039 .916 .04 r
.5 Mabswid
.59794 .5311 m
.69463 .502 L
s
% Start of user PostScript
0.0141605 0.688289 0.521815 0.53548 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69463 .502 Mdot
.039 .916 .04 r
.5 Mabswid
.61825 .564 m
.46832 .25149 L
s
% Start of user PostScript
0.120794 0.861026 -0.666344 -0.779668 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.46832 .25149 Mdot
.039 .916 .04 r
.5 Mabswid
.63937 .62627 m
.68192 .61894 L
s
0 0 0 r
2 Mabswid
.68192 .61894 Mdot
.039 .916 .04 r
.5 Mabswid
.69463 .298 m
.71503 .24838 L
s
% Start of user PostScript
0.521815 -0.53548 0.628901 -0.795993 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.71503 .24838 Mdot
.039 .916 .04 r
.5 Mabswid
.46832 .54851 m
.22509 .78095 L
s
% Start of user PostScript
-0.666344 0.779668 -1.94327 2. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.22509 .78095 Mdot
.039 .916 .04 r
.5 Mabswid
.69463 .502 m
.71503 .55162 L
s
% Start of user PostScript
0.521815 0.53548 0.628901 0.795993 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.71503 .55162 Mdot
.039 .916 .04 r
.5 Mabswid
.46832 .25149 m
.22509 .01905 L
s
% Start of user PostScript
-0.666344 -0.779668 -1.94327 -2. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.22509 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.68192 .61894 m
.75653 .58998 L
s
% Start of user PostScript
0.455098 1.14942 0.846794 0.99738 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.75653 .58998 Mdot
.039 .916 .04 r
.5 Mabswid
.68192 .61894 m
.3794 .44639 L
s
% Start of user PostScript
0.455098 1.14942 -1.13315 0.243531 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.3794 .44639 Mdot
.039 .916 .04 r
.5 Mabswid
.71503 .24838 m
.72689 .18243 L
s
% Start of user PostScript
0.628901 -0.795993 0.69115 -1.14225 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.72689 .18243 Mdot
.039 .916 .04 r
.5 Mabswid
.71503 .55162 m
.72689 .61757 L
s
% Start of user PostScript
0.628901 0.795993 0.69115 1.14225 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.72689 .61757 Mdot
.039 .916 .04 r
.5 Mabswid
.75653 .58998 m
.77885 .56658 L
s
0 0 0 r
2 Mabswid
.77885 .56658 Mdot
.039 .916 .04 r
.5 Mabswid
.75653 .58998 m
.94745 .78095 L
s
% Start of user PostScript
0.846794 0.99738 1.84913 2. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.94745 .78095 Mdot
.039 .916 .04 r
.5 Mabswid
.3794 .44639 m
.38276 .44738 L
s
0 0 0 r
2 Mabswid
.38276 .44738 Mdot
.039 .916 .04 r
.5 Mabswid
.77885 .56658 m
.81923 .50402 L
s
% Start of user PostScript
0.963979 0.874558 1.17594 0.546105 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81923 .50402 Mdot
.039 .916 .04 r
.5 Mabswid
.38276 .44738 m
.42277 .45357 L
s
0 0 0 r
2 Mabswid
.42277 .45357 Mdot
.039 .916 .04 r
.5 Mabswid
.81923 .50402 m
.83604 .4253 L
s
% Start of user PostScript
1.17594 0.546105 1.26421 0.132837 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.83604 .4253 Mdot
.039 .916 .04 r
.5 Mabswid
.81923 .50402 m
.42418 .48609 L
s
% Start of user PostScript
1.17594 0.546105 -0.898045 0.451948 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.42418 .48609 Mdot
.039 .916 .04 r
.5 Mabswid
.42277 .45357 m
.56605 .42435 L
s
% Start of user PostScript
-0.905453 0.281224 -0.153255 0.127825 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.56605 .42435 Mdot
.039 .916 .04 r
.5 Mabswid
.83604 .4253 m
.83206 .35483 L
s
% Start of user PostScript
1.26421 0.132837 1.24334 -0.237156 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.83206 .35483 Mdot
.039 .916 .04 r
.5 Mabswid
.42418 .48609 m
.21429 .46964 L
s
% Start of user PostScript
-0.898045 0.451948 -2. 0.365628 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.21429 .46964 Mdot
.039 .916 .04 r
.5 Mabswid
.56605 .42435 m
.56572 .41772 L
s
0 0 0 r
2 Mabswid
.56572 .41772 Mdot
.039 .916 .04 r
.5 Mabswid
.83206 .35483 m
.79787 .35119 L
s
0 0 0 r
2 Mabswid
.79787 .35119 Mdot
.039 .916 .04 r
.5 Mabswid
.56572 .41772 m
.7235 .38666 L
s
% Start of user PostScript
-0.154975 0.0930317 0.673365 -0.0700295 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.7235 .38666 Mdot
.039 .916 .04 r
.5 Mabswid
.79787 .35119 m
.75942 .34786 L
s
0 0 0 r
2 Mabswid
.75942 .34786 Mdot
.039 .916 .04 r
.5 Mabswid
.79787 .35119 m
.50143 .33066 L
s
% Start of user PostScript
1.0638 -0.256227 -0.492506 -0.364055 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50143 .33066 Mdot
.039 .916 .04 r
.5 Mabswid
.7235 .38666 m
.71648 .24466 L
s
% Start of user PostScript
0.673365 -0.0700295 0.636519 -0.815535 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.71648 .24466 Mdot
.039 .916 .04 r
.5 Mabswid
.75942 .34786 m
.43848 .32974 L
s
% Start of user PostScript
0.861955 -0.273738 -0.822999 -0.368885 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.43848 .32974 Mdot
.039 .916 .04 r
.5 Mabswid
.50143 .33066 m
.23569 .20876 L
s
% Start of user PostScript
-0.492506 -0.364055 -1.88762 -1.00403 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.23569 .20876 Mdot
.039 .916 .04 r
.5 Mabswid
.71648 .24466 m
.71784 .24438 L
s
0 0 0 r
2 Mabswid
.71784 .24438 Mdot
.039 .916 .04 r
.5 Mabswid
.43848 .32974 m
.42081 .30753 L
s
0 0 0 r
2 Mabswid
.42081 .30753 Mdot
.039 .916 .04 r
.5 Mabswid
.71784 .24438 m
.84533 .2641 L
s
% Start of user PostScript
0.643673 -0.816994 1.31297 -0.713475 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.84533 .2641 Mdot
.039 .916 .04 r
.5 Mabswid
.42081 .30753 m
.25246 .01905 L
s
% Start of user PostScript
-0.915724 -0.485464 -1.79958 -2. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.25246 .01905 Mdot
0 0 m
1 0 L
1 .8 L
0 .8 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{596, 476.688},
  ImageMargins->{{21, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001g2000`400?l00000o`00003oo`3ooooo
0?oooeH0oooo003o0?ooool0ooooEP3oool00?l0ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo
003o0?ooool0ooooEP3oool00?l0ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0
ooooEP3oool00?l0ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0ooooEP3oool0
07l0oooo200000000`09jPX000000000003o00000:H000000P09jPXD000000l0oooo001o0?ooo`03
0000003oool0oooo00<0oooo0P00000300WZ2P/0oooo0P0000000`09jPX0oooo0?ooo`2N0?ooo`80
0000J03oool2000008L0oooo1@09jPX00`3oool000000000000A0?ooo`030000003oool0oooo00d0
oooo001o0?ooo`030000003oool0oooo00D0oooo1009jPX;0?ooo`<02NX:X03oool200WZ2VP0oooo
0P09jPZ40?ooo`H02NX:5@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?oo
o`050?ooo`H02NX:2P3oool300WZ2Yl0oooo0P09jPYX0?ooo`<02NX:P`3oool200WZ2P030?ooo`09
jPX02NX:01H0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool01P3oool6
00WZ2PT0oooo1009jPZN0?ooo`<02NX:I`3oool400WZ2X00oooo0P09jPX30?ooo`0300WZ2P3oool0
oooo01D0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool01`3oool200WZ
2P030?ooo`09jPX0oooo00T0oooo1@09jPZM0?ooo`@02NX:I`3oool400WZ2W`0oooo0`09jPX40?oo
o`0300WZ2P3oool0oooo01H0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3o
ool01`3oool200WZ2P80oooo00<02NX:0?ooo`3oool01`3oool300WZ2P80oooo00<02NX:0?ooo`3o
ool0VP3oool400WZ2VL0oooo0`09jPX00`3oool02NX:0?ooo`1h0?ooo`802NX:803oool00`000000
oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`080?ooo`0500WZ2P3oool0oooo0?ooo`09
jPX02@3oool00`09jPX0oooo00WZ2P2N0?ooo`<02NX:00<0oooo00WZ2P3oool0I@3oool200WZ2P03
0?ooo`09jPX0oooo07L0oooo0P09jPXR0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000
003oool0oooo00d0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo00WZ2P2N0?ooo`0300WZ
2P3oool02NX:06T0oooo00<02NX:0?ooo`09jPX0MP3oool200WZ2R@0oooo00<000000?ooo`3oool0
3@3oool007l0oooo00<000000?ooo`3oool03P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3o
ool0oooo09h0oooo00<02NX:0?ooo`3oool0J@3oool00`09jPX0oooo0?ooo`1`0?ooo`<02NX:9P3o
ool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0?0?ooo`0300WZ2P3oool0
oooo00P0oooo00<02NX:0?ooo`3oool0W@3oool00`09jPX0oooo0?ooo`1Z0?ooo`0300WZ2P3oool0
oooo06d0oooo0P09jPXY0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo
0100oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`2M0?ooo`0300WZ2P3oool0oooo
06X0oooo00<02NX:0?ooo`3oool0J`3oool200WZ2R/0oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool04@3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo09d0
oooo00<02NX:0?ooo`3oool0JP3oool00`09jPX0oooo0?ooo`1W0?ooo`<02NX:;@3oool00`000000
oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo00H0oooo
00<02NX:0?ooo`3oool0W@3oool00`09jPX0oooo0?ooo`1[0?ooo`0300WZ2P3oool0oooo06@0oooo
0P09jPX`0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo01<0oooo00<0
2NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`2L0?ooo`0300WZ2P3oool0oooo06/0oooo00<0
2NX:0?ooo`3oool0HP3oool200WZ2S80oooo00<000000?ooo`3oool03@3oool007l0oooo00<00000
0?ooo`3oool0503oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo09`0oooo00<02NX:
0?ooo`3oool0K03oool00`09jPX0oooo0?ooo`1O0?ooo`802NX:=03oool00`000000oooo0?ooo`0=
0?ooo`00O`3oool00`000000oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?oo
o`3oool0W03oool00`09jPX0oooo0?ooo`1/0?ooo`0300WZ2P3oool0oooo05/0oooo0`09jPXf0?oo
o`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo01H0oooo00<02NX:0?ooo`3o
ool01@3oool00`09jPX0oooo0?ooo`2K0?ooo`0300WZ2P3oool0oooo06`0oooo00<02NX:0?ooo`3o
ool0F@3oool200WZ2ST0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0
5`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo09/0oooo00<02NX:0?ooo`3oool0
K@3oool00`09jPX0oooo0?ooo`1F0?ooo`802NX:>`3oool00`000000oooo0?ooo`0=0?ooo`00O`3o
ool00`000000oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0V`3o
ool00`09jPX0oooo0?ooo`1]0?ooo`0300WZ2P3oool0oooo0580oooo0`09jPXm0?ooo`030000003o
ool0oooo00d0oooo001o0?ooo`030000003oool0oooo01T0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`2K0?ooo`0300WZ2P3oool0oooo06h0oooo00<02NX:0?ooo`3oool0C`3oool2
00WZ2T00oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool06P3oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo09X0oooo00<02NX:0?ooo`3oool0KP3oool00`09
jPX0oooo0?ooo`1=0?ooo`802NX:@P3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000
oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0VP3oool00`09jPX0
oooo0?ooo`1^0?ooo`0300WZ2P3oool0oooo04X0oooo0P09jPY40?ooo`030000003oool0oooo00d0
oooo001o0?ooo`030000003oool0oooo01`0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo09X0oooo
00<02NX:0?ooo`3oool0K`3oool00`09jPX0oooo0?ooo`160?ooo`<02NX:AP3oool00`000000oooo
0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0N0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0
V`3oool00`09jPX0oooo0?ooo`1_0?ooo`0300WZ2P3oool0oooo04@0oooo0P09jPY90?ooo`030000
003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo01l0oooo00@02NX:0?ooo`3oool02NX:
V`3oool00`09jPX0oooo0?ooo`1`0?ooo`0300WZ2P3oool0oooo0440oooo0P09jPY;0?ooo`030000
003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo0200oooo00@02NX:0?ooo`3oool02NX:
V`3oool00`09jPX0oooo0?ooo`1`0?ooo`0300WZ2P3oool0oooo03d0oooo0`09jPY=0?ooo`030000
003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo0240oooo00<02NX:0?ooo`09jPX0V`3o
ool00`09jPX0oooo0?ooo`1`0?ooo`0300WZ2P3oool0oooo03/0oooo0P09jPY@0?ooo`030000003o
ool0oooo00d0oooo001o0?ooo`030000003oool0oooo0280oooo00<02NX:0?ooo`09jPX0VP3oool0
0`09jPX0oooo0?ooo`1a0?ooo`0300WZ2P3oool0oooo03P0oooo0P09jPYB0?ooo`030000003oool0
oooo00d0oooo001o0?ooo`030000003oool0oooo02<0oooo00<02NX:0?ooo`09jPX0N@3oool20000
01l0oooo00<02NX:0?ooo`3oool0G03oool2000001<0oooo00<02NX:0?ooo`3oool0=@3oool200WZ
2U@0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0903oool200WZ2WT0
oooo00<0000007moO`0000007P3oool00`09jPX0oooo0?ooo`1K0?ooo`030000001oOgl0000001<0
oooo00<02NX:0?ooo`3oool0<P3oool300WZ2UH0oooo00<000000?ooo`3oool03@3oool007l0oooo
00<000000?ooo`3oool09@3oool200WZ2WP0oooo0P0000000`1oOgl000000?ooo`0L0?ooo`0300WZ
2P3oool0oooo05X0oooo00@0000007moO`1oOgl00000503oool00`09jPX0oooo0?ooo`0_0?ooo`80
2NX:F@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0V0?ooo`0300WZ
2P3oool0oooo07D0oooo00<0000007moO`0000000P1oOgl00`000000oooo0?ooo`0K0?ooo`0300WZ
2P3oool0oooo05P0oooo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0B0?ooo`0300WZ
2P3oool0oooo02`0oooo0P09jPYK0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003o
ool0oooo02L0oooo00<02NX:0?ooo`3oool0M03oool00`000000Ogmo0000000307moO`030000003o
ool0oooo01X0oooo00<02NX:0?ooo`3oool0E`3oool00`000000Ogmo07moO`0307moO`030000003o
ool0oooo01<0oooo00<02NX:0?ooo`3oool0:03oool300WZ2Ud0oooo00<000000?ooo`3oool03@3o
ool007l0oooo00<000000?ooo`3oool09`3oool200WZ2WD0oooo00@0000007moO`1oOgl000000`1o
Ogl2000001X0oooo00<02NX:0?ooo`3oool0E@3oool2000000H0Ogmo00<000000?ooo`3oool04`3o
ool00`09jPX0oooo0?ooo`0V0?ooo`802NX:H03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool0
0`000000oooo0?ooo`0X0?ooo`802NX:M03oool010000000Ogmo07moO`00000507moO`030000003o
ool0oooo01P0oooo00<02NX:0?ooo`3oool0D`3oool00`000000Ogmo07moO`0607moO`030000003o
ool0oooo01@0oooo00<02NX:0?ooo`3oool08`3oool200WZ2V80oooo00<000000?ooo`3oool03@3o
ool007l0oooo00<000000?ooo`3oool0:@3oool200WZ2W80oooo00D0000007moO`1oOgl0Ogmo0000
000607moO`030000003oool0oooo01L0oooo00<02NX:0?ooo`3oool0DP3oool00`000000Ogmo07mo
O`0807moO`030000003oool0oooo01@0oooo00<02NX:0?ooo`3oool0803oool200WZ2V@0oooo00<0
00000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0:@3oool00`09jPX0oooo00WZ2P1a
0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0F
0?ooo`0300WZ2P3oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0D
0?ooo`0300WZ2P3oool0oooo01d0oooo0`09jPYV0?ooo`030000003oool0oooo00d0oooo001o0?oo
o`030000003oool0oooo02X0oooo00<02NX:0?ooo`09jPX0L03oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool05@3oool00`09jPX0oooo0?ooo`1@0?oo
o`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool05@3oool00`09jPX0oooo0?ooo`0J0?oo
o`802NX:J@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0Z0?ooo`04
00WZ2P3oool0oooo00WZ2Vl0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0607mo
O`8000005P3oool00`09jPX0oooo0?ooo`1=0?ooo`8000003@1oOgl00`000000oooo0?ooo`0F0?oo
o`0300WZ2P3oool0oooo01L0oooo0P09jPY[0?ooo`030000003oool0oooo00d0oooo001o0?ooo`03
0000003oool0oooo02/0oooo00@02NX:0?ooo`3oool02NX:K@3oool00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool04`3oool00`09jPX0oooo0?ooo`1<0?oo
o`030000001oOgl0Ogmo00h0Ogmo00<000000?ooo`3oool05@3oool00`09jPX0oooo0?ooo`0E0?oo
o`802NX:K@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0/0?ooo`04
00WZ2P3oool0oooo00WZ2V`0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0807mo
O`030000003oool0oooo0180oooo00<02NX:0?ooo`3oool0B`3oool00`000000Ogmo07moO`0?07mo
O`030000003oool0oooo01H0oooo00<02NX:0?ooo`3oool04@3oool300WZ2Vl0oooo00<000000?oo
o`3oool03@3oool007l0oooo00<000000?ooo`3oool0;03oool01@09jPX0oooo0?ooo`3oool02NX:
06/0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo
0180oooo00<02NX:0?ooo`3oool0B@3oool00`000000Ogmo07moO`0@07moO`030000003oool0oooo
01L0oooo00<02NX:0?ooo`3oool03P3oool200WZ2W80oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool0;@3oool01@09jPX0oooo0?ooo`3oool02NX:06X0oooo00<0000007mo
O`1oOgl01@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0140oooo00<02NX:0?oo
o`3oool0B03oool00`000000Ogmo07moO`0A07moO`030000003oool0oooo01L0oooo00<02NX:0?oo
o`3oool0303oool200WZ2W@0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3o
ool0;@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo06H0oooo00<0000007moO`1o
Ogl01P1oOgl00`000000Ogmo07moO`0:07moO`8000004@3oool00`09jPX0oooo0?ooo`160?ooo`80
00005@1oOgl00`000000oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo00P0oooo0`09jPYf0?ooo`03
0000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo02h0oooo00<02NX:0?ooo`3oool0
0P3oool00`09jPX0oooo0?ooo`1U0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo04@0oooo00<0000007moO`1oOgl0
5@1oOgl00`000000oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPYi0?ooo`030000
003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo02h0oooo00<02NX:0?ooo`3oool00`3o
ool200WZ2VD0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo00h0oooo00<02NX:0?ooo`3oool0@`3oool00`000000Ogmo07moO`0F07moO`030000003o
ool0oooo01T0oooo00<02NX:0?ooo`3oool00P3oool200WZ2W/0oooo00<000000?ooo`3oool03@3o
ool007l0oooo00<000000?ooo`3oool0;`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo0680oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0=07moO`030000003oool0
oooo00d0oooo00<02NX:0?ooo`3oool0@P3oool00`000000Ogmo07moO`0G07moO`030000003oool0
oooo01T0oooo00<02NX:0?ooo`3oool00P09jPYm0?ooo`030000003oool0oooo00d0oooo001o0?oo
o`030000003oool0oooo0300oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`1P0?oo
o`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl03P1oOgl00`000000oooo0?ooo`0<0?oo
o`0300WZ2P3oool0oooo0440oooo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`0H0?oo
o`<02NX:O`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0`0?ooo`03
00WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0G`3oool00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00h0Ogmo0P00000=0?ooo`0300WZ2P3oool0oooo03h0oooo0P00000L07moO`03
0000003oool0oooo01H0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo07d0oooo00<000000?ooo`3o
ool03@3oool007l0oooo00<000000?ooo`3oool0<@3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ
2P3oool0oooo05h0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0@07moO`030000
003oool0oooo00X0oooo00<02NX:0?ooo`3oool0?@3oool00`000000Ogmo07moO`0L07moO`030000
003oool0oooo01@0oooo0P09jPX40?ooo`0300WZ2P3oool0oooo07d0oooo00<000000?ooo`3oool0
3@3oool007l0oooo00<000000?ooo`3oool0<@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3o
ool0oooo05d0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0A07moO`030000003o
ool0oooo00T0oooo00<02NX:0?ooo`3oool0?03oool00`000000Ogmo07moO`0M07moO`030000003o
ool0oooo0140oooo0`09jPX70?ooo`0300WZ2P3oool0oooo07`0oooo00<000000?ooo`3oool03@3o
ool007l0oooo00<000000?ooo`3oool0<P3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0
oooo05/0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0A07moO`030000003oool0
oooo00T0oooo00<02NX:0?ooo`3oool0>P3oool00`000000Ogmo07moO`0O07moO`030000003oool0
oooo00h0oooo0P09jPX;0?ooo`0300WZ2P3oool0oooo07/0oooo00<000000?ooo`3oool03@3oool0
07l0oooo00<000000?ooo`3oool0<`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo
05X0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0B07moO`030000003oool0oooo
00P0oooo00<02NX:0?ooo`3oool0>@3oool00`000000Ogmo07moO`0P07moO`030000003oool0oooo
00`0oooo0P09jPX=0?ooo`0300WZ2P3oool0oooo07/0oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool0<`3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo05T0
oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0C07moO`800000203oool00`09jPX0
oooo0?ooo`0g0?ooo`8000008`1oOgl00`000000oooo0?ooo`0:0?ooo`802NX:403oool00`09jPX0
oooo0?ooo`1j0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo03@0oooo
00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`1H0?ooo`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0501oOgl00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0oooo03D0oooo
00<0000007moO`1oOgl08`1oOgl00`000000oooo0?ooo`070?ooo`<02NX:4`3oool00`09jPX0oooo
0?ooo`1i0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo03@0oooo00<0
2NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00d0Ogmo00<0
000007moO`1oOgl05@1oOgl00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo03@0oooo00<0
000007moO`1oOgl09@1oOgl00`000000oooo0?ooo`040?ooo`802NX:5P3oool00`09jPX0oooo0?oo
o`1i0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo03D0oooo00<02NX:
0?ooo`3oool0203oool00`09jPX0oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo00d0Ogmo00<00000
07moO`1oOgl05P1oOgl00`000000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo03<0oooo00<00000
07moO`1oOgl09P1oOgl00`000000oooo0?ooo`020?ooo`802NX:6@3oool00`09jPX0oooo0?ooo`1h
0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo03D0oooo00<02NX:0?oo
o`3oool02@3oool00`09jPX0oooo0?ooo`1D0?ooo`030000001oOgl0Ogmo00h0Ogmo00<0000007mo
O`1oOgl05P1oOgl00`000000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo0340oooo00<0000007mo
O`1oOgl09`1oOgl00`000000oooo00WZ2P0200WZ2Q`0oooo00<02NX:0?ooo`3oool0M`3oool00`00
0000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0f0?ooo`0300WZ2P3oool0oooo00T0
oooo00<02NX:0?ooo`3oool0D`3oool00`000000Ogmo07moO`0>07moO`030000001oOgl0Ogmo01L0
Ogmo0P0000040?ooo`0300WZ2P3oool0oooo02l0oooo0P00000Z07moO`802NX:803oool00`09jPX0
oooo0?ooo`1f0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo03L0oooo
00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00l0Ogmo
00<0000007moO`1oOgl06@1oOgl01@000000oooo0?ooo`3oool02NX:0300oooo00<0000007moO`1o
Ogl0:01oOgl200WZ2P0307moO`000000oooo01l0oooo00<02NX:0?ooo`3oool0MP3oool00`000000
oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0g0?ooo`0300WZ2P3oool0oooo00X0oooo
00<02NX:0?ooo`3oool0D03oool00`000000Ogmo07moO`0@07moO`030000001oOgl0Ogmo01T0Ogmo
00@000000?ooo`3oool02NX:;`3oool00`000000Ogmo07moO`0W07moO`802NX:0`1oOgl00`000000
oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo07D0oooo00<000000?ooo`3oool03@3oool007l0oooo
00<000000?ooo`3oool0>03oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo04l0oooo
00<0000007moO`1oOgl0401oOgl00`000000Ogmo07moO`0J07moO`040000003oool0oooo00WZ2Rd0
oooo00<0000007moO`1oOgl09@1oOgl300WZ2PD0Ogmo00<000000?ooo`3oool0803oool00`09jPX0
oooo0?ooo`1d0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo03P0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`1>0?ooo`030000001oOgl0Ogmo0100Ogmo
00<0000007moO`1oOgl06`1oOgl00`000000oooo00WZ2P0/0?ooo`030000001oOgl0Ogmo02@0Ogmo
0P09jPX807moO`030000003oool0oooo0200oooo00<02NX:0?ooo`3oool0M03oool00`000000oooo
0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool0C03oool00`000000Ogmo07moO`0B07moO`030000001oOgl0Ogmo01/0Ogmo00<0
000000WZ2P3oool0:@3oool2000002D0Ogmo0P09jPX;07moO`030000003oool0oooo0200oooo00<0
2NX:0?ooo`3oool0L`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0j
0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0B`3oool00`000000Ogmo07moO`0B
07moO`030000001oOgl0Ogmo01d0Ogmo00<02NX:0?ooo`3oool09P3oool00`000000Ogmo07moO`0R
07moO`<02NX:3@1oOgl00`000000oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo0780oooo00<00000
0?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0>P3oool00`09jPX0oooo0?ooo`0<0?oo
o`0300WZ2P3oool0oooo04X0oooo00<0000007moO`1oOgl04P1oOgl00`000000Ogmo07moO`0M07mo
O`0300WZ2P000000oooo02D0oooo00<0000007moO`1oOgl08@1oOgl200WZ2Q00Ogmo00<000000?oo
o`3oool08@3oool00`09jPX0oooo0?ooo`1b0?ooo`030000003oool0oooo00d0oooo001o0?ooo`03
0000003oool0oooo03/0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`190?ooo`03
0000001oOgl0Ogmo01<0Ogmo00<0000007moO`1oOgl0701oOgl00`09jPX0Ogmo0000000T0?ooo`03
0000001oOgl0Ogmo01L0Ogmo0P00000407moO`D02NX:00<0000007moO`1oOgl03`1oOgl00`000000
oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo0740oooo00<000000?ooo`3oool03@3oool007l0oooo
00<000000?ooo`3oool0>`3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo04L0oooo
00<0000007moO`1oOgl0501oOgl00`000000Ogmo07moO`0M07moO`0300WZ2P1oOgl000000280oooo
00<0000007moO`1oOgl0601oOgl00`0000002NX:00WZ2P0600WZ2P0307moO`00000000000180Ogmo
00<000000?ooo`3oool08P3oool00`09jPX0oooo0?ooo`1`0?ooo`030000003oool0oooo00d0oooo
001o0?ooo`030000003oool0oooo03`0oooo00<02NX:0?ooo`3oool03@3oool200WZ2TL0oooo00<0
000007moO`1oOgl0501oOgl00`000000Ogmo07moO`0M07moO`0300WZ2P1oOgl0Ogmo008000007P3o
ool2000001`0Ogmo00<02NX:07moO`09jPX00P09jPXH07moO`030000003oool0oooo0280oooo00<0
2NX:0?ooo`3oool0L03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0l
0?ooo`0300WZ2P3oool0oooo00l0oooo00<02NX:0?ooo`3oool0A03oool00`000000Ogmo07moO`0E
07moO`030000001oOgl0Ogmo01`0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000oooo0?ooo`0J
0?ooo`030000001oOgl0Ogmo01/0Ogmo0`09jPXK07moO`030000003oool0oooo02<0oooo00<02NX:
0?ooo`3oool0K`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0m0?oo
o`0300WZ2P3oool0oooo00l0oooo00<02NX:0?ooo`3oool0@`3oool00`000000Ogmo07moO`0E07mo
O`030000001oOgl0Ogmo01`0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0H0?oo
o`030000001oOgl0Ogmo01X0Ogmo0`09jPXM07moO`030000003oool0oooo02@0oooo00<02NX:0?oo
o`3oool0KP3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0n0?ooo`03
00WZ2P3oool0oooo00l0oooo00<02NX:0?ooo`3oool0@@3oool00`000000Ogmo07moO`0F07moO`03
0000001oOgl0Ogmo01d0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0F0?ooo`03
0000001oOgl0Ogmo01P0Ogmo0`09jPX00`1oOgl02NX:07moO`0N07moO`030000003oool0oooo02@0
oooo00<02NX:0?ooo`3oool0K@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo
0?ooo`0n0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0@03oool00`000000Ogmo
07moO`0G07moO`030000001oOgl0Ogmo01`0Ogmo00<02NX:07moO`1oOgl0101oOgl2000001@0oooo
0P00000H07moO`<02NX:101oOgl00`09jPX0Ogmo07moO`0M07moO`030000003oool0oooo02@0oooo
00<02NX:0?ooo`3oool0K@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?oo
o`0o0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0?`3oool00`000000Ogmo07mo
O`0G07moO`030000001oOgl0Ogmo01`0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`000000oooo0?oo
o`0@0?ooo`030000001oOgl0Ogmo01H0Ogmo0P09jPX607moO`0300WZ2P1oOgl0Ogmo01h0Ogmo00<0
00000?ooo`3oool09@3oool00`09jPX0oooo0?ooo`1/0?ooo`030000003oool0oooo00d0oooo001o
0?ooo`030000003oool0oooo03l0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0n
0?ooo`030000001oOgl0Ogmo01L0Ogmo00<0000007moO`1oOgl07@1oOgl00`09jPX0Ogmo07moO`06
07moO`030000003oool0oooo00h0oooo00<0000007moO`1oOgl0501oOgl300WZ2PP0Ogmo00<02NX:
07moO`1oOgl07P1oOgl00`000000oooo0?ooo`0V0?ooo`0300WZ2P3oool0oooo06/0oooo00<00000
0?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0@03oool00`09jPX0oooo0?ooo`0A0?oo
o`0300WZ2P3oool0oooo03`0oooo00<0000007moO`1oOgl06@1oOgl00`000000Ogmo07moO`0L07mo
O`0300WZ2P1oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0B07mo
O`<02NX:2P1oOgl00`09jPX0Ogmo07moO`0P07moO`030000003oool0oooo02D0oooo00<02NX:0?oo
o`3oool0J`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`100?ooo`03
00WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0>`3oool00`000000Ogmo07moO`0I07moO`03
0000001oOgl0Ogmo01`0Ogmo00<02NX:07moO`1oOgl0201oOgl00`000000oooo0?ooo`0:0?ooo`03
0000001oOgl0Ogmo00h0Ogmo0P00000300WZ2Pd0Ogmo00<02NX:07moO`1oOgl0801oOgl00`000000
oooo0?ooo`0V0?ooo`0300WZ2P3oool0oooo06X0oooo00<000000?ooo`3oool03@3oool007l0oooo
00<000000?ooo`3oool0@@3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo03X0oooo
00<0000007moO`1oOgl06@1oOgl00`000000Ogmo07moO`0M07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo
0P0000080?ooo`8000004@1oOgl00`0000002NX:07moO`0>07moO`0300WZ2P1oOgl0Ogmo0240Ogmo
00<000000?ooo`3oool09`3oool00`09jPX0oooo0?ooo`1Y0?ooo`030000003oool0oooo00d0oooo
001o0?ooo`030000003oool0oooo0480oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?oo
o`0i0?ooo`030000001oOgl0Ogmo01X0Ogmo00<0000007moO`1oOgl0701oOgl00`09jPX0Ogmo07mo
O`0:07moO`030000003oool0oooo00@0oooo00<0000007moO`1oOgl03P1oOgl400WZ2Pl0Ogmo00<0
2NX:07moO`1oOgl08P1oOgl00`000000oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo06T0oooo00<0
00000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0@P3oool00`09jPX0oooo0?ooo`0C
0?ooo`0300WZ2P3oool0oooo03L0oooo00<0000007moO`1oOgl06`1oOgl00`000000Ogmo07moO`0L
07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool00P3oool00`000000Ogmo07moO`0<
07moO`H02NX:401oOgl00`09jPX0Ogmo07moO`0S07moO`030000003oool0oooo02L0oooo00<02NX:
0?ooo`3oool0J03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`130?oo
o`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0=P3oool00`000000Ogmo07moO`0K07mo
O`030000001oOgl0Ogmo01d0Ogmo00<02NX:0000001oOgl02`1oOgl010000000oooo0?ooo`00000>
07moO`H02NX:401oOgl00`09jPX0Ogmo07moO`0T07moO`030000003oool0oooo02P0oooo00<02NX:
0?ooo`3oool0I`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`130?oo
o`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool0=@3oool00`000000Ogmo07moO`0L07mo
O`030000001oOgl0Ogmo01`0Ogmo00<02NX:0000001oOgl0301oOgl200000100Ogmo1009jPXA07mo
O`0300WZ2P1oOgl0Ogmo02@0Ogmo00<000000?ooo`3oool0:03oool00`09jPX0oooo0?ooo`1W0?oo
o`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo04@0oooo00<02NX:0?ooo`3o
ool0503oool00`09jPX0oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo01`0Ogmo00<0000007moO`1o
Ogl0701oOgl00`09jPX0Ogmo07moO`0;07moO`800000401oOgl01009jPX0Ogmo00WZ2P09jPXA07mo
O`0300WZ2P1oOgl0Ogmo02D0Ogmo00<000000?ooo`3oool0:@3oool00`09jPX0oooo0?ooo`1V0?oo
o`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo04D0oooo00<02NX:0?ooo`3o
ool0503oool00`09jPX0oooo0?ooo`0b0?ooo`030000001oOgl0Ogmo01d0Ogmo00<0000007moO`1o
Ogl0701oOgl200WZ2P/0Ogmo00<0000007moO`1oOgl03P1oOgl200WZ2P80Ogmo00<02NX:07moO`1o
Ogl0401oOgl00`09jPX0Ogmo07moO`0V07moO`030000003oool0oooo02T0oooo00<02NX:0?ooo`3o
ool0I@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`150?ooo`0300WZ
2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0<@3oool00`000000Ogmo07moO`0N07moO`030000
001oOgl0Ogmo01/0Ogmo0P09jPX:07moO`030000001oOgl0Ogmo00h0Ogmo00<02NX:07moO`1oOgl0
501oOgl00`09jPX0Ogmo07moO`0W07moO`030000003oool0oooo02X0oooo00<02NX:0?ooo`3oool0
I03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`160?ooo`0300WZ2P3o
ool0oooo01D0oooo00<02NX:0?ooo`3oool0<03oool00`000000Ogmo07moO`0N07moO`030000001o
Ogl0Ogmo01/0Ogmo0`09jPX807moO`030000001oOgl0Ogmo00d0Ogmo0P09jPXG07moO`0300WZ2P1o
Ogl0Ogmo02L0Ogmo00<000000?ooo`3oool0:P3oool00`09jPX0oooo0?ooo`1T0?ooo`030000003o
ool0oooo00d0oooo001o0?ooo`030000003oool0oooo04H0oooo00<02NX:0?ooo`3oool05P3oool0
0`09jPX0oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo01h0Ogmo00<0000007moO`1oOgl0701oOgl3
00WZ2PH0Ogmo00<0000007moO`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0F07moO`0300WZ2P1oOgl0
Ogmo02P0Ogmo00<000000?ooo`3oool0:`3oool00`09jPX0oooo0?ooo`1S0?ooo`030000003oool0
oooo00d0oooo001o0?ooo`030000003oool0oooo04L0oooo00<02NX:0?ooo`3oool05P3oool00`09
jPX0oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo0200Ogmo00<0000007moO`1oOgl06`1oOgl300WZ
2P@0Ogmo0P00000>07moO`802NX:6@1oOgl00`09jPX0Ogmo07moO`0Y07moO`030000003oool0oooo
02/0oooo00<02NX:0?ooo`3oool0HP3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000
oooo0?ooo`170?ooo`0300WZ2P3oool0oooo01L0oooo00<02NX:0?ooo`3oool0;03oool00`000000
Ogmo07moO`0P07moO`030000001oOgl0Ogmo01/0Ogmo0P09jPX01@1oOgl02NX:07moO`1oOgl00000
00l0Ogmo00<02NX:07moO`1oOgl0601oOgl00`09jPX0Ogmo07moO`0Z07moO`030000003oool0oooo
02/0oooo00<02NX:0?ooo`3oool0HP3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000
oooo0?ooo`180?ooo`0300WZ2P3oool0oooo01L0oooo00<02NX:0?ooo`3oool0:`3oool00`000000
Ogmo07moO`0P07moO`030000001oOgl0Ogmo01/0Ogmo0P09jPX307moO`030000001oOgl0Ogmo00`0
Ogmo0P09jPXK07moO`0300WZ2P1oOgl0Ogmo02X0Ogmo00<000000?ooo`3oool0;03oool00`09jPX0
oooo0?ooo`1Q0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo04T0oooo
00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`0Z0?ooo`030000001oOgl0Ogmo0240Ogmo
00<0000007moO`1oOgl0701oOgl00`09jPX0Ogmo0000000>07moO`0300WZ2P1oOgl0Ogmo01X0Ogmo
00<02NX:07moO`1oOgl0:`1oOgl00`000000oooo0?ooo`0]0?ooo`0300WZ2P3oool0oooo0600oooo
00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0B@3oool00`09jPX0oooo0?oo
o`0H0?ooo`802NX::@3oool00`000000Ogmo07moO`0R07moO`030000001oOgl0Ogmo01`0Ogmo00<0
2NX:0000001oOgl03@1oOgl00`09jPX0Ogmo07moO`0K07moO`0300WZ2P1oOgl0Ogmo02`0Ogmo00<0
00000?ooo`3oool0;03oool00`09jPX0oooo0?ooo`1P0?ooo`030000003oool0oooo00d0oooo001o
0?ooo`030000003oool0oooo04X0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`0V
0?ooo`030000001oOgl0Ogmo0280Ogmo00<0000007moO`1oOgl06`1oOgl00`0000002NX:07moO`0<
07moO`802NX:7@1oOgl00`09jPX0Ogmo07moO`0]07moO`030000003oool0oooo02d0oooo00<02NX:
0?ooo`3oool0G`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`1:0?oo
o`0300WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3oool09@3oool00`000000Ogmo07moO`0S07mo
O`030000001oOgl0Ogmo01T0Ogmo00@0000007moO`1oOgl02NX:2`1oOgl00`09jPX0Ogmo07moO`0M
07moO`0300WZ2P1oOgl0Ogmo02d0Ogmo00<000000?ooo`3oool0;P3oool00`09jPX0oooo0?ooo`1N
0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo04/0oooo00<02NX:0?oo
o`3oool06P3oool00`09jPX0oooo0?ooo`0T0?ooo`030000001oOgl0Ogmo02<0Ogmo00<0000007mo
O`1oOgl0601oOgl01@000000Ogmo07moO`1oOgl02NX:00T0Ogmo0P09jPXO07moO`0300WZ2P1oOgl0
Ogmo02h0Ogmo00<000000?ooo`3oool0;P3oool00`09jPX0oooo0?ooo`1N0?ooo`030000003oool0
oooo00d0oooo001o0?ooo`030000003oool0oooo04`0oooo00<02NX:0?ooo`3oool06P3oool00`09
jPX0oooo0?ooo`0R0?ooo`030000001oOgl0Ogmo02@0Ogmo00<0000007moO`1oOgl05`1oOgl00`00
0000Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl07`1oOgl00`09
jPX0Ogmo07moO`0_07moO`030000003oool0oooo02h0oooo00<02NX:0?ooo`3oool0G@3oool00`00
0000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`1<0?ooo`0300WZ2P3oool0oooo01/0
oooo00<02NX:0?ooo`3oool08@3oool00`000000Ogmo07moO`0U07moO`030000001oOgl0Ogmo01D0
Ogmo00<0000007moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0307moO`802NX:8@1oOgl00`09jPX0
Ogmo07moO`0/07moO`8000000P1oOgl00`000000oooo0?ooo`0_0?ooo`0300WZ2P3oool0oooo05`0
oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0C@3oool00`09jPX0oooo
0?ooo`0K0?ooo`0300WZ2P3oool0oooo0200oooo00<0000007moO`1oOgl09@1oOgl00`000000Ogmo
07moO`0C07moO`8000001`1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo0240Ogmo
00<02NX:07moO`1oOgl0;01oOgl200000080Ogmo00<000000?ooo`3oool0<03oool00`09jPX0oooo
0?ooo`1K0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo04d0oooo00<0
2NX:0?ooo`3oool0703oool00`09jPX0oooo0?ooo`0O0?ooo`030000001oOgl0Ogmo02D0Ogmo00<0
000007moO`1oOgl04P1oOgl00`000000Ogmo07moO`0707moO`0300WZ2P1oOgl0Ogmo00802NX:8`1o
Ogl00`09jPX0Ogmo07moO`0]07moO`802NX:0P1oOgl00`000000oooo0?ooo`0`0?ooo`0300WZ2P3o
ool0oooo05/0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0CP3oool0
0`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo01d0oooo00<0000007moO`1oOgl09`1oOgl0
0`000000Ogmo07moO`0@07moO`030000001oOgl0Ogmo00T0Ogmo0P09jPXT07moO`0300WZ2P1oOgl0
Ogmo02h0Ogmo0P09jPX307moO`030000003oool0oooo0300oooo00<02NX:0?ooo`3oool0FP3oool0
0`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`1>0?ooo`0300WZ2P3oool0oooo
01d0oooo00<02NX:0?ooo`3oool0703oool00`000000Ogmo07moO`0W07moO`030000001oOgl0Ogmo
00l0Ogmo00<0000007moO`1oOgl02@1oOgl200WZ2RD0Ogmo00<02NX:07moO`1oOgl0;@1oOgl300WZ
2P<0Ogmo00<000000?ooo`3oool0<@3oool00`09jPX0oooo0?ooo`1I0?ooo`030000003oool0oooo
00d0oooo001o0?ooo`030000003oool0oooo04l0oooo00<02NX:0?ooo`3oool07@3oool00`09jPX0
oooo0?ooo`0K0?ooo`030000001oOgl0Ogmo02L0Ogmo00<0000007moO`1oOgl03P1oOgl00`000000
Ogmo07moO`0807moO`0400000009jPX0Ogmo00WZ2R@0Ogmo00<02NX:07moO`1oOgl0;P1oOgl300WZ
2P<0Ogmo00<000000?ooo`3oool0<@3oool00`09jPX0oooo0?ooo`1I0?ooo`030000003oool0oooo
00d0oooo001o0?ooo`030000003oool0oooo0500oooo00<02NX:0?ooo`3oool07@3oool00`09jPX0
oooo0?ooo`0J0?ooo`030000001oOgl0Ogmo02P0Ogmo00<0000007moO`1oOgl02`1oOgl2000000X0
Ogmo0P09jPX010000000Ogmo07moO`09jPXS07moO`0300WZ2P1oOgl0Ogmo02d0Ogmo1009jPX307mo
O`030000003oool0oooo0380oooo00<02NX:0?ooo`3oool0F03oool00`000000oooo0?ooo`0=0?oo
o`00O`3oool00`000000oooo0?ooo`0g0?ooo`P000004@3oool00`09jPX0oooo0?ooo`0N0?ooo`03
00WZ2P3oool0oooo01P0oooo00<0000007moO`1oOgl0:@1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00L0Ogmo1@09jPX307moO`0300WZ2P1oOgl0Ogmo0200Ogmo00<02NX:07moO`1o
Ogl01P1oOgl600000280Ogmo00@02NX:07moO`09jPX02NX:101oOgl00`000000oooo0?ooo`0b0?oo
o`0300WZ2P3oool0oooo01H0oooo2000000i0?ooo`030000003oool0oooo00d0oooo001o0?ooo`03
0000003oool0oooo03L0oooo00<0000007moO`1oOgl01@1oOgl?000000<0oooo00<02NX:0?ooo`3o
ool07P3oool00`09jPX0oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo02T0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0607moO`H02NX:101oOgl00`09jPX0Ogmo07moO`0P07moO`03
00WZ2P000000000000H00000101oOgl00`000000Ogmo0000000P07moO`0300WZ2P1oOgl0Ogmo0080
2NX:101oOgl00`000000oooo0?ooo`0b0?ooo`0300WZ2P3oool0oooo00L0oooo3`00000507moO`03
0000001oOgl0000003T0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0
>03oool00`000000Ogmo07moO`0C07moO`<0000000<02NX:0000000000002@00000F0?ooo`0300WZ
2P3oool0oooo01H0oooo00<0000007moO`1oOgl0:P1oOgl00`000000Ogmo07moO`0707moO`030000
001oOgl0Ogmo00H0Ogmo1P09jPX607moO`0300WZ2P1oOgl0Ogmo01L0Ogmo1`0000000`09jPX0Ogmo
07moO`0;07moO`040000001oOgl0Ogmo00000280Ogmo0P09jPX407moO`030000003oool0oooo02d0
oooo1P0000000`09jPX0000000000006000001<0Ogmo00<0000007moO`000000>P3oool00`000000
oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0h0?ooo`030000001oOgl0Ogmo01L0Ogmo
00<02NX:07moO`1oOgl0201oOgl>000000T0oooo00<02NX:0?ooo`3oool05@3oool00`000000Ogmo
07moO`0Z07moO`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl02@1oOgl300WZ2PL0Ogmo
00<02NX:07moO`1oOgl03P1oOgl9000000L0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo01h0Ogmo00<02NX:07moO`1oOgl0101oOgl00`000000oooo
0?ooo`0O0?ooo`h000001`1oOgl00`09jPX0Ogmo07moO`0F07moO`8000000P1oOgl00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo03P0oooo00<0
000007moO`1oOgl0601oOgl00`09jPX0Ogmo07moO`0E07moO`X0000000<02NX:0000000000000P00
000A0?ooo`030000001oOgl0Ogmo02/0Ogmo00<0000007moO`1oOgl0101oOgl2000000/0Ogmo00<0
2NX:07moO`09jPX0201oOgl00`09jPX0Ogmo07moO`0607moO`P000003`1oOgl00`09jPX0Ogmo07mo
O`0;07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl07@1oOgl00`09jPX0Ogmo07mo
O`0507moO`030000003oool0oooo00l0oooo3`00000E07moO`0300WZ2P1oOgl0Ogmo01D0Ogmo00<0
000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00d0oooo001o
0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl05`1oOgl00`09jPX0Ogmo07moO`0P
07moO`0400WZ2P1oOgl0Ogmo07moO`l000000P3oool00`000000Ogmo07moO`0/07moO`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl02@1oOgl200WZ2P0307moO`09jPX0Ogmo00P0Ogmo00<0
2NX:0000000000001P00000G07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0L07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool03`00
000U07moO`0300WZ2P1oOgl0Ogmo01<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo03T0oooo00<00000
07moO`1oOgl0601oOgl00`09jPX0Ogmo07moO`0P07moO`0300WZ2P1oOgl0Ogmo00l0Ogmo3P00000S
07moO`050000001oOgl0Ogmo07moO`0000002`1oOgl00`09jPX0Ogmo07moO`0307moO`T0000000<0
2NX:07moO`1oOgl06`1oOgl00`09jPX0Ogmo07moO`0;07moO`030000001oOgl0Ogmo00H0Ogmo00<0
000007moO`1oOgl06`1oOgl00`09jPX0Ogmo07moO`0507moO`<00000=@1oOgl00`09jPX0Ogmo07mo
O`0@07moO`8000001@1oOgl00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00d0oooo001o
0?ooo`030000003oool0oooo03X0oooo00<0000007moO`1oOgl05`1oOgl00`09jPX0Ogmo07moO`0Q
07moO`0300WZ2P1oOgl0Ogmo01`0Ogmo3`00000D07moO`040000001oOgl0Ogmo000000X0Ogmo00<0
000000WZ2P0000001@00000907moO`0300WZ2P1oOgl0Ogmo01/0Ogmo00<02NX:07moO`1oOgl02`1o
Ogl00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo01X0Ogmo00<02NX:07moO`1oOgl01@1o
Ogl00`000000Ogmo07moO`0f07moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0
oooo00T0oooo0P00000_0?ooo`030000001oOgl0Ogmo01P0Ogmo00<02NX:07moO`1oOgl08@1oOgl0
0`09jPX0Ogmo07moO`0Z07moO`l000001P1oOgl200000080Ogmo2@0000000`09jPX0Ogmo07moO`0>
07moO`0300WZ2P1oOgl0Ogmo01X0Ogmo00<02NX:07moO`1oOgl0301oOgl00`000000Ogmo07moO`08
07moO`030000001oOgl0Ogmo01P0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`000000Ogmo07moO`0e
07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo0P00000707moO`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool02@3oool2000000802NX:;@3oool00`00
0000Ogmo07moO`0H07moO`0300WZ2P1oOgl0Ogmo0280Ogmo00<02NX:07moO`1oOgl0>01oOgl:0000
00P0Ogmo00<02NX:07moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0I07moO`0300WZ2P1oOgl0Ogmo
00/0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0G07moO`0300WZ2P1oOgl0Ogmo
00L0Ogmo00<0000007moO`1oOgl0=P1oOgl00`09jPX0000007moO`0:07moO`030000001oOgl0Ogmo
00L0Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000
oooo0?ooo`0<0?ooo`D02NX::P3oool00`000000Ogmo07moO`0H07moO`0300WZ2P1oOgl0Ogmo0280
Ogmo00<02NX:07moO`1oOgl0>P1oOgl20000000307moO`000000Ogmo00T0Ogmo00<02NX:07moO`1o
Ogl04@1oOgl00`09jPX0Ogmo07moO`0H07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl02`1oOgl00`000000Ogmo07moO`0F07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<0000007moO`1o
Ogl0=P1oOgl00`0000002NX:07moO`0907moO`030000001oOgl0Ogmo00L0Ogmo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0=0?ooo`H02NX:
:03oool00`000000Ogmo07moO`0I07moO`0300WZ2P1oOgl0Ogmo0280Ogmo0P09jPXi07moO`050000
001oOgl0Ogmo07moO`000000201oOgl200WZ2Q@0Ogmo00<02NX:07moO`1oOgl0601oOgl00`09jPX0
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl05@1oOgl00`09jPX0
Ogmo07moO`0707moO`030000001oOgl0Ogmo03L0Ogmo00<02NX:07moO`1oOgl01P1oOgl2000000X0
Ogmo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo
0?ooo`0>0?ooo`D02NX::@3oool00`000000Ogmo07moO`0H07moO`0300WZ2P1oOgl0Ogmo02@0Ogmo
00<02NX:07moO`1oOgl0=01oOgl2000000D0Ogmo00<0000007moO`1oOgl0101oOgl00`09jPX0Ogmo
07moO`0E07moO`0300WZ2P1oOgl0Ogmo01H0Ogmo00<02NX:07moO`1oOgl0301oOgl00`000000Ogmo
07moO`0>07moO`030000001oOgl0Ogmo01@0Ogmo00<02NX:07moO`1oOgl0201oOgl00`000000Ogmo
07moO`0f07moO`802NX:1P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo03`0oooo
00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool03`3oool200WZ2P80oooo0P09
jPXW0?ooo`030000001oOgl0Ogmo01T0Ogmo00<02NX:07moO`1oOgl0901oOgl00`09jPX0Ogmo07mo
O`0a07moO`8000001`1oOgl00`000000Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo01H0Ogmo00<0
2NX:07moO`1oOgl05P1oOgl00`09jPX0Ogmo07moO`0<07moO`030000001oOgl0Ogmo00l0Ogmo0P00
000D07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl0=@1oOgl00`09jPX0Ogmo00WZ
2P0507moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0=0?ooo`00O`3oool00`000000oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo0080oooo0P09jPXU
0?ooo`030000001oOgl0Ogmo01T0Ogmo00<02NX:07moO`1oOgl09@1oOgl00`09jPX0Ogmo07moO`0^
07moO`8000002@1oOgl00`000000Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo01L0Ogmo00<02NX:
07moO`1oOgl05@1oOgl00`09jPX0Ogmo07moO`0=07moO`030000001oOgl0Ogmo0140Ogmo00<00000
07moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0907moO`030000001oOgl0Ogmo03D0Ogmo00<02NX:
07moO`09jPX00`1oOgl2000000d0Ogmo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=
0?ooo`00O`3oool00`000000oooo0?ooo`0G0?ooo`802NX:903oool00`000000Ogmo07moO`0I07mo
O`0300WZ2P1oOgl0Ogmo02D0Ogmo00<02NX:07moO`1oOgl0;01oOgl00`000000Ogmo07moO`0:07mo
O`040000001oOgl0Ogmo00WZ2Q/0Ogmo00<02NX:07moO`1oOgl0501oOgl00`09jPX0Ogmo07moO`0<
07moO`030000001oOgl0Ogmo01<0Ogmo00<0000007moO`1oOgl03`1oOgl00`09jPX0Ogmo07moO`09
07moO`030000001oOgl0Ogmo03D0Ogmo00H02NX:07moO`1oOgl02NX:07moO`00000>07moO`030000
003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool06@3o
ool200WZ2R80oooo00<0000007moO`1oOgl06@1oOgl00`09jPX0Ogmo07moO`0V07moO`0300WZ2P1o
Ogl0Ogmo02T0Ogmo0P00000=07moO`030000001oOgl02NX:01`0Ogmo00<02NX:07moO`1oOgl04`1o
Ogl00`09jPX0Ogmo07moO`0=07moO`030000001oOgl0Ogmo01@0Ogmo00<0000007moO`1oOgl03P1o
Ogl00`09jPX0Ogmo07moO`0:07moO`030000001oOgl0Ogmo03<0Ogmo00H02NX:07moO`1oOgl0Ogmo
00WZ2P00000?07moO`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool007l0oooo
00<000000?ooo`3oool06`3oool300WZ2R00oooo00<0000007moO`1oOgl06@1oOgl00`09jPX0Ogmo
07moO`0V07moO`0300WZ2P1oOgl0Ogmo02H0Ogmo0P00000?07moO`802NX:7@1oOgl00`09jPX0Ogmo
07moO`0@07moO`0300WZ2P1oOgl02NX:0100Ogmo00<0000007moO`1oOgl05@1oOgl00`000000Ogmo
07moO`0=07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0<`1oOgl00`09jPX0Ogmo
07moO`020000000300WZ2P1oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0N0?ooo`802NX:7P3oool00`000000Ogmo07mo
O`0J07moO`0300WZ2P1oOgl0Ogmo02H0Ogmo00<02NX:07moO`1oOgl08`1oOgl200000100Ogmo00<0
2NX:07moO`0000007P1oOgl00`09jPX0Ogmo07moO`0?07moO`0300WZ2P1oOgl02NX:00l0Ogmo00<0
000007moO`1oOgl05`1oOgl00`000000Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl0<`1oOgl00`09jPX0Ogmo0000000207moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0P
0?ooo`802NX:7@3oool00`000000Ogmo07moO`0I07moO`0300WZ2P1oOgl0Ogmo02L0Ogmo00<02NX:
07moO`1oOgl0801oOgl200000140Ogmo00@02NX:07moO`1oOgl000007P1oOgl00`09jPX0Ogmo07mo
O`0?07moO`802NX:00<0Ogmo00WZ2P09jPX03@1oOgl00`000000Ogmo07moO`0H07moO`030000001o
Ogl0Ogmo00/0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0b07moO`0300WZ2P1o
Ogl0000000<0Ogmo00<02NX:07moO`1oOgl0301oOgl00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00d0oooo001o0?ooo`030000003oool0oooo0280oooo0P09jPXK0?ooo`030000001oOgl0
Ogmo01X0Ogmo00<02NX:07moO`1oOgl09`1oOgl00`09jPX0Ogmo07moO`0N07moO`030000001oOgl0
Ogmo0100Ogmo00D02NX:07moO`1oOgl0Ogmo0000000N07moO`0300WZ2P1oOgl0Ogmo00h0Ogmo1@09
jPX>07moO`030000001oOgl0Ogmo01T0Ogmo00<0000007moO`1oOgl02@1oOgl00`09jPX0Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo0340Ogmo00<02NX:0000001oOgl0101oOgl00`09jPX0Ogmo07mo
O`0:07moO`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool007l0oooo00<00000
0?ooo`3oool0903oool200WZ2QT0oooo00<0000007moO`1oOgl06P1oOgl00`09jPX0Ogmo07moO`0X
07moO`0300WZ2P1oOgl0Ogmo01/0Ogmo0P00000B07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0701oOgl00`09jPX0Ogmo07moO`0=07moO`@02NX:3P1oOgl00`000000Ogmo07moO`0K
07moO`030000001oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl0301oOgl00`000000Ogmo07moO`0`
07moO`0300000009jPX0Ogmo00D0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo02H0oooo0`09jPXG0?oo
o`030000001oOgl0Ogmo01X0Ogmo00<02NX:07moO`1oOgl0:01oOgl00`09jPX0Ogmo07moO`0H07mo
O`8000004`1oOgl00`09jPX0Ogmo07moO`0407moO`030000001oOgl0Ogmo01`0Ogmo00<02NX:07mo
O`1oOgl03@1oOgl300WZ2Pl0Ogmo00<0000007moO`1oOgl0701oOgl00`000000Ogmo07moO`0707mo
O`0300WZ2P1oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0;P1oOgl20000000300WZ2P1oOgl0Ogmo
00H0Ogmo00<02NX:07moO`1oOgl0201oOgl00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00d0oooo001o0?ooo`030000003oool0oooo02T0oooo0P09jPXE0?ooo`030000001oOgl0Ogmo01/0
Ogmo00<02NX:07moO`1oOgl0:01oOgl00`09jPX0Ogmo07moO`0E07moO`8000004`1oOgl200WZ2PL0
Ogmo00<0000007moO`1oOgl0701oOgl00`09jPX0Ogmo07moO`0=07moO`802NX:401oOgl00`000000
Ogmo07moO`0M07moO`030000001oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl0301oOgl00`000000
Ogmo07moO`0]07moO`040000001oOgl0Ogmo00WZ2PP0Ogmo00<02NX:07moO`1oOgl0201oOgl00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo02/0
oooo0P09jPXD0?ooo`030000001oOgl0Ogmo01X0Ogmo00<02NX:07moO`1oOgl0:@1oOgl00`09jPX0
Ogmo07moO`0C07moO`030000001oOgl0Ogmo0180Ogmo00<02NX:07moO`1oOgl0201oOgl00`000000
Ogmo07moO`0L07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo0P09jPXA07moO`030000001oOgl0Ogmo01h0
Ogmo00<0000007moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0=07moO`030000001oOgl0Ogmo02/0
Ogmo00D0000007moO`1oOgl0Ogmo00WZ2P0807moO`0300WZ2P000000000000P0Ogmo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0]0?ooo`80
2NX:4P3oool00`000000Ogmo07moO`0K07moO`0300WZ2P1oOgl0Ogmo02T0Ogmo00<02NX:07moO`1o
Ogl0401oOgl2000001@0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0L07moO`03
00WZ2P1oOgl0Ogmo00/0Ogmo00<02NX:0000001oOgl03`1oOgl00`000000Ogmo07moO`0P07moO`03
0000001oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl03P1oOgl00`000000Ogmo07moO`0Y07moO`80
00000`1oOgl00`09jPX0Ogmo07moO`0407moO`D02NX:00<0000007moO`1oOgl01@1oOgl00`000000
oooo0?ooo`110?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo02l0oooo
0P09jPX@0?ooo`030000001oOgl0Ogmo01/0Ogmo00<02NX:07moO`1oOgl0:P1oOgl00`09jPX0Ogmo
07moO`0:07moO`D02NX:0P1oOgl200000140Ogmo00<02NX:07moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0L07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<02NX:0000001oOgl03`1oOgl00`000000Ogmo
07moO`0Q07moO`8000000`1oOgl00`09jPX0Ogmo07moO`0>07moO`030000001oOgl0Ogmo02P0Ogmo
00<0000007moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0700WZ2PX0Ogmo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0a0?ooo`<02NX:3P3o
ool00`000000Ogmo07moO`0K07moO`0300WZ2P1oOgl0Ogmo02X0Ogmo00<02NX:07moO`1oOgl02P1o
Ogl600WZ2P0400000009jPX02NX:00WZ2Ph0Ogmo00<02NX:07moO`1oOgl0301oOgl00`000000Ogmo
07moO`0K07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<02NX:07moO`1oOgl0401oOgl00`000000Ogmo
07moO`0S07moO`040000001oOgl0Ogmo00WZ2Q00Ogmo00<0000007moO`1oOgl09`1oOgl00`000000
Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo0080Ogmo1009jPX:07moO`030000003oool0oooo0480
oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0=03oool200WZ2P`0oooo
00<0000007moO`1oOgl06`1oOgl00`09jPX0Ogmo07moO`0[07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo
2009jPX407moO`D02NX:201oOgl00`09jPX0Ogmo07moO`0=07moO`030000001oOgl0Ogmo01`0Ogmo
00<02NX:07moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0?07moO`030000001oOgl0Ogmo02D0Ogmo
00<0000007moO`09jPX04@1oOgl00`000000Ogmo07moO`0T07moO`8000001P1oOgl01009jPX0Ogmo
07moO`1oOgl200WZ2P0307moO`09jPX02NX:00/0Ogmo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0f0?ooo`802NX:2`3oool00`000000Ogmo
07moO`0K07moO`0300WZ2P1oOgl0Ogmo02/0Ogmo00<02NX:07moO`09jPX01P09jPX00`000000Ogmo
00WZ2P0200WZ2P`0Ogmo1009jPX207moO`802NX:401oOgl00`000000Ogmo07moO`0L07moO`0300WZ
2P1oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl0401oOgl00`000000Ogmo07moO`0V07moO`030000
0009jPX0Ogmo0100Ogmo00<0000007moO`1oOgl08`1oOgl00`000000Ogmo07moO`0507moO`030000
0009jPX02NX:00802NX:0P1oOgl200WZ2P`0Ogmo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0h0?ooo`802NX:2@3oool00`000000Ogmo07mo
O`0L07moO`0300WZ2P1oOgl0Ogmo02H0Ogmo1P09jPX407moO`8000000P1oOgl00`09jPX0Ogmo07mo
O`0A07moO`D02NX:401oOgl00`000000Ogmo07moO`0K07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<0
2NX:07moO`1oOgl0401oOgl00`000000Ogmo07moO`0V07moO`8000001009jPX=07moO`030000001o
Ogl0Ogmo0280Ogmo00<0000007moO`1oOgl01P1oOgl00`0000002NX:07moO`0407moO`0300WZ2P1o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool0
0`000000oooo0?ooo`0j0?ooo`802NX:1`3oool00`000000Ogmo07moO`0L07moO`0300WZ2P1oOgl0
Ogmo0200Ogmo1P09jPX607moO`0400WZ2P1oOgl00000000001P0Ogmo00<02NX:07moO`1oOgl00P1o
Ogl400WZ2P`0Ogmo00<0000007moO`1oOgl0701oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1o
Ogl0Ogmo0100Ogmo00<0000007moO`1oOgl09`1oOgl3000000<0Ogmo1P09jPX707moO`030000001o
Ogl0Ogmo0200Ogmo0P00000707moO`<02NX:4`1oOgl00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo00d0oooo001o0?ooo`030000003oool0oooo03`0oooo0`09jPX50?ooo`030000001oOgl0
Ogmo01`0Ogmo00<02NX:07moO`1oOgl0601oOgl700WZ2Pd0Ogmo00<02NX:07moO`1oOgl05`1oOgl0
0`09jPX0Ogmo07moO`0707moO`@02NX:201oOgl00`000000Ogmo07moO`0L07moO`0300WZ2P1oOgl0
Ogmo00H0Ogmo00<02NX:07moO`1oOgl0401oOgl00`000000Ogmo07moO`0V07moO`0500000009jPX0
2NX:07moO`000000201oOgl700WZ2P0307moO`000000Ogmo01l0Ogmo00<0000007moO`1oOgl0101o
Ogl300WZ2P80Ogmo00<02NX:07moO`1oOgl0401oOgl00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo00d0oooo001o0?ooo`030000003oool0oooo03l0oooo0P09jPX30?ooo`030000001oOgl0
Ogmo01`0Ogmo00<02NX:07moO`1oOgl04P1oOgl600WZ2Q80Ogmo0P0000000`1oOgl02NX:07moO`0F
07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo1@09jPX407moO`030000001oOgl0Ogmo01/0Ogmo00<02NX:
07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0A07moO`030000001oOgl0Ogmo02H0Ogmo00H00000
00WZ2P09jPX02NX:07moO`00000>07moO`H02NX:6P1oOgl2000000D0Ogmo0P09jPX407moO`0300WZ
2P1oOgl0Ogmo0140Ogmo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0=0?ooo`00O`3o
ool00`000000oooo0?ooo`110?ooo`802NX:0P3oool00`000000Ogmo07moO`0L07moO`0300WZ2P1o
Ogl0Ogmo00/0Ogmo1P09jPXF07moO`800000101oOgl00`09jPX0000007moO`0C07moO`0300WZ2P1o
Ogl0Ogmo0180Ogmo1009jPX00`000000Ogmo07moO`0L07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<0
2NX:07moO`1oOgl0401oOgl00`000000Ogmo07moO`0X07moO`<02NX:0P1oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo0080Ogmo1P09jPXC07moO`030000001oOgl0Ogmo00<0Ogmo0P09
jPX607moO`0300WZ2P1oOgl0Ogmo0140Ogmo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`0=0?ooo`00O`3oool00`000000oooo0?ooo`130?ooo`802NX:00<0000007moO`1oOgl07@1oOgl0
0`09jPX0Ogmo07moO`0407moO`H02NX:6P1oOgl2000000H0Ogmo0P00000B07moO`802NX:6@1oOgl5
00WZ2QX0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0A07moO`030000001oOgl0
Ogmo02L0Ogmo1009jPX307moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0201oOgl6
00WZ2P`0Ogmo00@0000007moO`1oOgl0Ogmo0`09jPX707moO`0300WZ2P1oOgl0Ogmo0140Ogmo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`15
0?ooo`802NX:3@1oOgl300WZ2Ph0Ogmo1`09jPXO07moO`030000001oOgl0Ogmo00H0Ogmo0P09jPXA
07moO`0300WZ2P1oOgl0Ogmo01X0Ogmo00@0000007moO`1oOgl0Ogmo1009jPXF07moO`0300WZ2P1o
Ogl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl04@1oOgl00`000000Ogmo07moO`0V07moO`D02NX:101o
Ogl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00d0Ogmo1`09jPX307moO`8000000P1o
Ogl200WZ2PX0Ogmo00<02NX:07moO`1oOgl04@1oOgl00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00d0oooo001o0?ooo`030000003oool0oooo04H0oooo00@0000000WZ2P09jPX02NX:2`1o
Ogl600WZ2P0407moO`000000000007moO`H02NX:00<0Ogmo00WZ2P1oOgl08@1oOgl2000000X0Ogmo
0P09jPX?07moO`0300WZ2P1oOgl0Ogmo01/0Ogmo00<0000007moO`1oOgl01@1oOgl500WZ2Q80Ogmo
00D02NX:07moO`1oOgl0Ogmo00WZ2P0C07moO`030000001oOgl0Ogmo02H0Ogmo1`09jPX407moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0501oOgl700WZ2P`0Ogmo00<02NX:07moO`1o
Ogl0401oOgl00`000000oooo0?ooo`160?ooo`030000003oool0oooo00d0oooo000>0?ooom<02NX:
1`1oOgl00`09jPX0Ogmo07moO`0N07moO`800000301oOgl300WZ2Pd0Ogmo00<02NX:07moO`1oOgl0
701oOgl00`000000Ogmo07moO`0:07moO`@02NX:3P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:01<0
Ogmo00<0000007moO`1oOgl05`1oOgl2000000`0Ogmo1009jPX0101oOgl02NX:07moO`09jPX507mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl05@1oOgl01@0000002NX:00WZ2P09jPX0
Ogmo00H02NX:1P1oOgl00`09jPX0Ogmo07moO`0A07moO`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0207mo
O`802NX:1`1oOgl500WZ2P80Ogmo00<02NX:07moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0K07mo
O`8000003P1oOgl300WZ2P`0Ogmo00<02NX:07moO`1oOgl07P1oOgl00`000000Ogmo07moO`0=07mo
O`D02NX:2@1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:01<0Ogmo00<0000007moO`1oOgl0501oOgl5
00WZ2P/0Ogmo0P09jPX01@1oOgl02NX:00WZ2P1oOgl02NX:00P0Ogmo00<0000007moO`1oOgl0201o
Ogl00`000000Ogmo07moO`0C07moO`0300000009jPX02NX:00X0Ogmo1`09jPX707moO`802NX:2P1o
Ogl00`000000oooo0?ooo`160?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0
oooo04L0oooo00<0000007moO`1oOgl0101oOgl200WZ2P@0Ogmo0P09jPX507moO`0300WZ2P1oOgl0
Ogmo00T0Ogmo00<02NX:07moO`1oOgl06@1oOgl200000100Ogmo1009jPX:07moO`0300WZ2P1oOgl0
Ogmo01l0Ogmo00<0000007moO`1oOgl04P1oOgl400WZ2PH0Ogmo00<02NX:07moO`09jPX04`1oOgl0
0`000000Ogmo07moO`0<07moO`T02NX:101oOgl00`09jPX0Ogmo07moO`0;07moO`0500WZ2P1oOgl0
2NX:07moO`09jPX02@1oOgl2000000T0Ogmo00<0000007moO`1oOgl04@1oOgl200WZ2Q40Ogmo2009
jPX00`1oOgl02NX:00WZ2P0300WZ2PH0Ogmo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0=0?ooo`00O`3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00H0Ogmo0P09jPX9
07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<02NX:07moO`1oOgl05`1oOgl00`000000Ogmo07moO`0A
07moO`802NX:00<0Ogmo00WZ2P1oOgl01P1oOgl200WZ2R80Ogmo00<0000007moO`1oOgl05P1oOgl4
00WZ2P80Ogmo00<02NX:07moO`09jPX04`1oOgl00`000000Ogmo07moO`0307moO`T02NX:3@1oOgl2
00WZ2P`0Ogmo00D02NX:07moO`09jPX0Ogmo00WZ2P0;07moO`030000001oOgl0Ogmo00H0Ogmo00<0
000007moO`1oOgl03P1oOgl300WZ2Q<0Ogmo00<02NX:07moO`1oOgl01@1oOgl800WZ2P8000000P1o
Ogl00`000000oooo0?ooo`170?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0
oooo04P0oooo00<0000007moO`1oOgl01`1oOgl300WZ2PD0Ogmo00<02NX:07moO`1oOgl0301oOgl0
0`09jPX0Ogmo07moO`0D07moO`800000501oOgl00`09jPX0Ogmo00WZ2P0707moO`0300WZ2P1oOgl0
Ogmo02<0Ogmo00<0000007moO`1oOgl06@1oOgl500WZ2P0307moO`09jPX02NX:00d0Ogmo2@09jPXF
07moO`<02NX:2P1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl01@1oOgl00`000000Ogmo07moO`0;07moO`0300WZ2P0000002NX:008000004`1oOgl0
0`09jPX0Ogmo07moO`0707moO`L02NX:0P0000000`1oOgl000000?ooo`190?ooo`030000003oool0
oooo00d0oooo001o0?ooo`030000003oool0oooo04P0oooo00<0000007moO`1oOgl02P1oOgl200WZ
2P80Ogmo00<02NX:07moO`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0B07moO`800000601oOgl00`09
jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo02@0Ogmo00<0000007moO`1oOgl0701oOgl600WZ
2P<0Ogmo2@09jPX307moO`030000001oOgl0Ogmo01T0Ogmo1009jPX907moO`0300WZ2P1oOgl0Ogmo
00<0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00L0Ogmo1@09jPX2000001D0Ogmo00<02NX:07moO`1oOgl01P1oOgl400WZ2PL0Ogmo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`190?ooo`03
0000001oOgl0Ogmo00/0Ogmo0`09jPX@07moO`0300WZ2P1oOgl0Ogmo00l0Ogmo0P00000K07moO`03
00WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl09@1oOgl00`000000Ogmo07moO`0H07moO`80
00003@09jPX907moO`030000001oOgl0Ogmo01/0Ogmo1009jPX807moO`0300WZ2P1oOgl0Ogmo00<0
Ogmo00<02NX:07moO`1oOgl02`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0
Ogmo1P09jPX00`1oOgl0000007moO`0D07moO`0300WZ2P1oOgl0Ogmo0180Ogmo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`190?ooo`030000
001oOgl0Ogmo00`0Ogmo0`09jPX?07moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00<0000007moO`1oOgl0
6`1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:02T0Ogmo00<0000007moO`1oOgl05@1oOgl:00WZ2PL0
Ogmo1009jPX507moO`030000001oOgl0Ogmo01/0Ogmo0`09jPX00`1oOgl02NX:07moO`0507moO`03
00WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl0301oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00D0Ogmo1009jPX2000001H0Ogmo00<02NX:07moO`1oOgl04@1oOgl00`000000
oooo0?ooo`190?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo04T0oooo
00<0000007moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0200WZ2Ph0Ogmo00<02NX:07moO`1oOgl0
2`1oOgl2000001l0Ogmo00<02NX:07moO`09jPX0:P1oOgl00`000000Ogmo07moO`0B07moO`<02NX:
101oOgl700WZ2PX0Ogmo1@09jPX00`000000Ogmo07moO`0K07moO`0300WZ2P1oOgl02NX:00P0Ogmo
00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0=07moO`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl00`1oOgl200WZ2P0407moO`09jPX02NX:000001L0Ogmo00<02NX:07moO`1o
Ogl04P1oOgl00`000000oooo0?ooo`190?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000
003oool0oooo04X0oooo00<0000007moO`1oOgl02P1oOgl00`09jPX0Ogmo07moO`0307moO`802NX:
3@1oOgl00`09jPX0Ogmo07moO`0907moO`800000801oOgl200WZ2R/0Ogmo00<0000007moO`1oOgl0
3`1oOgl300WZ2PL0Ogmo00<02NX:07moO`1oOgl01@09jPX=07moO`0300000009jPX02NX:00802NX:
6P1oOgl01009jPX0Ogmo07moO`09jPX607moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1o
Ogl03P1oOgl01@000000Ogmo07moO`1oOgl000000080Ogmo0`09jPX207moO`802NX:00<0000007mo
O`1oOgl05P1oOgl00`09jPX0Ogmo07moO`0A07moO`030000003oool0oooo04X0oooo00<000000?oo
o`3oool03@3oool007l0oooo00<000000?ooo`3oool0BP3oool00`000000Ogmo07moO`0:07moO`03
00WZ2P1oOgl0Ogmo00D0Ogmo0`09jPX:07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<0000007moO`00
00007P1oOgl200WZ2R`0Ogmo00<0000007moO`1oOgl0301oOgl300WZ2PT0Ogmo00D02NX:07moO`1o
Ogl0Ogmo00WZ2P0407moO`<02NX:2P1oOgl00`000000Ogmo07moO`0207moO`D02NX:601oOgl00`09
jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl03`1oOgl01000
0000Ogmo07moO`1oOgl200WZ2PD0Ogmo00<02NX:07moO`1oOgl05`1oOgl00`09jPX0Ogmo07moO`0B
07moO`030000003oool0oooo04X0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?oo
o`3oool0B`3oool00`000000Ogmo07moO`0807moO`0300WZ2P1oOgl0Ogmo00T0Ogmo0P09jPX907mo
O`0300WZ2P1oOgl0Ogmo00P0Ogmo00@0000007moO`1oOgl00000701oOgl01009jPX0Ogmo07moO`09
jPX/07moO`030000001oOgl0Ogmo00P0Ogmo0`09jPX<07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0
2NX:07moO`1oOgl0101oOgl300WZ2PL0Ogmo00<0000007moO`1oOgl01`1oOgl400WZ2Q@0Ogmo00<0
2NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo0100Ogmo00@0
000000WZ2P09jPX000001@1oOgl00`000000Ogmo07moO`0H07moO`0300WZ2P1oOgl0Ogmo0180Ogmo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?oo
o`1;0?ooo`030000001oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl0301oOgl200WZ2PL0Ogmo00<0
2NX:07moO`1oOgl0201oOgl010000000Ogmo07moO`1oOgl2000001T0Ogmo00D02NX:07moO`1oOgl0
Ogmo00WZ2P0/07moO`030000001oOgl0Ogmo00D0Ogmo0`09jPX>07moO`0300WZ2P1oOgl0Ogmo00<0
Ogmo00<02NX:07moO`1oOgl01`1oOgl400WZ2P80Ogmo00<0000007moO`1oOgl0301oOgl400WZ2Q40
Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00l0
Ogmo0P09jPX00`000000Ogmo0000000307moO`8000006P1oOgl00`09jPX0Ogmo07moO`0B07moO`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0
C03oool00`000000Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00h0Ogmo0P09jPX607moO`0300WZ
2P1oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0E07moO`0300WZ
2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0:@1oOgl00`000000Ogmo07moO`0207moO`<02NX:
4@1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00/0Ogmo0`09jPXB07moO`D02NX:
301oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl0
3@1oOgl200WZ2P<0Ogmo0P00000207moO`030000001oOgl0Ogmo01X0Ogmo00<02NX:07moO`1oOgl0
4P1oOgl00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003o
ool0oooo04`0oooo00<0000007moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0A07moO`802NX:101o
Ogl00`09jPX0Ogmo07moO`0607moO`030000001oOgl0Ogmo00D0Ogmo0P00000D07moO`0300WZ2P1o
Ogl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl0:P1oOgl0100000002NX:00WZ2P09jPXC07moO`0300WZ
2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl03@1oOgl00`0000002NX:00WZ2P0200WZ2Q<0Ogmo
1009jPX907moO`0400WZ2P1oOgl0Ogmo00WZ2PT0Ogmo00<02NX:07moO`1oOgl02`1oOgl200WZ2PH0
Ogmo0`00000M07moO`0300WZ2P1oOgl0Ogmo0140Ogmo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`1<0?ooo`030000001oOgl0Ogmo00D0Ogmo
00<02NX:07moO`1oOgl04`1oOgl300WZ2P80Ogmo00<02NX:07moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0707moO`030000001oOgl0Ogmo0100Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09jPX0Ogmo
07moO`0W07moO`<02NX:5P1oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00/0Ogmo
00<0000007moO`1oOgl00`1oOgl300WZ2Q@0Ogmo1@09jPX407moO`0400WZ2P1oOgl0Ogmo00WZ2PT0
Ogmo00<02NX:07moO`1oOgl02@1oOgl200WZ2PP0Ogmo0`00000L07moO`0300WZ2P1oOgl0Ogmo0180
Ogmo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo
0?ooo`1=0?ooo`030000001oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl05`1oOgl200WZ2P0307mo
O`09jPX0Ogmo00D0Ogmo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0=07moO`802NX:
2@1oOgl00`09jPX0Ogmo07moO`0T07moO`<02NX:0P1oOgl00`000000Ogmo07moO`0C07moO`0300WZ
2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl02`1oOgl00`000000Ogmo07moO`0607moO`<02NX:
5P1oOgl400WZ2P0407moO`09jPX0Ogmo00WZ2PT0Ogmo00<02NX:07moO`1oOgl01`1oOgl200WZ2PT0
Ogmo00D0000007moO`000000Ogmo0000000K07moO`0300WZ2P1oOgl0Ogmo0180Ogmo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`1=0?ooo`03
0000001oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl06P1oOgl200WZ2PH0Ogmo00<0000007moO`1o
Ogl02@1oOgl2000000`0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`09jPX0Ogmo07moO`0P07moO`<0
2NX:1P1oOgl00`000000Ogmo07moO`0B07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1o
Ogl02`1oOgl00`000000Ogmo07moO`0907moO`@02NX:5P1oOgl500WZ2PP0Ogmo00<02NX:07moO`1o
Ogl01@1oOgl200WZ2PX0Ogmo00H0000007moO`1oOgl0Ogmo0000001oOgl2000001P0Ogmo00<02NX:
07moO`1oOgl04P1oOgl00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00d0oooo001o0?oo
o`030000003oool0oooo04h0oooo00D0000007moO`1oOgl0Ogmo00WZ2P0N07moO`802NX:0`1oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl02`1oOgl0
0`09jPX0Ogmo07moO`0L07moO`@02NX:2@1oOgl00`000000Ogmo07moO`0A07moO`0300WZ2P1oOgl0
Ogmo00P0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0>07moO`<02NX:5@1oOgl0
0`09jPX0Ogmo07moO`0400WZ2P@0Ogmo00<02NX:07moO`1oOgl00`1oOgl200WZ2PX0Ogmo0P000004
07moO`040000001oOgl0Ogmo07moO`8000005P1oOgl00`09jPX0Ogmo07moO`0B07moO`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0CP3oool0
10000000Ogmo07moO`09jPXO07moO`0600WZ2P1oOgl02NX:00WZ2P1oOgl000003`1oOgl00`000000
Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00d0Ogmo00<02NX:07moO`1oOgl0601oOgl300WZ2Pd0
Ogmo00<0000007moO`1oOgl04@1oOgl00`09jPX0Ogmo07moO`0807moO`0300WZ2P1oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl04@1oOgl400WZ2Q00Ogmo0P09jPX607moO`D02NX:0P1oOgl300WZ2P/0
Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0180
Ogmo00<02NX:07moO`1oOgl04P1oOgl00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00d0
oooo001o0?ooo`030000003oool0oooo04h0oooo00@0000007moO`1oOgl02NX:801oOgl00`09jPX0
Ogmo07moO`0300WZ2Pl0Ogmo0P00000507moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00<02NX:07moO`1o
Ogl05@1oOgl300WZ2Q40Ogmo00<0000007moO`1oOgl03`1oOgl00`09jPX0Ogmo07moO`0907moO`03
00WZ2P1oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl05@1oOgl300WZ2P@0Ogmo0P09jPX707moO`03
00WZ2P1oOgl02NX:00T0Ogmo1@09jPX:07moO`800000201oOgl00`000000Ogmo07moO`0307moO`80
00004P1oOgl00`09jPX0Ogmo07moO`0B07moO`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool03@3oool007l0oooo00<000000?ooo`3oool0C`3oool00`0000002NX:07moO`0P07moO`0600WZ
2P1oOgl0Ogmo07moO`000000Ogmo0P09jPX?07moO`050000001oOgl0Ogmo07moO`09jPX04P1oOgl0
0`09jPX0Ogmo07moO`0A07moO`<02NX:501oOgl00`000000Ogmo07moO`0?07moO`0300WZ2P1oOgl0
Ogmo00X0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`000000Ogmo07moO`0I07moO`<02NX:00<0Ogmo
00WZ2P09jPX00P09jPX407moO`0400WZ2P1oOgl0Ogmo00WZ2PP0Ogmo0P09jPX407moO`@02NX:1@1o
Ogl00`000000Ogmo07moO`0200WZ2PL0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0>07moO`0300WZ2P1oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`0=0?ooo`00O`3oool00`000000oooo0?ooo`1?0?ooo`0300000009jPX0Ogmo0240Ogmo00@02NX:
07moO`1oOgl000000`1oOgl200WZ2Ph0Ogmo00<0000000WZ2P09jPX04`1oOgl00`09jPX0Ogmo07mo
O`0>07moO`<02NX:5`1oOgl00`000000Ogmo07moO`0>07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<0
2NX:07moO`1oOgl01`1oOgl00`000000Ogmo07moO`0L07moO`H02NX:0`1oOgl01@09jPX0Ogmo07mo
O`1oOgl02NX:00D0Ogmo0P09jPX00`1oOgl02NX:07moO`0707moO`D02NX:0`1oOgl400WZ2PD0Ogmo
00<0000007moO`1oOgl01@1oOgl2000000h0Ogmo00<02NX:07moO`1oOgl04P1oOgl00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo04l0oooo00<0
2NX:0000001oOgl08P1oOgl00`09jPX0000007moO`0507moO`802NX:301oOgl00`09jPX000000000
000D07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo0`09jPXK07moO`030000001oOgl0Ogmo00d0Ogmo00<0
2NX:07moO`1oOgl02`1oOgl00`09jPX0Ogmo07moO`0707moO`030000001oOgl0Ogmo01`0Ogmo2009
jPX00`1oOgl02NX:07moO`0207moO`0400WZ2P1oOgl0Ogmo07moO`802NX:0`1oOgl00`09jPX0Ogmo
07moO`0807moO`80000000<0Ogmo00WZ2P09jPX01P09jPX407moO`030000001oOgl0Ogmo00L0Ogmo
00<0000007moO`1oOgl02P1oOgl00`09jPX0Ogmo07moO`0C07moO`030000003oool0oooo04l0oooo
00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0CP3oool00`09jPX0oooo0000
000S07moO`0300WZ2P000000Ogmo00L0Ogmo0P09jPX907moO`0500WZ2P1oOgl0Ogmo07moO`000000
4`1oOgl01009jPX0Ogmo00WZ2P09jPX607moO`<02NX:7P1oOgl00`000000Ogmo07moO`0=07moO`03
00WZ2P1oOgl0Ogmo00`0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`000000Ogmo07moO`0L07moO`P0
2NX:00<0000000WZ2P1oOgl0101oOgl300WZ2PD0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`000000
Ogmo07moO`0407moO`L02NX:0`1oOgl00`000000Ogmo07moO`0707moO`8000002P1oOgl00`09jPX0
Ogmo07moO`0B07moO`030000003oool0oooo0500oooo00<000000?ooo`3oool03@3oool007l0oooo
00<000000?ooo`3oool0CP3oool00`09jPX0oooo0000000T07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo
0`09jPX507moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P00000B07moO`<02NX:0`1oOgl300WZ2R40Ogmo
00<0000007moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0=07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo
00<0000007moO`1oOgl0901oOgl2000000@0Ogmo0P09jPX807moO`0300WZ2P1oOgl0Ogmo00D0Ogmo
00<0000007moO`1oOgl0101oOgl:00WZ2P0307moO`000000Ogmo00X0Ogmo0P00000707moO`0300WZ
2P1oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0=0?ooo`00O`3o
ool00`000000oooo0?ooo`1=0?ooo`0500WZ2P3oool0oooo0?ooo`0000008`1oOgl00`09jPX0Ogmo
07moO`0;07moO`802NX:0P1oOgl00`09jPX0Ogmo07moO`0607moO`030000001oOgl0Ogmo00d0Ogmo
1009jPX0101oOgl02NX:00WZ2P09jPXU07moO`030000001oOgl0Ogmo00/0Ogmo00<02NX:07moO`1o
Ogl03@1oOgl00`09jPX0Ogmo07moO`0507moO`030000001oOgl0Ogmo02P0Ogmo0P09jPX00`1oOgl0
2NX:07moO`0707moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P00000;07moO`<02NX:00<0Ogmo00000000
00000P09jPX00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00@0Ogmo00<02NX:07moO`1o
Ogl04`1oOgl00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000
003oool0oooo04d0oooo00D02NX:0?ooo`3oool0oooo0000000S07moO`0300000009jPX0Ogmo00d0
Ogmo0P09jPX:07moO`030000001oOgl0Ogmo00/0Ogmo1P09jPXX07moO`030000001oOgl0Ogmo00X0
Ogmo00<02NX:07moO`1oOgl03`1oOgl00`09jPX0Ogmo07moO`0407moO`030000001oOgl0Ogmo02H0
Ogmo0P09jPX407moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0807moO`<02NX:201oOgl200WZ2P`0Ogmo0P00000307moO`0300WZ2P1oOgl0Ogmo01<0
Ogmo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo
0?ooo`1<0?ooo`0300WZ2P3oool0oooo00<0oooo00<0000007moO`1oOgl07`1oOgl010000000Ogmo
07moO`09jPX<07moO`802NX:00<0Ogmo00WZ2P09jPX02@1oOgl2000000P0Ogmo0P00000800WZ2RL0
Ogmo00<0000007moO`1oOgl02P1oOgl00`09jPX0Ogmo07moO`0?07moO`0300WZ2P1oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl09@1oOgl200WZ2PH0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09jPX0
Ogmo07moO`02000000L0Ogmo0P00000200WZ2P`0Ogmo00<0000000WZ2P09jPX0301oOgl010000000
Ogmo07moO`09jPXE07moO`030000003oool0oooo0540oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool0C03oool00`09jPX0oooo0?ooo`030?ooo`030000001oOgl0Ogmo01l0
Ogmo00D0000007moO`1oOgl02NX:0000000:07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P09jPX907mo
O`030000001oOgl0Ogmo00D0Ogmo0P00000300WZ2P<0Ogmo00<02NX:07moO`1oOgl09`1oOgl00`00
0000Ogmo07moO`0807moO`0300WZ2P1oOgl0Ogmo0100Ogmo00<02NX:07moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0R07moO`<02NX:2@1oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl00000
00T0Ogmo00<02NX:0000001oOgl03@1oOgl00`000000Ogmo07moO`0200WZ2P/0Ogmo0P0000000`09
jPX0Ogmo07moO`0C07moO`030000003oool0oooo0540oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool0B`3oool00`09jPX0oooo0?ooo`040?ooo`030000001oOgl0Ogmo01l0
Ogmo00D0000007moO`1oOgl0000000WZ2P0907moO`0300WZ2P1oOgl0Ogmo00H0Ogmo0`09jPX707mo
O`030000001oOgl0Ogmo00`0Ogmo00<02NX:07moO`1oOgl09`1oOgl00`000000Ogmo07moO`0807mo
O`0300WZ2P1oOgl0Ogmo0140Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0P07mo
O`802NX:301oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P000000Ogmo00T0Ogmo00<02NX:07mo
O`1oOgl03P1oOgl010000000Ogmo07moO`1oOgl200WZ2PX0Ogmo00<02NX:0000000000004`1oOgl0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo
04X0oooo00<02NX:0?ooo`3oool01P3oool00`000000Ogmo07moO`0N07moO`050000001oOgl0Ogmo
07moO`09jPX0201oOgl00`09jPX0Ogmo07moO`0:07moO`802NX:1P1oOgl2000000d0Ogmo00<02NX:
07moO`1oOgl09P1oOgl00`000000Ogmo07moO`0707moO`0300WZ2P1oOgl0Ogmo0180Ogmo00D02NX:
07moO`1oOgl0Ogmo0000000Q07moO`802NX:3`1oOgl00`09jPX0Ogmo07moO`0207moO`0300000009
jPX0Ogmo00T0Ogmo00<02NX:07moO`1oOgl03`1oOgl00`000000Ogmo07moO`0307moO`802NX:201o
Ogl01009jPX0Ogmo07moO`00000B07moO`030000003oool0oooo0580oooo00<000000?ooo`3oool0
3@3oool007l0oooo00<000000?ooo`3oool0BP3oool00`09jPX0oooo0?ooo`060?ooo`030000001o
Ogl0Ogmo01h0Ogmo00<0000007moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1o
Ogl0Ogmo00d0Ogmo0P09jPX607moO`030000001oOgl0Ogmo00X0Ogmo00<02NX:07moO`1oOgl09`1o
Ogl00`000000Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo0180Ogmo00D02NX:07moO`1oOgl0Ogmo
0000000O07moO`802NX:4@1oOgl01`09jPX0Ogmo07moO`1oOgl0000007moO`09jPX02@1oOgl00`09
jPX0Ogmo07moO`0A07moO`030000001oOgl0Ogmo00@0Ogmo0P09jPX507moO`0300WZ2P1oOgl0Ogmo
0080Ogmo0P00000?07moO`030000003oool0oooo05<0oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool0B@3oool00`09jPX0oooo0?ooo`080?ooo`030000001oOgl0Ogmo01`0
Ogmo00<0000007moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo0100
Ogmo0P09jPX507moO`8000002P1oOgl00`09jPX0Ogmo07moO`0W07moO`030000001oOgl0Ogmo00D0
Ogmo00<02NX:07moO`1oOgl0501oOgl01009jPX0Ogmo07moO`00000M07moO`802NX:501oOgl00`09
jPX0Ogmo0000000207moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl04@1oOgl00`00
0000Ogmo07moO`0607moO`802NX:0`1oOgl00`09jPX0Ogmo07moO`0407moO`030000001oOgl0Ogmo
00`0Ogmo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000
oooo0?ooo`190?ooo`0300WZ2P3oool0oooo00P0oooo00<0000007moO`1oOgl0701oOgl00`000000
Ogmo07moO`0507moO`0400WZ2P1oOgl02NX:00WZ2QD0Ogmo0P09jPX507moO`030000001oOgl0Ogmo
00P0Ogmo00<02NX:07moO`1oOgl09P1oOgl00`000000Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo
01@0Ogmo00<02NX:07moO`000000701oOgl200WZ2QH0Ogmo00<02NX:0000001oOgl00P1oOgl00`09
jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo0180Ogmo00<0000007moO`1oOgl0201oOgl300WZ
2PP0Ogmo0P00000<07moO`030000003oool0oooo05<0oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool0B03oool00`09jPX0oooo0?ooo`090?ooo`030000001oOgl0Ogmo01`0
Ogmo00<0000007moO`1oOgl01@1oOgl200WZ2QT0Ogmo0`09jPX307moO`030000001oOgl0Ogmo00L0
Ogmo00<02NX:07moO`1oOgl09`1oOgl00`000000Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo01D0
Ogmo00<02NX:07moO`0000006P1oOgl200WZ2QL0Ogmo00<0000007moO`09jPX00`1oOgl00`09jPX0
Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo01@0Ogmo00<0000007moO`1oOgl02@1oOgl300WZ2PP0
Ogmo0P00000907moO`030000003oool0oooo05@0oooo00<000000?ooo`3oool03@3oool007l0oooo
00<000000?ooo`3oool0B03oool00`09jPX0oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo01/0Ogmo
00<0000007moO`1oOgl01@1oOgl200WZ2Q`0Ogmo0P09jPX207moO`800000201oOgl00`09jPX0Ogmo
07moO`0V07moO`030000001oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl05@1oOgl00`09jPX0Ogmo
0000000H07moO`802NX:601oOgl010000000Ogmo07moO`09jPX307moO`0300WZ2P1oOgl0Ogmo00D0
Ogmo00<02NX:07moO`1oOgl0501oOgl00`000000Ogmo07moO`0807moO`0400WZ2P1oOgl0Ogmo07mo
O`802NX:201oOgl00`000000Ogmo07moO`0607moO`030000003oool0oooo05@0oooo00<000000?oo
o`3oool03@3oool007l0oooo00<000000?ooo`3oool0A`3oool00`09jPX0oooo0?ooo`0;0?ooo`03
0000001oOgl0Ogmo01/0Ogmo00<0000007moO`1oOgl0101oOgl01009jPX0Ogmo07moO`09jPXM07mo
O`802NX:0P1oOgl00`000000Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo02H0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0G07moO`0300WZ2P1oOgl0Ogmo01D0Ogmo0P09jPXH07mo
O`800000101oOgl01009jPX0Ogmo07moO`09jPX607moO`0300WZ2P1oOgl0Ogmo01H0Ogmo00<00000
07moO`1oOgl01`1oOgl00`09jPX0Ogmo07moO`0307moO`802NX:1`1oOgl2000000D0Ogmo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`160?oo
o`0300WZ2P3oool0oooo00d0oooo00<0000007moO`1oOgl06@1oOgl00`000000Ogmo07moO`0407mo
O`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl0701oOgl200WZ2P0307moO`000000Ogmo
00H0Ogmo00<02NX:07moO`1oOgl09P1oOgl01@000000Ogmo07moO`1oOgl02NX:01T0Ogmo00<02NX:
07moO`1oOgl04`1oOgl200WZ2QT0Ogmo00<0000007moO`1oOgl0101oOgl01009jPX0Ogmo07moO`09
jPX607moO`0300WZ2P1oOgl0Ogmo01H0Ogmo00<0000007moO`1oOgl01P1oOgl00`09jPX0Ogmo07mo
O`0607moO`802NX:1`1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo05D0oooo00<0
00000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0AP3oool00`09jPX0oooo0?ooo`0=
0?ooo`030000001oOgl0Ogmo01T0Ogmo00<0000007moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`04
07moO`0300WZ2P1oOgl0Ogmo01d0Ogmo0P09jPX2000000D0Ogmo00<02NX:07moO`1oOgl09P1oOgl0
10000000Ogmo07moO`09jPXJ07moO`0300WZ2P1oOgl0Ogmo0100Ogmo0`09jPXI07moO`800000201o
Ogl00`09jPX0Ogmo00WZ2P0507moO`0300WZ2P1oOgl0Ogmo01P0Ogmo00<0000007moO`1oOgl01@1o
Ogl00`09jPX0Ogmo07moO`0807moO`802NX:1P1oOgl200000080Ogmo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`150?ooo`0300WZ2P3oool0
oooo00l0oooo00<0000007moO`1oOgl0601oOgl010000000Ogmo07moO`1oOgl200WZ2PL0Ogmo00<0
2NX:07moO`1oOgl07`1oOgl300WZ2PD0Ogmo00<02NX:07moO`1oOgl09@1oOgl010000000Ogmo07mo
O`09jPXI07moO`030000001oOgl02NX:00l0Ogmo0P09jPXK07moO`030000001oOgl0Ogmo00P0Ogmo
00<02NX:07moO`09jPX0101oOgl00`09jPX0Ogmo07moO`0I07moO`030000001oOgl0Ogmo00@0Ogmo
00<02NX:07moO`1oOgl02`1oOgl200WZ2PH0Ogmo0P00001H0?ooo`030000003oool0oooo00d0oooo
001o0?ooo`030000003oool0oooo04D0oooo00<02NX:0?ooo`3oool03@3oool3000001X0Ogmo00@0
000007moO`1oOgl02NX:2P1oOgl00`09jPX0Ogmo07moO`0507moO`<02NX:6@1oOgl200WZ2P<0Ogmo
00<02NX:07moO`1oOgl09P1oOgl00`0000002NX:07moO`0I07moO`030000001oOgl02NX:00d0Ogmo
0P09jPXL07moO`030000001oOgl0Ogmo00X0Ogmo0P09jPX407moO`0300WZ2P1oOgl0Ogmo01X0Ogmo
00<0000007moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0=07moO`802NX:1@1oOgl2000005L0oooo
00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0A03oool00`09jPX0oooo0?oo
o`0<0?ooo`8000000P1oOgl00`000000Ogmo07moO`0H07moO`030000001oOgl02NX:00`0Ogmo00<0
2NX:0000000000001P09jPXK07moO`0300000009jPX02NX:0080Ogmo00<02NX:07moO`09jPX01009
jPXQ07moO`0300000009jPX0Ogmo01T0Ogmo00<0000007moO`09jPX02`1oOgl200WZ2Q`0Ogmo0P00
000=07moO`802NX:0`1oOgl00`09jPX0Ogmo07moO`0K07moO`030000001oOgl0Ogmo0080Ogmo00<0
2NX:07moO`1oOgl0401oOgl200WZ2PD0Ogmo0P00001E0?ooo`030000003oool0oooo00d0oooo001o
0?ooo`030000003oool0oooo04@0oooo00<02NX:0?ooo`3oool02`3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo01H0Ogmo00<0000007moO`09jPX03P1oOgl00`09jPX0000000WZ2P07
00WZ2Q/0Ogmo00<0000000WZ2P09jPX01P09jPXR07moO`0300WZ2P1oOgl0Ogmo01P0Ogmo00D00000
07moO`1oOgl0Ogmo00WZ2P0807moO`802NX:7@1oOgl00`000000Ogmo07moO`0=07moO`802NX:0P1o
Ogl00`09jPX0Ogmo07moO`0M07moO`050000001oOgl0Ogmo07moO`09jPX0501oOgl200WZ2PD0Ogmo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?oo
o`130?ooo`0300WZ2P3oool0oooo00X0oooo0P00000607moO`030000001oOgl0Ogmo01H0Ogmo00<0
000000WZ2P1oOgl04@1oOgl500WZ2P80Ogmo4@09jPX:07moO`<000001@09jPX00`1oOgl02NX:00WZ
2P0;00WZ2QD0Ogmo00<02NX:0000001oOgl0601oOgl01@000000Ogmo07moO`1oOgl02NX:00H0Ogmo
0P09jPXN07moO`030000001oOgl0Ogmo00l0Ogmo00@02NX:07moO`1oOgl02NX:7`1oOgl01@000000
Ogmo07moO`1oOgl02NX:01H0Ogmo0P09jPX407moO`800000DP3oool00`000000oooo0?ooo`0=0?oo
o`00O`3oool00`000000oooo0?ooo`120?ooo`0300WZ2P3oool0oooo00X0oooo00<0000007moO`1o
Ogl01`1oOgl00`000000Ogmo07moO`0E07moO`0300WZ2P1oOgl0Ogmo01D0Ogmo0P09jPXB07moOa<0
2NX:3@1oOgl>00WZ2PH0Ogmo00<02NX:07moO`0000006@1oOgl01@000000Ogmo07moO`1oOgl02NX:
00@0Ogmo0P09jPXN07moO`8000004P1oOgl00`09jPX0Ogmo00WZ2P0P07moO`040000001oOgl0Ogmo
00WZ2QT0Ogmo0P09jPX407moO`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool0
07l0oooo00<000000?ooo`3oool0@P3oool00`09jPX0oooo0?ooo`080?ooo`8000002P1oOgl00`00
0000Ogmo07moO`0607moO`l02NX:00<0000007moO`1oOgl0=`1oOgl00`0000002NX:07moO`0B00WZ
2P/0Ogmo3@09jPXE07moO`030000001oOgl0Ogmo0080Ogmo00@02NX:07moO`09jPX02NX:7`1oOgl0
0`000000Ogmo07moO`0C07moO`0300WZ2P1oOgl0Ogmo0200Ogmo00<0000007moO`09jPX06`1oOgl2
00WZ2P<0Ogmo0P00001?0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo
0440oooo00@02NX:0?ooo`3oool0oooo7@09jPX>07moO`800000>P1oOgl00`09jPX0000007moO`0A
07moOa802NX:0P1oOgl010000000Ogmo07moO`1oOgl>00WZ2PH0Ogmo00<0000007moO`1oOgl00`1o
Ogl200WZ2Ql0Ogmo0P00000F07moO`0300WZ2P1oOgl0Ogmo0200Ogmo00<0000000WZ2P1oOgl07@1o
Ogl200WZ2P<0Ogmo0P00001=0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0
oooo00<0oooo0`09jPXR0?oooad02NX:1@3oool00`000000Ogmo07moO`0=07moO`030000001oOgl0
Ogmo0180Ogmo00<02NX:0000001oOgl0>`1oOgl00`09jPX0000007moO`0P07moOa<02NX:0`1oOgl=
00WZ2Ql0Ogmo00<0000007moO`1oOgl05@1oOgl300WZ2R80Ogmo00<02NX:07moO`1oOgl07P1oOgl2
00WZ2P<0Ogmo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool20000
00H02NX:1P3ooolM00WZ2QP0oooo00<02NX:0?ooo`3oool01@3oool200000100Ogmo00<0000007mo
O`1oOgl04@1oOgl00`09jPX0Ogmo0000000l07moO`0300WZ2P1oOgl000000200Ogmo00D02NX:07mo
O`1oOgl0Ogmo0000000>07moOah02NX:401oOgl00`000000Ogmo07moO`0F07moO`<02NX:8@1oOgl0
0`09jPX0000007moO`0Q07moO`802NX:0P1oOgl2000004X0oooo00<000000?ooo`3oool03@3oool0
07l0oooo0P00000<00WZ2S@0oooo00<02NX:0?ooo`3oool01@3oool00`000000Ogmo07moO`0A07mo
O`030000001oOgl0Ogmo00l0Ogmo00@02NX:07moO`1oOgl00000?@1oOgl01009jPX0Ogmo00000000
000M07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0501oOgl200WZ2PH0Ogmo7009
jPX2000001P0Ogmo00D02NX:07moO`09jPX0Ogmo00WZ2P0P07moO`0300WZ2P1oOgl0000002<0Ogmo
0P09jPX207moO`030000003oool0oooo04L0oooo00<000000?ooo`3oool03@3oool007l0oooo00<0
00000?ooo`3oool01@09jPXj0?ooo`0300WZ2P3oool0oooo00<0oooo0P00000D07moO`030000001o
Ogl0Ogmo00h0Ogmo00D02NX:07moO`1oOgl0Ogmo0000000m07moO`0500WZ2P1oOgl0Ogmo07moO`00
0000701oOgl00`09jPX0Ogmo07moO`0307moO`030000001oOgl0Ogmo0140Ogmo0P09jPX00`000000
Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00l0Ogmo5`09jPX<07moO`0600WZ2P1oOgl0Ogmo00WZ
2P1oOgl02NX:7`1oOgl01009jPX0Ogmo07moO`00000U07moO`802NX:00<0Ogmo000000000000A`3o
ool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`040?ooo`802NX:>03oool0
0`09jPX0oooo0?ooo`030?ooo`030000001oOgl0Ogmo01@0Ogmo00<0000007moO`1oOgl03P1oOgl0
1@09jPX0Ogmo07moO`1oOgl0000003h0Ogmo00@02NX:07moO`1oOgl0Ogmo0P00000I07moO`0300WZ
2P1oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl03`1oOgl200WZ2P80Ogmo00<0000007moO`1oOgl0
1P1oOgl00`09jPX0Ogmo07moO`0F07moO`030000001oOgl0Ogmo00L0Ogmo4`09jPX01@1oOgl02NX:
07moO`1oOgl02NX:01h0Ogmo00D02NX:07moO`1oOgl0Ogmo0000000V07moO`802NX:00<0Ogmo0000
003oool0A@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0n0?ooo`04
00WZ2P3oool0oooo0?ooo`800000601oOgl00`000000Ogmo07moO`0<07moO`0500WZ2P1oOgl0Ogmo
07moO`000000?`1oOgl00`09jPX0Ogmo07moO`0307moO`030000001oOgl0Ogmo01H0Ogmo00<02NX:
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0=07moO`802NX:0`1oOgl00`000000Ogmo07moO`07
07moO`0300WZ2P1oOgl0Ogmo01@0Ogmo0P00000J07moOa802NX:201oOgl2000000T0Ogmo00<02NX:
07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0V07moO`802NX:0P0000140?ooo`030000003oool0
oooo00d0oooo001o0?ooo`030000003oool0oooo03d0oooo00<02NX:0?ooo`3oool00P00000J07mo
O`040000001oOgl0Ogmo07moO`<02NX:1`1oOgl00`09jPX0Ogmo07moO`0207moO`030000001oOgl0
Ogmo03h0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0D07moO`0300WZ2P1oOgl0
Ogmo00H0Ogmo00<0000007moO`1oOgl02P1oOgl200WZ2PD0Ogmo00<0000007moO`1oOgl01`1oOgl0
0`09jPX0Ogmo07moO`0C07moO`030000001oOgl0Ogmo01T0Ogmo00<02NX:07moO`1oOgl00P1oOgl0
1@09jPX0Ogmo07moO`1oOgl02NX:00L0Ogmo4@09jPX407moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl09`1oOgl200WZ2P800000@P3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool0
0`000000oooo0?ooo`0m0?ooo`0300WZ2P3oool0000001d0Ogmo00@0000007moO`1oOgl0Ogmo1P09
jPX207moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0?P1oOgl00`09jPX0Ogmo07mo
O`0407moO`800000501oOgl00`09jPX0Ogmo07moO`0607moO`030000001oOgl0Ogmo00P0Ogmo0P09
jPX707moO`030000001oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl0401oOgl2000001`0Ogmo00<0
2NX:07moO`1oOgl00P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:01D0Ogmo3P09jPX507moO`800000
901oOgl200WZ2P030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool000h0oooof`09
jPX00`0000002NX:00WZ2P0507moO`030000001oOgl0Ogmo03h0Ogmo00<02NX:07moO`1oOgl01P1o
Ogl00`000000Ogmo07moO`0@07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl01P1o
Ogl200WZ2PP0Ogmo00<0000007moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0?07moO`030000001o
Ogl0Ogmo01/0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1o
Ogl0Ogmo01P0Ogmo00<02NX:07moO`1oOgl0101oOgl700WZ2P0300000009jPX02NX:00802NX:8P1o
Ogl300WZ2Sl0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0>`3oool0
0`09jPX0000007moO`0O07moO`040000001oOgl0Ogmo07moO`D02NX:00@0Ogmo000000000000Ogmo
0P09jPX307moO`030000001oOgl0Ogmo03l0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`000000Ogmo
07moO`0?07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl00`1oOgl200WZ2PX0Ogmo
00<0000007moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0>07moO`030000001oOgl0Ogmo01/0Ogmo
00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo01L0Ogmo
00<02NX:07moO`1oOgl01P1oOgl00`000000Ogmo07moO`0807moO`X02NX:101oOgl2000001D0Ogmo
0P09jPXm0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo03X0oooo00<0
000000WZ2P1oOgl08@1oOgl010000000Ogmo00WZ2P09jPX:07moO`802NX:00<0000007moO`1oOgl0
@01oOgl00`09jPX0Ogmo07moO`0707moO`8000003P1oOgl00`09jPX0Ogmo07moO`0907moO`030000
001oOgl0Ogmo00<02NX:301oOgl00`000000Ogmo07moO`0:07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo
0P00000N07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo
07moO`0G07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl04P1oOgl500WZ2P030000
001oOgl0Ogmo01@0Ogmo00<0000000WZ2P09jPX0>`3oool00`000000oooo0?ooo`0=0?ooo`00O`3o
ool00`000000oooo0?ooo`0h0?ooo`80000000<02NX:07moO`1oOgl08@1oOgl00`000000Ogmo07mo
O`0=07moO`802NX:@P1oOgl00`09jPX0Ogmo07moO`0807moO`030000001oOgl0Ogmo00/0Ogmo00<0
2NX:07moO`1oOgl02@1oOgl00`0000002NX:00WZ2P0>07moO`030000001oOgl0Ogmo00/0Ogmo00<0
2NX:07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0M07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<0
2NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0F07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<0
000007moO`1oOgl05@1oOgl00`09jPX0Ogmo07moO`0G07moO`0300000009jPX02NX:03T0oooo00<0
00000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0=`3oool010000000Ogmo07moO`09
jPXT07moO`030000001oOgl0Ogmo00`0Ogmo00@0000007moO`09jPX02NX:@01oOgl00`09jPX0Ogmo
07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl02@1oOgl200WZ2P030000
001oOgl0Ogmo00d0Ogmo00<0000007moO`1oOgl02`1oOgl00`09jPX0Ogmo07moO`0907moO`030000
001oOgl0Ogmo01h0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ
2P1oOgl0Ogmo01D0Ogmo00<02NX:07moO`1oOgl0201oOgl00`000000Ogmo07moO`0E07moO`802NX:
6P1oOgl00`0000002NX:00WZ2P0g0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003o
ool0oooo03D0oooo0P00000207moO`0300WZ2P1oOgl0Ogmo02<0Ogmo00<0000007moO`1oOgl0301o
Ogl010000000Ogmo07moO`1oOgl300WZ2Sh0Ogmo00<02NX:07moO`1oOgl02@1oOgl2000000T0Ogmo
00<02NX:07moO`1oOgl01`1oOgl200WZ2P80Ogmo00<0000007moO`1oOgl03@1oOgl00`000000Ogmo
07moO`0;07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo0P00000P07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo
00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0D07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl0501oOgl200WZ2Q/0Ogmo0P00000200WZ2SD0oooo00<000000?ooo`3oool0
3@3oool007l0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0207moO`0300WZ2P1o
Ogl0Ogmo02<0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0407moO`802NX:?01o
Ogl00`09jPX0Ogmo07moO`0;07moO`030000001oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl01P1o
Ogl200WZ2P@0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0=07moO`0300WZ2P1o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl07`1oOgl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1o
Ogl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl04`1oOgl00`09jPX0Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo01@0Ogmo0P09jPXM07moO`040000003oool02NX:00WZ2S<0oooo00<000000?ooo`3oool0
3@3oool007l0oooo00<000000?ooo`3oool0<P3oool2000000@0Ogmo00<02NX:07moO`1oOgl09@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00L0Ogmo0P09jPXk07moO`0300WZ2P1o
Ogl0Ogmo00/0Ogmo0P00000507moO`0300WZ2P1oOgl0Ogmo00@0Ogmo0P09jPX707moO`030000001o
Ogl0Ogmo00/0Ogmo00<0000007moO`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0307moO`8000008P1o
Ogl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl04P1o
Ogl00`09jPX0Ogmo07moO`0;07moO`030000001oOgl0Ogmo0180Ogmo1009jPXM07moO`80000000<0
oooo00WZ2P09jPX0<@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0a
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl09P1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo0P09jPXi07moO`0300WZ2P1oOgl0Ogmo00d0Ogmo00D00000
07moO`1oOgl0Ogmo00WZ2P0507moO`802NX:2@1oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00d0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0Q07moO`0300WZ2P1o
Ogl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0A07moO`0300WZ2P1o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl04P1oOgl400WZ2Ql0Ogmo00<000000?ooo`3oool00P09
jPX_0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo02l0oooo0P000006
07moO`0300WZ2P1oOgl0Ogmo02L0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0;
07moO`802NX:>01oOgl00`09jPX0Ogmo07moO`0=07moO`040000001oOgl0Ogmo00WZ2P<0Ogmo0P09
jPX;07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl03`1oOgl01009jPX0Ogmo07mo
O`00000S07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09jPX0Ogmo
07moO`0@07moO`0300WZ2P1oOgl0Ogmo00d0Ogmo00<0000007moO`1oOgl04@1oOgl200WZ2P0307mo
O`09jPX0Ogmo01l0Ogmo0P0000020?ooo`802NX:;@3oool00`000000oooo0?ooo`0=0?ooo`00O`3o
ool00`000000oooo0?ooo`0]0?ooo`8000001`1oOgl00`09jPX0Ogmo07moO`0X07moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl03@1oOgl200WZ2SH0Ogmo00<02NX:07moO`1oOgl03P1o
Ogl0100000002NX:07moO`1oOgl200WZ2Ph0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0?07moO`0300WZ2P000000000002@0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX0Ogmo
07moO`0607moO`0300WZ2P1oOgl0Ogmo00l0Ogmo00<02NX:07moO`1oOgl03P1oOgl00`000000Ogmo
07moO`0A07moO`0500WZ2P1oOgl02NX:07moO`09jPX08@1oOgl200000080oooo0P09jPX[0?ooo`03
0000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo02`0oooo00<0000007moO`1oOgl0
1`1oOgl00`09jPX0Ogmo07moO`0X07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
3`1oOgl200WZ2SD0Ogmo00<02NX:07moO`1oOgl03P1oOgl300WZ2Q00Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0?07moO`0300WZ2P1oOgl0Ogmo02<0Ogmo00<02NX:07moO`1oOgl0
2`1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00<02NX:07moO`1oOgl0
3`1oOgl00`000000Ogmo07moO`0B07moO`0300WZ2P1oOgl0Ogmo02<0Ogmo00@000000?ooo`3oool0
oooo0P09jPXY0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo02X0oooo
0P00000907moO`0300WZ2P1oOgl0Ogmo02X0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo
07moO`0B07moO`802NX:<`1oOgl00`09jPX0Ogmo07moO`0<07moO`<02NX:00<0Ogmo0000001oOgl0
3`1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00h0Ogmo00<0000007moO`09jPX0
8`1oOgl00`09jPX0Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl0
3@1oOgl00`09jPX0Ogmo07moO`0@07moO`030000001oOgl0Ogmo0180Ogmo00<02NX:07moO`1oOgl0
901oOgl2000000<0oooo0P09jPXW0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003o
ool0oooo02T0oooo00<0000007moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0Z07moO`030000001o
Ogl0Ogmo00L0Ogmo00<0000007moO`1oOgl0501oOgl200WZ2S80Ogmo00<02NX:07moO`1oOgl02@1o
Ogl200WZ2P0307moO`09jPX0Ogmo0080Ogmo0P00000?07moO`030000001oOgl0Ogmo00L0Ogmo00<0
000007moO`1oOgl03@1oOgl200000080Ogmo00<02NX:07moO`1oOgl08@1oOgl00`09jPX0Ogmo07mo
O`0<07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl0301oOgl00`09jPX0Ogmo07mo
O`0@07moO`030000001oOgl0Ogmo0180Ogmo00<02NX:07moO`1oOgl09P1oOgl00`000000oooo0?oo
o`020?ooo`802NX:9@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0W
0?ooo`8000002`1oOgl00`09jPX0Ogmo07moO`0/07moO`030000001oOgl0Ogmo00H0Ogmo00<00000
07moO`1oOgl05P1oOgl200WZ2S00Ogmo00<02NX:07moO`1oOgl01`1oOgl200WZ2P<0Ogmo00<02NX:
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00L0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo0200Ogmo00<02NX:
07moO`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<02NX:
07moO`1oOgl04P1oOgl00`000000Ogmo07moO`0A07moO`0300WZ2P1oOgl0Ogmo02L0Ogmo0P000004
0?ooo`802NX:8`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0U0?oo
o`800000301oOgl00`09jPX0Ogmo07moO`0]07moO`030000001oOgl0Ogmo00H0Ogmo00<0000007mo
O`1oOgl0601oOgl300WZ2Rh0Ogmo00<02NX:07moO`1oOgl0101oOgl200WZ2P@0Ogmo00<02NX:07mo
O`1oOgl01@1oOgl2000000`0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0;07mo
O`030000001oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl07`1oOgl00`09jPX0Ogmo07moO`0=07mo
O`0300WZ2P1oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`09jPX0Ogmo07moO`0B07mo
O`030000001oOgl0Ogmo0140Ogmo00<02NX:07moO`1oOgl0:@1oOgl2000000@0oooo0P09jPXQ0?oo
o`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo02@0oooo00<0000007moO`1o
Ogl0301oOgl00`09jPX0Ogmo07moO`0^07moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl06`1oOgl200WZ2R`0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2PH0Ogmo00<02NX:07moO`1o
Ogl01`1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl02P1oOgl2000000L0Ogmo00<02NX:07moO`1oOgl07P1oOgl00`09jPX0Ogmo07moO`0>07moO`03
00WZ2P1oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0D07moO`03
0000001oOgl0Ogmo0100Ogmo00<02NX:07moO`1oOgl0:`1oOgl00`000000oooo0?ooo`030?ooo`80
2NX:7`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0R0?ooo`800000
3P1oOgl00`09jPX0Ogmo07moO`0_07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
7P1oOgl200WZ2R/0Ogmo00@02NX:07moO`09jPX02NX:1`1oOgl00`09jPX0Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl07@1oOgl00`09jPX0Ogmo07moO`0?07moO`03
00WZ2P1oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0D07moO`03
0000001oOgl0Ogmo0100Ogmo00<02NX:07moO`1oOgl0;01oOgl2000000D0oooo0P09jPXM0?ooo`03
0000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl0
3P1oOgl00`09jPX0Ogmo07moO`0_07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
801oOgl200WZ2RT0Ogmo0P09jPX907moO`0300WZ2P1oOgl0Ogmo00X0Ogmo0P00000907moO`030000
001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl01`1oOgl2000000/0Ogmo00<02NX:07moO`1oOgl0
701oOgl00`09jPX0Ogmo07moO`0?07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl0
201oOgl00`09jPX0Ogmo07moO`0E07moO`030000001oOgl0Ogmo00l0Ogmo00<02NX:07moO`1oOgl0
;P1oOgl00`000000oooo0?ooo`040?ooo`802NX:6`3oool00`000000oooo0?ooo`0=0?ooo`00O`3o
ool00`000000oooo0?ooo`0O0?ooo`800000401oOgl00`09jPX0Ogmo07moO`0a07moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl08P1oOgl200WZ2RD0Ogmo0P09jPX00`1oOgl02NX:07mo
O`0707moO`0300WZ2P1oOgl0Ogmo00d0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl02`1oOgl00`09jPX0Ogmo07mo
O`0K07moO`0300WZ2P1oOgl0Ogmo0100Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX0Ogmo07mo
O`0707moO`0300WZ2P1oOgl0Ogmo01H0Ogmo00<0000007moO`1oOgl03`1oOgl00`09jPX0Ogmo07mo
O`0_07moO`8000001P3oool200WZ2QT0oooo00<000000?ooo`3oool03@3oool007l0oooo00<00000
0?ooo`3oool07@3oool200000180Ogmo00<02NX:07moO`1oOgl0<@1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo02@0Ogmo0P09jPXQ07moO`802NX:0`1oOgl00`09jPX0Ogmo07moO`06
07moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0J
07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo1@09jPX207moO`0300000009jPX0Ogmo00/0Ogmo00<02NX:
07moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0G07moO`030000001oOgl0Ogmo00h0Ogmo00<02NX:
07moO`1oOgl0<@1oOgl2000000H0oooo0P09jPXG0?ooo`030000003oool0oooo00d0oooo001o0?oo
o`030000003oool0oooo01`0oooo00<0000007moO`1oOgl04@1oOgl00`09jPX0Ogmo07moO`0c07mo
O`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl09P1oOgl200WZ2Qd0Ogmo0P09jPX607mo
O`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl0401oOgl2000000H0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`800000401oOgl00`09jPX0Ogmo07moO`0I07mo
O`0300WZ2P1oOgl0Ogmo00X0Ogmo1P09jPX00`0000002NX:07moO`0;07moO`0300WZ2P1oOgl0Ogmo
00D0Ogmo00<02NX:07moO`1oOgl0601oOgl00`000000Ogmo07moO`0>07moO`0300WZ2P1oOgl0Ogmo
03<0Ogmo00<000000?ooo`3oool01@3oool300WZ2Q@0oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool06P3oool2000001<0Ogmo00<02NX:07moO`1oOgl0=01oOgl01@000000
Ogmo07moO`1oOgl0000002/0Ogmo0P09jPXH07moO`<02NX:201oOgl00`09jPX0Ogmo07moO`0407mo
O`0300WZ2P1oOgl0Ogmo0180Ogmo00<0000007moO`1oOgl0101oOgl01@000000Ogmo07moO`1oOgl0
000000H0Ogmo00<0000007moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0H07moO`0300WZ2P1oOgl0
Ogmo00X0Ogmo1`09jPX?07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl06@1oOgl0
0`000000Ogmo07moO`0=07moO`0300WZ2P1oOgl0Ogmo03@0Ogmo0P0000080?ooo`802NX:4P3oool0
0`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0I0?ooo`030000001oOgl0Ogmo
01<0Ogmo00<02NX:07moO`1oOgl0=01oOgl01@000000Ogmo07moO`1oOgl0000002d0Ogmo0P09jPXD
07moO`802NX:2`1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo01@0Ogmo00<00000
07moO`1oOgl00`1oOgl01@000000Ogmo07moO`1oOgl0000000D0Ogmo00<0000007moO`1oOgl04@1o
Ogl00`09jPX0Ogmo07moO`0G07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo1@09jPX0101oOgl02NX:00WZ
2P09jPXB07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl06P1oOgl00`000000Ogmo
07moO`0=07moO`0300WZ2P1oOgl0Ogmo03H0Ogmo00<000000?ooo`3oool01`3oool200WZ2Q00oooo
00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool05`3oool2000001D0Ogmo00<0
2NX:07moO`1oOgl0=P1oOgl010000000Ogmo07moO`00000_07moO`802NX:401oOgl200WZ2Ph0Ogmo
00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0E07moO`8000000`1oOgl01@000000Ogmo
07moO`1oOgl0000000<0Ogmo0P00000E07moO`0300WZ2P1oOgl0Ogmo01H0Ogmo00@02NX:07moO`1o
Ogl0Ogmo1@09jPX507moO`0300WZ2P1oOgl0Ogmo01@0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09
jPX0Ogmo07moO`0J07moO`030000001oOgl0Ogmo00h0Ogmo00<02NX:07moO`1oOgl0=P1oOgl20000
00T0oooo0P09jPX>0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo01H0
oooo00<0000007moO`1oOgl05@1oOgl00`09jPX0Ogmo07moO`0f07moO`040000001oOgl0Ogmo0000
0340Ogmo0`09jPX;07moO`802NX:401oOgl01@09jPX0Ogmo07moO`1oOgl02NX:01X0Ogmo00L00000
07moO`1oOgl0Ogmo0000001oOgl0000000<0Ogmo00<0000007moO`1oOgl05@1oOgl00`09jPX0Ogmo
07moO`0D07moO`H02NX:8@1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:01h0Ogmo00<0000007moO`1o
Ogl03@1oOgl00`09jPX0Ogmo07moO`0h07moO`030000003oool0oooo00P0oooo0P09jPX<0?ooo`03
0000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo01@0oooo0P00000G07moO`0300WZ
2P1oOgl0Ogmo03P0Ogmo00<0000007moO`000000=01oOgl200WZ2PL0Ogmo0P09jPXC07moO`0400WZ
2P1oOgl0Ogmo00WZ2Q/0Ogmo0P0000001@1oOgl0000007moO`000000Ogmo00800000601oOgl00`09
jPX0Ogmo07moO`0?07moO`D02NX:00<0Ogmo00WZ2P1oOgl09@1oOgl01009jPX0Ogmo07moO`09jPXN
07moO`030000001oOgl0Ogmo00d0Ogmo00<02NX:07moO`1oOgl0>@1oOgl2000000X0oooo0P09jPX:
0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo0180oooo0P00000H07mo
O`0300WZ2P1oOgl0Ogmo03T0Ogmo0P00000g07moO`802NX:0`1oOgl200WZ2QD0Ogmo00<02NX:07mo
O`09jPX07P1oOgl20000000307moO`000000000001X0Ogmo00<02NX:07moO`1oOgl02P1oOgl500WZ
2PD0Ogmo00<02NX:07moO`1oOgl09@1oOgl00`09jPX0Ogmo00WZ2P0P07moO`030000001oOgl0Ogmo
00`0Ogmo00<02NX:07moO`1oOgl0>`1oOgl2000000X0oooo0P09jPX20?ooo`802NX:103oool00`00
0000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0A0?ooo`030000001oOgl0Ogmo01P0
Ogmo00<02NX:07moO`1oOgl0>@1oOgl2000003T0Ogmo0`09jPXH07moO`802NX:7`1oOgl3000001`0
Ogmo00<02NX:07moO`1oOgl0101oOgl500WZ2PT0Ogmo00<02NX:07moO`1oOgl09`1oOgl200WZ2R00
Ogmo00<0000007moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0m07moO`030000003oool0oooo00T0
oooo1@09jPX30?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo0100oooo
6`0000000`09jPX000000000001d000000802NX:00<0000000WZ2P09jPX05`0000000`09jPX00000
0000000m0000000300WZ2P0000002NX:00@02NX:3P0000000`09jPX000000000000W0000000300WZ
2P0000000000024000003@1oOgl00`09jPX0Ogmo07moO`0m07moO`800000303oool400WZ2P80oooo
00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool04P3oool00`000000Ogmo07mo
O`0F07moO`0300WZ2P1oOgl0Ogmo03/0Ogmo00<0000007moO`1oOgl0=01oOgl200WZ2PD0Ogmo0P09
jPXE07moO`802NX:7P1oOgl01@000000Ogmo0000001oOgl0000001L0Ogmo1P09jPXB07moO`0300WZ
2P1oOgl0Ogmo02P0Ogmo0P09jPXQ07moO`030000001oOgl0Ogmo00/0Ogmo00<02NX:07moO`1oOgl0
?01oOgl00`000000oooo0?ooo`0<0?ooo`D02NX:00<0oooo0000003oool03P3oool007l0oooo00<0
00000?ooo`3oool04`3oool2000001D0Ogmo00<02NX:07moO`1oOgl0>`1oOgl2000003@0Ogmo0P09
jPX907moO`802NX:4P1oOgl00`09jPX0Ogmo00WZ2P0M07moO`040000001oOgl0Ogmo00000080Ogmo
00<0000007moO`1oOgl03`1oOgl500WZ2PD0Ogmo00<02NX:07moO`1oOgl03`1oOgl00`09jPX0Ogmo
07moO`0X07moO`0300WZ2P1oOgl02NX:0200Ogmo00<0000007moO`1oOgl0301oOgl00`09jPX0Ogmo
07moO`0j07moO`8000003@3oool800WZ2P030000003oool0oooo00d0oooo001o0?ooo`030000003o
ool0oooo01D0oooo0P00000C07moO`0300WZ2P1oOgl0Ogmo03/0Ogmo00<0000007moO`000000<01o
Ogl300WZ2Pd0Ogmo0P09jPX@07moO`0400WZ2P1oOgl0Ogmo00WZ2QX0Ogmo0P00000207moO`030000
001oOgl000000080Ogmo0P00000:07moO`D02NX:2P1oOgl00`09jPX0Ogmo07moO`0?07moO`0300WZ
2P1oOgl0Ogmo02P0Ogmo00@02NX:07moO`1oOgl02NX:7`1oOgl00`000000Ogmo07moO`0<07moO`03
00WZ2P1oOgl0Ogmo03P0Ogmo0P00000D0?ooo`<02NX:0P00000>0?ooo`00O`3oool00`000000oooo
0?ooo`0G0?ooo`030000001oOgl0Ogmo00l0Ogmo00<02NX:07moO`1oOgl0?01oOgl00`000000Ogmo
0000000^07moO`802NX:4P1oOgl200WZ2Pd0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0I07moO`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`000000101oOgl00`000000Ogmo07moO`0207moO`D0
2NX:3`1oOgl00`09jPX0Ogmo07moO`0>07moO`0300WZ2P1oOgl0Ogmo02T0Ogmo00@02NX:07moO`1o
Ogl02NX:7P1oOgl00`000000Ogmo07moO`0=07moO`0300WZ2P1oOgl0Ogmo03L0Ogmo00<000000?oo
o`3oool05`3oool2000000h0oooo001o0?ooo`030000003oool0oooo01P0oooo0P00000>07moO`03
00WZ2P1oOgl0Ogmo03`0Ogmo00@0000007moO`1oOgl00000;01oOgl200WZ2QH0Ogmo0P09jPX;07mo
O`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl0501oOgl2000000D0Ogmo00<0000007mo
O`0000000`1oOgl600WZ2QD0Ogmo00<02NX:07moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0Y07mo
O`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl06`1oOgl00`000000Ogmo07moO`0=07mo
O`0300WZ2P1oOgl0Ogmo03D0Ogmo0P00000J0?ooo`030000003oool0oooo00d0oooo001o0?ooo`03
0000003oool0oooo01X0oooo00<0000007moO`1oOgl02`1oOgl00`09jPX0Ogmo07moO`0l07moO`04
0000001oOgl0Ogmo000002X0Ogmo0P09jPXJ07moO`<02NX:1`1oOgl00`09jPX0Ogmo07moO`0307mo
O`0300WZ2P1oOgl0Ogmo01<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo00WZ2P0400WZ
2P@0Ogmo00<0000007moO`1oOgl0501oOgl00`09jPX0Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo
02T0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0J07moO`030000001oOgl0Ogmo
00h0Ogmo00<02NX:07moO`1oOgl0=01oOgl00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00d0oooo001o0?ooo`030000003oool0oooo01/0oooo0P00000:07moO`0300WZ2P1oOgl0Ogmo03`0
Ogmo00D0000007moO`1oOgl0Ogmo0000000X07moO`802NX:7`1oOgl200WZ2PD0Ogmo00<02NX:07mo
O`1oOgl0101oOgl00`09jPX0Ogmo07moO`0A07moO`030000001oOgl0Ogmo0080Ogmo1@09jPX207mo
O`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl04`1oOgl00`09jPX0Ogmo07moO`0;07mo
O`0300WZ2P1oOgl0Ogmo02T0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0J07mo
O`030000001oOgl0Ogmo00h0Ogmo00<02NX:07moO`1oOgl0<P1oOgl2000001d0oooo00<000000?oo
o`3oool03@3oool007l0oooo00<000000?ooo`3oool07@3oool00`000000Ogmo07moO`0707moO`03
00WZ2P1oOgl0Ogmo03`0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0S07moO`80
2NX:8`1oOgl200WZ2P<0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0?07moO`80
00001@09jPX307moO`050000001oOgl0Ogmo07moO`000000201oOgl2000001@0Ogmo00<02NX:07mo
O`1oOgl02P1oOgl00`09jPX0Ogmo07moO`0Y07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07mo
O`1oOgl06@1oOgl00`000000Ogmo07moO`0>07moO`0300WZ2P1oOgl0Ogmo0340Ogmo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0N0?ooo`80
00001P1oOgl00`09jPX0Ogmo07moO`0m07moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1o
Ogl08@1oOgl200WZ2RL0Ogmo0`09jPX807moO`0300WZ2P1oOgl0Ogmo00/0Ogmo1@09jPX707moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0A07moO`03
00WZ2P1oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl0:@1oOgl00`09jPX0Ogmo07moO`0507moO`03
00WZ2P1oOgl0Ogmo01P0Ogmo00<0000007moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0^07moO`80
0000803oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0P0?ooo`800000
101oOgl00`09jPX0Ogmo07moO`0l07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
7`1oOgl200WZ2R/0Ogmo0P09jPX707moO`0300WZ2P1oOgl0Ogmo00P0Ogmo0`09jPX2000000X0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo0100Ogmo
00<02NX:07moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0Z07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo
00<02NX:07moO`1oOgl05`1oOgl00`000000Ogmo07moO`0@07moO`0300WZ2P1oOgl0Ogmo02`0Ogmo
0P00000R0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo0280oooo00@0
000007moO`1oOgl02NX:?`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo01d0Ogmo
0P09jPX/07moO`0300WZ2P1oOgl0Ogmo00802NX:1P1oOgl00`09jPX0Ogmo07moO`0707moO`<00000
301oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00T0Ogmo0P00000A07moO`0300WZ
2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl0:@1oOgl00`09jPX0Ogmo07moO`0707moO`0300WZ
2P1oOgl0Ogmo01H0Ogmo00<0000007moO`1oOgl04@1oOgl00`09jPX0Ogmo07moO`0[07moO`030000
003oool0oooo0280oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool08`3o
ool00`0000002NX:07moO`0n07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl06`1o
Ogl200WZ2Rh0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2P@0Ogmo00<02NX:07moO`1oOgl01`1o
Ogl00`09jPX0000007moO`0;07moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0>07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl0:P1o
Ogl00`09jPX0Ogmo07moO`0807moO`0300WZ2P1oOgl0Ogmo01D0Ogmo00<0000007moO`1oOgl04@1o
Ogl00`09jPX0Ogmo07moO`0Y07moO`8000009@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool0
0`000000oooo0?ooo`0T0?ooo`0300WZ2P000000Ogmo03d0Ogmo00<0000007moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0G07moO`<02NX:;`1oOgl00`09jPX0Ogmo07moO`0507moO`802NX:0`1oOgl0
0`09jPX0Ogmo07moO`0507moO`0300000009jPX0Ogmo00`0Ogmo00<0000007moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0;07moO`8000003P1oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0
Ogmo02X0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0D07moO`030000001oOgl0
Ogmo0180Ogmo00<02NX:07moO`1oOgl0:01oOgl00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00d0oooo001o0?ooo`030000003oool0oooo02<0oooo00<02NX:0?ooo`3oool00P00000k07mo
O`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl05@1oOgl200WZ2S80Ogmo00<02NX:07mo
O`1oOgl01`1oOgl200WZ2P0307moO`09jPX02NX:00P02NX:00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0507moO`030000001oOgl0Ogmo00d0Ogmo00<0000007moO`1oOgl0301oOgl01@09
jPX0Ogmo07moO`1oOgl02NX:0080Ogmo00<02NX:07moO`1oOgl0:P1oOgl00`09jPX0Ogmo07moO`0:
07moO`0300WZ2P1oOgl0Ogmo01<0Ogmo00<0000007moO`1oOgl04@1oOgl00`0000002NX:07moO`0W
07moO`800000:03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0S0?oo
o`0300WZ2P3oool0oooo0080oooo0P00000i07moO`030000001oOgl0Ogmo00H0Ogmo00<0000007mo
O`1oOgl04`1oOgl200WZ2S<0Ogmo00<02NX:07moO`1oOgl02P1oOgl900WZ2P0307moO`0000000000
00/0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0=07moO`030000001oOgl0Ogmo
00/0Ogmo00L02NX:07moO`1oOgl0Ogmo00WZ2P1oOgl02NX:02`0Ogmo00<02NX:07moO`1oOgl02`1o
Ogl00`09jPX0Ogmo07moO`0B07moO`030000001oOgl0Ogmo0180Ogmo00<0000000WZ2P1oOgl09@1o
Ogl2000002X0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool08P3oool0
0`09jPX0oooo0?ooo`050?ooo`030000001oOgl0Ogmo03H0Ogmo00<0000007moO`1oOgl01P1oOgl0
0`000000Ogmo07moO`0A07moO`802NX:=@1oOgl00`09jPX0Ogmo07moO`0807moO`T02NX:401oOgl0
0`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00h0Ogmo0P00000;07moO`0400WZ2P1oOgl0
Ogmo07moO`D02NX::P1oOgl00`09jPX0Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo0140Ogmo00<0
000007moO`1oOgl04`1oOgl00`09jPX0Ogmo07moO`0S07moO`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool08P3oool00`09jPX0oooo0?ooo`06
0?ooo`800000=@1oOgl00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00l0Ogmo0P09jPXf
07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo1@09jPX407moO`D02NX:401oOgl00`000000Ogmo07moO`07
07moO`030000001oOgl0Ogmo0100Ogmo00<0000007moO`1oOgl02@1oOgl00`09jPX0Ogmo00WZ2P03
00WZ2R/0Ogmo00<02NX:07moO`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0@07moO`030000001oOgl0
Ogmo01<0Ogmo0P09jPXS07moO`800000;@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`00
0000oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo00T0oooo00<0000007moO`1oOgl0<P1oOgl00`00
0000Ogmo07moO`0807moO`030000001oOgl0Ogmo00`0Ogmo0P09jPXh07moO`0300WZ2P1oOgl0Ogmo
00@02NX:2@1oOgl00`0000002NX:07moO`0207moO`802NX:3@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo0100Ogmo00<0000007moO`1oOgl0201oOgl00`09jPX0Ogmo00WZ2P0200WZ
2R`0Ogmo00<02NX:07moO`1oOgl03P1oOgl00`09jPX0Ogmo07moO`0?07moO`030000001oOgl0Ogmo
01<0Ogmo0P09jPXR07moO`030000003oool0oooo02d0oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool0803oool00`09jPX0oooo0?ooo`0;0?ooo`800000<@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo0P09jPXh07moO`D02NX:301oOgl00`000000
Ogmo00WZ2P0507moO`802NX:2`1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo0140
Ogmo0P00000807moO`0400WZ2P1oOgl02NX:00WZ2Rd0Ogmo00<02NX:07moO`1oOgl03P1oOgl00`09
jPX0Ogmo07moO`0?07moO`030000001oOgl0Ogmo0180Ogmo0`09jPXP07moO`800000<03oool00`00
0000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo00d0
oooo0P00000_07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0201oOgl200WZ2SD0
Ogmo1@09jPX00`1oOgl02NX:07moO`0=07moO`050000001oOgl0Ogmo07moO`09jPX01P1oOgl200WZ
2PT0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0C07moO`030000001oOgl0Ogmo
00H0Ogmo0P09jPX]07moO`0300WZ2P1oOgl0Ogmo0100Ogmo00<02NX:07moO`1oOgl03@1oOgl00`00
0000Ogmo07moO`0B07moO`@02NX:7P1oOgl200000380oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0@0?ooo`030000001oOgl0Ogmo02`0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0607moO`802NX:<`1oOgl400WZ2PD0
Ogmo00<02NX:07moO`1oOgl02`1oOgl2000000@0Ogmo00<02NX:07moO`1oOgl01P1oOgl200WZ2PH0
Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0C07moO`030000001oOgl0Ogmo00@0
Ogmo00<0000000WZ2P1oOgl0;@1oOgl00`09jPX0Ogmo07moO`0@07moO`0300WZ2P1oOgl0Ogmo00d0
Ogmo00<0000007moO`1oOgl04P1oOgl400WZ2Qd0Ogmo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo0140oooo
0P00000[07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0101oOgl200WZ2S00Ogmo
1@09jPX907moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl01@1oOgl00`09jPX0Ogmo
07moO`0707moO`802NX:101oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo01@0Ogmo
0P00000407moO`0300WZ2P000000Ogmo02`0Ogmo00<02NX:07moO`1oOgl04@1oOgl00`09jPX0Ogmo
07moO`0<07moO`030000001oOgl0Ogmo0180Ogmo0P09jPX00`1oOgl02NX:00WZ2P0K07moO`800000
=@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0N0?ooo`0300WZ2P3o
ool0oooo01@0oooo00<0000007moO`1oOgl0:01oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00<02NX:;@1oOgl500WZ2Pd0Ogmo00<02NX:07moO`1oOgl02@1oOgl2000000P0Ogmo00<0
2NX:07moO`1oOgl02@1oOgl200WZ2P80Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07mo
O`0F07moO`040000001oOgl0Ogmo00WZ2Rl0Ogmo00<02NX:07moO`1oOgl04P1oOgl00`09jPX0Ogmo
07moO`0;07moO`030000001oOgl0Ogmo01@0Ogmo00<02NX:07moO`09jPX06P1oOgl00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo01h0oooo00<0
2NX:0?ooo`3oool05@3oool2000002L0Ogmo00<0000007moO`1oOgl0301oOgl00`0000002NX:00WZ
2P0[07moO`D02NX:4P1oOgl00`09jPX0Ogmo07moO`0807moO`030000001oOgl0Ogmo00T0Ogmo00<0
2NX:07moO`1oOgl02P1oOgl200WZ2Pl0Ogmo00<0000007moO`1oOgl05P1oOgl00`0000002NX:07mo
O`0^07moO`0300WZ2P1oOgl0Ogmo01<0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0E07moO`0300WZ2P1oOgl0Ogmo01P0Ogmo0P00000h0?ooo`030000003oool0oooo00d0oooo001o
0?ooo`030000003oool0oooo01d0oooo00<02NX:0?ooo`3oool0603oool00`000000Ogmo07moO`0T
07moO`030000001oOgl0Ogmo00/0Ogmo0P09jPXY07moO`@02NX:5P1oOgl00`09jPX0Ogmo07moO`08
07moO`030000001oOgl0Ogmo00X0Ogmo00<02NX:07moO`1oOgl02`1oOgl0100000002NX:00WZ2P09
jPX<07moO`030000001oOgl0Ogmo01H0Ogmo00<02NX:07moO`000000;P1oOgl00`09jPX0Ogmo07mo
O`0D07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl05@1oOgl00`09jPX0Ogmo07mo
O`0G07moO`030000003oool0oooo03P0oooo00<000000?ooo`3oool03@3oool007l0oooo00<00000
0?ooo`3oool0703oool00`09jPX0oooo0?ooo`0J0?ooo`800000901oOgl0100000002NX:00WZ2P09
jPX807moO`802NX:00<0Ogmo0000001oOgl08`1oOgl500WZ2QX0Ogmo00<02NX:07moO`1oOgl01P1o
Ogl2000000h0Ogmo00<02NX:07moO`1oOgl02P1oOgl010000000Ogmo07moO`1oOgl200WZ2PX0Ogmo
00<0000007moO`1oOgl05@1oOgl01@09jPX0Ogmo07moO`1oOgl0000002`0Ogmo00<02NX:07moO`1o
Ogl05@1oOgl00`09jPX0Ogmo07moO`0807moO`030000001oOgl0Ogmo01H0Ogmo00<02NX:07moO`1o
Ogl05@1oOgl2000003/0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0
703oool00`09jPX0oooo0?ooo`0L0?ooo`8000008@1oOgl00`0000002NX:00WZ2P02000000@02NX:
0P00000200WZ2P<0Ogmo00<0000007moO`1oOgl07@1oOgl500WZ2Qh0Ogmo00<02NX:07moO`1oOgl0
1P1oOgl00`000000Ogmo07moO`0>07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
101oOgl200WZ2PP0Ogmo00<0000007moO`1oOgl0501oOgl00`09jPX0Ogmo07moO`0307moO`800000
:P1oOgl00`09jPX0Ogmo07moO`0F07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl0
5P1oOgl00`09jPX0Ogmo07moO`0C07moO`800000?@3oool00`000000oooo0?ooo`0=0?ooo`003P3o
oooC00WZ2P8000001P09jPX00`0000002NX:07moO`0507moO`030000001oOgl0Ogmo01P0Ogmo1009
jPXS07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo0P00000B07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<0
000007moO`1oOgl01P1oOgl200WZ2PL0Ogmo00<0000007moO`1oOgl04@1oOgl300WZ2PL0Ogmo00<0
000007moO`1oOgl09P1oOgl00`09jPX0Ogmo07moO`0G07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<0
000007moO`1oOgl05P1oOgl00`09jPX0Ogmo07moO`0C07moO`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool06`3oool00`09jPX0oooo0?ooo`0P
0?ooo`8000007@1oOgl010000000Ogmo07moO`1oOgl:00WZ2P@0Ogmo00<0000007moO`1oOgl04`1o
Ogl500WZ2RH0Ogmo00<02NX:07moO`1oOgl0101oOgl00`000000Ogmo07moO`0B07moO`0300WZ2P1o
Ogl0Ogmo00P0Ogmo00<0000007moO`1oOgl0201oOgl200WZ2PD0Ogmo00<0000007moO`1oOgl0401o
Ogl01@09jPX0Ogmo0000000000002NX:00L0Ogmo00<0000007moO`1oOgl09@1oOgl00`09jPX0Ogmo
07moO`0H07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl05P1oOgl00`09jPX0Ogmo
07moO`0A07moO`800000@03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?oo
o`0J0?ooo`0300WZ2P3oool0oooo02<0oooo00<0000007moO`1oOgl06P1oOgl00`000000Ogmo07mo
O`0600WZ2P<0Ogmo00<02NX:07moO`09jPX01@09jPX?07moO`D02NX::`1oOgl00`09jPX0Ogmo07mo
O`0307moO`030000001oOgl0Ogmo01@0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`000000Ogmo07mo
O`0;07moO`802NX:0`1oOgl00`000000Ogmo07moO`0?07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P09
jPX607moO`800000901oOgl00`09jPX0Ogmo07moO`0I07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl05P1oOgl00`09jPX0Ogmo07moO`0@07moO`030000003oool0oooo0400oooo00<0
00000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool06@3oool00`09jPX0oooo0?ooo`0U
0?ooo`8000006@1oOgl00`000000Ogmo07moO`0407moO`802NX:00<0Ogmo00WZ2P09jPX00P1oOgl0
0`09jPX0Ogmo07moO`0207moO`030000001oOgl02NX:00D02NX:0P1oOgl2000000D02NX:<01oOgl0
1009jPX0Ogmo07moO`1oOgl2000001L0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`000000Ogmo07mo
O`0=07moO`802NX:0P1oOgl00`000000Ogmo07moO`0=07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<0
2NX:07moO`1oOgl01@1oOgl00`000000Ogmo07moO`0Q07moO`0300WZ2P1oOgl0Ogmo01X0Ogmo00<0
2NX:07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0G07moO`0300WZ2P1oOgl0Ogmo00h0Ogmo0P00
00130?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo01T0oooo00<02NX:
0?ooo`3oool09`3oool2000001L0Ogmo00<0000007moO`1oOgl01@1oOgl200WZ2P80Ogmo0P09jPX0
0`1oOgl02NX:07moO`0207moO`030000001oOgl0Ogmo00D0Ogmo1009jPXd07moO`0500WZ2P1oOgl0
Ogmo07moO`0000006P1oOgl00`09jPX0Ogmo07moO`0507moO`030000001oOgl0Ogmo00l0Ogmo0P09
jPX00`000000Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl01@1o
Ogl200000200Ogmo00<02NX:07moO`1oOgl06`1oOgl00`09jPX0Ogmo07moO`0307moO`030000001o
Ogl0Ogmo01H0Ogmo00<02NX:07moO`1oOgl03@1oOgl2000004D0oooo00<000000?ooo`3oool03@3o
ool007l0oooo00@000000?ooo`3oool0oooo1@09jPXB0?ooo`0300WZ2P3oool0oooo02X0oooo00<0
000007moO`1oOgl0501oOgl00`000000Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0
2NX:07moO`09jPX00`1oOgl00`000000Ogmo07moO`0l07moO`0400WZ2P1oOgl0Ogmo000001/0Ogmo
00<02NX:07moO`1oOgl0101oOgl00`000000Ogmo07moO`0B07moO`802NX:301oOgl00`09jPX0Ogmo
07moO`0:07moO`802NX:1`1oOgl00`000000Ogmo07moO`0M07moO`0300WZ2P1oOgl0Ogmo01`0Ogmo
00D02NX:07moO`1oOgl0Ogmo0000000I07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool2000000d02NX:303oool00`09jPX0oooo
0?ooo`0[0?ooo`8000004`1oOgl00`000000Ogmo07moO`0=07moO`802NX:0`1oOgl00`000000Ogmo
07moO`0k07moO`0400WZ2P1oOgl00000000001d0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0C07moO`0300000009jPX02NX:00P0Ogmo0P09jPX?07moO`0300WZ2P1oOgl0Ogmo00D0
Ogmo00<0000007moO`1oOgl0701oOgl00`09jPX0Ogmo07moO`0L07moO`0500WZ2P1oOgl0Ogmo07mo
O`0000006@1oOgl00`09jPX0Ogmo07moO`0:07moO`800000B03oool00`000000oooo0?ooo`0=0?oo
o`00O`3oool2000000D02NX:203ooolM00WZ2Ql0oooo00<0000007moO`1oOgl0401oOgl00`000000
Ogmo07moO`0?07moO`802NX:00<0Ogmo0000001oOgl0?01oOgl00`09jPX0000007moO`0N07moO`03
00WZ2P1oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl04`1oOgl00`000000Ogmo07moO`0300WZ2P@0
Ogmo00<02NX:07moO`1oOgl0401oOgl200WZ2PH0Ogmo0P00000K07moO`0300WZ2P1oOgl0Ogmo01h0
Ogmo00<02NX:07moO`0000006P1oOgl00`09jPX0Ogmo07moO`0907moO`030000003oool0oooo04P0
oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool00P3oool300WZ2Q80oooo
00<02NX:0?ooo`3oool03`3ooolM00WZ2P<0oooo0P00000?07moO`030000001oOgl0Ogmo0140Ogmo
0`09jPXl07moO`0300WZ2P000000Ogmo0200Ogmo00D02NX:07moO`1oOgl0Ogmo0000000F07moO`03
0000001oOgl0Ogmo00<0Ogmo0P09jPX00`1oOgl02NX:07moO`0D07moO`0300WZ2P1oOgl0Ogmo00D0
Ogmo00<0000007moO`1oOgl0601oOgl00`09jPX0Ogmo07moO`0N07moO`0300WZ2P1oOgl0000001X0
Ogmo00<02NX:07moO`1oOgl01`1oOgl2000004/0oooo00<000000?ooo`3oool03@3oool007l0oooo
00<000000?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo02d0oooo
7@09jPX<07moO`0300WZ2P0000002NX:03X0Ogmo00<0000000WZ2P1oOgl08@1oOgl01@09jPX0Ogmo
07moO`1oOgl0000001L0Ogmo00<0000007moO`1oOgl0101oOgl200WZ2QH0Ogmo0P09jPX607moO`03
0000001oOgl0Ogmo01H0Ogmo00<02NX:07moO`1oOgl0801oOgl00`09jPX0Ogmo07moO`0H07moO`03
00WZ2P1oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0=0?ooo`00
O`3oool00`000000oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo03@0oooo0P00000<07moO`030000
001oOgl0Ogmo00H0Ogmo4@09jPXg07moO`0300000009jPX0Ogmo02<0Ogmo00@02NX:07moO`1oOgl0
00005`1oOgl00`000000Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00802NX:5P1oOgl00`09jPX0
Ogmo07moO`0407moO`8000005P1oOgl00`09jPX0Ogmo07moO`0P07moO`0300WZ2P1oOgl0Ogmo01P0
Ogmo00<02NX:07moO`1oOgl01@1oOgl2000004h0oooo00<000000?ooo`3oool03@3oool007l0oooo
00<000000?ooo`3oool05@3oool00`09jPX0oooo0?ooo`0f0?ooo`8000002@1oOgl00`000000Ogmo
07moO`0E07moO`0300000009jPX0Ogmo00802NX:<`1oOgl20000000307moO`09jPX0Ogmo02<0Ogmo
00<02NX:07moO`000000601oOgl010000000Ogmo07moO`1oOgl200WZ2PD0Ogmo0P09jPXE07moO`80
2NX:1P1oOgl00`000000Ogmo07moO`0B07moO`0300WZ2P1oOgl0Ogmo0200Ogmo00<0000000WZ2P1o
Ogl06@1oOgl00`09jPX0Ogmo07moO`0307moO`800000D03oool00`000000oooo0?ooo`0=0?ooo`00
O`3oool010000000oooo0?ooo`3oool500WZ2Ph0oooo00<02NX:0?ooo`3oool0>@3oool00`000000
Ogmo07moO`0607moO`030000001oOgl0Ogmo01D0Ogmo00<0000007moO`09jPX00P1oOgl200WZ2S00
Ogmo00@0000007moO`1oOgl02NX:9@1oOgl00`09jPX0Ogmo0000000I07moO`030000001oOgl02NX:
00T0Ogmo0P09jPXE07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo0P00000B07moO`0300WZ2P1oOgl0Ogmo
0200Ogmo00<0000007moO`09jPX06@1oOgl00`09jPX0Ogmo07moO`0207moO`030000003oool0oooo
0500oooo00<000000?ooo`3oool03@3oool007l0oooo0P00000600WZ2Pl0oooo00<02NX:0?ooo`3o
ool0>P3oool2000000D0Ogmo00<0000007moO`1oOgl05P1oOgl010000000Ogmo07moO`09jPX307mo
O`0300WZ2P1oOgl0Ogmo02/0Ogmo0P00000307moO`0300WZ2P1oOgl0Ogmo02@0Ogmo00<02NX:0000
001oOgl0601oOgl00`0000002NX:07moO`0;07moO`802NX:501oOgl00`09jPX0Ogmo07moO`0507mo
O`030000001oOgl0Ogmo00h0Ogmo00<02NX:07moO`1oOgl0801oOgl010000000Ogmo07moO`09jPXI
07moO`0300WZ2P1oOgl0Ogmo00800000D`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool20000
01802NX:0P3oool00`09jPX0oooo0?ooo`0m0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007mo
O`1oOgl05P1oOgl01@000000Ogmo07moO`1oOgl02NX:00<0Ogmo0P09jPXZ07moO`030000001oOgl0
Ogmo0080Ogmo00<02NX:07moO`1oOgl09@1oOgl00`09jPX0Ogmo07moO`0H07moO`0300WZ2P1oOgl0
Ogmo00d0Ogmo0P09jPXC07moO`802NX:1P1oOgl00`000000Ogmo07moO`0=07moO`0300WZ2P1oOgl0
Ogmo0200Ogmo00D0000007moO`1oOgl0Ogmo00WZ2P0G07moO`0400WZ2P1oOgl0Ogmo000005D0oooo
00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool00P3oool300WZ2P`0oooo3009
jPXg0?ooo`8000000P1oOgl00`000000Ogmo07moO`0G07moO`050000001oOgl0Ogmo07moO`09jPX0
101oOgl200WZ2RL0Ogmo00<0000007moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0U07moO`030000
0009jPX0Ogmo01L0Ogmo00<02NX:07moO`000000401oOgl200WZ2Q<0Ogmo00<02NX:07moO`1oOgl0
101oOgl2000000`0Ogmo00<02NX:07moO`1oOgl08@1oOgl01@000000Ogmo07moO`1oOgl02NX:01L0
Ogmo00<02NX:000000000000EP3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo
0?ooo`050?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0203oool=00WZ2R`0oooo
0P00000J07moO`030000001oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl00`1oOgl200WZ2R<0Ogmo
0P00000507moO`0300WZ2P1oOgl0Ogmo02H0Ogmo00<0000000WZ2P1oOgl05P1oOgl01009jPX0Ogmo
07moO`00000B07moO`802NX:4P1oOgl200WZ2PH0Ogmo00<0000007moO`1oOgl02@1oOgl00`09jPX0
Ogmo07moO`0P07moO`030000001oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl04`1oOgl00`000000
2NX:0?ooo`1G0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo0140oooo
00<02NX:0?ooo`3oool05P3oool<00WZ2R40oooo00<0000007moO`1oOgl0601oOgl00`000000Ogmo
07moO`0307moO`802NX:1@1oOgl00`09jPX0Ogmo07moO`0O07moO`030000001oOgl0Ogmo00D0Ogmo
00<02NX:07moO`1oOgl09@1oOgl010000000Ogmo07moO`09jPXD07moO`802NX:0`1oOgl00`000000
Ogmo07moO`0B07moO`<02NX:4@1oOgl00`09jPX0Ogmo00WZ2P0407moO`030000001oOgl0Ogmo00L0
Ogmo00<02NX:07moO`1oOgl08@1oOgl00`000000Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo0180
Ogmo00<0000007moO`09jPX0F03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo
0?ooo`0A0?ooo`0300WZ2P3oool0oooo0280oooo3@09jPXC0?ooo`030000001oOgl0Ogmo01T0Ogmo
00<0000007moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0307moO`802NX:7P1oOgl00`000000Ogmo
07moO`0507moO`0300WZ2P1oOgl0Ogmo02H0Ogmo00@0000007moO`1oOgl02NX:4`1oOgl00`09jPX0
Ogmo07moO`0407moO`030000001oOgl0Ogmo01@0Ogmo0P09jPX@07moO`<02NX:101oOgl2000000L0
Ogmo00<02NX:07moO`1oOgl0801oOgl00`000000Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00l0
Ogmo0P00000207moO`0300WZ2P3oool0oooo05H0oooo00<000000?ooo`3oool03@3oool007l0oooo
00<000000?ooo`3oool0403oool00`09jPX0oooo0?ooo`0`0?ooo``02NX:1`3oool00`000000Ogmo
07moO`0I07moO`030000001oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl0101oOgl200WZ2QX0Ogmo
0P00000807moO`0300WZ2P1oOgl0Ogmo02H0Ogmo00D0000007moO`1oOgl0Ogmo00WZ2P0A07moO`03
00WZ2P1oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl05P1oOgl200WZ2Q00Ogmo0P09jPX507moO`03
0000001oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl08@1oOgl00`000000Ogmo07moO`0507moO`03
00WZ2P1oOgl0Ogmo00h0Ogmo00L0000007moO`1oOgl0Ogmo00WZ2P1oOgl0000005L0oooo00<00000
0?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0403oool00`09jPX0oooo0?ooo`0l0?oo
o`d02NX:5`1oOgl00`000000Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00D0Ogmo0P09jPXG07mo
O`030000001oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl09P1oOgl00`000000Ogmo07moO`0207mo
O`0300WZ2P1oOgl0Ogmo00h0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`000000Ogmo07moO`0H07mo
O`802NX:2`1oOgl600WZ2PD0Ogmo0P00000307moO`0300WZ2P1oOgl0Ogmo0200Ogmo00<0000007mo
O`1oOgl01`1oOgl00`09jPX0Ogmo07moO`0;07moO`800000101oOgl00`09jPX0Ogmo0000001G0?oo
o`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo00l0oooo00<02NX:0?ooo`3o
ool0@`3oool00`000000Ogmo07moO`0407moO``02NX:2`1oOgl00`000000Ogmo07moO`0707moO`03
00WZ2P1oOgl0Ogmo00<02NX:0`1oOgl00`09jPX0Ogmo07moO`0B07moO`8000002P1oOgl00`09jPX0
Ogmo07moO`0V07moO`030000001oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0301oOgl00`09jPX0
Ogmo07moO`0807moO`030000001oOgl0Ogmo01T0Ogmo0P09jPX;07moO`D02NX:1P1oOgl010000000
Ogmo07moO`09jPXR07moO`030000001oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0407moO`0300WZ2P1oOgl0000005L0oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool03`3oool00`09jPX0oooo0?ooo`130?ooo`030000001oOgl0Ogmo0100
Ogmo3@09jPX407moO`80000000<0Ogmo00WZ2P09jPX01009jPX507moO`802NX:4@1oOgl00`000000
Ogmo07moO`0907moO`0300WZ2P1oOgl0Ogmo02L0Ogmo00<0000007moO`1oOgl00`1oOgl00`09jPX0
Ogmo07moO`0;07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl06`1oOgl200WZ2P`0
Ogmo0`09jPX607moO`0300000009jPX0Ogmo0240Ogmo00<0000007moO`1oOgl02@1oOgl00`09jPX0
Ogmo07moO`0707moO`8000001`1oOgl01009jPX0Ogmo07moO`00001F0?ooo`030000003oool0oooo
00d0oooo001o0?ooo`030000003oool0oooo00h0oooo00<02NX:0?ooo`3oool0@`3oool00`000000
Ogmo07moO`0L07moO`030000001oOgl02NX:01002NX:0`1oOgl200WZ2Ph0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`09jPX0Ogmo07moO`0V07moO`030000001oOgl0Ogmo00D0Ogmo00<02NX:07moO`1o
Ogl0201oOgl200WZ2P`0Ogmo00<0000007moO`1oOgl07@1oOgl200WZ2P`0Ogmo0P00000607moO`03
00WZ2P000000Ogmo0200Ogmo00<0000007moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0507moO`80
0000201oOgl01@09jPX0Ogmo07moO`1oOgl0000005H0oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool03@3oool00`09jPX0oooo0?ooo`140?ooo`030000001oOgl0Ogmo01`0
Ogmo00<0000007moO`1oOgl01`1oOgl500WZ2P@0Ogmo5@09jPX:07moO`0300WZ2P1oOgl0Ogmo02L0
Ogmo00<0000007moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl07`1oOgl200WZ2PX0Ogmo0P00000507moO`0400WZ2P1oOgl0Ogmo0000
01l0Ogmo00<0000007moO`1oOgl02`1oOgl00`09jPX0Ogmo07moO`0307moO`030000001oOgl0Ogmo
00P0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
00d0oooo001o0?ooo`030000003oool0oooo00d0oooo00<02NX:0?ooo`3oool0@`3oool00`000000
Ogmo07moO`0N07moO`030000001oOgl0Ogmo00X0Ogmo0P09jPX:07moO`0300WZ2P1oOgl0Ogmo00H0
Ogmo00<0000007moO`1oOgl00P1oOglE00WZ2Ql0Ogmo00<0000007moO`1oOgl01P1oOgl00`09jPX0
Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00<0000007moO`1oOgl0801oOgl200WZ2Pl0
Ogmo00D02NX:07moO`1oOgl0Ogmo0000000N07moO`030000001oOgl0Ogmo00/0Ogmo00@02NX:07mo
O`1oOgl0Ogmo0P00000;07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo
04@0oooo00<0000007moO`1oOgl07P1oOgl00`000000Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo
00P0Ogmo0P09jPX407moO`8000003`1oOgl00`09jPX0Ogmo07moO`0807moOaH02NX:201oOgl00`00
0000Ogmo07moO`0707moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl03`1oOgl00`00
0000Ogmo07moO`0R07moO`802NX:301oOgl00`09jPX0Ogmo07moO`0307moO`800000701oOgl00`00
0000Ogmo07moO`0;07moO`0400WZ2P1oOgl0Ogmo000000d0Ogmo00<02NX:07moO`1oOgl00P1oOgl0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo
00`0oooo00<02NX:0?ooo`3oool0A03oool00`000000Ogmo07moO`0N07moO`030000001oOgl0Ogmo
00d0Ogmo00<02NX:07moO`1oOgl02@1oOgl200WZ2P0307moO`000000Ogmo00L0Ogmo0P00000607mo
O`0300WZ2P1oOgl0Ogmo01l0Ogmo5@09jPX307moO`0300WZ2P1oOgl0Ogmo0100Ogmo00<0000007mo
O`1oOgl0901oOgl300WZ2PT0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`000000Ogmo07moO`0H07mo
O`030000001oOgl0Ogmo00d0Ogmo00<02NX:0000001oOgl03@1oOgl00`09jPX0Ogmo07moO`0307mo
O`030000003oool0oooo0580oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`140?ooo`030000001oOgl0Ogmo01l0Ogmo00<0000007moO`1o
Ogl03P1oOgl00`09jPX0Ogmo07moO`0:07moO`802NX:201oOgl2000000P02NX::01oOgl00`000000
Ogmo07moO`0807moO`0300WZ2P1oOgl02NX:01D02NX:00<0Ogmo0000001oOgl09`1oOgl200WZ2PH0
Ogmo00<02NX:07moO`1oOgl01`1oOgl00`000000Ogmo07moO`0G07moO`030000001oOgl0Ogmo00/0
Ogmo0P0000000`09jPX0Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0;0?ooo`0300WZ
2P3oool0oooo04@0oooo00<0000007moO`1oOgl07`1oOgl00`000000Ogmo07moO`0?07moO`0300WZ
2P1oOgl0Ogmo00L0Ogmo0P00000207moO`0300WZ2P1oOgl0Ogmo00P0Ogmo1@09jPXY07moO`030000
001oOgl0Ogmo00X0Ogmo0P09jPXE07moOaD02NX:5`1oOgl200WZ2P@0Ogmo00<02NX:07moO`1oOgl0
201oOgl2000001H0Ogmo00<0000007moO`1oOgl02`1oOgl01@000000Ogmo07moO`1oOgl02NX:00d0
Ogmo00<02NX:07moO`1oOgl01@1oOgl00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00d0
oooo001o0?ooo`030000003oool0oooo00X0oooo00<02NX:0?ooo`3oool0A03oool00`000000Ogmo
07moO`0Q07moO`030000001oOgl0Ogmo00l0Ogmo0P09jPX607moO`030000001oOgl0Ogmo00<0Ogmo
0P09jPX:07moO`D02NX:9`1oOgl00`000000Ogmo07moO`0:07moO`<02NX:5@1oOgl00`000000Ogmo
07moO`0A07moOaD02NX:101oOgl200WZ2P0307moO`09jPX0Ogmo00`0Ogmo00<0000007moO`1oOgl0
4`1oOgl00`000000Ogmo07moO`0907moO`800000101oOgl00`09jPX0Ogmo07moO`0;07moO`0300WZ
2P1oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0=0?ooo`00O`3o
ool00`000000oooo0?ooo`090?ooo`0300WZ2P3oool0oooo04D0oooo00<0000007moO`1oOgl08@1o
Ogl00`000000Ogmo07moO`0A07moO`0400WZ2P1oOgl0Ogmo07moO`800000201oOgl200WZ2PT0Ogmo
0`09jPX0101oOgl02NX:00WZ2P09jPXT07moO`030000001oOgl0Ogmo00T0Ogmo1@09jPXE07moO`03
0000001oOgl0Ogmo02D0Ogmo5P09jPX200000180Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`000000
oooo0?ooo`1A0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo00T0oooo
00<02NX:0?ooo`3oool0A@3oool00`000000Ogmo07moO`0Q07moO`030000001oOgl0Ogmo0180Ogmo
00<02NX:07moO`000000301oOgl200WZ2PL0Ogmo00<02NX:07moO`09jPX0101oOgl300WZ2R40Ogmo
00<0000007moO`1oOgl0201oOgl400WZ2QL0Ogmo00<0000007moO`1oOgl08@1oOgl300WZ2P030000
0009jPX0Ogmo00@0Ogmo00@02NX:07moO`09jPX02NX:301oOglE00WZ2PT0Ogmo0P00000807moO`03
00WZ2P1oOgl0Ogmo00X0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo00P0oooo00<02NX:0?ooo`3oool0
A@3oool00`000000Ogmo07moO`0R07moO`030000001oOgl0Ogmo01<0Ogmo00<02NX:07moO`1oOgl0
3@1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00P0Ogmo0`09jPXM07moO`030000
001oOgl0Ogmo00P0Ogmo0P09jPX307moO`0300WZ2P1oOgl0Ogmo01@0Ogmo00<0000007moO`1oOgl0
701oOgl800WZ2P0300000009jPX0Ogmo00@0Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPX=07moO`03
0000001oOgl0Ogmo00d0Ogmo00<0000007moO`09jPX05009jPX907moO`0300000009jPX0Ogmo00P0
Ogmo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo
0?ooo`080?ooo`0300WZ2P3oool0oooo04D0oooo00<0000007moO`1oOgl08P1oOgl00`000000Ogmo
07moO`0A07moO`80000000<0Ogmo00WZ2P1oOgl03P1oOgl200WZ2P<0Ogmo00<02NX:07moO`1oOgl0
2`1oOgl300WZ2QX0Ogmo00<0000007moO`1oOgl01`1oOgl00`09jPX0000007moO`0307moO`0300WZ
2P1oOgl0Ogmo01D0Ogmo00<0000007moO`1oOgl0701oOgl600WZ2P<0Ogmo00D02NX:07moO`1oOgl0
Ogmo00WZ2P0607moO`802NX:301oOgl2000000d0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000
Ogmo07moO`0;07moO``02NX:2P1oOgl00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0
oooo001o0?ooo`030000003oool0oooo00L0oooo00<02NX:0?ooo`3oool0A@3oool00`000000Ogmo
07moO`0T07moO`030000001oOgl0Ogmo00l0Ogmo00<0000007moO`1oOgl00P1oOgl00`09jPX0Ogmo
07moO`0>07moO`<02NX:4@1oOgl300WZ2QL0Ogmo00<0000007moO`1oOgl01`1oOgl00`09jPX00000
07moO`0307moO`0300WZ2P1oOgl0Ogmo01D0Ogmo00<0000007moO`1oOgl06@1oOgl300WZ2P80Ogmo
0P09jPX507moO`0500WZ2P1oOgl0Ogmo07moO`09jPX0201oOgl200WZ2P`0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0407moO`8000003`1oOgl00`09jPX0Ogmo07moO`0507moO`<0
2NX:2P1oOgl00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000
003oool0oooo00H0oooo00<02NX:0?ooo`3oool0AP3oool00`000000Ogmo07moO`0T07moO`030000
001oOgl0Ogmo00h0Ogmo00<0000007moO`1oOgl0101oOgl200WZ2Q00Ogmo0P09jPXC07moO`<02NX:
4`1oOgl00`000000Ogmo07moO`0907moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0
501oOgl00`000000Ogmo07moO`0E07moO`@02NX:101oOgl200WZ2PH0Ogmo00D02NX:07moO`1oOgl0
Ogmo00WZ2P0:07moO`802NX:2`1oOgl00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl03`1oOgl00`09jPX0Ogmo07moO`0407moO`<02NX:301oOgl00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo00H0oooo
00<02NX:0?ooo`3oool0AP3oool00`000000Ogmo07moO`0T07moO`030000001oOgl0Ogmo00`0Ogmo
0P00000907moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00@02NX:07moO`1oOgl02NX:5@1oOgl300WZ2Q00
Ogmo00<0000007moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo01D0
Ogmo00<0000007moO`1oOgl04@1oOgl300WZ2PP0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09jPX0
Ogmo00WZ2P0=07moO`<02NX:2@1oOgl2000000P0Ogmo00@0000007moO`1oOgl0Ogmo0P00000C07mo
O`0300WZ2P1oOgl0Ogmo0080Ogmo1009jPX<07moO`030000003oool0oooo04h0oooo00<000000?oo
o`3oool03@3oool007l0oooo00<000000?ooo`3oool01@3oool00`09jPX0oooo0?ooo`160?ooo`03
0000001oOgl0Ogmo02D0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0:07moO`03
00WZ2P1oOgl0Ogmo00/0Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPXF07moO`<02NX:3@1oOgl00`00
0000Ogmo07moO`0:07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0501oOgl00`00
0000Ogmo07moO`0>07moO`<02NX:501oOgl00`09jPX0Ogmo00WZ2P0@07moO`802NX:2@1oOgl00`00
0000Ogmo07moO`0407moO`050000001oOgl0Ogmo07moO`0000005@1oOgl01009jPX0Ogmo07moO`1o
Ogl400WZ2Pd0Ogmo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool0
0`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo04H0oooo00<0000007moO`1oOgl09@1oOgl0
0`000000Ogmo07moO`0907moO`8000003P1oOgl00`09jPX0Ogmo07moO`0907moO`0300WZ2P1oOgl0
Ogmo00@0Ogmo0P09jPXG07moO`@02NX:201oOgl00`000000Ogmo07moO`0;07moO`0300WZ2P1oOgl0
Ogmo00<0Ogmo00<02NX:07moO`1oOgl0501oOgl00`000000Ogmo07moO`0;07moO`<02NX:601oOgl0
0`09jPX0Ogmo07moO`0A07moO`802NX:201oOgl2000000@0Ogmo00@0000007moO`00000000005`1o
Ogl00`09jPX0Ogmo00WZ2P0400WZ2Ph0Ogmo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`0=0?ooo`00O`3oool00`000000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo04H0oooo00<00000
07moO`1oOgl09`1oOgl00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00l0Ogmo00<02NX:
07moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0607moO`802NX:6@1oOgl300WZ2PD0Ogmo00<00000
07moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo01@0Ogmo00<00000
07moO`1oOgl01`1oOgl300WZ2Q/0Ogmo00<02NX:07moO`1oOgl04`1oOgl200WZ2PP0Ogmo00<00000
07moO`1oOgl00`00000I07moO`0400WZ2P1oOgl0Ogmo07moO`<02NX:3P1oOgl00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo00@0oooo00<02NX:
0?ooo`3oool0AP3oool00`000000Ogmo07moO`0W07moO`030000001oOgl0Ogmo00H0Ogmo00<00000
07moO`1oOgl04@1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<02NX:
07moO`1oOgl06@1oOgl300WZ2P80Ogmo00<0000007moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`03
07moO`0300WZ2P1oOgl0Ogmo01@0Ogmo00<0000007moO`1oOgl00`1oOgl400WZ2Qd0Ogmo0P09jPXG
07moO`802NX:1`1oOgl00`000000Ogmo0000000L07moO`0300WZ2P1oOgl0Ogmo00802NX:401oOgl0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo
00<0oooo00<02NX:0?ooo`3oool0A`3oool00`000000Ogmo07moO`0W07moO`030000001oOgl0Ogmo
00@0Ogmo0P00000E07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl02P1oOgl200WZ
2Q`0Ogmo0`09jPX?07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl04`1oOgl00`00
0000Ogmo07moO`0300WZ2R40Ogmo00<02NX:07moO`09jPX0601oOgl200WZ2PD0Ogmo0`00000L07mo
O`0300WZ2P1oOgl02NX:0180Ogmo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0=0?oo
o`00O`3oool00`000000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo04L0oooo00<0000007moO`1o
Ogl0:01oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo01H0Ogmo0P09jPX407moO`03
00WZ2P1oOgl0Ogmo00d0Ogmo0P09jPXK07moO`030000001oOgl02NX:00802NX:301oOgl00`09jPX0
Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo01<0Ogmo0`09jPXS07moO`0400WZ2P1oOgl0Ogmo00WZ
2QX0Ogmo0P09jPX207moO`050000001oOgl0000007moO`0000006`1oOgl200WZ2Q<0Ogmo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo00WZ2P020?oo
o`0300WZ2P3oool0oooo04L0oooo00<0000007moO`1oOgl0:01oOgl010000000Ogmo07moO`1oOgl2
000001/0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0A07moO`802NX:6@1oOgl00`000000Ogmo07mo
O`0207moO`<02NX:2P1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00l0Ogmo0`09
jPX00`1oOgl0000007moO`0S07moO`0500WZ2P1oOgl0Ogmo07moO`09jPX06`1oOgl200WZ2P80Ogmo
00@0000007moO`1oOgl000006`1oOgl00`09jPX0Ogmo07moO`0B07moO`030000003oool0oooo04/0
oooo00<000000?ooo`3oool03@3oool007l0oooo00D000000?ooo`09jPX0oooo00WZ2P190?ooo`03
0000001oOgl0Ogmo02X0Ogmo00<0000007moO`0000007P1oOgl00`09jPX0Ogmo00WZ2P0D07moO`03
00WZ2P1oOgl0Ogmo01D0Ogmo00<0000007moO`1oOgl01P1oOgl300WZ2PL0Ogmo00<02NX:07moO`1o
Ogl00`1oOgl00`09jPX0Ogmo07moO`0;07moO`@02NX:101oOgl00`000000Ogmo07moO`0Q07moO`03
00WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl06@1oOgl010000000Ogmo00WZ2P09jPX407mo
O`800000601oOgl200WZ2Q@0Ogmo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0=0?oo
o`00O`3oool00`000000oooo00WZ2P0400WZ2TL0oooo00<0000007moO`1oOgl0:P1oOgl200000200
Ogmo0P09jPXE07moO`802NX:5@1oOgl00`000000Ogmo07moO`0907moO`<02NX:1@1oOgl00`09jPX0
Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00L0Ogmo0`09jPX807moO`030000001oOgl0Ogmo0240
Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0H07moO`050000001oOgl0Ogmo07mo
O`0000000P09jPX407moO`030000001oOgl0Ogmo01D0Ogmo00<02NX:07moO`09jPX0501oOgl00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo00d0oooo001o0?ooo`0300000009jPX02NX:00<0
2NX:A`3oool00`000000Ogmo07moO`0[07moO`800000801oOgl200WZ2QL0Ogmo0P09jPXC07moO`03
0000001oOgl0Ogmo00`0Ogmo0`09jPX207moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1o
Ogl0101oOgl300WZ2P`0Ogmo00<0000007moO`1oOgl07`1oOgl00`09jPX0Ogmo07moO`0407moO`03
00WZ2P1oOgl0Ogmo01H0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0300WZ2P04
07moO`09jPX02NX:000001@0Ogmo00@02NX:07moO`1oOgl02NX:501oOgl00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo00d0oooo001o0?ooo`0300000009jPX02NX:00802NX:B03oool00`00
0000Ogmo07moO`0]07moO`8000007P1oOgl00`09jPX0Ogmo00WZ2P0H07moO`802NX:401oOgl00`00
0000Ogmo07moO`0@07moO`@02NX:1@1oOgl00`09jPX0Ogmo07moO`0300WZ2Pl0Ogmo00<0000007mo
O`1oOgl0701oOgl01009jPX0Ogmo07moO`09jPX607moO`0300WZ2P1oOgl0Ogmo01D0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`@02NX:00<0000007moO`1oOgl0401oOgl0
0`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo0140Ogmo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0=0?ooo`00O`3oool0100000002NX:00WZ2P09jPY90?ooo`030000001oOgl0
Ogmo02l0Ogmo00<0000007moO`1oOgl06`1oOgl01009jPX0Ogmo07moO`09jPXI07moO`0300WZ2P1o
Ogl0Ogmo00d0Ogmo00<0000007moO`1oOgl04`1oOgl300WZ2P0307moO`000000000000L02NX:3P1o
Ogl00`000000Ogmo07moO`0L07moO`0300WZ2P1oOgl02NX:00802NX:1P1oOgl00`09jPX0Ogmo07mo
O`0C07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl01@1oOgl500WZ2Q40Ogmo00<0
2NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0B07moO`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool03@3oool007l0oooo00<0000000WZ2P09jPX0B@3oool00`000000Ogmo07moO`0a
07moO`8000006P1oOgl00`09jPX0Ogmo07moO`0207moO`802NX:601oOgl200WZ2Pd0Ogmo00<00000
07moO`1oOgl0501oOgl00`09jPX0Ogmo00WZ2P0700WZ2Q40Ogmo00<0000007moO`1oOgl06`1oOgl5
00WZ2PH0Ogmo00<02NX:07moO`1oOgl04P1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo1`09jPX00`000000Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:
07moO`1oOgl04@1oOgl00`000000oooo0?ooo`190?ooo`030000003oool0oooo00d0oooo001o0?oo
o`802NX:BP3oool00`000000Ogmo07moO`0c07moO`800000601oOgl00`09jPX0Ogmo07moO`0407mo
O`0300WZ2P1oOgl0Ogmo01L0Ogmo0P09jPX:07moO`030000001oOgl0Ogmo01D0Ogmo00<02NX:07mo
O`1oOgl00P1oOgl<00WZ2PX0Ogmo00<0000007moO`1oOgl06`1oOgl400WZ2PL0Ogmo00<02NX:07mo
O`1oOgl04@1oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00L0Ogmo1009jPX20000
00`0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0B07moO`030000003oool0oooo
04P0oooo00<000000?ooo`3oool03@3oool007l0oooo0P0000190?ooo`030000001oOgl0Ogmo03H0
Ogmo0P00000C07moO`0300WZ2P1oOgl02NX:00P0Ogmo00<02NX:07moO`1oOgl0601oOgl00`09jPX0
Ogmo07moO`0707moO`030000001oOgl0Ogmo01H0Ogmo00<02NX:07moO`1oOgl00`1oOgl400WZ2PH0
Ogmo2@09jPX00`1oOgl0000007moO`0L07moO`<02NX:2@1oOgl00`09jPX0Ogmo07moO`0>07moO`80
0000201oOgl00`000000Ogmo07moO`0;07moO`0400000009jPX02NX:000000X0Ogmo00<02NX:07mo
O`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0A07moO`030000003oool0oooo04P0oooo00<000000?oo
o`3oool03@3oool007l0oooo0P0000190?ooo`030000001oOgl0Ogmo03P0Ogmo00<0000007moO`1o
Ogl0401oOgl00`09jPX0Ogmo00WZ2P0907moO`0300WZ2P1oOgl0Ogmo01P0Ogmo0P09jPX707moO`03
0000001oOgl0Ogmo01H0Ogmo00<02NX:07moO`1oOgl00`1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:
00h0Ogmo2@09jPXE07moO`<02NX:2P1oOgl00`09jPX0Ogmo07moO`0=07moO`030000001oOgl0Ogmo
00L0Ogmo00<0000007moO`1oOgl03`1oOgl200WZ2PP0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`09
jPX0Ogmo07moO`0A07moO`030000003oool0oooo04P0oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool0B03oool00`000000Ogmo07moO`0i07moO`800000401oOgl400WZ2PT0
Ogmo00<02NX:07moO`1oOgl06@1oOgl200WZ2P@0Ogmo00<0000007moO`1oOgl0601oOgl00`09jPX0
Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo0140Ogmo00<0000007moO`1oOgl0101oOgl900WZ2P`0
Ogmo0`09jPX;07moO`0300WZ2P1oOgl02NX:00/0Ogmo00<0000007moO`1oOgl0201oOgl00`000000
Ogmo07moO`0A07moO`<02NX:101oOgl00`09jPX0Ogmo07moO`0907moO`0300WZ2P1oOgl0Ogmo0140
Ogmo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo
0?ooo`170?ooo`030000001oOgl0Ogmo03`0Ogmo0P00000=07moO`D02NX:2P1oOgl00`09jPX0Ogmo
07moO`0J07moO`802NX:0P1oOgl00`000000Ogmo07moO`0H07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo
00<02NX:07moO`1oOgl04@1oOgl00`000000Ogmo07moO`0=07moO`T02NX:0P1oOgl20000000300WZ
2P1oOgl0Ogmo00P0Ogmo0`09jPX00`1oOgl02NX:07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl04P1oOgl2000000802NX:0P1oOgl00`09jPX0Ogmo07moO`0907moO`0300WZ
2P1oOgl0Ogmo0140Ogmo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0=0?ooo`00O`3o
ool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo03h0Ogmo0P00000;07moO`@02NX:301o
Ogl200WZ2Q`0Ogmo00<02NX:07moO`0000006`1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1o
Ogl0Ogmo0140Ogmo00<0000007moO`1oOgl05@1oOgl400WZ2P/0Ogmo1@09jPX907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl0501oOgl010000000Ogmo00WZ2P09jPX=07moO`0300WZ
2P1oOgl0Ogmo0140Ogmo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0=0?ooo`00O`3o
ool00`000000oooo0?ooo`160?ooo`030000001oOgl0Ogmo0440Ogmo0P00000907moO`<02NX:3`1o
Ogl00`09jPX0Ogmo07moO`0J07moO`802NX:6`1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1o
Ogl0Ogmo0140Ogmo00<0000007moO`1oOgl09@1oOgl400WZ2PP0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0F07moO`0300000009jPX0Ogmo00802NX:2`1oOgl00`09jPX0Ogmo07mo
O`0A07moO`030000003oool0oooo04H0oooo00<000000?ooo`3oool03@3oool007l0oooo00<00000
0?ooo`3oool0AP3oool00`000000Ogmo07moO`1307moO`030000001oOgl0Ogmo00H0Ogmo0P09jPXA
07moO`0300WZ2P1oOgl0Ogmo01T0Ogmo00@0000007moO`09jPX02NX:6P1oOgl00`09jPX0Ogmo07mo
O`0207moO`0300WZ2P1oOgl0Ogmo0140Ogmo00<0000007moO`1oOgl09P1oOgl300WZ2PL0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0G07moO`0400WZ2P000000Ogmo07moO`802NX:
2@1oOgl00`09jPX0Ogmo07moO`0A07moO`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
3@3oool007l0oooo00<000000?ooo`3oool0AP3oool00`000000Ogmo07moO`1407moO`8000001@1o
Ogl2000001<0Ogmo00<02NX:07moO`1oOgl0601oOgl010000000Ogmo07moO`1oOgl200WZ2QP0Ogmo
00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0A07moO`030000001oOgl0Ogmo02H0Ogmo
0`09jPX507moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl05P1oOgl01009jPX0Ogmo
07moO`00000307moO`<02NX:1`1oOgl00`09jPX0Ogmo07moO`0A07moO`030000003oool0oooo04D0
oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0A@3oool00`000000Ogmo
07moO`1707moO`8000000P1oOgl200WZ2P030000001oOgl0Ogmo0180Ogmo00<02NX:07moO`1oOgl0
5P1oOgl00`000000Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo01H0Ogmo00<02NX:07moO`1oOgl0
0P1oOgl00`09jPX0Ogmo07moO`0A07moO`030000001oOgl0Ogmo02H0Ogmo0`09jPX407moO`030000
001oOgl0Ogmo00d0Ogmo00<0000007moO`1oOgl05@1oOgl00`09jPX0Ogmo07moO`0207moO`800000
101oOgl200WZ2PD0Ogmo00<02NX:07moO`1oOgl04@1oOgl00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo04D0oooo00<0000007moO`1oOgl0B@1o
Ogl00`0000002NX:07moO`0G07moO`0300WZ2P1oOgl0Ogmo01D0Ogmo00<0000007moO`1oOgl01@1o
Ogl200WZ2QH0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0@07moO`030000001o
Ogl0Ogmo02L0Ogmo0P00000307moO`030000001oOgl0Ogmo00d0Ogmo00<0000007moO`1oOgl05P1o
Ogl00`09jPX0Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo0P09jPX407moO`0300WZ2P1o
Ogl0Ogmo0140Ogmo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool0
0`000000oooo0?ooo`140?ooo`030000001oOgl0Ogmo04X0Ogmo00<02NX:07moO`000000601oOgl0
0`09jPX0Ogmo07moO`0D07moO`030000001oOgl0Ogmo00L0Ogmo0P09jPXE07moO`0300WZ2P1oOgl0
Ogmo0080Ogmo00<02NX:07moO`1oOgl04@1oOgl00`000000Ogmo07moO`0V07moO`0500000009jPX0
Ogmo07moO`000000401oOgl00`000000Ogmo07moO`0E07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<0
000007moO`1oOgl0101oOgl200WZ2P80Ogmo00<02NX:07moO`1oOgl04@1oOgl00`000000oooo0?oo
o`140?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo04@0oooo00<00000
07moO`1oOgl0B@1oOgl01009jPX0Ogmo07moO`1oOgl2000001L0Ogmo0P09jPXC07moO`030000001o
Ogl0Ogmo00X0Ogmo0P09jPXC07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0401o
Ogl00`000000Ogmo07moO`0W07moO`0300WZ2P00000000000140Ogmo00<0000007moO`1oOgl05@1o
Ogl00`09jPX0Ogmo07moO`0707moO`8000001P1oOgl400WZ2Q80Ogmo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`130?ooo`030000001oOgl0
Ogmo04T0Ogmo00<02NX:07moO`1oOgl0101oOgl2000001L0Ogmo00<02NX:07moO`1oOgl0401oOgl0
0`000000Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo0140Ogmo00<02NX:07moO`1oOgl00P1oOgl0
0`09jPX0Ogmo07moO`0@07moO`030000001oOgl0Ogmo02L0Ogmo00<02NX:07moO`1oOgl04@1oOgl0
0`000000Ogmo07moO`0D07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl01P1oOgl0
0`09jPX0000007moO`0A07moO`030000003oool0oooo04<0oooo00<000000?ooo`3oool03@3oool0
07l0oooo00<000000?ooo`3oool0@`3oool00`000000Ogmo07moO`1807moO`0300WZ2P1oOgl0Ogmo
00L0Ogmo0P00000F07moO`0300WZ2P1oOgl0Ogmo00l0Ogmo00<0000007moO`1oOgl03@1oOgl200WZ
2Q40Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0@07moO`030000001oOgl0Ogmo
02D0Ogmo00<0000000WZ2P1oOgl04@1oOgl00`000000Ogmo07moO`0D07moO`0300WZ2P1oOgl0Ogmo
00`0Ogmo0P00000607moO`0400000009jPX02NX:00WZ2P<0Ogmo0P09jPX;07moO`030000003oool0
oooo04<0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0@`3oool00`00
0000Ogmo07moO`1707moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0501oOgl00`09
jPX0Ogmo07moO`0=07moO`030000001oOgl0Ogmo0100Ogmo0P09jPX@07moO`0300WZ2P1oOgl0Ogmo
0080Ogmo00<02NX:07moO`1oOgl0401oOgl00`000000Ogmo07moO`0T07moO`040000001oOgl0Ogmo
00WZ2Q40Ogmo00<0000007moO`1oOgl0501oOgl00`09jPX0Ogmo07moO`0>07moO`030000001oOgl0
Ogmo00@0Ogmo00<02NX:07moO`1oOgl00P09jPX0101oOgl02NX:00WZ2P09jPX;07moO`030000003o
ool0oooo0480oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0@P3oool0
0`000000Ogmo07moO`1707moO`0300WZ2P1oOgl0Ogmo00`0Ogmo0P00000E07moO`0300WZ2P1oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl04P1oOgl200WZ2Ph0Ogmo00<02NX:07moO`1oOgl00`1oOgl0
0`09jPX0Ogmo07moO`0?07moO`030000001oOgl0Ogmo02<0Ogmo00D0000007moO`1oOgl0Ogmo00WZ
2P0A07moO`030000001oOgl0Ogmo01<0Ogmo00<02NX:07moO`1oOgl0401oOgl00`000000Ogmo07mo
O`0307moO`0300WZ2P1oOgl0Ogmo0080Ogmo1@09jPX:07moO`030000003oool0oooo0480oooo00<0
00000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0@P3oool00`000000Ogmo07moO`16
07moO`0300WZ2P1oOgl0Ogmo00l0Ogmo0P00000D07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<00000
07moO`1oOgl0501oOgl00`09jPX0Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:
07moO`1oOgl0401oOgl00`000000Ogmo07moO`0Q07moO`030000001oOgl0Ogmo0080Ogmo00<02NX:
07moO`1oOgl03`1oOgl00`000000Ogmo07moO`0B07moO`0300WZ2P1oOgl0Ogmo0180Ogmo0P000004
07moO`0300WZ2P1oOgl0Ogmo00L02NX:2@1oOgl00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00d0oooo001o0?ooo`030000003oool0oooo0440oooo00<0000007moO`1oOgl0AP1oOgl00`09
jPX0Ogmo07moO`0B07moO`8000004`1oOgl00`09jPX0Ogmo07moO`0907moO`030000001oOgl0Ogmo
01H0Ogmo0P09jPX<07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:0000001oOgl03`1oOgl00`00
0000Ogmo07moO`0P07moO`030000001oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl03P1oOgl00`00
0000Ogmo07moO`0C07moO`0300WZ2P1oOgl0Ogmo01@0Ogmo00D0000007moO`1oOgl0Ogmo00WZ2P05
07moO`D02NX:0P00000707moO`030000003oool0oooo0440oooo00<000000?ooo`3oool03@3oool0
07l0oooo00<000000?ooo`3oool0@@3oool00`000000Ogmo07moO`1507moO`0300WZ2P1oOgl0Ogmo
01D0Ogmo00<0000007moO`1oOgl04@1oOgl200WZ2PT0Ogmo00<0000007moO`1oOgl0601oOgl200WZ
2P/0Ogmo00<02NX:07moO`1oOgl00P1oOgl200000100Ogmo00<0000007moO`1oOgl07`1oOgl00`00
0000Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00<0000007moO`1oOgl0401oOgl20000
000300WZ2P1oOgl0Ogmo01H0Ogmo00@0000007moO`1oOgl02NX:2@1oOgl200WZ2P030000001oOgl0
Ogmo00D0Ogmo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`00
0000oooo0?ooo`110?ooo`030000001oOgl0Ogmo04@0Ogmo00<02NX:07moO`1oOgl05`1oOgl20000
01<0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`000000Ogmo07moO`0J07moO`802NX:2@1oOgl00`09
jPX0Ogmo07moO`0207moO`<02NX:3`1oOgl00`000000Ogmo07moO`0N07moO`030000001oOgl0Ogmo
00H0Ogmo00<02NX:07moO`1oOgl03@1oOgl00`000000Ogmo07moO`0@07moO`0300000009jPX0Ogmo
01T0Ogmo0P0000000`1oOgl02NX:07moO`0807moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`100?ooo`03
0000001oOgl0Ogmo04@0Ogmo00<02NX:07moO`1oOgl06P1oOgl200000180Ogmo00<02NX:07moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0M07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1o
Ogl00P1oOgl300WZ2Pl0Ogmo00<0000007moO`1oOgl0701oOgl00`000000Ogmo07moO`0707moO`03
00WZ2P1oOgl0Ogmo00d0Ogmo00<0000007moO`1oOgl04@1oOgl00`09jPX0Ogmo07moO`0J07moO`03
00000009jPX0Ogmo00L0Ogmo00<02NX:07moO`1oOgl0201oOgl00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo0400oooo00<0000007moO`1oOgl0
@`1oOgl00`09jPX0Ogmo07moO`0M07moO`8000004@1oOgl00`09jPX0Ogmo07moO`0307moO`030000
001oOgl0Ogmo01h0Ogmo0P09jPX707moO`0300WZ2P1oOgl0Ogmo0080Ogmo1009jPX>07moO`030000
001oOgl0Ogmo01X0Ogmo0P00000:07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
4@1oOgl00`09jPX0Ogmo07moO`0L07moO`0300WZ2P000000Ogmo00H0Ogmo00<02NX:07moO`1oOgl0
201oOgl00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003o
ool0oooo03l0oooo00<0000007moO`1oOgl0@`1oOgl00`09jPX0Ogmo07moO`0P07moO`030000001o
Ogl0Ogmo00l0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0P07moO`802NX:1P1o
Ogl01009jPX0Ogmo07moO`1oOgl500WZ2Pd0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000Ogmo
07moO`0:07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0401oOgl00`09jPX0Ogmo
07moO`0N07moO`0300WZ2P000000Ogmo00D0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo03l0oooo00<0
000007moO`1oOgl0@P1oOgl00`09jPX0Ogmo07moO`0R07moO`800000401oOgl01009jPX0Ogmo07mo
O`00000U07moO`802NX:101oOgl01009jPX0Ogmo07moO`1oOgl600WZ2Pd0Ogmo00<0000007moO`1o
Ogl05`1oOgl00`000000Ogmo07moO`0;07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl03`1oOgl00`09jPX0Ogmo07moO`0O07moO`0300WZ2P1oOgl0000000@0Ogmo00<02NX:07moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000
003oool0oooo03l0oooo00<0000007moO`1oOgl0@@1oOgl00`09jPX0Ogmo07moO`0U07moO`800000
3`1oOgl200WZ2P030000001oOgl0Ogmo02D0Ogmo00<02NX:07moO`1oOgl00P1oOgl01009jPX0Ogmo
07moO`1oOgl200WZ2Q00Ogmo00<0000007moO`1oOgl05P1oOgl00`000000Ogmo07moO`0<07moO`03
00WZ2P1oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl03P1oOgl00`09jPX0Ogmo07moO`0P07moO`03
00WZ2P1oOgl0Ogmo008000000P1oOgl00`09jPX0Ogmo07moO`0;07moO`030000003oool0oooo03h0
oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0?P3oool00`000000Ogmo
07moO`1107moO`0300WZ2P1oOgl0Ogmo02P0Ogmo0P00000?07moO`0300WZ2P1oOgl0Ogmo02H0Ogmo
0P09jPX207moO`0700WZ2P1oOgl0Ogmo07moO`09jPX0Ogmo00WZ2P0?07moO`030000001oOgl0Ogmo
01D0Ogmo00<0000007moO`1oOgl03P1oOgl00`09jPX0Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00h0Ogmo00<02NX:07moO`1oOgl08@1oOgl00`09jPX0Ogmo07moO`0207moO`0300000009jPX0Ogmo
00d0Ogmo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000
oooo0?ooo`0n0?ooo`030000001oOgl0Ogmo0400Ogmo00<02NX:07moO`1oOgl0:`1oOgl2000000`0
Ogmo00<0000007moO`09jPX0:@1oOgl200WZ2P0307moO`09jPX0Ogmo00<0Ogmo00<02NX:07moO`1o
Ogl03P1oOgl00`000000Ogmo07moO`0C07moO`030000001oOgl0Ogmo00l0Ogmo00<02NX:07moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0=07moO`0300WZ2P1oOgl0Ogmo02<0Ogmo00<02NX:07moO`1o
Ogl00P1oOgl00`09jPX0000007moO`0<07moO`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool03@3oool007l0oooo00<000000?ooo`3oool0?@3oool00`000000Ogmo07moO`1007moO`0300WZ
2P1oOgl0Ogmo02h0Ogmo00<0000007moO`1oOgl02@1oOgl010000000Ogmo07moO`09jPXZ07moO`80
2NX:1@1oOgl00`09jPX0Ogmo07moO`0=07moO`030000001oOgl0Ogmo0180Ogmo00<0000007moO`1o
Ogl0401oOgl00`09jPX0Ogmo07moO`0:07moO`030000001oOgl0Ogmo00`0Ogmo00<02NX:07moO`1o
Ogl0901oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0000000d0Ogmo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0m0?ooo`030000
001oOgl0Ogmo03l0Ogmo00<02NX:07moO`1oOgl0<01oOgl2000000T0Ogmo00D0000007moO`1oOgl0
Ogmo00WZ2P0[07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0301oOgl00`000000
Ogmo07moO`0A07moO`030000001oOgl0Ogmo0140Ogmo00<02NX:07moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0;07moO`0300WZ2P1oOgl0Ogmo02D0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0307mo
O`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?oo
o`00O`3oool00`000000oooo0?ooo`0m0?ooo`030000001oOgl0Ogmo03h0Ogmo00<02NX:07moO`1o
Ogl0<`1oOgl2000000H0Ogmo00<0000007moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0X07moO`<0
2NX:0`1oOgl00`09jPX0Ogmo07moO`0=07moO`030000001oOgl0Ogmo00l0Ogmo00<0000007moO`1o
Ogl04P1oOgl00`09jPX0Ogmo07moO`0907moO`030000001oOgl0Ogmo00/0Ogmo00<02NX:07moO`1o
Ogl09`1oOgl01009jPX0Ogmo07moO`09jPX407moO`8000002`1oOgl00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo03`0oooo00<0000007moO`1o
Ogl0?P1oOgl00`09jPX0Ogmo07moO`0f07moO`800000101oOgl00`000000Ogmo07moO`0407moO`03
00WZ2P1oOgl0Ogmo02P0Ogmo00@02NX:07moO`09jPX02NX:0P1oOgl00`09jPX0Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00h0Ogmo00<0000007moO`1oOgl0501oOgl00`09jPX0Ogmo07moO`0807mo
O`030000001oOgl0Ogmo00X0Ogmo00<02NX:07moO`1oOgl0:01oOgl00`09jPX0Ogmo00WZ2P0707mo
O`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?oo
o`00O`3oool00`000000oooo0?ooo`0l0?ooo`030000001oOgl0Ogmo03`0Ogmo0P09jPXk07moO`05
0000001oOgl0Ogmo07moO`0000001`1oOgl200WZ2RP0Ogmo00@02NX:07moO`1oOgl0Ogmo0`09jPX>
07moO`030000001oOgl0Ogmo00d0Ogmo00<0000007moO`1oOgl05@1oOgl00`09jPX0Ogmo07moO`08
07moO`030000001oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl0:@1oOgl00`09jPX0Ogmo00WZ2P08
07moO`030000001oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=
0?ooo`00O`3oool00`000000oooo0?ooo`0k0?ooo`030000001oOgl0Ogmo03`0Ogmo00<02NX:07mo
O`1oOgl0?01oOgl3000000X0Ogmo00<02NX:07moO`1oOgl09P1oOgl00`09jPX0Ogmo07moO`0207mo
O`802NX:3P1oOgl00`000000Ogmo07moO`0:07moO`800000601oOgl00`09jPX0Ogmo07moO`0807mo
O`030000001oOgl0Ogmo00H0Ogmo0P0000000`09jPX0Ogmo07moO`0Z07moO`0300000009jPX02NX:
00T0Ogmo0P00000807moO`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool0>`3oool00`000000Ogmo07moO`0k07moO`0300WZ2P1oOgl0Ogmo03P0
Ogmo3000000707moO`0300WZ2P1oOgl0Ogmo02D0Ogmo00<02NX:07moO`1oOgl00`1oOgl200WZ2Pd0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0H07moO`0300WZ2P1oOgl0Ogmo00L0
Ogmo00<0000007moO`1oOgl0101oOgl300WZ2P0300000009jPX0Ogmo02`0Ogmo00<0000000WZ2P1o
Ogl02`1oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool03@3oool007l0oooo00<000000?ooo`3oool0>P3oool00`000000Ogmo07moO`0k07moO`0300WZ
2P1oOgl0Ogmo02X0Ogmo3`00000707moO`030000001oOgl000000080Ogmo200000000`09jPX0Ogmo
07moO`0U07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0`09jPX;07moO`030000001oOgl0Ogmo00P0Ogmo
00<0000007moO`1oOgl06@1oOgl00`09jPX0Ogmo07moO`0707moO`030000001oOgl02NX:00L02NX:
0P1oOgl00`09jPX0Ogmo07moO`0[07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo0P00000607moO`030000
003oool0oooo03X0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0>P3o
ool00`000000Ogmo07moO`0j07moO`0300WZ2P1oOgl0Ogmo01`0Ogmo3`00000E07moO`050000001o
Ogl0Ogmo07moO`0000002P1oOgl00`09jPX0000000000005000001l0Ogmo00<02NX:07moO`1oOgl0
0`1oOgl00`09jPX0Ogmo07moO`0200WZ2PX0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo
07moO`0J07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00@0000007moO`1oOgl0Ogmo1009jPX507moO`03
00WZ2P1oOgl0Ogmo02T0Ogmo00<02NX:07moO`1oOgl03P1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0
>P3oool00`000000Ogmo07moO`0i07moO`0300WZ2P1oOgl0Ogmo00l0Ogmo3P00000T07moO`030000
001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0407moO`T00000
5`1oOgl00`09jPX0Ogmo07moO`0307moO`0500WZ2P1oOgl0Ogmo07moO`09jPX02@1oOgl00`000000
Ogmo07moO`0507moO`030000001oOgl0Ogmo01`0Ogmo00<02NX:07moO`1oOgl01P1oOgl200000080
2NX:00<0Ogmo00WZ2P09jPX01`1oOgl00`09jPX0Ogmo07moO`0W07moO`0300WZ2P1oOgl0Ogmo0100
Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00d0
oooo001o0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl0>@1oOgl01009jPX0Ogmo
07moO`1oOgl?000000<0oooo00<0000007moO`1oOgl0;01oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00P0Ogmo0P09jPX00`1oOgl02NX:07moO`0:07moO`P000003`1oOgl00`09jPX0
Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P09jPX707moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl07@1oOgl00`09jPX0Ogmo07moO`0507moO`<02NX:00<0oooo00000009
jPX02P0000000`09jPX000000000000V07moO`0300WZ2P1oOgl0Ogmo0140Ogmo0P00000307moO`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0
>@3oool00`000000Ogmo07moO`0^07moO`X0000000<02NX:0000000000000P00000B0?ooo`030000
001oOgl0Ogmo02/0Ogmo00<0000007moO`1oOgl01@1oOgl2000000X0Ogmo0P09jPXC07moO`P00000
201oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P09jPX607moO`030000
001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl07P1oOgl00`09jPX0Ogmo07moO`0207moO`<02NX:
00<000000?ooo`3oool03P3oool00`09jPX0oooo0000000>000001H0Ogmo00<02NX:07moO`1oOgl0
501oOgl010000000Ogmo07moO`00000k0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000
003oool0oooo03P0oooo00<0000007moO`1oOgl08@1oOgl>000000T0oooo00<02NX:0?ooo`3oool0
5@3oool00`000000Ogmo07moO`0[07moO`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl0
201oOgl200WZ2QX0Ogmo200000000`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00D0Ogmo
0P09jPX407moO`050000001oOgl0Ogmo07moO`0000008@1oOgl00`09jPX0Ogmo07moO`0200WZ2P<0
Ogmo00<000000?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0=0?ooo`h000001`1oOgl00`09jPX0
Ogmo07moO`0F07moO`80000000<0Ogmo0000003oool0>@3oool00`000000oooo0?ooo`0=0?ooo`00
O`3oool00`000000oooo0?ooo`0h0?ooo`030000001oOgl0Ogmo0180Ogmo3`00000F0?ooo`0300WZ
2P3oool0oooo01H0oooo00<0000007moO`1oOgl0:`1oOgl00`000000Ogmo07moO`0807moO`030000
001oOgl0Ogmo00D0Ogmo1@09jPXR07moO`0300WZ2P000000000000<0000000<02NX:0000001oOgl0
1P1oOgl01@09jPX0Ogmo07moO`1oOgl000000080Ogmo00<0000007moO`1oOgl0801oOgl300WZ2PD0
Ogmo00<000000?ooo`3oool0403oool00`09jPX0oooo0?ooo`0J0?ooo`H0000000<02NX:00000000
00001P00000C07moO`800000>P3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo
0?ooo`0h0?ooo`030000001oOgl0Ogmo00<0Ogmo3`00000T0?ooo`0300WZ2P3oool0oooo01P0oooo
00<0000007moO`1oOgl0:@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00H0Ogmo
1009jPXQ07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`0000001`00000200WZ2P80Ogmo
0P00000P07moO`@02NX:00<0Ogmo00WZ2P1oOgl00`1oOgl00`000000oooo0?ooo`0B0?ooo`0300WZ
2P3oool0oooo01l0oooo00<02NX:0?ooo`3oool01P3oool?000000D0Ogmo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0g0?ooo`L00000<P3o
ool00`09jPX0oooo0?ooo`0I0?ooo`030000001oOgl0Ogmo02T0Ogmo00<0000007moO`1oOgl02`1o
Ogl00`000000Ogmo07moO`0707moO`802NX:8P1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1o
Ogl0Ogmo00L0Ogmo00@0000000WZ2P09jPX000007`1oOgl200WZ2P0307moO`09jPX02NX:00<02NX:
101oOgl00`000000oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01d0oooo00<02NX:0?ooo`3oool0
5P3oool7000003T0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0K`3o
ool00`09jPX0oooo0?ooo`0J0?ooo`030000001oOgl0Ogmo02T0Ogmo00<0000007moO`1oOgl0301o
Ogl2000000P0Ogmo0P09jPX2000001l0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07mo
O`0:07moO`802NX:6`1oOgl300WZ2P<0Ogmo1@09jPX407moO`030000003oool0oooo01@0oooo00<0
2NX:0?ooo`3oool06`3oool00`09jPX0oooo0?ooo`1G0?ooo`030000003oool0oooo00d0oooo001o
0?ooo`030000003oool0oooo06h0oooo00<02NX:0?ooo`3oool06`3oool00`000000Ogmo07moO`0X
07moO`030000001oOgl0Ogmo00l0Ogmo00<0000007moO`1oOgl01`1oOgl200WZ2R00Ogmo00<02NX:
07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0;07moO`0300WZ2P1oOgl0Ogmo01H0Ogmo0P09jPX7
07moO`@02NX:101oOgl00`000000oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`1]0?oo
o`0300WZ2P3oool0oooo01d0oooo00<0000007moO`1oOgl09`1oOgl00`000000Ogmo07moO`0@07mo
O`030000001oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl07@1oOgl00`09jPX0Ogmo07moO`0307mo
O`0300WZ2P1oOgl0Ogmo00`0Ogmo0P09jPXC07moO`<02NX:2@1oOgl400WZ2P<0Ogmo00<000000?oo
o`3oool05`3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo05P0oooo00<000000?oo
o`3oool03@3oool007l0oooo00<000000?ooo`3oool0K03oool00`09jPX0oooo0?ooo`0N0?ooo`03
0000001oOgl0Ogmo02L0Ogmo00<0000007moO`1oOgl04@1oOgl00`000000Ogmo07moO`0807moO`80
2NX:7P1oOgl00`09jPX0Ogmo00WZ2P0307moO`0300WZ2P1oOgl0Ogmo00d0Ogmo0P09jPX>07moO`<0
2NX:3@1oOgl300WZ2P<0Ogmo00<000000?ooo`3oool0603oool00`09jPX0oooo0?ooo`0F0?ooo`03
00WZ2P3oool0oooo05T0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0
J`3oool00`09jPX0oooo0?ooo`0O0?ooo`030000001oOgl0Ogmo02H0Ogmo00<0000007moO`1oOgl0
4`1oOgl00`000000Ogmo07moO`0907moO`0300WZ2P1oOgl0Ogmo01/0Ogmo00<02NX:07moO`09jPX0
0`1oOgl00`09jPX0Ogmo07moO`0?07moO`802NX:2P1oOgl200WZ2Q40Ogmo0P09jPX307moO`030000
003oool0oooo01T0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`1I0?ooo`030000
003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo06X0oooo00<02NX:0?ooo`3oool0803o
ool00`000000Ogmo07moO`0V07moO`030000001oOgl0Ogmo01@0Ogmo0P00000:07moO`802NX:6@1o
Ogl500WZ2P@0Ogmo00<02NX:07moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0407moO`<02NX:4`1o
Ogl200WZ2P<0Ogmo00<000000?ooo`3oool06P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3o
ool0oooo05X0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0J@3oool0
0`09jPX0oooo0?ooo`0R0?ooo`030000001oOgl0Ogmo02D0Ogmo00<0000007moO`1oOgl05P1oOgl0
0`000000Ogmo07moO`0907moO`0300WZ2P1oOgl0Ogmo01L0Ogmo1@09jPX407moO`0300WZ2P1oOgl0
Ogmo0100Ogmo0P09jPX0100000002NX:00WZ2P09jPXF07moO`8000000P1oOgl00`000000oooo0?oo
o`0L0?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool0F`3oool00`000000oooo0?oo
o`0=0?ooo`00O`3oool00`000000oooo0?ooo`1X0?ooo`0300WZ2P3oool0oooo02<0oooo00<00000
07moO`1oOgl0901oOgl00`000000Ogmo07moO`0H07moO`030000001oOgl0Ogmo00T0Ogmo0P09jPXH
07moO`@02NX:101oOgl00`09jPX0Ogmo07moO`0?07moO`@02NX:00<0000007moO`1oOgl05P1oOgl2
00000080Ogmo00<000000?ooo`3oool07@3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0
oooo05`0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0I`3oool00`09
jPX0oooo0?ooo`0T0?ooo`030000001oOgl0Ogmo02@0Ogmo00<0000007moO`1oOgl06@1oOgl00`00
0000Ogmo07moO`0:07moO`0300WZ2P1oOgl0Ogmo01H0Ogmo0`09jPX507moO`0300WZ2P1oOgl0Ogmo
00P0Ogmo1P09jPXQ07moO`030000003oool0oooo01h0oooo00<02NX:0?ooo`3oool03P3oool00`09
jPX0oooo0?ooo`1L0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo06H0
oooo00<02NX:0?ooo`3oool09@3oool00`000000Ogmo07moO`0T07moO`030000001oOgl0Ogmo01X0
Ogmo00<0000007moO`1oOgl02P1oOgl200WZ2QL0Ogmo0P09jPX507moO`0400WZ2P1oOgl0Ogmo07mo
O`L02NX:9`1oOgl00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?oo
o`3oool0G@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`1U0?ooo`03
00WZ2P3oool0oooo02L0oooo00<0000007moO`1oOgl08P1oOgl00`000000Ogmo07moO`0L07moO`80
0000301oOgl00`09jPX0Ogmo07moO`0E07moO`802NX:0P1oOgl600WZ2Rd0Ogmo00<000000?ooo`3o
ool08@3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo05h0oooo00<000000?ooo`3o
ool03@3oool007l0oooo00<000000?ooo`3oool0H`3oool200WZ2RX0oooo00<0000007moO`1oOgl0
8P1oOgl00`000000Ogmo07moO`0N07moO`030000001oOgl0Ogmo00X0Ogmo0P09jPXE07moO`040000
0009jPX02NX:00WZ2P<0Ogmo00<02NX:07moO`1oOgl0;@1oOgl00`000000oooo0?ooo`0R0?ooo`03
00WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool0GP3oool00`000000oooo0?ooo`0=0?ooo`00
O`3oool00`000000oooo0?ooo`1R0?ooo`0300WZ2P3oool0oooo02X0oooo00<0000007moO`1oOgl0
8P1oOgl00`000000Ogmo07moO`0O07moO`030000001oOgl0Ogmo00/0Ogmo00<02NX:07moO`1oOgl0
4P1oOgl2000000H0Ogmo00<02NX:07moO`1oOgl0;01oOgl00`000000oooo0?ooo`0S0?ooo`0300WZ
2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool0G`3oool00`000000oooo0?ooo`0=0?ooo`00O`3o
ool00`000000oooo0?ooo`1Q0?ooo`0300WZ2P3oool0oooo02`0oooo00<0000007moO`1oOgl0801o
Ogl00`000000Ogmo07moO`0Q07moO`030000001oOgl0Ogmo00/0Ogmo0P09jPXJ07moO`0300WZ2P1o
Ogl0Ogmo02/0Ogmo00<000000?ooo`3oool09@3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3o
ool0oooo0600oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0H03oool0
0`09jPX0oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo0200Ogmo00<0000007moO`1oOgl08P1oOgl0
0`000000Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo01P0Ogmo00<02NX:07moO`1oOgl0:P1oOgl0
0`000000oooo0?ooo`0V0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0H03oool0
0`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`1O0?ooo`0300WZ2P3oool0oooo
02h0oooo00<0000007moO`1oOgl0801oOgl00`000000Ogmo07moO`0S07moO`8000003@1oOgl00`09
jPX0Ogmo07moO`0G07moO`0300WZ2P1oOgl0Ogmo02X0Ogmo00<000000?ooo`3oool09`3oool00`09
jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo0640oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool0GP3oool00`09jPX0oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo01l0
Ogmo00<0000007moO`1oOgl09P1oOgl00`000000Ogmo07moO`0;07moO`802NX:601oOgl00`09jPX0
Ogmo07moO`0Y07moO`030000003oool0oooo02P0oooo00@02NX:0?ooo`3oool02NX:I03oool00`00
0000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`1M0?ooo`0300WZ2P3oool0oooo0340
oooo00<0000007moO`1oOgl07P1oOgl00`000000Ogmo07moO`0W07moO`030000001oOgl0Ogmo00`0
Ogmo00<02NX:07moO`1oOgl05@1oOgl00`09jPX0Ogmo07moO`0X07moO`030000003oool0oooo02X0
oooo0P09jPYU0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo05`0oooo
00<02NX:0?ooo`3oool0<P3oool00`000000Ogmo07moO`0N07moO`030000001oOgl0Ogmo02P0Ogmo
00<0000007moO`1oOgl0301oOgl200WZ2QH0Ogmo00<02NX:07moO`1oOgl09`1oOgl00`000000oooo
0?ooo`0[0?ooo`0300WZ2P3oool0oooo06<0oooo00<000000?ooo`3oool03@3oool007l0oooo00<0
00000?ooo`3oool0F`3oool00`09jPX0oooo0?ooo`0c0?ooo`030000001oOgl0Ogmo01d0Ogmo00<0
000007moO`1oOgl0:P1oOgl00`000000Ogmo07moO`0=07moO`0500WZ2P1oOgl0Ogmo07moO`09jPX0
4@1oOgl00`09jPX0Ogmo07moO`0W07moO`030000003oool0oooo02X0oooo00<02NX:0?ooo`09jPX0
I03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`1J0?ooo`0300WZ2P3o
ool0oooo03@0oooo00<0000007moO`1oOgl07@1oOgl00`000000Ogmo07moO`0[07moO`8000003P1o
Ogl200WZ2P0307moO`09jPX0Ogmo0140Ogmo00<02NX:07moO`1oOgl09P1oOgl00`000000oooo0?oo
o`0Y0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0H`3oool00`000000oooo0?ooo`0=0?ooo`00O`3o
ool00`000000oooo0?ooo`1I0?ooo`0300WZ2P3oool0oooo03H0oooo00<0000007moO`1oOgl0701o
Ogl00`000000Ogmo07moO`0Z07moO`040000003oool0oooo000000l0Ogmo00<02NX:07moO`09jPX0
4@1oOgl00`09jPX0Ogmo07moO`0U07moO`030000003oool0oooo02X0oooo00<02NX:0?ooo`3oool0
0P3oool00`09jPX0oooo0?ooo`1P0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003o
ool0oooo05P0oooo00<02NX:0?ooo`3oool0=`3oool00`000000Ogmo07moO`0K07moO`030000001o
Ogl0Ogmo02X0Ogmo00<000000?ooo`3oool00P3oool00`000000Ogmo07moO`0=07moO`<02NX:4@1o
Ogl00`09jPX0Ogmo07moO`0T07moO`030000003oool0oooo02T0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`1O0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0
oooo05L0oooo00<02NX:0?ooo`3oool0>03oool00`000000Ogmo07moO`0K07moO`030000001oOgl0
Ogmo02T0Ogmo00<000000?ooo`3oool0103oool00`000000Ogmo07moO`0:07moO`H02NX:401oOgl0
0`09jPX0Ogmo07moO`0T07moO`030000003oool0oooo02P0oooo00<02NX:0?ooo`3oool01P3oool0
0`09jPX0oooo0?ooo`1N0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo
05H0oooo00<02NX:0?ooo`3oool0>@3oool00`000000Ogmo07moO`0K07moO`030000001oOgl0Ogmo
02P0Ogmo00<000000?ooo`3oool01P3oool00`000000Ogmo07moO`0;07moO`D02NX:401oOgl00`09
jPX0Ogmo07moO`0S07moO`030000003oool0oooo02P0oooo00<02NX:0?ooo`3oool01`3oool00`09
jPX0oooo0?ooo`1M0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo05D0
oooo00<02NX:0?ooo`3oool0>`3oool00`000000Ogmo07moO`0I07moO`030000001oOgl0Ogmo02L0
Ogmo0P00000:0?ooo`8000003P1oOgl200WZ2P8000003P1oOgl00`09jPX0Ogmo07moO`0R07moO`03
0000003oool0oooo02P0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`1L0?ooo`03
0000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo05@0oooo00<02NX:0?ooo`3oool0
?03oool00`000000Ogmo07moO`0I07moO`030000001oOgl0Ogmo02H0Ogmo00<000000?ooo`3oool0
303oool00`000000Ogmo07moO`0=07moO`0400000009jPX02NX:00WZ2Pd0Ogmo00<02NX:07moO`1o
Ogl08@1oOgl00`000000oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`1C0?ooo`0300WZ
2P3oool0oooo03d0oooo00<0000007moO`1oOgl06@1oOgl00`000000Ogmo07moO`0U07moO`030000
003oool0oooo00h0oooo00<0000007moO`1oOgl0401oOgl300WZ2P/0Ogmo00<02NX:07moO`1oOgl0
801oOgl00`000000oooo0?ooo`0V0?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool0
FP3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`1B0?ooo`0300WZ2P3o
ool0oooo03h0oooo00<0000007moO`1oOgl0601oOgl00`000000Ogmo07moO`0U07moO`030000003o
ool0oooo0100oooo00<0000007moO`1oOgl04P1oOgl300WZ2PP0Ogmo00<02NX:07moO`1oOgl0801o
Ogl00`000000oooo0?ooo`0V0?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool0F@3o
ool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`1A0?ooo`0300WZ2P3oool0
oooo0400oooo00<0000007moO`1oOgl05`1oOgl00`000000Ogmo07moO`0T07moO`030000003oool0
oooo0180oooo00<0000007moO`1oOgl0501oOgl300WZ2PH0Ogmo00<02NX:07moO`1oOgl07P1oOgl0
0`000000oooo0?ooo`0V0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0F03oool0
0`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`1@0?ooo`0300WZ2P3oool0oooo
0440oooo00<0000007moO`1oOgl05`1oOgl00`000000Ogmo07moO`0R07moO`8000005P3oool20000
01L0Ogmo0`09jPX307moO`0300WZ2P1oOgl0Ogmo01h0Ogmo00<000000?ooo`3oool09@3oool00`09
jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo05L0oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool0C`3oool00`09jPX0oooo0?ooo`120?ooo`030000001oOgl0Ogmo01H0
Ogmo00<0000007moO`1oOgl08P1oOgl00`000000oooo0?ooo`0H0?ooo`030000001oOgl0Ogmo01L0
Ogmo0`09jPX00`1oOgl02NX:07moO`0N07moO`030000003oool0oooo02D0oooo00<02NX:0?ooo`3o
ool04`3oool00`09jPX0oooo0?ooo`1F0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000
003oool0oooo04h0oooo00<02NX:0?ooo`3oool0@`3oool00`000000Ogmo07moO`0F07moO`030000
001oOgl0Ogmo0240Ogmo00<000000?ooo`3oool06P3oool00`000000Ogmo07moO`0I07moO`<02NX:
7P1oOgl00`000000oooo0?ooo`0T0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0
E@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`1=0?ooo`0300WZ2P3o
ool0oooo04D0oooo00<0000007moO`1oOgl05@1oOgl00`000000Ogmo07moO`0P07moO`030000003o
ool0oooo01`0oooo00<0000007moO`1oOgl06P1oOgl400WZ2QX0Ogmo00<000000?ooo`3oool0903o
ool00`09jPX0oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo05@0oooo00<000000?ooo`3oool03@3o
ool007l0oooo00<000000?ooo`3oool0B`3oool200WZ2TP0oooo00<0000007moO`1oOgl0501oOgl0
0`000000Ogmo07moO`0O07moO`800000803oool2000001X0Ogmo00@02NX:07moO`1oOgl0Ogmo0`09
jPXG07moO`030000003oool0oooo02@0oooo00<02NX:0?ooo`3oool0603oool00`09jPX0oooo0?oo
o`1C0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo04X0oooo00<02NX:
0?ooo`3oool0B03oool00`000000Ogmo07moO`0D07moO`030000001oOgl0Ogmo01h0Ogmo00<00000
0?ooo`3oool08P3oool00`000000Ogmo07moO`0G07moO`0300000009jPX02NX:00L02NX:0P00000B
07moO`030000003oool0oooo02<0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`1B
0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo04T0oooo00<02NX:0?oo
o`3oool0B@3oool00`000000Ogmo07moO`0D07moO`030000001oOgl0Ogmo01d0Ogmo00<000000?oo
o`3oool0903oool00`000000Ogmo07moO`0F07moO`8000001@1oOgl500WZ2Q80Ogmo00<000000?oo
o`3oool08P3oool00`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo0540oooo00<000000?oo
o`3oool03@3oool007l0oooo00<000000?ooo`3oool0B03oool00`09jPX0oooo0?ooo`1;0?ooo`03
0000001oOgl0Ogmo0180Ogmo00<0000007moO`1oOgl07@1oOgl00`000000oooo0?ooo`0V0?ooo`03
0000001oOgl0Ogmo0240Ogmo0P09jPX?07moO`030000003oool0oooo0280oooo00<02NX:0?ooo`3o
ool07P3oool00`09jPX0oooo0?ooo`1@0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000
003oool0oooo04L0oooo00<02NX:0?ooo`3oool0C03oool00`000000Ogmo07moO`0B07moO`030000
001oOgl0Ogmo01`0Ogmo00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0R07moO`<02NX:
301oOgl00`000000oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo01l0oooo00<02NX:0?ooo`3oool0
C`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`160?ooo`0300WZ2P3o
ool0oooo04d0oooo00<0000007moO`1oOgl04P1oOgl00`000000Ogmo07moO`0J07moO`800000;03o
ool2000002D0Ogmo0P09jPX:07moO`030000003oool0oooo0240oooo00<02NX:0?ooo`3oool08@3o
ool00`09jPX0oooo0?ooo`1>0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0
oooo04D0oooo00<02NX:0?ooo`3oool0CP3oool00`000000Ogmo07moO`0A07moO`030000001oOgl0
Ogmo01X0Ogmo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0T07moO`802NX:201oOgl0
0`000000oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo02<0oooo00<02NX:0?ooo`3oool0C@3oool0
0`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`140?ooo`0300WZ2P3oool0oooo
0500oooo00<0000007moO`1oOgl0401oOgl00`000000Ogmo07moO`0I07moO`030000003oool0oooo
0300oooo00<0000007moO`1oOgl09@1oOgl300WZ2P@0Ogmo00<000000?ooo`3oool08@3oool00`09
jPX0oooo0?ooo`0T0?ooo`0300WZ2P3oool0oooo04`0oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool0@`3oool00`09jPX0oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo0100
Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`0b0?ooo`030000001oOgl0Ogmo02L0
Ogmo0P09jPX207moO`030000003oool0oooo0200oooo00<02NX:0?ooo`3oool09P3oool00`09jPX0
oooo0?ooo`1;0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo0480oooo
00<02NX:0?ooo`3oool0DP3oool00`000000Ogmo07moO`0?07moO`030000001oOgl0Ogmo01P0Ogmo
00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0X07moO`802NX:00<000000?ooo`3oool0
7`3oool00`09jPX0oooo0?ooo`0X0?ooo`0300WZ2P3oool0oooo04X0oooo00<000000?ooo`3oool0
3@3oool007l0oooo00<000000?ooo`3oool0@@3oool00`09jPX0oooo0?ooo`1C0?ooo`030000001o
Ogl0Ogmo00l0Ogmo00<0000007moO`1oOgl05P1oOgl2000003P0oooo0P00000Z07moO`802NX:803o
ool00`09jPX0oooo0?ooo`0Y0?ooo`0300WZ2P3oool0oooo04T0oooo00<000000?ooo`3oool03@3o
ool007l0oooo00<000000?ooo`3oool0@03oool00`09jPX0oooo0?ooo`1E0?ooo`030000001oOgl0
Ogmo00h0Ogmo00<0000007moO`1oOgl05@1oOgl00`000000oooo0?ooo`0j0?ooo`030000001oOgl0
Ogmo02H0Ogmo00<000000?ooo`3oool00`09jPXL0?ooo`0300WZ2P3oool0oooo02/0oooo00<02NX:
0?ooo`3oool0B03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0o0?oo
o`0300WZ2P3oool0oooo05H0oooo00<0000007moO`1oOgl03@1oOgl00`000000Ogmo07moO`0E07mo
O`030000003oool0oooo03`0oooo00<0000007moO`1oOgl09@1oOgl00`000000oooo0?ooo`030?oo
o`802NX:6@3oool00`09jPX0oooo0?ooo`0]0?ooo`0300WZ2P3oool0oooo04L0oooo00<000000?oo
o`3oool03@3oool007l0oooo00<000000?ooo`3oool0?P3oool00`09jPX0oooo0?ooo`1G0?ooo`03
0000001oOgl0Ogmo00d0Ogmo00<0000007moO`1oOgl0501oOgl00`000000oooo0?ooo`0n0?ooo`03
0000001oOgl0Ogmo02@0Ogmo00<000000?ooo`3oool01@3oool200WZ2QH0oooo00<02NX:0?ooo`3o
ool0;`3oool00`09jPX0oooo0?ooo`160?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000
003oool0oooo03d0oooo00<02NX:0?ooo`3oool0F03oool00`000000Ogmo07moO`0=07moO`030000
001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0@03oool00`000000Ogmo07moO`0S07moO`030000
003oool0oooo00L0oooo0`09jPXC0?ooo`0300WZ2P3oool0oooo0300oooo00<02NX:0?ooo`3oool0
A@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0l0?ooo`0300WZ2P3o
ool0oooo05X0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0B07moO`800000A03o
ool200000280Ogmo00<000000?ooo`3oool02`3oool200WZ2Q00oooo00<02NX:0?ooo`3oool0<P3o
ool00`09jPX0oooo0?ooo`140?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0
oooo03/0oooo00<02NX:0?ooo`3oool0F`3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0
Ogmo0140Ogmo00<000000?ooo`3oool0AP3oool00`000000Ogmo07moO`0O07moO`030000003oool0
oooo00d0oooo0P09jPX=0?ooo`0300WZ2P3oool0oooo03@0oooo00<02NX:0?ooo`3oool0@`3oool0
0`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0j0?ooo`0300WZ2P3oool0oooo
05`0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0@07moO`030000003oool0oooo
04P0oooo00<0000007moO`1oOgl07P1oOgl00`000000oooo0?ooo`0?0?ooo`802NX:2`3oool00`09
jPX0oooo0?ooo`0e0?ooo`0300WZ2P3oool0oooo0480oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`1M0?ooo`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl0401oOgl00`000000oooo0?ooo`1:0?ooo`030000001oOgl0Ogmo01d0
Ogmo00<000000?ooo`3oool04@3oool300WZ2PL0oooo00<02NX:0?ooo`3oool0=`3oool00`09jPX0
oooo0?ooo`110?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo03P0oooo
00<02NX:0?ooo`3oool0G`3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00l0Ogmo
00<000000?ooo`3oool0C03oool00`000000Ogmo07moO`0K07moO`030000003oool0oooo01D0oooo
0P09jPX40?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool0@03oool00`000000oooo
0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0g0?ooo`0300WZ2P3oool0oooo0600oooo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0=07moO`800000D03oool2000001/0Ogmo00<0
00000?ooo`3oool05`3oool200WZ2P80oooo00<02NX:0?ooo`3oool0>P3oool00`09jPX0oooo0?oo
o`0o0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo03H0oooo00<02NX:
0?ooo`3oool0H@3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo00d0Ogmo00<00000
0?ooo`3oool0DP3oool00`000000Ogmo07moO`0H07moO`030000003oool0oooo01T0oooo0`09jPXm
0?ooo`0300WZ2P3oool0oooo03h0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?oo
o`3oool0=@3oool00`09jPX0oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000oooo0?ooo`1D0?ooo`030000001oOgl0Ogmo01L0Ogmo00<000000?oo
o`3oool06@3oool00`09jPX0oooo0?ooo`0200WZ2S`0oooo00<02NX:0?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0c0?ooo`802NX:IP3oool00`000000
Ogmo07moO`0707moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0EP3oool00`000000
Ogmo07moO`0E07moO`030000003oool0oooo01X0oooo00<02NX:0?ooo`3oool00P3oool200WZ2S/0
oooo00<02NX:0?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo
0?ooo`0b0?ooo`0300WZ2P3oool0oooo06H0oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo
07moO`0;07moO`030000003oool0oooo05P0oooo00<0000007moO`1oOgl0501oOgl00`000000oooo
0?ooo`0I0?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPXj0?ooo`0300WZ2P3oool0oooo03/0oooo
00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0<@3oool00`09jPX0oooo0?oo
o`1W0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl02@1oOgl2000005`0oooo0P00
000D07moO`030000003oool0oooo01P0oooo00<02NX:0?ooo`3oool0203oool300WZ2SP0oooo00<0
2NX:0?ooo`3oool0>P3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0`
0?ooo`0300WZ2P3oool0oooo06P0oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`08
07moO`030000003oool0oooo05h0oooo00<0000007moO`1oOgl04@1oOgl00`000000oooo0?ooo`0G
0?ooo`0300WZ2P3oool0oooo00`0oooo0P09jPXg0?ooo`0300WZ2P3oool0oooo03T0oooo00<00000
0?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0;`3oool00`09jPX0oooo0?ooo`1Z0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`1P0?oo
o`030000001oOgl0Ogmo00l0Ogmo00<000000?ooo`3oool0603oool00`09jPX0oooo0?ooo`0>0?oo
o`802NX:=P3oool00`09jPX0oooo0?ooo`0h0?ooo`030000003oool0oooo00d0oooo001o0?ooo`03
0000003oool0oooo02h0oooo00<02NX:0?ooo`3oool0J`3oool00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool0HP3oool00`000000Ogmo07moO`0>07moO`03
0000003oool0oooo01L0oooo00<02NX:0?ooo`3oool04@3oool300WZ2S@0oooo00<02NX:0?ooo`3o
ool0=`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0]0?ooo`0300WZ
2P3oool0oooo06`0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0607moO`030000
003oool0oooo06@0oooo00<0000007moO`1oOgl03@1oOgl00`000000oooo0?ooo`0F0?ooo`0300WZ
2P3oool0oooo01D0oooo0P09jPXc0?ooo`0300WZ2P3oool0oooo03H0oooo00<000000?ooo`3oool0
3@3oool007l0oooo00<000000?ooo`3oool0;03oool00`09jPX0oooo0?ooo`1]0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl01@1oOgl2000006P0oooo0P00000=07moO`030000003o
ool0oooo01H0oooo00<02NX:0?ooo`3oool05`3oool200WZ2S80oooo00<02NX:0?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0[0?ooo`0300WZ2P3oool0
oooo06l0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`030000003oool0
oooo06X0oooo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0F0?ooo`0300WZ2P3oool0
oooo01X0oooo0P09jPXa0?ooo`0300WZ2P3oool0oooo03@0oooo00<000000?ooo`3oool03@3oool0
07l0oooo00<000000?ooo`3oool0:P3oool00`09jPX0oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo
0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1/0?ooo`030000001oOgl0Ogmo
00P0Ogmo00<000000?ooo`3oool05@3oool00`09jPX0oooo0?ooo`0M0?ooo`<02NX:;`3oool00`09
jPX0oooo0?ooo`0c0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo02T0
oooo00<02NX:0?ooo`3oool0L@3oool01@000000Ogmo07moO`1oOgl0000000D0Ogmo00<000000?oo
o`3oool0KP3oool00`000000Ogmo07moO`0707moO`030000003oool0oooo01D0oooo00<02NX:0?oo
o`3oool0803oool200WZ2Rh0oooo00<02NX:0?ooo`3oool0<P3oool00`000000oooo0?ooo`0=0?oo
o`00O`3oool00`000000oooo0?ooo`0X0?ooo`0300WZ2P3oool0oooo0780oooo00D0000007moO`1o
Ogl0Ogmo0000000407moO`030000003oool0oooo0700oooo00<0000007moO`1oOgl01P1oOgl00`00
0000oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo02<0oooo0P09jPX]0?ooo`0300WZ2P3oool0oooo
0340oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool09`3oool00`09jPX0
oooo0?ooo`1d0?ooo`040000001oOgl0Ogmo00000080Ogmo0P00001d0?ooo`8000001@1oOgl00`00
0000oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo02H0oooo0`09jPX[0?ooo`0300WZ2P3oool0oooo
0300oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool09P3oool00`09jPX0
oooo0?ooo`1e0?ooo`030000001oOgl000000080Ogmo00<000000?ooo`3oool0MP3oool00`000000
Ogmo07moO`0207moO`030000003oool0oooo01<0oooo00<02NX:0?ooo`3oool0:P3oool200WZ2RX0
oooo00<02NX:0?ooo`3oool0;`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo
0?ooo`0U0?ooo`0300WZ2P3oool0oooo07H0oooo00D0000007moO`000000Ogmo0000001j0?ooo`05
0000001oOgl0Ogmo07moO`0000005@3oool00`09jPX0oooo0?ooo`0/0?ooo`802NX::@3oool00`09
jPX0oooo0?ooo`0^0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo02@0
oooo00<02NX:0?ooo`3oool0M`3oool010000000Ogmo00000000001l0?ooo`040000001oOgl0Ogmo
000001@0oooo00<02NX:0?ooo`3oool0;`3oool200WZ2RP0oooo00<02NX:0?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo
07T0oooo0P00001n0?ooo`800000503oool00`09jPX0oooo0?ooo`0b0?ooo`<02NX:9P3oool00`09
jPX0oooo0?ooo`0/0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo0280
oooo00<02NX:0?ooo`3oool0NP3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0180
oooo00<02NX:0?ooo`3oool0=@3oool200WZ2RD0oooo00<02NX:0?ooo`3oool0:`3oool00`000000
oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo0?l0oooo
4@3oool00`09jPX0oooo0?ooo`0h0?ooo`802NX:903oool00`09jPX0oooo0?ooo`0Z0?ooo`030000
003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo0200oooo00<02NX:0?ooo`3oool0o`3o
oolA0?ooo`0300WZ2P3oool0oooo03/0oooo0P09jPXS0?ooo`0300WZ2P3oool0oooo02T0oooo00<0
00000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`3o
0?oooa80oooo00<02NX:0?ooo`3oool0?@3oool300WZ2R40oooo00<02NX:0?ooo`3oool0:03oool0
0`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo
0?l0oooo4P3oool00`09jPX0oooo0?ooo`110?ooo`802NX:803oool00`09jPX0oooo0?ooo`0W0?oo
o`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo01d0oooo00<02NX:0?ooo`3o
ool0o`3ooolB0?ooo`0300WZ2P3oool0oooo04@0oooo0P09jPXO0?ooo`0300WZ2P3oool0oooo02H0
oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool06`3oool200WZ2_l0oooo
503oool00`09jPX0oooo0?ooo`170?ooo`<02NX:7@3oool00`09jPX0oooo0?ooo`0U0?ooo`030000
003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo01X0oooo00<02NX:0?ooo`3oool0o`3o
oolD0?ooo`0300WZ2P3oool0oooo04X0oooo0P09jPXL0?ooo`0300WZ2P3oool0oooo02@0oooo00<0
00000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool06@3oool00`09jPX0oooo0?ooo`3o
0?oooa@0oooo00<02NX:0?ooo`3oool0C@3oool200WZ2Q/0oooo00<02NX:0?ooo`3oool08`3oool0
0`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo
0?l0oooo503oool00`09jPX0oooo0?ooo`1@0?ooo`802NX:6P3oool00`09jPX0oooo0?ooo`0R0?oo
o`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo01L0oooo00<02NX:0?ooo`3o
ool0o`3ooolE0?ooo`0300WZ2P3oool0oooo0580oooo0`09jPXH0?ooo`0300WZ2P3oool0oooo0240
oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool05P3oool00`09jPX0oooo
0?ooo`3o0?oooaD0oooo00<02NX:0?ooo`3oool0EP3oool200WZ2QL0oooo00<02NX:0?ooo`3oool0
803oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0E0?ooo`0300WZ2P3o
ool0oooo0?l0oooo5@3oool00`09jPX0oooo0?ooo`1I0?ooo`802NX:5P3oool00`09jPX0oooo0?oo
o`0O0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo01@0oooo00<02NX:
0?ooo`3oool0o`3ooolF0?ooo`0300WZ2P3oool0oooo05/0oooo0`09jPXD0?ooo`0300WZ2P3oool0
oooo01h0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool04`3oool00`09
jPX0oooo0?ooo`3o0?oooaH0oooo00<02NX:0?ooo`3oool0G`3oool200WZ2Q<0oooo00<02NX:0?oo
o`3oool07@3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0B0?ooo`03
00WZ2P3oool0oooo0?l0oooo5P3oool00`09jPX0oooo0?ooo`1R0?ooo`802NX:4P3oool00`09jPX0
oooo0?ooo`0L0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo0140oooo
00<02NX:0?ooo`3oool0o`3ooolF0?ooo`0300WZ2P3oool0oooo06D0oooo0P09jPXA0?ooo`0300WZ
2P3oool0oooo01/0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool0403o
ool00`09jPX0oooo0?ooo`3o0?oooaL0oooo00<02NX:0?ooo`3oool0I`3oool300WZ2Pl0oooo00<0
2NX:0?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`0?
0?ooo`0300WZ2P3oool0oooo0?l0oooo5`3oool00`09jPX0oooo0?ooo`1[0?ooo`802NX:3P3oool0
0`09jPX0oooo0?ooo`0I0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo
00h0oooo00<02NX:0?ooo`3oool0o`3ooolG0?ooo`0300WZ2P3oool0oooo06h0oooo0P09jPX=0?oo
o`0300WZ2P3oool0oooo01P0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3o
ool03@3oool00`09jPX0oooo0?ooo`3o0?oooaP0oooo00<02NX:0?ooo`3oool0L03oool300WZ2P/0
oooo00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo
0?ooo`0<0?ooo`0300WZ2P3oool0oooo0?l0oooo5@3oool01009jPX0oooo0?ooo`09jPYf0?ooo`80
2NX:2P3oool00`09jPX0oooo0?ooo`0F0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000
003oool0oooo00P0oooo00@02NX:0?ooo`3oool02NX:o`3ooolH0?ooo`0300WZ2P3oool02NX:07T0
oooo0P09jPX90?ooo`0400WZ2P3oool0oooo00WZ2Q@0oooo00<000000?ooo`3oool03@3oool007l0
oooo00<000000?ooo`3oool0203oool00`09jPX0oooo00WZ2P3o0?oooaP0oooo0P09jPX00`3oool0
2NX:0?ooo`1j0?ooo`802NX:203oool00`09jPX0oooo00WZ2P0D0?ooo`030000003oool0oooo00d0
oooo001o0?ooo`030000003oool0oooo00L0oooo0`09jP[o0?oooaT0oooo1@09jPYl0?ooo`<02NX:
0`3oool200WZ2P040?ooo`09jPX02NX:00WZ2Q<0oooo00<000000?ooo`3oool03@3oool007l0oooo
00<000000?ooo`3oool01`3oool500WZ2_l0oooo5`3oool300WZ2X40oooo0P09jPX00`3oool02NX:
00WZ2P0400WZ2Q<0oooo00<000000?ooo`3oool03@3oool007l0oooo00<000000?ooo`3oool01P3o
ool400WZ2_l0oooo603oool300WZ2X@0oooo2009jPXB0?ooo`030000003oool0oooo00d0oooo001o
0?ooo`030000003oool0oooo00D0oooo0`09jP[o0?oooaX0oooo0P09jPZ60?ooo`P02NX:4@3oool0
0`000000oooo0?ooo`0=0?ooo`00O`3oool00`000000oooo0?ooo`050?ooo`802NX:o`3ooolK0?oo
o`0300WZ2P3oool0oooo08<0oooo2P09jPXA0?ooo`030000003oool0oooo00d0oooo001o0?ooool0
0000/000000300WZ2Q@000003`3oool008D0oooo0P00003o0?oooa`0oooo0P00002=0?ooo`@00000
7`3oool00?l0ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0ooooEP3oool00?l0
ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0ooooEP3oool00?l0ooooo`3ooomF
0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0ooooEP3oool00?l0ooooo`3ooomF0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 595}, {475.688, 0}} -> {-3.12675, -2.10002, \
0.00882942, 0.00882942}},
  CellTags->"CustomPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[stelsys = 
\tTurboPlot[
\t\t{Move[GridOfRays[{1,1}],{-3,-.25}],
\t\tsolidstelprism,
\t\tBoundary[{-2,-2,-2},{2,2,2}]},
\t\tThresholdIntensity->.1
\t]][[1]]\
\>", "Input",
  CellTags->"CustomPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99498 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0181309 1.06537 0 1.06537 [
[ 0 0 0 0 ]
[ 1 .99498 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .99498 L
0 .99498 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.91969 .3684 m
.4709 .51462 L
s
0 0 0 r
2 Mabswid
.47395 .76904 Mdot
0 g
.5 Mabswid
.91969 .3684 m
.9759 .81805 L
s
.50813 .43773 m .50813 .43773 L .56175 .49769 L .372 .397 .757 r
F
.67953 .41808 m .57461 .38394 L .5746 .38394 L .633 .072 0 r
F
.74941 .57568 m .59857 .53886 L .59857 .53886 L .642 .688 .878 r
F
.73296 .51407 m .59857 .53886 L .66675 .4978 L F
.72004 .4657 m .66675 .4978 L .72004 .4657 L F
.73296 .51407 m .6796 .50096 L .72004 .4657 L F
.6796 .50096 m .66675 .4978 L .72004 .4657 L F
.74941 .57568 m .59857 .53886 L .74941 .57568 L F
.67953 .41808 m .59857 .53886 L .59857 .53886 L .864 .745 .729 r
F
.67953 .41808 m .59857 .53886 L .67953 .41808 L F
.60202 .53371 m .71181 .45602 L .59857 .53886 L .294 .027 .326 r
F
.67953 .41808 m .67953 .41808 L .60211 .53358 L F
.67953 .41808 m .67953 .41808 L .59567 .39079 L .864 .745 .729 r
F
.60211 .53358 m .67953 .41808 L .60202 .53371 L .294 .027 .326 r
F
.67953 .41808 m .71181 .45602 L .60202 .53371 L F
.67953 .41808 m .59857 .53886 L .59567 .39079 L .864 .745 .729 r
F
.67953 .41808 m .59567 .39079 L .59567 .39079 L F
.74941 .57568 m .74941 .57568 L .65907 .55363 L .718 .333 .319 r
F
.61694 .69292 m .61694 .69292 L .61089 .64218 L .88 .712 .67 r
F
.74941 .57568 m .74941 .57568 L .68256 .63217 L .974 .848 .655 r
F
.68503 .63113 m .68213 .63171 L .68256 .63217 L .655 .165 .074 r
F
.61694 .69292 m .59857 .53886 L .59857 .53886 L .315 .301 .684 r
F
.61694 .69292 m .59857 .53886 L .66817 .61618 L F
.61694 .69292 m .59857 .53886 L .61694 .69292 L F
.61694 .69292 m .68256 .63217 L .68256 .63217 L .606 .81 .978 r
F
.68213 .63171 m .682 .63173 L .68256 .63217 L .655 .165 .074 r
F
.61694 .69292 m .68256 .63217 L .61694 .69292 L .606 .81 .978 r
F
.61694 .69292 m .66613 .61924 L .68256 .63217 L .315 .301 .684 r
F
.4686 .60514 m .4686 .60514 L .59857 .53886 L .701 .728 .871 r
F
.4686 .60514 m .59857 .53886 L .59857 .53886 L .358 .031 .267 r
F
.4686 .60514 m .59857 .53886 L .4686 .60514 L F
.47733 .59404 m .53499 .52072 L .48053 .59906 L .701 .728 .871 r
F
.48053 .59906 m .53499 .52072 L .59857 .53886 L F
.4686 .60514 m .4686 .60514 L .46212 .57013 L 0 .017 .583 r
F
.4686 .60514 m .44839 .49601 L .53499 .52072 L .701 .728 .871 r
F
.50813 .43773 m .59857 .53886 L .59857 .53886 L .787 .432 .385 r
F
.50813 .43773 m .59857 .53886 L .50813 .43773 L F
.50813 .43773 m .59857 .53886 L .59857 .53886 L F
.59857 .53886 m .59857 .53886 L .59567 .39079 L .864 .745 .729 r
F
.67953 .41808 m .72004 .4657 L .72004 .4657 L .633 .072 0 r
F
.67953 .41808 m .67953 .41808 L .72004 .4657 L F
.71181 .45602 m .72004 .4657 L .72004 .4657 L .294 .027 .326 r
F
.71181 .45602 m .72004 .4657 L .72004 .4657 L F
.71181 .45602 m .72004 .4657 L .66049 .49356 L F
.72004 .4657 m .66675 .4978 L .72004 .4657 L .642 .688 .878 r
F
.61694 .69292 m .68256 .63217 L .68256 .63217 L .606 .81 .978 r
F
.61089 .64218 m .51262 .6495 L .51262 .6495 L .88 .712 .67 r
F
.56634 .60112 m .51262 .6495 L .55694 .59245 L F
.61089 .64218 m .51262 .6495 L .56634 .60112 L F
.61089 .64218 m .55694 .59245 L .59857 .53886 L F
.59857 .53886 m .68256 .63217 L .59857 .53886 L .718 .333 .319 r
F
.35245 .62362 m .51262 .6495 L .51262 .6495 L .567 .727 .95 r
F
.35245 .62362 m .51262 .6495 L .35245 .62362 L F
.35245 .62362 m .35245 .62362 L .42941 .63606 L .705 .537 .658 r
F
.42135 .3385 m .44839 .49601 L .44839 .49601 L 0 .028 .555 r
F
.35245 .62362 m .35245 .62362 L .44839 .49601 L 0 0 0 r
F
.42135 .3385 m .44839 .49601 L .42135 .3385 L 0 .028 .555 r
F
.50813 .43773 m .44839 .49601 L .44839 .49601 L 0 0 0 r
F
.35245 .62362 m .44839 .49601 L .44839 .49601 L F
.4686 .60514 m .59857 .53886 L .54778 .60424 L .358 .031 .267 r
F
.4686 .60514 m .54055 .60433 L .51262 .6495 L F
.54055 .60433 m .54778 .60424 L .51262 .6495 L F
.4686 .60514 m .47733 .59404 L .48053 .59906 L .701 .728 .871 r
F
.4686 .60514 m .51262 .6495 L .46212 .57013 L 0 .017 .583 r
F
.4686 .60514 m .4686 .60514 L .51262 .6495 L .358 .031 .267 r
F
.4686 .60514 m .51262 .6495 L .51262 .6495 L F
.51262 .6495 m .51262 .6495 L .58177 .64245 L .665 .485 .631 r
F
.46212 .57013 m .51262 .6495 L .47988 .57125 L 0 .017 .583 r
F
.51262 .6495 m .45062 .50132 L .51262 .6495 L .705 .537 .658 r
F
.44839 .49601 m .47988 .57125 L .44839 .49601 L 0 .017 .583 r
F
.46212 .57013 m .47988 .57125 L .44839 .49601 L F
.4815 .64447 m .44839 .49601 L .45062 .50132 L .705 .537 .658 r
F
.4815 .64447 m .45062 .50132 L .51262 .6495 L F
.42941 .63606 m .44839 .49601 L .44839 .49601 L F
.4748 .47025 m .59857 .53886 L .5983 .53879 L .787 .432 .385 r
F
.4748 .47025 m .5983 .53879 L .44839 .49601 L F
.50813 .43773 m .59857 .53886 L .4748 .47025 L F
.50813 .43773 m .5746 .38394 L .56175 .49769 L .372 .397 .757 r
F
.44839 .49601 m .5746 .38394 L .44839 .49601 L .697 .565 .701 r
F
.56175 .49769 m .5746 .38394 L .59857 .53886 L .372 .397 .757 r
F
.5746 .38394 m .59857 .53886 L .5746 .38394 L .864 .745 .729 r
F
.50813 .43773 m .50813 .43773 L .5746 .38394 L 0 0 0 r
F
.67953 .41808 m .5746 .38394 L .67953 .41808 L .633 .072 0 r
F
.58369 .38689 m .59857 .53886 L .5746 .38394 L .864 .745 .729 r
F
.59567 .39079 m .59567 .39079 L .58369 .38689 L F
.59567 .39079 m .59857 .53886 L .58369 .38689 L F
.59857 .53886 m .59857 .53886 L .5746 .38394 L F
.5746 .38394 m .5746 .38394 L .59857 .53886 L .372 .397 .757 r
F
.67953 .41808 m .59567 .39079 L .72004 .4657 L .633 .072 0 r
F
.72004 .4657 m .72004 .4657 L .59857 .53886 L .294 .027 .326 r
F
.74941 .57568 m .68256 .63217 L .68256 .63217 L .718 .333 .319 r
F
.74941 .57568 m .68256 .63217 L .65907 .55363 L F
.74941 .57568 m .68256 .63217 L .68256 .63217 L .974 .848 .655 r
F
.74941 .57568 m .68256 .63217 L .74941 .57568 L .718 .333 .319 r
F
.74941 .57568 m .72004 .4657 L .74941 .57568 L .974 .848 .655 r
F
.51262 .6495 m .51262 .6495 L .68256 .63217 L .665 .485 .631 r
F
.5746 .38394 m .5746 .38394 L .44839 .49601 L .697 .565 .701 r
F
.56115 .39483 m .44839 .49601 L .5746 .38394 L 0 0 0 r
F
.50813 .43773 m .44839 .49601 L .56115 .39483 L F
.44839 .49601 m .44839 .49601 L .56115 .39483 L F
.50813 .43773 m .5746 .38394 L .5746 .38394 L F
.50813 .43773 m .44839 .49601 L .44839 .49601 L F
.50813 .43773 m .44839 .49601 L .50813 .43773 L F
.50813 .43773 m .50813 .43773 L .4748 .47025 L .787 .432 .385 r
F
.50813 .43773 m .5746 .38394 L .5746 .38394 L .372 .397 .757 r
F
.67953 .41808 m .59567 .39079 L .59567 .39079 L .864 .745 .729 r
F
.67953 .41808 m .71181 .45602 L .67953 .41808 L .294 .027 .326 r
F
.67953 .41808 m .59567 .39079 L .59567 .39079 L .864 .745 .729 r
F
.67953 .41808 m .71181 .45602 L .71181 .45602 L .294 .027 .326 r
F
.64616 .34231 m .71879 .43414 L .57461 .38394 L .653 .532 .704 r
F
.71358 .30309 m .71358 .30309 L .71572 .3568 L .955 .767 .609 r
F
.71358 .30309 m .57461 .38394 L .57461 .38394 L 0 0 0 r
F
.71358 .30309 m .71879 .43414 L .64624 .34227 L .653 .532 .704 r
F
.50813 .43773 m .5746 .38394 L .50813 .43773 L .372 .397 .757 r
F
.42135 .3385 m .42135 .3385 L .54928 .37643 L .605 .071 0 r
F
.42135 .3385 m .5746 .38394 L .42135 .3385 L .697 .565 .701 r
F
.54481 .3751 m .5746 .38394 L .50177 .42908 L F
.42135 .3385 m .5746 .38394 L .5746 .38394 L F
.54783 .24868 m .5746 .38394 L .5746 .38394 L .906 .815 .746 r
F
.54783 .24868 m .54783 .24868 L .55692 .2946 L .224 .343 .775 r
F
.50177 .42908 m .5746 .38394 L .44839 .49601 L .697 .565 .701 r
F
.42135 .3385 m .54481 .3751 L .44839 .49601 L F
.5493 .37644 m .46806 .38945 L .5746 .38394 L .605 .071 0 r
F
.42135 .3385 m .45857 .3791 L .5493 .37644 L F
.5746 .38394 m .57461 .38394 L .65866 .35539 L 0 0 0 r
F
.57461 .38394 m .72004 .4657 L .66656 .43563 L .653 .532 .704 r
F
.57461 .38394 m .66656 .43563 L .5746 .38394 L F
.57461 .38394 m .66656 .43563 L .57461 .38394 L F
.71181 .45602 m .72004 .4657 L .71181 .45602 L .294 .027 .326 r
F
.71879 .43414 m .72004 .4657 L .57461 .38394 L .653 .532 .704 r
F
.72004 .4657 m .64475 .36863 L .72004 .4657 L .955 .767 .609 r
F
.71572 .3568 m .64475 .36863 L .72004 .4657 L F
.51262 .6495 m .58177 .64245 L .68256 .63217 L .665 .485 .631 r
F
.68256 .63217 m .68256 .63217 L .59857 .53886 L .718 .333 .319 r
F
.61694 .69292 m .51262 .6495 L .51262 .6495 L .606 .81 .978 r
F
.61694 .69292 m .51262 .6495 L .51262 .6495 L .88 .712 .67 r
F
.61694 .69292 m .61694 .69292 L .51262 .6495 L .606 .81 .978 r
F
.61694 .69292 m .51262 .6495 L .51262 .6495 L .88 .712 .67 r
F
.61694 .69292 m .51262 .6495 L .61089 .64218 L F
.60605 .77605 m .60605 .77605 L .68256 .63217 L .665 .485 .631 r
F
.61694 .69292 m .68256 .63217 L .68256 .63217 L .606 .81 .978 r
F
.60605 .77605 m .68256 .63217 L .68256 .63217 L .922 .837 .743 r
F
.60605 .77605 m .68256 .63217 L .60605 .77605 L F
.60605 .77605 m .68256 .63217 L .68256 .63217 L .665 .485 .631 r
F
.61694 .69292 m .51262 .6495 L .61694 .69292 L .88 .712 .67 r
F
.60605 .77605 m .51262 .6495 L .51262 .6495 L .665 .485 .631 r
F
.53356 .65822 m .68256 .63217 L .68225 .6322 L .606 .81 .978 r
F
.53356 .65822 m .68225 .6322 L .51262 .6495 L F
.61694 .69292 m .68256 .63217 L .53356 .65822 L F
.61694 .69292 m .68256 .63217 L .68256 .63217 L F
.60605 .77605 m .51262 .6495 L .68256 .63217 L .665 .485 .631 r
F
.60605 .77605 m .68256 .63217 L .68256 .63217 L F
.60605 .77605 m .51262 .6495 L .51262 .6495 L F
.60605 .77605 m .60605 .77605 L .56677 .72284 L .131 .289 .759 r
F
.60605 .77605 m .60605 .77605 L .51262 .6495 L F
.60605 .77605 m .57955 .65206 L .56677 .72284 L F
.60605 .77605 m .51262 .6495 L .51262 .6495 L F
.60605 .77605 m .51263 .64951 L .60605 .77605 L .665 .485 .631 r
F
.57955 .65206 m .56791 .65162 L .57955 .65206 L .13 0 0 r
F
.51262 .6495 m .54778 .60424 L .51262 .6495 L .358 .031 .267 r
F
.51262 .6495 m .51262 .6495 L .68256 .63217 L .665 .485 .631 r
F
.51262 .6495 m .68225 .6322 L .51262 .6495 L .606 .81 .978 r
F
.56669 .72273 m .57955 .65206 L .51262 .6495 L .131 .289 .759 r
F
.42941 .63606 m .44839 .49601 L .4815 .64447 L .705 .537 .658 r
F
.35245 .62362 m .44839 .49601 L .42941 .63606 L F
.43333 .73312 m .51262 .6495 L .56791 .65162 L .13 0 0 r
F
.68256 .63217 m .51262 .6495 L .68256 .63217 L .665 .485 .631 r
F
.57955 .65206 m .42687 .56201 L .57955 .65206 L .702 .179 0 r
F
.35245 .62362 m .51262 .6495 L .44159 .57703 L .567 .727 .95 r
F
.35245 .62362 m .44159 .57703 L .42687 .56201 L F
.35245 .62362 m .42687 .56201 L .42687 .56201 L 0 0 0 r
F
.35245 .62362 m .44839 .49601 L .44839 .49601 L .705 .537 .658 r
F
.44839 .49601 m .44839 .49601 L .42687 .56201 L .814 .391 .239 r
F
.44839 .49601 m .5983 .53879 L .44839 .49601 L .787 .432 .385 r
F
.42997 .52051 m .42687 .56201 L .44839 .49601 L 0 0 0 r
F
.42135 .3385 m .42135 .3385 L .44839 .49601 L .697 .565 .701 r
F
.35245 .62362 m .44839 .49601 L .44839 .49601 L .705 .537 .658 r
F
.35245 .62362 m .44839 .49601 L .35245 .62362 L F
.44839 .49601 m .44839 .49601 L .40549 .54032 L .814 .391 .239 r
F
.42687 .56201 m .42687 .56201 L .57955 .65206 L .702 .179 0 r
F
.44839 .49601 m .42687 .56201 L .44839 .49601 L 0 0 0 r
F
.42687 .56201 m .42687 .56201 L .44839 .49601 L F
.42687 .56201 m .44839 .49601 L .42687 .56201 L .814 .391 .239 r
F
.42997 .52051 m .42916 .53136 L .42997 .52051 L 0 0 0 r
F
.42916 .53136 m .42687 .56201 L .42997 .52051 L F
.35328 .62251 m .42687 .56201 L .42997 .52051 L F
.42687 .56201 m .42687 .56201 L .42997 .52051 L F
.41254 .54747 m .44839 .49601 L .42687 .56201 L .814 .391 .239 r
F
.3188 .45236 m .3188 .45236 L .36719 .46865 L .711 .794 .916 r
F
.35245 .62362 m .35245 .62362 L .42687 .56201 L .567 .727 .95 r
F
.43333 .73312 m .42687 .56201 L .47687 .61303 L .937 .753 .629 r
F
.51262 .6495 m .47687 .61303 L .51262 .6495 L F
.43333 .73312 m .47687 .61303 L .51262 .6495 L F
.42687 .56201 m .44159 .57703 L .42687 .56201 L .567 .727 .95 r
F
.43333 .73312 m .56276 .65473 L .57955 .65206 L .13 0 0 r
F
.56276 .65473 m .56791 .65162 L .57955 .65206 L F
.42687 .56201 m .57955 .65206 L .42687 .56201 L .649 .529 .703 r
F
.42687 .56201 m .55238 .48289 L .42687 .56201 L .213 0 .249 r
F
.42687 .56201 m .44839 .49601 L .40549 .54032 L .814 .391 .239 r
F
.3188 .45236 m .3188 .45236 L .42687 .56201 L F
.42135 .3385 m .44839 .49601 L .44839 .49601 L .697 .565 .701 r
F
.3188 .45236 m .44839 .49601 L .42687 .56201 L .814 .391 .239 r
F
.40549 .54032 m .44839 .49601 L .41254 .54747 L F
.44839 .49601 m .44839 .49601 L .45857 .3791 L 0 .028 .555 r
F
.3188 .45236 m .44839 .49601 L .44839 .49601 L .814 .391 .239 r
F
.3188 .45236 m .44839 .49601 L .3188 .45236 L F
.3188 .45236 m .36824 .50252 L .3188 .45236 L .625 .473 .656 r
F
.5746 .38394 m .5746 .38394 L .44839 .49601 L .697 .565 .701 r
F
.46806 .38945 m .5746 .38394 L .46806 .38945 L .906 .815 .746 r
F
.46806 .38945 m .46806 .38945 L .5746 .38394 L .605 .071 0 r
F
.46806 .38945 m .5746 .38394 L .46806 .38945 L .906 .815 .746 r
F
.47482 .37753 m .50158 .37925 L .46806 .38945 L F
.50158 .37925 m .5746 .38394 L .46806 .38945 L F
.48371 .36184 m .5746 .38394 L .47482 .37753 L F
.5746 .38394 m .5746 .38394 L .46806 .38945 L F
.46806 .38945 m .46806 .38945 L .5746 .38394 L .605 .071 0 r
F
.54783 .24868 m .5746 .38394 L .54783 .24868 L .906 .815 .746 r
F
.54783 .24868 m .46812 .38935 L .54783 .24868 L .661 .477 .624 r
F
.46806 .38945 m .46806 .38945 L .44839 .49601 L .711 .794 .916 r
F
.45857 .3791 m .44839 .49601 L .46806 .38945 L 0 .028 .555 r
F
.3188 .45236 m .40548 .54031 L .3188 .45236 L .625 .473 .656 r
F
.42135 .3385 m .44839 .49601 L .45857 .3791 L 0 .028 .555 r
F
.36719 .46865 m .46806 .38945 L .44306 .49421 L .711 .794 .916 r
F
.36719 .46865 m .46806 .38945 L .46806 .38945 L F
.3188 .45236 m .46806 .38945 L .46806 .38945 L .625 .473 .656 r
F
.42135 .3385 m .46806 .38945 L .46806 .38945 L .605 .071 0 r
F
.3188 .45236 m .46806 .38945 L .46806 .38945 L .711 .794 .916 r
F
.42135 .3385 m .46806 .38945 L .42135 .3385 L .605 .071 0 r
F
.3188 .45236 m .46806 .38945 L .36719 .46865 L .711 .794 .916 r
F
.3188 .45236 m .3188 .45236 L .46806 .38945 L .625 .473 .656 r
F
.3188 .45236 m .40549 .54032 L .46806 .38945 L F
.3188 .45236 m .46806 .38945 L .46806 .38945 L .711 .794 .916 r
F
.3188 .45236 m .46806 .38945 L .3188 .45236 L F
.54783 .24868 m .46806 .38945 L .46806 .38945 L .661 .477 .624 r
F
.37865 .44026 m .46806 .38945 L .46806 .38945 L .956 .828 .676 r
F
.41788 .53931 m .46806 .38945 L .42687 .56201 L F
.37865 .44026 m .46806 .38945 L .41788 .53931 L F
.37865 .44026 m .37865 .44026 L .40934 .42282 L .706 .29 .255 r
F
.37865 .44026 m .46806 .38945 L .37865 .44026 L .956 .828 .676 r
F
.44306 .49421 m .46806 .38945 L .44839 .49601 L .711 .794 .916 r
F
.46806 .38945 m .46806 .38945 L .42687 .56201 L .956 .828 .676 r
F
.45378 .44926 m .46806 .38945 L .44611 .48142 L F
.45378 .44926 m .44611 .48142 L .42687 .56201 L F
.42687 .56201 m .45378 .44926 L .42687 .56201 L F
.42687 .56201 m .42687 .56201 L .46806 .38945 L .625 .473 .656 r
F
.46806 .38945 m .42687 .56201 L .46806 .38945 L F
.3188 .45236 m .42687 .56201 L .40548 .54031 L F
.3188 .45236 m .42687 .56201 L .42687 .56201 L F
.35245 .62362 m .42687 .56201 L .42687 .56201 L 0 0 0 r
F
.35245 .62362 m .42687 .56201 L .42687 .56201 L .567 .727 .95 r
F
.43333 .73312 m .42687 .56201 L .42687 .56201 L .649 .529 .703 r
F
.37865 .44026 m .42687 .56201 L .42687 .56201 L .631 .697 .893 r
F
.37865 .44026 m .37865 .44026 L .40954 .51824 L .956 .828 .676 r
F
.37865 .44026 m .40954 .51824 L .42687 .56201 L F
.44839 .49601 m .46806 .38945 L .44839 .49601 L .711 .794 .916 r
F
.5746 .38394 m .44839 .49601 L .5746 .38394 L 0 0 0 r
F
.44839 .49601 m .44839 .49601 L .5746 .38394 L F
.37865 .44026 m .42687 .56201 L .51883 .47466 L .631 .697 .893 r
F
.37865 .44026 m .42687 .56201 L .37865 .44026 L F
.37865 .44026 m .55238 .48289 L .40934 .42282 L .706 .29 .255 r
F
.37865 .44026 m .5173 .47428 L .37865 .44026 L F
.42687 .56201 m .42687 .56201 L .51883 .47466 L .631 .697 .893 r
F
.37865 .44026 m .42687 .56201 L .42687 .56201 L .956 .828 .676 r
F
.37865 .44026 m .51883 .47466 L .51883 .47466 L .631 .697 .893 r
F
.37865 .44026 m .37865 .44026 L .51883 .47466 L F
.37865 .44026 m .37865 .44026 L .42687 .56201 L .956 .828 .676 r
F
.55238 .48289 m .42687 .56201 L .55238 .48289 L .631 .697 .893 r
F
.40934 .42282 m .55238 .48289 L .46806 .38945 L .706 .29 .255 r
F
.46812 .38935 m .46806 .38945 L .54783 .24868 L .661 .477 .624 r
F
.54783 .24868 m .62558 .34491 L .62558 .34491 L F
.65865 .3554 m .57461 .38394 L .64475 .36863 L 0 0 0 r
F
.71358 .30309 m .65866 .35539 L .71572 .3568 L .955 .767 .609 r
F
.71358 .30309 m .71358 .30309 L .65866 .35539 L 0 0 0 r
F
.71358 .30309 m .57461 .38394 L .65866 .35539 L F
.71358 .30309 m .65866 .35539 L .65866 .35539 L F
.71358 .30309 m .57461 .38394 L .71358 .30309 L F
.71358 .30309 m .71358 .30309 L .64624 .34227 L .653 .532 .704 r
F
.71358 .30309 m .64475 .36863 L .64475 .36863 L .955 .767 .609 r
F
.62558 .34491 m .64475 .36863 L .64475 .36863 L .661 .477 .624 r
F
.54783 .24868 m .64475 .36863 L .64475 .36863 L .224 .343 .775 r
F
.64475 .36863 m .65768 .3853 L .64475 .36863 L .591 .718 .932 r
F
.64475 .36863 m .64475 .36863 L .72004 .4657 L .955 .767 .609 r
F
.68256 .63217 m .57955 .65206 L .68256 .63217 L .655 .165 .074 r
F
.67352 .63391 m .57955 .65206 L .68256 .63217 L F
.68213 .63171 m .68256 .63217 L .68256 .63217 L F
.66613 .61924 m .66817 .61618 L .68256 .63217 L .315 .301 .684 r
F
.65907 .55363 m .68256 .63217 L .59857 .53886 L .718 .333 .319 r
F
.68256 .63217 m .66817 .61618 L .68256 .63217 L .315 .301 .684 r
F
.74941 .57568 m .59857 .53886 L .73296 .51407 L .642 .688 .878 r
F
.68256 .63217 m .72004 .4657 L .68256 .63217 L .974 .848 .655 r
F
.74941 .57568 m .72004 .4657 L .68256 .63217 L F
.72004 .4657 m .72004 .4657 L .68256 .63217 L F
.74941 .57568 m .72004 .4657 L .72004 .4657 L F
.74941 .57568 m .74941 .57568 L .73296 .51407 L .642 .688 .878 r
F
.7689 .51115 m .68256 .63217 L .71459 .48992 L .631 .482 .661 r
F
.7689 .51115 m .71459 .48992 L .72004 .4657 L F
.83552 .57313 m .83552 .57313 L .76132 .60177 L .703 .814 .933 r
F
.83552 .57313 m .68256 .63217 L .7689 .51115 L .631 .482 .661 r
F
.79326 .55811 m .72004 .4657 L .71709 .51949 L .801 .342 .145 r
F
.79326 .55811 m .71709 .51949 L .71647 .53081 L F
.72004 .4657 m .71647 .53081 L .72004 .4657 L 0 0 .082 r
F
.73569 .50426 m .71647 .53081 L .72004 .4657 L F
.71903 .48408 m .71647 .53081 L .72004 .4657 L F
.68097 .63194 m .57955 .65206 L .68256 .63217 L .655 .165 .074 r
F
.60605 .77605 m .68256 .63217 L .57955 .65206 L .922 .837 .743 r
F
.60605 .77605 m .57955 .65206 L .57955 .65206 L .131 .289 .759 r
F
.60605 .77605 m .57955 .65206 L .57955 .65206 L .922 .837 .743 r
F
.60605 .77605 m .57955 .65206 L .60605 .77605 L .131 .289 .759 r
F
.43333 .73312 m .57955 .65206 L .43333 .73312 L .649 .529 .703 r
F
.60605 .77605 m .57955 .65206 L .57955 .65206 L .922 .837 .743 r
F
.43333 .73312 m .42687 .56201 L .42687 .56201 L .937 .753 .629 r
F
.43333 .73312 m .57955 .65206 L .43333 .73312 L .649 .529 .703 r
F
.68256 .63217 m .71647 .53081 L .68256 .63217 L .703 .814 .933 r
F
.71647 .53081 m .69446 .59658 L .71647 .53081 L .078 .124 .609 r
F
.71647 .53081 m .71647 .53081 L .68256 .63217 L .703 .814 .933 r
F
.66049 .49356 m .72004 .4657 L .59857 .53886 L .294 .027 .326 r
F
.59857 .53886 m .72004 .4657 L .59857 .53886 L F
.59857 .53886 m .72004 .4657 L .59857 .53886 L F
.59857 .53886 m .5746 .38394 L .59857 .53886 L .372 .397 .757 r
F
.72004 .4657 m .71459 .48992 L .72004 .4657 L .631 .482 .661 r
F
.71647 .53081 m .71647 .53081 L .64475 .36863 L 0 .127 .653 r
F
.68256 .63217 m .67352 .63391 L .68256 .63217 L .655 .165 .074 r
F
.76132 .60177 m .71647 .53081 L .68256 .63217 L .703 .814 .933 r
F
.83552 .57313 m .71647 .53081 L .76132 .60177 L F
.83552 .57313 m .83552 .57313 L .79327 .55811 L .801 .342 .145 r
F
.83552 .57313 m .72004 .4657 L .79326 .55811 L F
.83552 .57313 m .72004 .4657 L .83552 .57313 L F
.83552 .57313 m .83552 .57313 L .7689 .51115 L .631 .482 .661 r
F
.83552 .57313 m .72004 .4657 L .72004 .4657 L .801 .342 .145 r
F
.83552 .57313 m .71647 .53081 L .71647 .53081 L .703 .814 .933 r
F
.83552 .57313 m .71647 .53081 L .83552 .57313 L F
.73569 .50426 m .71647 .53081 L .71647 .53081 L 0 0 .082 r
F
.74663 .70259 m .71647 .53081 L .71647 .53081 L .697 .564 .701 r
F
.73553 .69039 m .68256 .63217 L .68256 .63217 L .078 .124 .609 r
F
.74663 .70259 m .73337 .68802 L .73553 .69039 L F
.73337 .68802 m .68256 .63217 L .73553 .69039 L F
.74663 .70259 m .68261 .63223 L .74663 .70259 L F
.71647 .53081 m .71647 .53081 L .61185 .66183 L .697 .564 .701 r
F
.74663 .70259 m .61185 .66183 L .61185 .66183 L F
.68261 .63223 m .68256 .63217 L .73814 .69326 L .078 .124 .609 r
F
.68256 .63218 m .61185 .66183 L .68256 .63217 L .655 .165 .074 r
F
.74663 .70259 m .74663 .70259 L .68256 .63218 L F
.74663 .70259 m .61185 .66183 L .68256 .63218 L F
.74663 .70259 m .71647 .53081 L .74663 .70259 L .697 .564 .701 r
F
.74663 .70259 m .61185 .66183 L .61185 .66183 L .655 .165 .074 r
F
.74663 .70259 m .68256 .63217 L .68256 .63217 L .078 .124 .609 r
F
.74663 .70259 m .71647 .53081 L .71647 .53081 L .697 .564 .701 r
F
.74663 .70259 m .69446 .59658 L .71647 .53081 L .078 .124 .609 r
F
.74663 .70258 m .71647 .53081 L .71647 .53081 L .697 .564 .701 r
F
.74663 .70259 m .68256 .63217 L .69446 .59658 L .078 .124 .609 r
F
.682 .63173 m .68097 .63194 L .68256 .63217 L .655 .165 .074 r
F
.68097 .63194 m .68256 .63217 L .68256 .63217 L F
.74663 .70259 m .71647 .53081 L .61185 .66183 L .697 .564 .701 r
F
.71647 .53081 m .64539 .59376 L .71647 .53081 L 0 0 0 r
F
.71647 .53081 m .71647 .53081 L .57955 .65206 L .697 .564 .701 r
F
.57955 .65206 m .71647 .53081 L .57955 .65206 L F
.57955 .65206 m .57955 .65206 L .42687 .56201 L .649 .529 .703 r
F
.61185 .66183 m .71647 .53081 L .57955 .65206 L .697 .564 .701 r
F
.57955 .65206 m .71647 .53081 L .57955 .65206 L F
.66061 .60376 m .71647 .53081 L .71647 .53081 L .786 .405 .334 r
F
.68832 .56756 m .64538 .59377 L .71647 .53081 L 0 0 0 r
F
.66061 .60376 m .64538 .59377 L .68832 .56756 L F
.66061 .60376 m .71647 .53081 L .66961 .59201 L .786 .405 .334 r
F
.66061 .60376 m .66061 .60376 L .68832 .56756 L 0 0 0 r
F
.66061 .60376 m .57955 .65206 L .64538 .59377 L F
.64475 .36863 m .64475 .36863 L .5746 .38394 L .224 .343 .775 r
F
.55692 .2946 m .64475 .36863 L .5746 .38394 L F
.5551 .3792 m .5551 .3792 L .48371 .36184 L .906 .815 .746 r
F
.5746 .38394 m .5551 .3792 L .5551 .3792 L F
.5746 .38394 m .5746 .38394 L .5551 .3792 L F
.54783 .24868 m .46806 .38945 L .46806 .38945 L .661 .477 .624 r
F
.54783 .24868 m .5746 .38394 L .48371 .36184 L .906 .815 .746 r
F
.46806 .38945 m .58589 .37557 L .46806 .38945 L .632 .794 .96 r
F
.64475 .36863 m .5746 .38394 L .64475 .36863 L 0 0 0 r
F
.57461 .38394 m .5746 .38394 L .64475 .36863 L F
.64475 .36863 m .46806 .38945 L .64475 .36863 L .661 .477 .624 r
F
.71647 .53081 m .71709 .51949 L .71647 .53081 L .801 .342 .145 r
F
.72004 .4657 m .71903 .48408 L .72004 .4657 L 0 0 .082 r
F
.64475 .36863 m .71647 .53081 L .64475 .36863 L 0 .127 .653 r
F
.5746 .38394 m .64475 .36863 L .57461 .38394 L .224 .343 .775 r
F
.8146 .39531 m .73569 .50426 L .73569 .50426 L .705 .534 .654 r
F
.779 .42181 m .73569 .50426 L .72004 .4657 L 0 0 .082 r
F
.8146 .39531 m .8146 .39531 L .779 .42181 L F
.8146 .39531 m .73569 .50426 L .779 .42181 L F
.8146 .39531 m .73791 .4524 L .65768 .3853 L .591 .718 .932 r
F
.73791 .4524 m .72004 .4657 L .72004 .4657 L F
.73791 .4524 m .72004 .4657 L .65768 .3853 L F
.8146 .39531 m .65768 .3853 L .64475 .36863 L F
.67762 .3738 m .66893 .40469 L .73569 .50426 L .705 .534 .654 r
F
.8146 .39531 m .64475 .36863 L .8146 .39531 L F
.62558 .34491 m .62558 .34491 L .64475 .36863 L .661 .477 .624 r
F
.8146 .39531 m .73575 .50418 L .8146 .39531 L 0 0 .082 r
F
.73575 .50418 m .73571 .50423 L .8146 .39531 L F
.65866 .35539 m .65866 .35539 L .64475 .36863 L 0 0 0 r
F
.8146 .39531 m .64475 .36863 L .64475 .36863 L .705 .534 .654 r
F
.54783 .24868 m .64475 .36863 L .63623 .35808 L .224 .343 .775 r
F
.8146 .39531 m .73569 .50426 L .73569 .50426 L 0 0 .082 r
F
.54783 .24868 m .64475 .36863 L .64475 .36863 L .224 .343 .775 r
F
.54783 .24868 m .64475 .36863 L .54783 .24868 L F
.8146 .39531 m .64475 .36863 L .64475 .36863 L .591 .718 .932 r
F
.65866 .35539 m .64475 .36863 L .64475 .36863 L 0 0 0 r
F
.72646 .51702 m .64475 .36863 L .71647 .53081 L .705 .534 .654 r
F
.73569 .50426 m .64475 .36863 L .72646 .51702 L F
.64475 .36863 m .55238 .48289 L .64475 .36863 L .894 .724 .663 r
F
.55238 .48289 m .59025 .43605 L .55238 .48289 L .285 0 .182 r
F
.55238 .48289 m .55238 .48289 L .42687 .56201 L .213 0 .249 r
F
.55506 .36485 m .46806 .38945 L .64475 .36863 L .661 .477 .624 r
F
.54783 .24868 m .64475 .36863 L .55692 .2946 L .224 .343 .775 r
F
.62558 .34491 m .55506 .36485 L .64475 .36863 L .661 .477 .624 r
F
.54783 .24868 m .46806 .38945 L .62558 .34491 L F
.50913 .33421 m .58589 .37557 L .46806 .38945 L .632 .794 .96 r
F
.54783 .24868 m .46806 .38945 L .46806 .38945 L .661 .477 .624 r
F
.53091 .30491 m .46806 .38945 L .46806 .38945 L .252 .255 .668 r
F
.53091 .30491 m .64475 .36863 L .64475 .36863 L .632 .794 .96 r
F
.5746 .38394 m .46806 .38945 L .5746 .38394 L .605 .071 0 r
F
.53756 .36005 m .46806 .38945 L .55238 .48289 L .252 .255 .668 r
F
.53091 .30491 m .53091 .30491 L .60052 .34387 L .894 .724 .663 r
F
.53091 .30491 m .58589 .37557 L .50913 .33421 L .632 .794 .96 r
F
.53091 .30491 m .64475 .36863 L .64475 .36863 L F
.58203 .3706 m .64475 .36863 L .58589 .37557 L F
.53091 .30491 m .64475 .36863 L .58203 .3706 L F
.53091 .30491 m .55238 .48289 L .60052 .34387 L .894 .724 .663 r
F
.53091 .30491 m .53091 .30491 L .53756 .36005 L .252 .255 .668 r
F
.50932 .33395 m .53091 .30491 L .50913 .33421 L .632 .794 .96 r
F
.53091 .30491 m .46806 .38945 L .53756 .36005 L .252 .255 .668 r
F
.53091 .30491 m .46806 .38945 L .53091 .30491 L F
.53091 .30491 m .53091 .30491 L .50932 .33395 L .632 .794 .96 r
F
.53876 .37 m .54273 .40286 L .54346 .40897 L .252 .255 .668 r
F
.54273 .40286 m .55238 .48289 L .54346 .40897 L F
.54346 .40897 m .55238 .48289 L .55238 .48289 L F
.53757 .36008 m .55238 .48289 L .53876 .37 L F
.51883 .47466 m .51883 .47466 L .55238 .48289 L .631 .697 .893 r
F
.53091 .30491 m .55238 .48289 L .55238 .48289 L .894 .724 .663 r
F
.53091 .30491 m .53757 .36008 L .53876 .37 L .252 .255 .668 r
F
.53091 .30491 m .55238 .48289 L .53091 .30491 L .894 .724 .663 r
F
.51883 .47466 m .47679 .5146 L .55238 .48289 L .631 .697 .893 r
F
.47679 .5146 m .42687 .56201 L .55238 .48289 L F
.60052 .34387 m .55238 .48289 L .64475 .36863 L .894 .724 .663 r
F
.55238 .48289 m .55238 .48289 L .64475 .36863 L F
.64475 .36863 m .64475 .36863 L .73569 .50426 L .705 .534 .654 r
F
.8146 .39531 m .67762 .3738 L .73569 .50426 L F
.67762 .3738 m .64475 .36863 L .66893 .40469 L F
.70622 .40246 m .64475 .36863 L .64475 .36863 L .285 0 .182 r
F
.68289 .38962 m .71647 .53081 L .64475 .36863 L 0 .127 .653 r
F
.70622 .40246 m .71647 .53081 L .68289 .38962 L F
.70622 .40246 m .64475 .36863 L .59025 .43605 L .285 0 .182 r
F
.70622 .40246 m .64475 .36863 L .70622 .40246 L F
.70622 .40246 m .70622 .40246 L .68289 .38962 L 0 .127 .653 r
F
.70622 .40246 m .55238 .48289 L .70622 .40246 L .698 .74 .884 r
F
.71007 .45072 m .55238 .48289 L .71647 .53081 L F
.70622 .40246 m .70622 .40246 L .71007 .45072 L F
.70622 .40246 m .55238 .48289 L .71007 .45072 L F
.70622 .40246 m .60005 .43321 L .55238 .48289 L .285 0 .182 r
F
.70622 .40246 m .55243 .48286 L .70622 .40246 L .698 .74 .884 r
F
.55243 .48286 m .55238 .48289 L .70622 .40246 L F
.70622 .40246 m .71647 .53081 L .70622 .40246 L 0 .127 .653 r
F
.55238 .48289 m .62383 .50375 L .55238 .48289 L .786 .405 .334 r
F
.71647 .53081 m .55238 .48289 L .71647 .53081 L .698 .74 .884 r
F
.55238 .48289 m .55238 .48289 L .71647 .53081 L F
.59857 .53886 m .53499 .52072 L .59857 .53886 L .701 .728 .871 r
F
.55238 .48289 m .56343 .55166 L .55238 .48289 L .878 .759 .728 r
F
.59857 .53886 m .55694 .59245 L .59857 .53886 L .88 .712 .67 r
F
.6327 .62039 m .55238 .48289 L .56245 .54559 L .321 .366 .753 r
F
.57955 .65206 m .56245 .54559 L .57955 .65206 L F
.6327 .62039 m .56245 .54559 L .57955 .65206 L F
.43333 .73312 m .57955 .65206 L .57955 .65206 L .649 .529 .703 r
F
.42812 .59516 m .57955 .65206 L .42812 .59516 L F
.43333 .73312 m .57955 .65206 L .42812 .59516 L F
.42812 .59516 m .57955 .65206 L .42687 .56201 L F
.50191 .63522 m .42687 .56201 L .57955 .65206 L .702 .179 0 r
F
.49109 .57256 m .57955 .65206 L .56343 .55166 L .878 .759 .728 r
F
.49109 .57256 m .56343 .55166 L .55238 .48289 L F
.43333 .73312 m .42687 .56201 L .43333 .73312 L .937 .753 .629 r
F
.45518 .62508 m .42687 .56201 L .42687 .56201 L .702 .179 0 r
F
.45518 .62508 m .42687 .56201 L .50191 .63522 L F
.44443 .60115 m .55238 .48289 L .43208 .57361 L .213 0 .249 r
F
.45518 .62508 m .45518 .62508 L .44443 .60115 L F
.45518 .62508 m .57955 .65206 L .49109 .57256 L .878 .759 .728 r
F
.45518 .62508 m .55238 .48289 L .44443 .60115 L .213 0 .249 r
F
.45518 .62508 m .57955 .65206 L .45518 .62508 L .878 .759 .728 r
F
.45518 .62508 m .47034 .6029 L .45518 .62508 L .213 0 .249 r
F
.47034 .6029 m .55238 .48289 L .45518 .62508 L F
.45518 .62508 m .42687 .56201 L .42687 .56201 L .702 .179 0 r
F
.45518 .62508 m .42687 .56201 L .45518 .62508 L F
.45518 .62508 m .45518 .62508 L .49108 .57256 L .878 .759 .728 r
F
.45518 .62508 m .45518 .62508 L .50191 .63522 L .702 .179 0 r
F
.45518 .62508 m .55238 .48289 L .47034 .6029 L .213 0 .249 r
F
.45518 .62508 m .55238 .48289 L .55238 .48289 L F
.47034 .6029 m .55238 .48289 L .55238 .48289 L F
.66061 .60376 m .55238 .48289 L .63271 .62039 L .321 .366 .753 r
F
.61185 .66183 m .61185 .66183 L .57955 .65206 L .697 .564 .701 r
F
.43333 .73312 m .57955 .65206 L .57955 .65206 L .13 0 0 r
F
.60605 .77605 m .57955 .65206 L .57955 .65206 L .922 .837 .743 r
F
.66061 .60376 m .57955 .65206 L .57955 .65206 L 0 0 0 r
F
.66061 .60376 m .66061 .60376 L .63271 .62039 L .321 .366 .753 r
F
.66061 .60376 m .57955 .65206 L .66061 .60376 L 0 0 0 r
F
.66061 .60376 m .71647 .53081 L .57279 .50568 L .786 .405 .334 r
F
.66061 .60376 m .66961 .59201 L .66061 .60376 L F
.66961 .59201 m .71647 .53081 L .66061 .60376 L F
.66061 .60376 m .66061 .60376 L .57279 .50568 L F
.66061 .60376 m .57279 .50568 L .57279 .50568 L F
.57279 .50568 m .55238 .48289 L .55238 .48289 L F
.43208 .57361 m .55238 .48289 L .42687 .56201 L .213 0 .249 r
F
.60005 .43321 m .55238 .48289 L .55238 .48289 L .285 0 .182 r
F
.57279 .50568 m .62383 .50375 L .55238 .48289 L .786 .405 .334 r
F
.57279 .50568 m .71647 .53081 L .62383 .50375 L F
.66061 .60376 m .55238 .48289 L .55238 .48289 L .321 .366 .753 r
F
.70622 .40246 m .55238 .48289 L .55238 .48289 L .285 0 .182 r
F
.42687 .56201 m .42687 .56201 L .55238 .48289 L .631 .697 .893 r
F
.37865 .44026 m .55238 .48289 L .55238 .48289 L .706 .29 .255 r
F
.70622 .40246 m .70622 .40246 L .55238 .48289 L .285 0 .182 r
F
.60005 .43321 m .59025 .43605 L .55238 .48289 L F
.51883 .47466 m .55238 .48289 L .55238 .48289 L .631 .697 .893 r
F
.70622 .40246 m .55238 .48289 L .55238 .48289 L .698 .74 .884 r
F
.70622 .40246 m .71647 .53081 L .71647 .53081 L 0 .127 .653 r
F
.71301 .48753 m .71647 .53081 L .71647 .53081 L F
.70622 .40246 m .71647 .53081 L .71301 .48753 L F
.8146 .39531 m .8146 .39531 L .64475 .36863 L .591 .718 .932 r
F
.73569 .50426 m .73569 .50426 L .72646 .51702 L .705 .534 .654 r
F
.57279 .50568 m .57279 .50568 L .55238 .48289 L .786 .405 .334 r
F
.66961 .59201 m .71647 .53081 L .71647 .53081 L F
.66061 .60376 m .55238 .48289 L .66061 .60376 L .321 .366 .753 r
F
.74663 .70259 m .61185 .66183 L .6762 .68129 L .655 .165 .074 r
F
.74663 .70259 m .61185 .66183 L .61185 .66183 L F
.74663 .70259 m .74663 .70259 L .61185 .66183 L .697 .564 .701 r
F
.74663 .70259 m .61185 .66183 L .61185 .66183 L .655 .165 .074 r
F
.43333 .73312 m .57955 .65206 L .57955 .65206 L .649 .529 .703 r
F
.45518 .62508 m .57955 .65206 L .57955 .65206 L .878 .759 .728 r
F
.73569 .50426 m .71647 .53081 L .73569 .50426 L 0 0 .082 r
F
.8146 .39531 m .8146 .39531 L .73569 .50426 L .705 .534 .654 r
F
.53091 .30491 m .64475 .36863 L .53091 .30491 L .632 .794 .96 r
F
.63623 .35808 m .64475 .36863 L .64475 .36863 L .224 .343 .775 r
F
.37865 .44026 m .55238 .48289 L .37865 .44026 L .706 .29 .255 r
F
.43333 .73312 m .43333 .73312 L .57955 .65206 L .13 0 0 r
F
.54783 .24868 m .54783 .24868 L .62558 .34491 L .661 .477 .624 r
F
.48371 .36184 m .48371 .36184 L .47482 .37753 L .906 .815 .746 r
F
.3188 .45236 m .40548 .54031 L .36824 .50252 L .625 .473 .656 r
F
.3188 .45236 m .3188 .45236 L .40549 .54032 L .814 .391 .239 r
F
.3188 .45236 m .40549 .54032 L .40549 .54032 L F
.40549 .54032 m .40549 .54032 L .41254 .54747 L F
.35245 .62362 m .42686 .56202 L .35245 .62362 L 0 0 0 r
F
.43333 .73312 m .43333 .73312 L .42687 .56201 L .649 .529 .703 r
F
.60605 .77605 m .60605 .77605 L .57955 .65206 L .922 .837 .743 r
F
.71358 .30309 m .64475 .36863 L .71358 .30309 L .955 .767 .609 r
F
.42135 .3385 m .45857 .3791 L .45857 .3791 L 0 .028 .555 r
F
.42135 .3385 m .42135 .3385 L .45857 .3791 L F
0 g
.2015 .22529 m
.21267 .23729 L
s
.21267 .23729 m
.21267 .23729 L
s
.21267 .23729 m
.21267 .23729 L
s
.21267 .23729 m
.38301 .42023 L
s
.38301 .42023 m
.38301 .42023 L
s
.38301 .42023 m
.3864 .42387 L
s
.46535 .94568 m
.46834 .71372 L
s
.039 .916 .04 r
.24433 .58862 m
.40236 .53714 L
s
.47395 .76904 m
.50647 .69388 L
s
.50647 .69388 m
.50722 .69216 L
s
0 0 0 r
2 Mabswid
.91763 .45204 Mdot
.039 .916 .04 r
.5 Mabswid
.76771 .50818 m
.80691 .4935 L
s
.80691 .4935 m
.91763 .45204 L
s
.76771 .50818 m
.76771 .50818 L
s
.76771 .50818 m
.76771 .50818 L
s
.76628 .50872 m
.76771 .50818 L
s
.2401 .64273 m
.3548 .60648 L
s
.3548 .60648 m
.3548 .60648 L
s
.3548 .60648 m
.3548 .60648 L
s
.3548 .60648 m
.3548 .60648 L
s
.3548 .60648 m
.3548 .60648 L
s
.3548 .60648 m
.3548 .60648 L
s
.3548 .60648 m
.3548 .60648 L
s
.3548 .60648 m
.36862 .60211 L
s
.54866 .48834 m
.54866 .48834 L
s
.55648 .4899 m
.55648 .4899 L
s
.75187 .31207 m
.78991 .25374 L
s
.75187 .31207 m
.75187 .31207 L
s
.71612 .36689 m
.75187 .31207 L
s
0 0 0 r
2 Mabswid
.66604 .3114 Mdot
.039 .916 .04 r
.5 Mabswid
.65489 .33723 m
.65889 .32796 L
s
.65889 .32796 m
.65889 .32796 L
s
.65889 .32796 m
.65889 .32796 L
s
.66461 .31473 m
.66604 .3114 L
s
.66461 .31473 m
.66461 .31473 L
s
.66461 .31473 m
.66461 .31473 L
s
.66461 .31473 m
.66461 .31473 L
s
.66461 .31473 m
.66461 .31473 L
s
.65889 .32796 m
.66461 .31473 L
s
.46083 .89411 m
.49147 .70089 L
s
.20771 .55527 m
.36758 .50185 L
s
.41243 .29294 m
.43272 .32818 L
s
.43272 .32818 m
.43272 .32818 L
s
.43272 .32818 m
.44224 .34469 L
s
0 g
.60203 .56787 m
.60203 .56788 L
s
.039 .916 .04 r
.51138 .48173 m
.51138 .48173 L
s
.54827 .48891 m
.54827 .48891 L
s
.55688 .49059 m
.55688 .49059 L
s
0 0 0 r
2 Mabswid
.51301 .8649 Mdot
.039 .916 .04 r
.5 Mabswid
.55166 .74465 m
.56113 .7152 L
s
.51301 .8649 m
.55135 .74562 L
s
.55135 .74562 m
.55135 .74562 L
s
.55135 .74562 m
.55166 .74465 L
s
.56492 .56098 m
.56492 .56098 L
s
.57283 .51789 m
.57283 .51789 L
s
0 g
.64607 .51025 m
.64607 .51025 L
s
.56774 .57854 m
.56774 .57854 L
s
.59087 .54878 m
.59087 .54877 L
s
.64607 .51025 m
.64607 .51025 L
s
.56774 .57854 m
.56774 .57854 L
s
.59087 .54878 m
.59087 .54877 L
s
.59168 .49437 m
.59168 .49437 L
s
.57832 .40798 m
.57832 .40798 L
s
.48528 .50653 m
.48528 .50653 L
s
.5279 .5187 m
.5279 .5187 L
s
.58238 .53424 m
.58238 .53425 L
s
.59168 .49437 m
.59168 .49437 L
s
.57832 .40798 m
.57832 .40798 L
s
.48528 .50653 m
.48528 .50653 L
s
.5279 .5187 m
.5279 .5187 L
s
.58238 .53424 m
.58238 .53425 L
s
.039 .916 .04 r
.20321 .27729 m
.24214 .30337 L
s
.24214 .30337 m
.26008 .31539 L
s
.26008 .31539 m
.26008 .31539 L
s
.26008 .31539 m
.26008 .31539 L
s
.26008 .31539 m
.37358 .39144 L
s
.37358 .39144 m
.37358 .39144 L
s
.37358 .39144 m
.40824 .41466 L
s
.62984 .6393 m
.62984 .6393 L
s
.61041 .58222 m
.61042 .58225 L
s
0 0 0 r
2 Mabswid
.41243 .29294 Mdot
.039 .916 .04 r
.5 Mabswid
.57338 .51884 m
.57339 .51884 L
s
.53856 .50311 m
.53856 .50311 L
s
.50489 .4879 m
.50489 .4879 L
s
.59054 .54821 m
.59054 .54821 L
s
.54153 .47087 m
.54153 .47087 L
s
.54888 .45384 m
.54888 .45384 L
s
0 0 0 r
2 Mabswid
.36162 .60669 Mdot
.039 .916 .04 r
.5 Mabswid
.36162 .60669 m
.36555 .60619 L
s
.59985 .56415 m
.59985 .56415 L
s
.57168 .60303 m
.57168 .60303 L
s
.50938 .54579 m
.50938 .54579 L
s
0 0 0 r
2 Mabswid
.47258 .2856 Mdot
.039 .916 .04 r
.5 Mabswid
.4925 .30388 m
.50832 .31841 L
s
.4925 .30388 m
.4925 .30388 L
s
.47258 .2856 m
.4925 .30388 L
s
.58253 .53449 m
.58253 .53449 L
s
.40849 .6457 m
.42979 .63918 L
s
.23574 .69857 m
.40849 .6457 L
s
.61724 .59392 m
.61724 .59391 L
s
.64253 .50922 m
.64253 .50922 L
s
0 g
.46535 .94568 m
.9759 .81805 L
s
.15448 .69059 m
.30752 .81617 L
s
.30752 .81617 m
.46535 .94568 L
s
.039 .916 .04 r
.62901 .50527 m
.62901 .50527 L
s
.612 .42975 m
.612 .42975 L
s
.31896 .57221 m
.40835 .54322 L
s
.31896 .57221 m
.31896 .57221 L
s
.20282 .60988 m
.31896 .57221 L
s
.52131 .44846 m
.52131 .44846 L
s
.54477 .41982 m
.54477 .41982 L
s
.23064 .49972 m
.33142 .46516 L
s
.23064 .49972 m
.23064 .49972 L
s
.23064 .49972 m
.23064 .49972 L
s
.16969 .52063 m
.23064 .49972 L
s
0 0 0 r
2 Mabswid
.34033 .58204 Mdot
.039 .916 .04 r
.5 Mabswid
.38177 .54428 m
.39632 .53102 L
s
.38177 .54428 m
.38177 .54428 L
s
.38177 .54428 m
.38177 .54428 L
s
.34033 .58204 m
.38177 .54428 L
s
.51432 .53857 m
.51432 .53857 L
s
.56498 .56134 m
.56498 .56134 L
s
.61003 .58159 m
.61004 .58159 L
s
.47171 .51942 m
.47171 .51942 L
s
.60101 .56613 m
.60101 .56613 L
s
.46365 .52707 m
.46365 .52707 L
s
.51265 .54101 m
.51265 .54101 L
s
.49508 .49722 m
.49508 .49722 L
s
.5395 .50173 m
.5395 .50173 L
s
.56489 .50431 m
.56489 .50431 L
s
.57145 .51554 m
.57146 .51554 L
s
.52073 .5292 m
.52073 .5292 L
s
.61971 .50255 m
.61971 .50255 L
s
.6488 .36796 m
.66357 .35552 L
s
.49295 .49924 m
.49295 .49924 L
s
.5351 .46374 m
.5351 .46374 L
s
.54869 .45229 m
.54869 .45229 L
s
.56886 .43529 m
.56886 .43529 L
s
0 0 0 r
2 Mabswid
.83603 .26062 Mdot
.039 .916 .04 r
.5 Mabswid
.71239 .35473 m
.72151 .34779 L
s
.71239 .35473 m
.71239 .35473 L
s
.71239 .35473 m
.71239 .35473 L
s
.72151 .34779 m
.83603 .26062 L
s
.62084 .50288 m
.62084 .50288 L
s
.57469 .41846 m
.57469 .41846 L
s
0 0 0 r
2 Mabswid
.77123 .7031 Mdot
.039 .916 .04 r
.5 Mabswid
.77123 .7031 m
.78913 .61788 L
s
.78913 .61788 m
.78913 .61788 L
s
.78913 .61788 m
.79527 .58866 L
s
.79928 .63234 m
.93851 .70476 L
s
.79928 .63234 m
.79928 .63234 L
s
.74937 .60638 m
.79928 .63234 L
s
0 0 0 r
2 Mabswid
.33119 .57325 Mdot
.039 .916 .04 r
.5 Mabswid
.33119 .57325 m
.3965 .55907 L
s
.3965 .55907 m
.3965 .55907 L
s
.3965 .55907 m
.3965 .55907 L
s
.3965 .55907 m
.3965 .55907 L
s
.3965 .55907 m
.3965 .55907 L
s
.3965 .55907 m
.3965 .55907 L
s
.3965 .55907 m
.40185 .55791 L
s
0 0 0 r
2 Mabswid
.78991 .25374 Mdot
.039 .916 .04 r
.5 Mabswid
.66386 .51544 m
.66386 .51544 L
s
.66386 .51544 m
.66386 .51544 L
s
0 0 0 r
2 Mabswid
.35495 .65353 Mdot
.039 .916 .04 r
.5 Mabswid
.35495 .65353 m
.36684 .64554 L
s
.36684 .64554 m
.36684 .64554 L
s
.36684 .64554 m
.36684 .64554 L
s
.36684 .64554 m
.39035 .62974 L
s
0 g
.42135 .3385 m
.42135 .3385 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.42135 .3385 m
.46806 .38945 L
s
.42135 .3385 m
.42135 .3385 L
s
.42135 .3385 m
.42135 .3385 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.45857 .3791 m
.46806 .38945 L
s
.42135 .3385 m
.45857 .3791 L
s
.42135 .3385 m
.42135 .3385 L
s
.42135 .3385 m
.42135 .3385 L
s
.42135 .3385 m
.42135 .3385 L
s
.42135 .3385 m
.43266 .40437 L
s
.42135 .3385 m
.42135 .3385 L
s
.42135 .3385 m
.48606 .35769 L
s
.039 .916 .04 r
.53846 .46746 m
.53846 .46746 L
s
.5401 .50085 m
.5401 .50085 L
s
.6413 .62495 m
.6413 .62495 L
s
.5734 .61375 m
.5734 .61375 L
s
0 0 0 r
2 Mabswid
.35106 .64639 Mdot
.039 .916 .04 r
.5 Mabswid
.41695 .63434 m
.4221 .63339 L
s
.35106 .64639 m
.41695 .63434 L
s
.58383 .39208 m
.58383 .39208 L
s
.45742 .39232 m
.45742 .39232 L
s
.47063 .3923 m
.47063 .3923 L
s
0 g
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.3188 .45236 m
.3188 .45236 L
s
.3188 .45236 m
.3188 .45236 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.35245 .62362 m
.35245 .62362 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46204 .52861 m
.46204 .52861 L
s
.35245 .62362 m
.35245 .62362 L
s
.35245 .62362 m
.41093 .54584 L
s
.54375 .41134 m
.54375 .41134 L
s
.5127 .43891 m
.5127 .43891 L
s
.46204 .52861 m
.46204 .52861 L
s
.54375 .41134 m
.54375 .41134 L
s
.5127 .43891 m
.5127 .43891 L
s
0 0 0 r
2 Mabswid
.74911 .74599 Mdot
.039 .916 .04 r
.5 Mabswid
.73522 .69914 m
.74911 .74599 L
s
.69157 .52354 m
.69157 .52354 L
s
.69157 .52354 m
.69157 .52354 L
s
0 g
.54783 .24868 m
.54783 .24868 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.58763 .3811 m
.58763 .3811 L
s
.64475 .36863 m
.64475 .36863 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.54783 .24868 m
.54783 .24868 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.58763 .3811 m
.58763 .3811 L
s
.63074 .35128 m
.656 .33659 L
s
.70215 .0272 m
.83 .22773 L
s
.83 .22773 m
.91969 .3684 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.71358 .30309 m
.71358 .30309 L
s
.63074 .35128 m
.71358 .30309 L
s
.58469 .38961 m
.58469 .38961 L
s
.64111 .42132 m
.64111 .42132 L
s
.58469 .38961 m
.58469 .38961 L
s
.64111 .42132 m
.64111 .42132 L
s
.039 .916 .04 r
.26321 .64571 m
.37275 .61129 L
s
.37275 .61129 m
.37275 .61129 L
s
.37275 .61129 m
.37275 .61129 L
s
.37275 .61129 m
.37275 .61129 L
s
.37275 .61129 m
.37275 .61129 L
s
.37275 .61129 m
.42808 .59391 L
s
.19777 .66627 m
.26321 .64571 L
s
.58594 .38598 m
.58594 .38598 L
s
.48819 .41175 m
.48819 .41175 L
s
0 0 0 r
2 Mabswid
.25898 .37261 Mdot
.039 .916 .04 r
.5 Mabswid
.28175 .38379 m
.37403 .42908 L
s
.28175 .38379 m
.28175 .38379 L
s
.28175 .38379 m
.28175 .38379 L
s
.25898 .37261 m
.28175 .38379 L
s
.21291 .34014 m
.31333 .36321 L
s
.31333 .36321 m
.31333 .36321 L
s
.31333 .36321 m
.31333 .36321 L
s
.31333 .36321 m
.43293 .39068 L
s
.43293 .39068 m
.43293 .39068 L
s
.43293 .39068 m
.43293 .39068 L
s
0 0 0 r
2 Mabswid
.43293 .39068 Mdot
.039 .916 .04 r
.5 Mabswid
.58694 .38309 m
.58694 .38309 L
s
.17467 .57222 m
.37212 .50646 L
s
.17467 .57222 m
.17467 .57222 L
s
.16408 .57575 m
.17467 .57222 L
s
.52237 .44963 m
.52237 .44963 L
s
.54709 .439 m
.54709 .439 L
s
.57117 .42865 m
.57117 .42865 L
s
.60579 .49848 m
.60579 .49848 L
s
.57177 .51608 m
.57177 .51608 L
s
0 0 0 r
2 Mabswid
.53272 .23076 Mdot
.039 .916 .04 r
.5 Mabswid
.59766 .27404 m
.67574 .32609 L
s
.67574 .32609 m
.67574 .32609 L
s
.67574 .32609 m
.67574 .32609 L
s
.59766 .27404 m
.59766 .27404 L
s
.53272 .23076 m
.59766 .27404 L
s
.67574 .32609 m
.67574 .32609 L
s
.51239 .43857 m
.51239 .43857 L
s
.54781 .44502 m
.54781 .44502 L
s
.56445 .44805 m
.56445 .44805 L
s
.46675 .38801 m
.46675 .38801 L
s
.46675 .38801 m
.47133 .38368 L
s
.47133 .38368 m
.47133 .38368 L
s
.40036 .58381 m
.40048 .58386 L
s
.40048 .58386 m
.40048 .58386 L
s
.40048 .58386 m
.40048 .58386 L
s
.40048 .58386 m
.40048 .58386 L
s
.3855 .59602 m
.38572 .59608 L
s
.38572 .59608 m
.38572 .59608 L
s
.38572 .59608 m
.38572 .59608 L
s
.38572 .59608 m
.38572 .59608 L
s
0 g
.2015 .22529 m
.70215 .0272 L
s
.15448 .69059 m
.2015 .22529 L
s
.039 .916 .04 r
.48464 .50714 m
.48464 .50714 L
s
.5227 .5263 m
.5227 .5263 L
s
.60067 .56556 m
.60068 .56556 L
s
0 0 0 r
2 Mabswid
.93093 .6215 Mdot
.039 .916 .04 r
.5 Mabswid
.82563 .60505 m
.93093 .6215 L
s
.82563 .60505 m
.82563 .60505 L
s
.77378 .59696 m
.82563 .60505 L
s
.69799 .52541 m
.69799 .52541 L
s
.69799 .52541 m
.69799 .52541 L
s
.68077 .35594 m
.68144 .36252 L
s
0 g
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.35245 .62362 m
.42687 .56201 L
s
.35245 .62362 m
.35245 .62362 L
s
.39225 .63005 m
.42967 .6361 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.35245 .62362 m
.42687 .56201 L
s
.35245 .62362 m
.35245 .62362 L
s
.35245 .62362 m
.35245 .62362 L
s
.35245 .62362 m
.42941 .63606 L
s
.42941 .63606 m
.42967 .6361 L
s
.039 .916 .04 r
.39486 .58833 m
.39493 .58845 L
s
.39493 .58845 m
.39493 .58845 L
s
.59254 .55164 m
.59254 .55164 L
s
.61711 .50179 m
.61711 .50179 L
s
.65936 .41604 m
.65936 .41604 L
s
.68612 .36174 m
.68824 .35745 L
s
0 0 0 r
2 Mabswid
.68824 .35745 Mdot
.039 .916 .04 r
.5 Mabswid
.6882 .35612 m
.68824 .35745 L
s
.51426 .44065 m
.51426 .44065 L
s
.70254 .359 m
.70805 .35661 L
s
.54564 .42704 m
.54564 .42704 L
s
.57633 .41373 m
.57633 .41373 L
s
.70818 .35662 m
.70944 .35785 L
s
0 0 0 r
2 Mabswid
.67574 .32609 Mdot
.37351 .21704 Mdot
.039 .916 .04 r
.5 Mabswid
.47687 .33685 m
.49314 .35571 L
s
.49314 .35571 m
.49314 .35571 L
s
.41574 .26599 m
.42912 .28149 L
s
.42912 .28149 m
.47687 .33685 L
s
.37351 .21704 m
.41574 .26599 L
s
.5722 .51682 m
.5722 .51681 L
s
.59272 .49467 m
.59272 .49467 L
s
0 0 0 r
2 Mabswid
.4221 .63339 Mdot
.039 .916 .04 r
.5 Mabswid
.4221 .63339 m
.42954 .63272 L
s
0 g
.57955 .65206 m
.57955 .65206 L
s
.43333 .73312 m
.43333 .73312 L
s
.43333 .73312 m
.43333 .73312 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.60605 .77605 m
.60605 .77605 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.57807 .64283 m
.57807 .64283 L
s
.63136 .63739 m
.63136 .63739 L
s
.60605 .77605 m
.60605 .77605 L
s
.57807 .64283 m
.57807 .64283 L
s
.63136 .63739 m
.63136 .63739 L
s
.71358 .30309 m
.71358 .30309 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.71358 .30309 L
s
.71358 .30309 m
.71358 .30309 L
s
.65866 .35539 m
.71358 .30309 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.65866 .35539 L
s
.71358 .30309 m
.71358 .30309 L
s
.71358 .30309 m
.71663 .37992 L
s
0 0 0 r
2 Mabswid
.91217 .6562 Mdot
.039 .916 .04 r
.5 Mabswid
.73439 .63288 m
.8208 .64421 L
s
.8208 .64421 m
.91217 .6562 L
s
0 g
.8146 .39531 m
.8146 .39531 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.8146 .39531 m
.8146 .39531 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.83552 .57313 m
.83552 .57313 L
s
.74608 .48992 m
.79009 .53086 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.83552 .57313 m
.83552 .57313 L
s
.74608 .48992 m
.83552 .57313 L
s
.70606 .52777 m
.70606 .52777 L
s
.70606 .52777 m
.70606 .52777 L
s
.70607 .52777 m
.70607 .52777 L
s
.70607 .52777 m
.70607 .52777 L
s
0 0 0 r
2 Mabswid
.37869 .804 Mdot
.039 .916 .04 r
.5 Mabswid
.37992 .60321 m
.37998 .59416 L
s
.37992 .60321 m
.37992 .60321 L
s
.37992 .60321 m
.37992 .60321 L
s
.37992 .60321 m
.37992 .60321 L
s
.37869 .804 m
.37992 .60321 L
s
.37998 .59416 m
.37998 .59416 L
s
.37998 .59416 m
.38046 .51492 L
s
.38046 .51492 m
.38046 .51492 L
s
.79691 .41974 m
.89368 .44339 L
s
.66081 .41562 m
.66081 .41562 L
s
.66732 .36487 m
.6685 .35564 L
s
0 0 0 r
2 Mabswid
.67182 .32979 Mdot
.039 .916 .04 r
.5 Mabswid
.70468 .35653 m
.70548 .35851 L
s
.52825 .18107 m
.57384 .22004 L
s
.57384 .22004 m
.57384 .22004 L
s
.57384 .22004 m
.57384 .22004 L
s
.57384 .22004 m
.62522 .26396 L
s
.62522 .26396 m
.62522 .26396 L
s
.62522 .26396 m
.62522 .26396 L
s
.62522 .26396 m
.68943 .31885 L
s
.68943 .31885 m
.68943 .31885 L
s
0 0 0 r
2 Mabswid
.68943 .31885 Mdot
.89368 .44339 Mdot
.7135 .3618 Mdot
.44248 .38961 Mdot
.039 .916 .04 r
.5 Mabswid
.45796 .38615 m
.45796 .38615 L
s
.46383 .38484 m
.47167 .38309 L
s
.47167 .38309 m
.47167 .38309 L
s
0 0 0 r
2 Mabswid
.71239 .35473 Mdot
.31474 .61253 Mdot
.039 .916 .04 r
.5 Mabswid
.31474 .61253 m
.38142 .59974 L
s
.38142 .59974 m
.38142 .59974 L
s
.38142 .59974 m
.38142 .59974 L
s
.38142 .59974 m
.38663 .59874 L
s
.49988 .4247 m
.49988 .4247 L
s
.5973 .55978 m
.5973 .55977 L
s
.60738 .49895 m
.60738 .49895 L
s
0 0 0 r
2 Mabswid
.46083 .89411 Mdot
.70848 .36591 Mdot
.75522 .20153 Mdot
.039 .916 .04 r
.5 Mabswid
.56784 .27345 m
.75522 .20153 L
s
0 0 0 r
2 Mabswid
.31032 .612 Mdot
.039 .916 .04 r
.5 Mabswid
.31032 .612 m
.32203 .60338 L
s
.32203 .60338 m
.32203 .60338 L
s
.32203 .60338 m
.40644 .54128 L
s
.30455 .58548 m
.39908 .55497 L
s
.39908 .55497 m
.39908 .55497 L
s
.1583 .63269 m
.30455 .58548 L
s
.39908 .55497 m
.40951 .5516 L
s
.40951 .5516 m
.40951 .5516 L
s
.40951 .5516 m
.42125 .54781 L
s
0 0 0 r
2 Mabswid
.24361 .40456 Mdot
.039 .916 .04 r
.5 Mabswid
.35271 .49218 m
.42091 .54696 L
s
.35271 .49218 m
.35271 .49218 L
s
.35271 .49218 m
.35271 .49218 L
s
.35271 .49218 m
.35271 .49218 L
s
.35271 .49218 m
.35271 .49218 L
s
.35271 .49218 m
.35271 .49218 L
s
.30683 .45533 m
.35271 .49218 L
s
.24361 .40456 m
.30683 .45533 L
s
0 0 0 r
2 Mabswid
.70626 .34258 Mdot
.039 .916 .04 r
.5 Mabswid
.68286 .36228 m
.69011 .35617 L
s
.54687 .47678 m
.54687 .47678 L
s
.55121 .47313 m
.55121 .47313 L
s
.55121 .47313 m
.55121 .47313 L
s
.55764 .46772 m
.55764 .46772 L
s
.59786 .43385 m
.59786 .43385 L
s
.36754 .50181 m
.39082 .58154 L
s
.39082 .58154 m
.39082 .58154 L
s
.39082 .58154 m
.39082 .58154 L
s
.39082 .58154 m
.39082 .58154 L
s
0 0 0 r
2 Mabswid
.39082 .58154 Mdot
.82355 .2376 Mdot
.039 .916 .04 r
.5 Mabswid
.8196 .2407 m
.82355 .2376 L
s
.65418 .37011 m
.8196 .2407 L
s
0 0 0 r
2 Mabswid
.68238 .32606 Mdot
.039 .916 .04 r
.5 Mabswid
.67148 .35571 m
.67182 .36412 L
s
.67803 .51958 m
.67803 .51958 L
s
.67803 .51958 m
.67803 .51958 L
s
.62417 .34316 m
.67061 .33393 L
s
.67061 .33393 m
.67061 .33393 L
s
0 0 0 r
2 Mabswid
.67061 .33393 Mdot
0 g
.5 Mabswid
.74663 .70259 m
.74663 .70259 L
s
.74663 .70259 m
.74663 .70259 L
s
.57955 .65206 m
.57955 .65206 L
s
.62696 .64291 m
.62696 .64291 L
s
.83552 .57313 m
.83552 .57313 L
s
.71647 .53081 m
.71647 .53081 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.62696 .64291 m
.62696 .64291 L
s
.60605 .77605 m
.60605 .77605 L
s
.83552 .57313 m
.83552 .57313 L
s
.73098 .61348 m
.83552 .57313 L
s
.60605 .77605 m
.60605 .77605 L
s
.60605 .77605 m
.65918 .67614 L
s
.039 .916 .04 r
.35418 .76929 m
.43239 .70815 L
s
.72834 .54958 m
.72834 .54958 L
s
.74599 .5413 m
.74599 .5413 L
s
.62079 .60001 m
.6208 .6 L
s
.57466 .62163 m
.57466 .62163 L
s
0 0 0 r
2 Mabswid
.35418 .76929 Mdot
.039 .916 .04 r
.5 Mabswid
.72374 .54232 m
.72374 .54232 L
s
.73125 .53606 m
.73125 .53606 L
s
.57731 .66437 m
.57733 .66435 L
s
.58144 .66092 m
.58144 .66092 L
s
0 0 0 r
2 Mabswid
.7646 .50826 Mdot
.039 .916 .04 r
.5 Mabswid
.59714 .55952 m
.59715 .55952 L
s
.45054 .53953 m
.45054 .53953 L
s
.57133 .60087 m
.57133 .60087 L
s
.48064 .51094 m
.48064 .51094 L
s
.51197 .54201 m
.51197 .54201 L
s
0 0 0 r
2 Mabswid
.68741 .32503 Mdot
.20321 .27729 Mdot
.039 .916 .04 r
.5 Mabswid
.57589 .62926 m
.57589 .62926 L
s
.6369 .63046 m
.6369 .63046 L
s
.69999 .31829 m
.77684 .16882 L
s
.69999 .31829 m
.69999 .31829 L
s
.69999 .31829 m
.69999 .31829 L
s
.69406 .32983 m
.69999 .31829 L
s
.69406 .32983 m
.69406 .32983 L
s
.69406 .32983 m
.69406 .32983 L
s
0 0 0 r
2 Mabswid
.69406 .32983 Mdot
.039 .916 .04 r
.5 Mabswid
.75434 .59072 m
.75434 .59072 L
s
.75114 .58566 m
.75114 .58566 L
s
.47868 .40121 m
.47868 .40121 L
s
0 0 0 r
2 Mabswid
.38442 .59574 Mdot
.039 .916 .04 r
.5 Mabswid
.38496 .59647 m
.38507 .59662 L
s
.38507 .59662 m
.38507 .59662 L
s
0 0 0 r
2 Mabswid
.69072 .33096 Mdot
.039 .916 .04 r
.5 Mabswid
.82748 .35956 m
.83462 .33139 L
s
.82748 .35956 m
.82748 .35956 L
s
.78464 .5285 m
.80668 .44158 L
s
.82748 .35956 m
.82748 .35956 L
s
.80668 .44158 m
.82748 .35956 L
s
0 0 0 r
2 Mabswid
.78464 .5285 Mdot
.67167 .33746 Mdot
.039 .916 .04 r
.5 Mabswid
.6533 .35722 m
.65331 .35721 L
s
.65331 .35721 m
.65331 .35721 L
s
.54455 .47421 m
.54455 .47421 L
s
.55056 .46774 m
.55056 .46774 L
s
.55056 .46774 m
.55056 .46774 L
s
.56183 .45562 m
.56183 .45562 L
s
0 0 0 r
2 Mabswid
.38663 .59874 Mdot
.039 .916 .04 r
.5 Mabswid
.38663 .59874 m
.4281 .5946 L
s
0 0 0 r
2 Mabswid
.93851 .70476 Mdot
.039 .916 .04 r
.5 Mabswid
.39886 .58504 m
.39894 .58513 L
s
.39894 .58513 m
.39894 .58513 L
s
0 0 0 r
2 Mabswid
.39619 .58201 Mdot
.039 .916 .04 r
.5 Mabswid
.46518 .28715 m
.50547 .14918 L
s
.44104 .36982 m
.44891 .34288 L
s
.44891 .34288 m
.44891 .34288 L
s
.44891 .34288 m
.44891 .34288 L
s
.44891 .34288 m
.46518 .28715 L
s
.44104 .36982 m
.44104 .36982 L
s
.43071 .40519 m
.44104 .36982 L
s
.48461 .45443 m
.48585 .46656 L
s
.47922 .40182 m
.47922 .40182 L
s
.48953 .5025 m
.48953 .5025 L
s
0 0 0 r
2 Mabswid
.77684 .16882 Mdot
.039 .916 .04 r
.5 Mabswid
.51234 .43851 m
.51234 .43851 L
s
.54273 .497 m
.54273 .497 L
s
.25312 .38115 m
.36422 .43224 L
s
.36422 .43224 m
.36422 .43224 L
s
.36422 .43224 m
.36534 .43275 L
s
.55004 .4803 m
.55004 .4803 L
s
.5522 .48133 m
.5522 .48133 L
s
.5522 .48133 m
.5522 .48133 L
s
.55282 .48163 m
.55282 .48163 L
s
.73683 .74603 m
.74902 .80843 L
s
.73683 .74603 m
.73683 .74603 L
s
.73683 .74603 m
.73683 .74603 L
s
.72719 .69671 m
.73683 .74603 L
s
0 0 0 r
2 Mabswid
.74431 .59604 Mdot
0 g
.5 Mabswid
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.60605 .77605 L
s
.60605 .77605 m
.60605 .77605 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.60605 .77605 L
s
.60605 .77605 m
.60605 .77605 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.3188 .45236 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.3188 .45236 m
.3188 .45236 L
s
.46806 .38945 m
.46806 .38945 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.3188 .45236 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.40549 .54032 m
.42687 .56201 L
s
.3188 .45236 m
.40549 .54032 L
s
.3188 .45236 m
.3188 .45236 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.3188 .45236 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.3188 .45236 m
.3188 .45236 L
s
0 0 0 r
2 Mabswid
.40714 .59444 Mdot
0 g
.5 Mabswid
.83552 .57313 m
.83552 .57313 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.83552 .57313 L
s
.83552 .57313 m
.83552 .57313 L
s
.039 .916 .04 r
.31953 .35624 m
.36287 .3739 L
s
.36287 .3739 m
.39058 .38519 L
s
.39058 .38519 m
.39058 .38519 L
s
.39058 .38519 m
.39058 .38519 L
s
.39058 .38519 m
.43237 .40222 L
s
.43237 .40222 m
.43237 .40222 L
s
.43237 .40222 m
.43237 .40222 L
s
.43237 .40222 m
.43511 .40334 L
s
.48244 .40538 m
.48244 .40538 L
s
.76192 .54696 m
.76192 .54696 L
s
0 0 0 r
2 Mabswid
.75667 .58993 Mdot
0 g
.5 Mabswid
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.54783 .24868 m
.64475 .36863 L
s
.54783 .24868 m
.54783 .24868 L
s
.64475 .36863 m
.64475 .36863 L
s
.54783 .24868 m
.54783 .24868 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.54783 .24868 m
.54783 .24868 L
s
.64475 .36863 m
.64475 .36863 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.48371 .36184 L
s
.48371 .36184 m
.54783 .24868 L
s
.54783 .24868 m
.54783 .24868 L
s
0 0 0 r
2 Mabswid
.80119 .54939 Mdot
.039 .916 .04 r
.5 Mabswid
.74744 .57981 m
.74744 .57981 L
s
.55775 .49208 m
.55775 .49208 L
s
.48518 .50662 m
.48518 .50662 L
s
.54425 .49479 m
.54425 .49479 L
s
.60705 .43636 m
.60722 .45422 L
s
.60722 .45422 m
.60722 .45422 L
s
.607 .4312 m
.607 .4312 L
s
.79025 .28079 m
.80522 .27503 L
s
.66565 .3287 m
.77034 .28845 L
s
.77034 .28845 m
.77034 .28845 L
s
.77034 .28845 m
.77034 .28845 L
s
.77034 .28845 m
.79025 .28079 L
s
.66565 .3287 m
.66565 .3287 L
s
.66565 .3287 m
.66565 .3287 L
s
.62509 .3443 m
.66565 .3287 L
s
.67787 .33971 m
.76786 .25729 L
s
.67787 .33971 m
.67787 .33971 L
s
.67787 .33971 m
.67787 .33971 L
s
.67386 .34339 m
.67787 .33971 L
s
.67386 .34339 m
.67386 .34339 L
s
0 0 0 r
2 Mabswid
.67386 .34339 Mdot
.50547 .14918 Mdot
.53786 .28606 Mdot
.039 .916 .04 r
.5 Mabswid
.57838 .65847 m
.57839 .65847 L
s
.58096 .65866 m
.58096 .65866 L
s
.26613 .72895 m
.34032 .53499 L
s
.35105 .50695 m
.37255 .45074 L
s
.37255 .45074 m
.37255 .45074 L
s
.37255 .45074 m
.37255 .45074 L
s
.35105 .50695 m
.35105 .50695 L
s
.34032 .53499 m
.35105 .50695 L
s
0 0 0 r
2 Mabswid
.37255 .45074 Mdot
.039 .916 .04 r
.5 Mabswid
.58965 .37527 m
.58965 .37527 L
s
.75926 .54602 m
.75926 .54602 L
s
.63667 .42261 m
.63667 .42261 L
s
0 0 0 r
2 Mabswid
.78604 .57298 Mdot
.36532 .47028 Mdot
.74715 .57998 Mdot
.039 .916 .04 r
.5 Mabswid
.57013 .59339 m
.57013 .59339 L
s
.61721 .59387 m
.61722 .59387 L
s
0 0 0 r
2 Mabswid
.83462 .33139 Mdot
.039 .916 .04 r
.5 Mabswid
.75156 .48235 m
.76362 .53304 L
s
0 0 0 r
2 Mabswid
.76362 .53304 Mdot
.039 .916 .04 r
.5 Mabswid
.64521 .3682 m
.64521 .3682 L
s
.64521 .3682 m
.64521 .3682 L
s
.64521 .3682 m
.6457 .36848 L
s
0 0 0 r
2 Mabswid
.21291 .34014 Mdot
.039 .916 .04 r
.5 Mabswid
.72092 .77377 m
.72621 .79019 L
s
.72092 .77377 m
.72092 .77377 L
s
.72092 .77377 m
.72092 .77377 L
s
.69273 .68629 m
.72092 .77377 L
s
.64172 .70919 m
.6637 .75775 L
s
.64172 .70919 m
.64172 .70919 L
s
.62162 .66479 m
.64172 .70919 L
s
.54813 .47817 m
.54813 .47817 L
s
.54938 .48729 m
.54938 .48729 L
s
0 g
.55238 .48289 m
.55238 .48289 L
s
.53091 .30491 m
.53091 .30491 L
s
.46806 .38945 m
.52905 .30741 L
s
.53091 .30491 m
.53091 .30491 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.52402 .45146 L
s
.55238 .48289 m
.55238 .48289 L
s
.46806 .38945 m
.46806 .38945 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.53091 .30491 m
.53091 .30491 L
s
.46806 .38945 m
.53091 .30491 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.37865 .44026 m
.37865 .44026 L
s
.37865 .44026 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.5897 .37512 m
.5897 .37512 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.42687 .56201 m
.42687 .56201 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.46806 .38945 m
.46806 .38945 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
0 0 0 r
2 Mabswid
.827 .31998 Mdot
.039 .916 .04 r
.5 Mabswid
.68648 .3916 m
.74804 .36023 L
s
.74804 .36023 m
.827 .31998 L
s
.57325 .42262 m
.57325 .42262 L
s
.60528 .49834 m
.60528 .49834 L
s
.65276 .61059 m
.65276 .61059 L
s
.5723 .51699 m
.5723 .51698 L
s
.59409 .49507 m
.59409 .49507 L
s
.73587 .64133 m
.76426 .69395 L
s
.76426 .69395 m
.76426 .69395 L
s
.76426 .69395 m
.82373 .80419 L
s
.57991 .4034 m
.57991 .4034 L
s
.50873 .43451 m
.50873 .43451 L
s
.54465 .41881 m
.54465 .41881 L
s
.30508 .49446 m
.39932 .49244 L
s
.30508 .49446 m
.30508 .49446 L
s
.18083 .49713 m
.30508 .49446 L
s
0 g
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.45518 .62508 m
.45518 .62508 L
s
.42687 .56201 m
.45518 .62508 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.42687 .56201 m
.42687 .56201 L
s
.55238 .48289 m
.55238 .48289 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.37865 .44026 m
.37865 .44026 L
s
.37865 .44026 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.57955 .65206 m
.57955 .65206 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.45518 .62508 m
.45518 .62508 L
s
.42687 .56201 m
.45518 .62508 L
s
.37865 .44026 m
.37865 .44026 L
s
.37865 .44026 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42812 .59516 m
.43333 .73312 L
s
.42687 .56201 m
.42812 .59516 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.42687 .56201 m
.42687 .56201 L
s
.57955 .65206 m
.57955 .65206 L
s
.42687 .56201 m
.42687 .56201 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.42687 .56201 m
.43333 .73312 L
s
.43333 .73312 m
.43333 .73312 L
s
.42687 .56201 m
.42687 .56201 L
s
.57955 .65206 m
.57955 .65206 L
s
.43333 .73312 m
.43333 .73312 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.43333 .73312 m
.57955 .65206 L
s
.43333 .73312 m
.43333 .73312 L
s
.57955 .65206 m
.57955 .65206 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.70622 .40246 m
.70622 .40246 L
s
.64475 .36863 m
.70622 .40246 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.53091 .30491 m
.53091 .30491 L
s
.53091 .30491 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.70622 .40246 m
.70622 .40246 L
s
.64475 .36863 m
.70622 .40246 L
s
.71647 .53081 m
.71647 .53081 L
s
.53091 .30491 m
.53091 .30491 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.66499 .4144 m
.66499 .4144 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.8146 .39531 L
s
.8146 .39531 m
.8146 .39531 L
s
.64475 .36863 m
.64475 .36863 L
s
.64475 .36863 m
.8146 .39531 L
s
.64475 .36863 m
.64475 .36863 L
s
.8146 .39531 m
.8146 .39531 L
s
0 0 0 r
2 Mabswid
.80522 .27503 Mdot
.039 .916 .04 r
.5 Mabswid
.57728 .66451 m
.5773 .6645 L
s
.58184 .66278 m
.58184 .66278 L
s
0 g
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.73569 .50426 L
s
.73569 .50426 m
.8146 .39531 L
s
.8146 .39531 m
.8146 .39531 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.8146 .39531 L
s
.8146 .39531 m
.8146 .39531 L
s
.71647 .53081 m
.71647 .53081 L
s
.73338 .50986 m
.89665 .71734 L
s
.89665 .71734 m
.9759 .81805 L
s
.039 .916 .04 r
.46999 .77222 m
.55286 .6889 L
s
.55286 .6889 m
.55286 .6889 L
s
.55286 .6889 m
.55286 .6889 L
s
.55286 .6889 m
.57702 .66461 L
s
0 0 0 r
2 Mabswid
.57702 .66461 Mdot
.72257 .42165 Mdot
.039 .916 .04 r
.5 Mabswid
.44831 .54164 m
.44831 .54164 L
s
.5264 .52089 m
.5264 .52089 L
s
.56811 .50981 m
.56811 .50981 L
s
.60814 .49917 m
.60814 .49917 L
s
0 0 0 r
2 Mabswid
.43059 .54635 Mdot
.039 .916 .04 r
.5 Mabswid
.25622 .75812 m
.34405 .69861 L
s
.34405 .69861 m
.45457 .62373 L
s
.55032 .46582 m
.55032 .46582 L
s
.55032 .46582 m
.55032 .46582 L
s
.55497 .4754 m
.55497 .4754 L
s
.62127 .65003 m
.62127 .65003 L
s
0 0 0 r
2 Mabswid
.74902 .80843 Mdot
.82373 .80419 Mdot
.25312 .38115 Mdot
0 g
.5 Mabswid
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.66061 .60376 m
.66061 .60376 L
s
.57955 .65206 m
.66061 .60376 L
s
.57955 .65206 m
.57955 .65206 L
s
.55238 .48289 m
.55238 .48289 L
s
.57135 .60099 m
.57955 .65206 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.45518 .62508 m
.45518 .62508 L
s
.45518 .62508 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.45518 .62508 m
.45518 .62508 L
s
.57955 .65206 m
.57955 .65206 L
s
.45518 .62508 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.61185 .66183 L
s
.61185 .66183 m
.74663 .70259 L
s
.57955 .65206 m
.57955 .65206 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.57955 .65206 m
.57955 .65206 L
s
.62677 .61024 m
.62678 .61024 L
s
.71647 .53081 m
.71647 .53081 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.57955 .65206 L
s
.57955 .65206 m
.74663 .70259 L
s
.74663 .70259 m
.74663 .70259 L
s
0 0 0 r
2 Mabswid
.60839 .63762 Mdot
.63635 .63377 Mdot
.039 .916 .04 r
.5 Mabswid
.61597 .63036 m
.61597 .63036 L
s
.61597 .63036 m
.63635 .63377 L
s
0 0 0 r
2 Mabswid
.6648 .6062 Mdot
.039 .916 .04 r
.5 Mabswid
.62467 .62518 m
.62467 .62518 L
s
.62467 .62518 m
.63542 .6557 L
s
0 0 0 r
2 Mabswid
.63542 .6557 Mdot
0 g
.5 Mabswid
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.70622 .40246 m
.70622 .40246 L
s
.70622 .40246 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.66061 .60376 m
.66061 .60376 L
s
.66061 .60376 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.70622 .40246 m
.70622 .40246 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.74663 .70259 L
s
.74663 .70259 m
.74663 .70259 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.71647 .53081 L
s
.71647 .53081 m
.74663 .70259 L
s
.74663 .70259 m
.74663 .70259 L
s
0 0 0 r
2 Mabswid
.68672 .63144 Mdot
.039 .916 .04 r
.5 Mabswid
.49573 .796 m
.55461 .64665 L
s
.6546 .41742 m
.6546 .41742 L
s
.59449 .55498 m
.59449 .55498 L
s
.57217 .60608 m
.57217 .60608 L
s
.61766 .50195 m
.61766 .50195 L
s
0 0 0 r
2 Mabswid
.49573 .796 Mdot
.039 .916 .04 r
.5 Mabswid
.47282 .4744 m
.48144 .4617 L
s
.48144 .4617 m
.48144 .4617 L
s
.47282 .4744 m
.47282 .4744 L
s
.47282 .4744 m
.47282 .4744 L
s
.48144 .4617 m
.5128 .41548 L
s
.37596 .61716 m
.43547 .52945 L
s
.43547 .52945 m
.47282 .4744 L
s
0 0 0 r
2 Mabswid
.5128 .41548 Mdot
.56805 .62373 Mdot
.72621 .79019 Mdot
.31953 .35624 Mdot
.039 .916 .04 r
.5 Mabswid
.66687 .38283 m
.66741 .37753 L
s
.66741 .37753 m
.69394 .11645 L
s
0 0 0 r
2 Mabswid
.66687 .38283 Mdot
.039 .916 .04 r
.5 Mabswid
.55113 .35028 m
.66687 .38283 L
s
.55113 .35028 m
.55113 .35028 L
s
0 0 0 r
2 Mabswid
.51474 .37748 Mdot
.039 .916 .04 r
.5 Mabswid
.6475 .51407 m
.64873 .50982 L
s
0 0 0 r
2 Mabswid
.64873 .50982 Mdot
.039 .916 .04 r
.5 Mabswid
.64959 .55989 m
.6518 .6083 L
s
.64959 .55989 m
.64959 .55989 L
s
.6475 .51407 m
.64959 .55989 L
s
.61436 .589 m
.61436 .58899 L
s
0 0 0 r
2 Mabswid
.6475 .51407 Mdot
.039 .916 .04 r
.5 Mabswid
.55428 .59024 m
.59089 .65496 L
s
.59089 .65496 m
.62754 .71977 L
s
0 0 0 r
2 Mabswid
.55428 .59024 Mdot
.039 .916 .04 r
.5 Mabswid
.55428 .59024 m
.5906 .56543 L
s
.5906 .56543 m
.5906 .56543 L
s
0 0 0 r
2 Mabswid
.18083 .49713 Mdot
.52825 .18107 Mdot
0 g
.5 Mabswid
.72059 .31221 m
.73338 .50986 L
s
.70215 .0272 m
.72059 .31221 L
s
0 0 0 r
2 Mabswid
.59685 .62168 Mdot
.039 .916 .04 r
.5 Mabswid
.6203 .59917 m
.62031 .59916 L
s
0 0 0 r
2 Mabswid
.46999 .77222 Mdot
.59971 .62213 Mdot
.64511 .48935 Mdot
.62109 .51455 Mdot
.61856 .43143 Mdot
.52488 .34671 Mdot
.039 .916 .04 r
.5 Mabswid
.71072 .45886 m
.80848 .40855 L
s
.59998 .59395 m
.6043 .53048 L
s
.6043 .53048 m
.6043 .53048 L
s
.59998 .59395 m
.59998 .59395 L
s
.59998 .59395 m
.59998 .59395 L
s
.6043 .53048 m
.6043 .53048 L
s
.6043 .53048 m
.6075 .48337 L
s
.6075 .48337 m
.6075 .48337 L
s
.59656 .64417 m
.59998 .59395 L
s
0 0 0 r
2 Mabswid
.6075 .48337 Mdot
.55113 .35028 Mdot
.039 .916 .04 r
.5 Mabswid
.38413 .44557 m
.4453 .46413 L
s
.4453 .46413 m
.4453 .46413 L
s
.4453 .46413 m
.47069 .47184 L
s
.47069 .47184 m
.47069 .47184 L
s
0 0 0 r
2 Mabswid
.47069 .47184 Mdot
.53327 .3792 Mdot
.55906 .48382 Mdot
.039 .916 .04 r
.5 Mabswid
.55906 .48382 m
.56379 .49087 L
s
.56379 .49087 m
.56379 .49087 L
s
0 0 0 r
2 Mabswid
.66583 .4012 Mdot
.039 .916 .04 r
.5 Mabswid
.65741 .4166 m
.65741 .4166 L
s
0 g
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.57279 .50568 L
s
.57279 .50568 m
.66061 .60376 L
s
.66061 .60376 m
.66061 .60376 L
s
.66061 .60376 m
.66061 .60376 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.70622 .40246 m
.70622 .40246 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.45518 .62508 m
.55238 .48289 L
s
.45518 .62508 m
.45518 .62508 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.70622 .40246 L
s
.70622 .40246 m
.70622 .40246 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.45518 .62508 m
.55238 .48289 L
s
.45518 .62508 m
.45518 .62508 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.53091 .30491 m
.55238 .48289 L
s
.53091 .30491 m
.53091 .30491 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.51883 .47466 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.37865 .44026 m
.51883 .47466 L
s
.37865 .44026 m
.37865 .44026 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.53091 .30491 m
.55238 .48289 L
s
.53091 .30491 m
.53091 .30491 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.37865 .44026 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.55238 .48289 m
.55238 .48289 L
s
.37865 .44026 m
.37865 .44026 L
s
0 0 0 r
2 Mabswid
.65888 .47103 Mdot
.039 .916 .04 r
.5 Mabswid
.56439 .50344 m
.56439 .50344 L
s
0 0 0 r
2 Mabswid
.56477 .51131 Mdot
.56379 .49087 Mdot
.69265 .46459 Mdot
.25622 .75812 Mdot
.6637 .75775 Mdot
.039 .916 .04 r
.5 Mabswid
.54433 .37742 m
.6992 .38808 L
s
0 0 0 r
2 Mabswid
.54433 .37742 Mdot
.76786 .25729 Mdot
.5906 .56543 Mdot
.039 .916 .04 r
.5 Mabswid
.59813 .56122 m
.59814 .56121 L
s
.48447 .44939 m
.57434 .50195 L
s
.57434 .50195 m
.59877 .51623 L
s
.59877 .51623 m
.59877 .51623 L
s
.59877 .51623 m
.59877 .51623 L
s
.59877 .51623 m
.60744 .5213 L
s
.60744 .5213 m
.63775 .53903 L
s
0 0 0 r
2 Mabswid
.63775 .53903 Mdot
.039 .916 .04 r
.5 Mabswid
.68473 .7021 m
.68833 .71661 L
s
.66035 .60392 m
.68473 .7021 L
s
0 0 0 r
2 Mabswid
.63336 .4606 Mdot
.039 .916 .04 r
.5 Mabswid
.59151 .55374 m
.61041 .65438 L
s
.59151 .55374 m
.59151 .55374 L
s
.61041 .65438 m
.61313 .66885 L
s
0 0 0 r
2 Mabswid
.59151 .55374 Mdot
.70635 .44894 Mdot
.039 .916 .04 r
.5 Mabswid
.60989 .54623 m
.70635 .44894 L
s
.70635 .44894 m
.70635 .44894 L
s
.60989 .54623 m
.60989 .54623 L
s
.60989 .54623 m
.60989 .54623 L
s
.68637 .40821 m
.68637 .40821 L
s
.6679 .45251 m
.67314 .33732 L
s
.6679 .45251 m
.6679 .45251 L
s
.6679 .45251 m
.6679 .45251 L
s
.6631 .55808 m
.6679 .45251 L
s
.6631 .55808 m
.6631 .55808 L
s
.6631 .55808 m
.6631 .55808 L
s
0 0 0 r
2 Mabswid
.6631 .55808 Mdot
.68527 .44465 Mdot
.039 .916 .04 r
.5 Mabswid
.68053 .40991 m
.68053 .40991 L
s
0 0 0 r
2 Mabswid
.61763 .53556 Mdot
.039 .916 .04 r
.5 Mabswid
.51246 .40075 m
.61685 .40352 L
s
.61685 .40352 m
.61685 .40352 L
s
.61685 .40352 m
.61685 .40352 L
s
.61685 .40352 m
.67989 .40519 L
s
.67989 .40519 m
.67989 .40519 L
s
.67989 .40519 m
.67989 .40519 L
s
0 0 0 r
2 Mabswid
.67989 .40519 Mdot
.80848 .40855 Mdot
.6097 .5661 Mdot
.69394 .11645 Mdot
.60902 .54728 Mdot
.60989 .54623 Mdot
.26613 .72895 Mdot
.62754 .71977 Mdot
.68833 .71661 Mdot
.38413 .44557 Mdot
0 g
.5 Mabswid
.73338 .50986 m
.15448 .69059 L
s
0 0 0 r
2 Mabswid
.51246 .40075 Mdot
.61313 .66885 Mdot
.48447 .44939 Mdot
.59656 .64417 Mdot
.67314 .33732 Mdot
.37596 .61716 Mdot
.6518 .6083 Mdot
.6992 .38808 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{552.812, 550.062},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008X00029R000`400?l00000o`00003oo`3ooooo
0?ooobX0oooo003o0?ooool0oooo:P3oool00?l0ooooo`3ooolZ0?ooo`00o`3ooooo0?ooobX0oooo
003o0?ooool0oooo:P3oool00?l0ooooo`3ooolZ0?ooo`00o`3ooooo0?ooobX0oooo003o0?ooool0
oooo:P3oool00?l0ooooo`3ooolZ0?ooo`00o`3ooooo0?ooobX0oooo003o0?ooool0oooo:P3oool0
0?l0ooooo`3ooolZ0?ooo`00o`3ooooo0?ooobX0oooo003o0?ooool0oooo:P3oool00?l0ooooo`3o
oolZ0?ooo`00o`3ooon30?ooo`800000Y03oool00?l0ooooP03oool3000000030?ooo`000000oooo
0:<0oooo003o0?ooogh0oooo0P0000040?ooo`800000X`3oool00?l0ooooN`3oool3000000H0oooo
00<000000?ooo`000000XP3oool00?l0ooooN@3oool2000000T0oooo00<000000?ooo`000000XP3o
ool00?l0ooooMP3oool3000000/0oooo00@000000?ooo`3oool00000X@3oool00?l0ooooM03oool2
000000h0oooo00D000000?ooo`3oool0oooo0000002P0?ooo`00o`3oooma0?ooo`<00000403oool0
1@000000oooo0?ooo`3oool000000:00oooo003o0?ooofl0oooo0P00000C0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0W@3oool00?l0ooooK03oool3000001H0oooo00D000000?oo
o`3oool0oooo0000002O0?ooo`00o`3ooomZ0?ooo`8000006@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo09`0oooo003o0?ooofL0oooo0`00000K0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0V`3oool00?l0ooooI@3oool2000001h0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`2K0?ooo`00o`3ooomR0?ooo`<00000803oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo09X0oooo003o0?ooof00oooo0P00000S0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0V@3oool00?l0ooooG@3oool3000002D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`2I0?ooo`00o`3ooomK0?ooo`800000:03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo09P0oooo003o0?oooeP0oooo0`00000Z0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0U`3oool00?l0ooooEP3oool2000002d0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`2G0?ooo`00o`3ooomC0?ooo`<00000;`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo09H0oooo003o0?oooe40oooo0P00000b0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0UP3oool00?l0ooooCP3oool3000003@0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2E0?ooo`00o`3ooom<0?ooo`800000
=`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo09@0oooo003o0?ooodT0oooo0`00
000i0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0U03oool00?l0ooooA`3oool2
000003`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2C0?ooo`00o`3ooom40?oo
o`<00000?`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0980oooo003o0?oood80
oooo0P0000120?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0TP3oool00?l0oooo
?`3oool3000004@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2A0?ooo`00o`3o
ooll0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0900oooo003o
0?ooocX0oooo0P00001:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0T03oool0
0?l0oooo=`3oool3000004`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2?0?oo
o`00o`3ooole0?ooo`800000C`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo08h0
oooo003o0?oooc80oooo0`00001A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
SP3oool00?l0oooo<03oool2000005@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`2=0?ooo`00o`3oool]0?ooo`<00000EP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo08d0oooo003o0?ooob/0oooo0P00001I0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0S03oool00?l0oooo:03oool3000005/0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`2;0?ooo`00o`3ooolV0?ooo`800000GP3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo08/0oooo003o0?ooob<0oooo0`00001P0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0RP3oool00?l0oooo8@3oool2000006<0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`290?ooo`00o`3ooolN0?ooo`<00000IP3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo08T0oooo003o0?oooa`0oooo0P00001Y0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0R03oool00?l0oooo6@3oool3000006/0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`270?ooo`00o`3ooolG0?ooo`800000KP3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo08L0oooo003o0?oooa@0oooo0`00001`0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0QP3oool00?l0oooo4P3oool2000007<0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`260?ooo`00o`3oool?0?ooo`<00000M@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo08D0oooo003o0?ooo`d0oooo0P00001h0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0Q03oool00?l0oooo2P3oool3000007X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`240?ooo`00o`3oool80?ooo`800000M@3oool2
000000H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`230?ooo`00o`3oool50?oo
o`<00000M`3oool2000000H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`220?oo
o`00o`3oool30?ooo`800000NP3oool00`09jPX0oooo0?ooo`050?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0PP3oool00?l0oooo0`00001l0?ooo`0300WZ2P3oool0oooo00D0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`210?ooo`00o@3oool2000007l0oooo00<0
2NX:0?ooo`3oool01@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0800oooo003j
0?ooo`<00000P@3oool00`09jPX0oooo0?ooo`050?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0P03oool00?P0oooo0P0000240?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1o0?ooo`00m@3oool3000008D0oooo00<02NX:0?ooo`3o
ool01`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo07h0oooo003c0?ooo`800000
R03oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
OP3oool00?00oooo0`00002:0?ooo`0300WZ2P3oool0oooo00L0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`1m0?ooo`00kP3oool2000008d0oooo00<02NX:0?ooo`3oool01`3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo07d0oooo003[0?ooo`<00000S`3oool00`09
jPX0oooo0?ooo`070?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0O03oool00>T0
oooo0P00002B0?ooo`0300WZ2P3oool0oooo00L0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`1k0?ooo`00iP3oool3000009@0oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo07/0oooo003T0?ooo`800000U`3oool00`09jPX0oooo0?oo
o`070?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0NP3oool00>40oooo0`00002I
0?ooo`0300WZ2P3oool0oooo00L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1i
0?ooo`00g`3oool2000009`0oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo07T0oooo003L0?ooo`<00000W@3oool00`09jPX0oooo0?ooo`080?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0N03oool00=X0oooo0P00000j0?ooo`800000
I03oool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
M`3oool00=L0oooo0`00000l0?ooo`800000I03oool00`09jPX0oooo0?ooo`080?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0M`3oool00=D0oooo0P00000o0?ooo`0300WZ2P3oool0
oooo06<0oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo07H0oooo003B0?ooo`<00000@@3oool00`09jPX0oooo0?ooo`1S0?ooo`0300WZ2P3oool0oooo
00P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1f0?ooo`00d03oool2000004<0
oooo00<02NX:0?ooo`3oool0I03oool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0M@3oool00<d0oooo0`0000150?ooo`0300WZ2P3oool0oooo06@0oooo
00<02NX:0?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo07@0oooo
003;0?ooo`800000B03oool00`09jPX0oooo0?ooo`1T0?ooo`0300WZ2P3oool0oooo00T0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`1d0?ooo`00b03oool3000004T0oooo00<02NX:
0?ooo`3oool0I@3oool00`09jPX0oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0L`3oool00<H0oooo0P00001<0?ooo`0300WZ2P3oool0oooo06D0oooo00<02NX:0?oo
o`3oool02@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0780oooo00330?ooo`<0
0000CP3oool00`09jPX0oooo0?ooo`1U0?ooo`0300WZ2P3oool0oooo00T0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`1b0?ooo`00`@3oool200000540oooo00<02NX:0?ooo`3oool0
I03oool00`09jPX0oooo0?ooo`0:0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
L@3oool00;h0oooo0`00001B0?ooo`0300WZ2P3oool0oooo06D0oooo00<02NX:0?ooo`3oool02P3o
ool00`000000oooo0?ooo`0Q0?ooo`8000001`3oool00`000000oooo0?ooo`1`0?ooo`00_03oool2
000005D0oooo00<02NX:0?ooo`3oool0I@3oool00`09jPX0oooo0?ooo`0:0?ooo`030000003oool0
oooo0240oooo0P0000070?ooo`030000003oool0oooo0700oooo002i0?ooo`<00000E`3oool00`09
jPX0oooo0?ooo`1U0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool08@3oool00`09
jPX0oooo0?ooo`070?ooo`030000003oool0oooo06l0oooo002g0?ooo`800000F@3oool00`09jPX0
oooo0?ooo`1V0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool0803oool00`09jPX0
oooo0?ooo`080?ooo`030000003oool0oooo06l0oooo002d0?ooo`<00000F`3oool00`09jPX0oooo
0?ooo`1V0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool0803oool00`09jPX0oooo
0?ooo`090?ooo`030000003oool0oooo06h0oooo002a0?ooo`<00000GP3oool00`09jPX0oooo0?oo
o`1V0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?oo
o`0;0?ooo`030000003oool0oooo06d0oooo002_0?ooo`800000H@3oool00`09jPX0oooo0?ooo`1V
0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0;
0?ooo`030000003oool0oooo06d0oooo002/0?ooo`<00000HP3oool00`09jPX0oooo0?ooo`0>0?oo
o`80000000<02NX:0?ooo`3oool0E03oool00`09jPX0oooo0?ooo`0:0?ooo`030000003oool0oooo
01h0oooo00<02NX:0?ooo`3oool03@3oool00`000000oooo0?ooo`1/0?ooo`00ZP3oool2000006D0
oooo00<02NX:0?ooo`3oool03P3oool2000000030?ooo`09jPX0oooo05@0oooo00<02NX:0?ooo`3o
ool02P3oool00`000000oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo00h0oooo00<000000?ooo`3o
ool0J`3oool00:L0oooo0`00001W0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0
D@3oool00`09jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo01d0oooo00<02NX:0?ooo`3oool0
3`3oool00`000000oooo0?ooo`1[0?ooo`00Y@3oool2000006T0oooo00<02NX:0?ooo`3oool0503o
ool00`09jPX0oooo0?ooo`1@0?ooo`0300WZ2P3oool0oooo00`0oooo00<000000?ooo`3oool0703o
ool00`09jPX0oooo0?ooo`0@0?ooo`030000003oool0oooo06X0oooo002R0?ooo`<00000J`3oool0
0`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo04l0oooo00<02NX:0?ooo`3oool0303oool0
0`000000oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo0180oooo00<000000?ooo`3oool0J@3oool0
0:00oooo0P00001^0?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool0CP3oool00`09
jPX0oooo0?ooo`0<0?ooo`030000003oool0oooo01/0oooo00<02NX:0?ooo`3oool04P3oool00`00
0000oooo0?ooo`1Y0?ooo`00W@3oool3000006l0oooo00<02NX:0?ooo`3oool0603oool00`09jPX0
oooo0?ooo`1=0?ooo`0300WZ2P3oool0oooo00`0oooo00<000000?ooo`3oool06P3oool00`09jPX0
oooo0?ooo`0D0?ooo`030000003oool0oooo06P0oooo002K0?ooo`800000LP3oool00`09jPX0oooo
0?ooo`0I0?ooo`802NX:C@3oool00`09jPX0oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo
00<02NX:0?ooo`3oool05@3oool00`000000oooo0?ooo`1W0?ooo`00V03oool3000007@0oooo00<0
2NX:0?ooo`3oool06`3oool00`09jPX0oooo0?ooo`1:0?ooo`0300WZ2P3oool0oooo00`0oooo00<0
00000?ooo`3oool06@3oool00`09jPX0oooo0?ooo`0F0?ooo`030000003oool0oooo06L0oooo002F
0?ooo`800000M`3oool00`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo04T0oooo00<02NX:
0?ooo`3oool0303oool00`000000oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo01L0oooo00<00000
0?ooo`3oool0IP3oool009<0oooo0`00001h0?ooo`0300WZ2P3oool0oooo01h0oooo00<02NX:0?oo
o`3oool0B03oool00`09jPX0oooo0?ooo`0<0?ooo`030000003oool0oooo01P0oooo00<02NX:0?oo
o`3oool0603oool00`000000oooo0?ooo`1V0?ooo`00T@3oool2000007/0oooo00<02NX:0?ooo`3o
ool07`3oool00`09jPX0oooo0?ooo`170?ooo`0300WZ2P3oool0oooo00`0oooo00<000000?ooo`3o
ool0503oool200000080oooo00<02NX:0?ooo`3oool06@3oool00`000000oooo0?ooo`1U0?ooo`00
SP3oool3000007d0oooo00<02NX:0?ooo`3oool0803oool00`09jPX0oooo0?ooo`150?ooo`0300WZ
2P3oool0oooo00d0oooo00<000000?ooo`3oool04`3oool200WZ2P030000003oool02NX:01d0oooo
00<000000?ooo`3oool0I03oool008`0oooo0P00001o0?ooo`0300WZ2P3oool0oooo0280oooo00<0
2NX:0?ooo`3oool0A03oool00`09jPX0oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo0`09
jPX40?ooo`0300WZ2P3oool0oooo01/0oooo00<000000?ooo`3oool0I03oool008T0oooo0`000021
0?ooo`0300WZ2P3oool0oooo02<0oooo00<02NX:0?ooo`3oool0@`3oool00`09jPX0oooo0?ooo`0=
0?ooo`030000003oool0oooo00d0oooo0`09jPX60?ooo`0300WZ2P3oool0oooo01d0oooo00<00000
0?ooo`3oool0H`3oool008L0oooo0P0000240?ooo`0300WZ2P3oool0oooo02@0oooo0P09jPY30?oo
o`0300WZ2P3oool0oooo00d0oooo00<000000?ooo`3oool02`3oool200WZ2PP0oooo00<02NX:0?oo
o`3oool07`3oool00`000000oooo0?ooo`1R0?ooo`00Q03oool3000008H0oooo00<02NX:0?ooo`3o
ool09P3oool00`09jPX0oooo0?ooo`100?ooo`0300WZ2P3oool0oooo00d0oooo00<000000?ooo`3o
ool0203oool300WZ2PX0oooo00<02NX:0?ooo`3oool07`3oool00`000000oooo0?ooo`1R0?ooo`00
PP3oool2000008P0oooo00<02NX:0?ooo`3oool0:03oool00`09jPX0oooo0?ooo`0o0?ooo`0300WZ
2P3oool0oooo00d0oooo00<000000?ooo`3oool01@3oool300WZ2P`0oooo00<02NX:0?ooo`3oool0
8@3oool00`000000oooo0?ooo`1Q0?ooo`00O`3oool3000008X0oooo00<02NX:0?ooo`3oool0:@3o
ool00`09jPX0oooo0?ooo`0n0?ooo`0300WZ2P3oool0oooo00d0oooo00<000000?ooo`3oool00`3o
ool200WZ2Pl0oooo00<02NX:0?ooo`3oool08P3oool00`000000oooo0?ooo`1P0?ooo`00O@3oool2
000008d0oooo00<02NX:0?ooo`3oool0:P3oool00`09jPX0oooo0?ooo`0m0?ooo`0300WZ2P3oool0
oooo00h0oooo00<000000?ooo`09jPX00P09jPX@0?ooo`0300WZ2P3oool0oooo02<0oooo00<00000
0?ooo`3oool0H03oool007X0oooo0`00001@0?ooo`0300000009jPX0oooo03/0oooo00<02NX:0?oo
o`3oool0;03oool00`09jPX0oooo0?ooo`0l0?ooo`0300WZ2P3oool0oooo00h0oooo00<0000000WZ
2P3oool04P3oool00`09jPX0oooo0?ooo`0T0?ooo`030000003oool0oooo05l0oooo001h0?ooo`80
0000D`3oool00`0000002NX:0?ooo`0k0?ooo`0300WZ2P3oool0oooo02d0oooo00<02NX:0?ooo`3o
ool0>`3oool00`09jPX0oooo0?ooo`0;0?ooo`<02NX:00<000000?ooo`3oool04@3oool00`09jPX0
oooo0?ooo`0U0?ooo`030000003oool0oooo05l0oooo001e0?ooo`<00000E`3oool00`09jPX0oooo
0?ooo`0i0?ooo`0300WZ2P3oool0oooo02h0oooo0P09jPXk0?ooo`0300WZ2P3oool0oooo00P0oooo
0`09jPX30?ooo`030000003oool0oooo0140oooo00<02NX:0?ooo`3oool09P3oool00`000000oooo
0?ooo`1N0?ooo`00L`3oool2000005/0oooo00<02NX:0?ooo`3oool0>03oool00`09jPX0oooo0?oo
o`0`0?ooo`0300WZ2P3oool0oooo03L0oooo00<02NX:0?ooo`3oool01`3oool200WZ2PH0oooo00<0
00000?ooo`3oool0403oool00`09jPX0oooo0?ooo`0X0?ooo`030000003oool0oooo05d0oooo001`
0?ooo`<00000GP3oool00`09jPX0oooo0?ooo`0f0?ooo`0300WZ2P3oool0oooo0380oooo00<02NX:
0?ooo`3oool0=P3oool00`09jPX0oooo0?ooo`040?ooo`<02NX:203oool00`000000oooo0?ooo`0@
0?ooo`0300WZ2P3oool0oooo02P0oooo00<000000?ooo`3oool0G@3oool006l0oooo00<000000?oo
o`3oool0H03oool00`09jPX0oooo0?ooo`0e0?ooo`0300WZ2P3oool0oooo03<0oooo00<02NX:0?oo
o`3oool0=@3oool01009jPX0oooo0?ooo`3oool300WZ2P/0oooo00<000000?ooo`3oool03`3oool0
0`09jPX0oooo0?ooo`0Z0?ooo`030000003oool0oooo05`0oooo001_0?ooo`800000HP3oool00`09
jPX0oooo0?ooo`0d0?ooo`0300WZ2P3oool0oooo03@0oooo00<02NX:0?ooo`3oool0=03oool01009
jPX0oooo00WZ2P09jPX>0?ooo`030000003oool0oooo00l0oooo00<02NX:0?ooo`3oool0:`3oool0
0`000000oooo0?ooo`1K0?ooo`00K`3oool00`000000oooo0000001R0?ooo`0300WZ2P3oool0oooo
0380oooo00<02NX:0?ooo`3oool06@3oool2000001/0oooo0P09jPXc0?ooo`<02NX:403oool00`00
0000oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo02`0oooo00<000000?ooo`3oool0F`3oool006l0
oooo00@000000?ooo`3oool00000H@3oool00`09jPX0oooo0?ooo`0b0?ooo`0300WZ2P3oool0oooo
01T0oooo0P09jPXM0?ooo`0300WZ2P3oool0oooo02d0oooo0`09jPX00`3oool02NX:0?ooo`0@0?oo
o`030000003oool0oooo00h0oooo00<02NX:0?ooo`3oool0;@3oool00`000000oooo0?ooo`1J0?oo
o`00K`3oool01@000000oooo0?ooo`3oool000000640oooo00<02NX:0?ooo`3oool0<@3oool00`09
jPX0oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0?ooo`3oool0:P3oool200WZ
2P@0oooo00<02NX:0?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo
02l0oooo00<000000?ooo`3oool0F@3oool006l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1O0?ooo`0300WZ2P3oool0oooo0300oooo00<02NX:0?ooo`3oool0703oool200WZ2Q`0
oooo00<02NX:0?ooo`3oool09P3oool300WZ2PH0oooo00<02NX:0?ooo`3oool03`3oool00`000000
oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo02l0oooo00<000000?ooo`3oool0F@3oool006h0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1O0?ooo`0300WZ2P3oool0oooo02h0oooo
00<02NX:0?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo0280oooo
0`09jPX90?ooo`0300WZ2P3oool0oooo00l0oooo00<000000?ooo`3oool0303oool00`09jPX0oooo
0?ooo`0Y0?ooo`8000001P3oool00`000000oooo0?ooo`1H0?ooo`00KP3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0600oooo00<02NX:0?ooo`3oool0;@3oool00`09jPX0oooo0?oo
o`0P0?ooo`802NX:6`3oool200WZ2R00oooo0P09jPX<0?ooo`0300WZ2P3oool0oooo00l0oooo00<0
00000?ooo`3oool0303oool00`09jPX0oooo0?ooo`0Y0?ooo`802NX:1P3oool00`000000oooo0?oo
o`1H0?ooo`00KP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0600oooo00<02NX:
0?ooo`3oool0;03oool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:
0?ooo`3oool06P3oool300WZ2Pd0oooo00<02NX:0?ooo`3oool0403oool00`000000oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo02P0oooo0P09jPX90?ooo`030000003oool0oooo05L0oooo001^0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0H03oool00`09jPX0oooo0?ooo`0Z0?oo
o`0300WZ2P3oool0oooo02@0oooo0P09jPXK0?ooo`0300WZ2P3oool0oooo01L0oooo0P09jPX@0?oo
o`0300WZ2P3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0W0?oo
o`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool0EP3oool006h0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`1O0?ooo`0300WZ2P3oool0oooo02X0oooo00<02NX:0?ooo`3o
ool09P3oool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo01<0oooo0`09jPXB0?ooo`03
00WZ2P3oool0oooo0140oooo00<000000?ooo`3oool02@3oool00`09jPX0oooo0?ooo`0W0?ooo`03
00WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool0EP3oool006h0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`1O0?ooo`0300WZ2P3oool0oooo02T0oooo00<02NX:0?ooo`3oool0
9`3oool200WZ2QX0oooo0P09jPX@0?ooo`<02NX:5@3oool00`09jPX0oooo0?ooo`0A0?ooo`030000
003oool0oooo00T0oooo00<02NX:0?ooo`3oool09P3oool00`09jPX0oooo0?ooo`0=0?ooo`030000
003oool0oooo05D0oooo001^0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0G`3o
ool00`09jPX0oooo0?ooo`0X0?ooo`0300WZ2P3oool0oooo02@0oooo00<000000?ooo`3oool00P3o
ool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo00/0oooo0P09jPXH0?ooo`0300WZ2P3o
ool0oooo0140oooo00<000000?ooo`3oool0203oool00`09jPX0oooo0?ooo`0U0?ooo`802NX:4@3o
ool00`000000oooo0?ooo`1D0?ooo`00KP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo05l0oooo00<02NX:0?ooo`3oool09P3oool00`09jPX0oooo0?ooo`0U0?ooo`030000003oool0
oooo00<0oooo0P09jPXJ0?ooo`0300WZ2P3oool0oooo00L0oooo0`09jPXJ0?ooo`0300WZ2P3oool0
oooo0140oooo00<000000?ooo`3oool0203oool00`09jPX0oooo0?ooo`0T0?ooo`0300WZ2P3oool0
oooo0140oooo00<000000?ooo`3oool0E03oool006h0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1O0?ooo`0300WZ2P3oool0oooo02D0oooo00<02NX:0?ooo`3oool09@3oool00`00
0000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool00`3oool300WZ
2Qd0oooo00<02NX:0?ooo`3oool04@3oool00`000000oooo0?ooo`070?ooo`0300WZ2P3oool0oooo
02@0oooo00<02NX:0?ooo`3oool04`3oool00`000000oooo0?ooo`1C0?ooo`00KP3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo05l0oooo00<02NX:0?ooo`3oool0903oool00`09jPX0
oooo0?ooo`0T0?ooo`030000002YNYl0000000L0oooo0P09jPXI0?ooo`0300WZ2P3oool0oooo0080
2NX:803oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo00<02NX:0?ooo`3o
ool06`3oool2000000D0oooo0P09jPXF0?ooo`030000003oool0oooo05<0oooo001]0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0GP3oool00`09jPX0oooo0?ooo`0S0?ooo`0300WZ
2P3oool0oooo02D0oooo00@000000:UjW`2YNYl00000203oool00`09jPX0oooo0?ooo`0F0?ooo`<0
2NX:8P3oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo00<02NX:0?ooo`3o
ool0703oool2000000@0oooo00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`1B0?ooo`00
K@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05h0oooo00<02NX:0?ooo`3oool0
8P3oool00`09jPX0oooo0?ooo`0T0?ooo`030000002YNYl0ZGZO0080ZGZO00<000000?ooo`3oool0
1P3oool200WZ2Q<0oooo0`09jPX30?ooo`0300WZ2P3oool0oooo01l0oooo00<02NX:0?ooo`3oool0
4@3oool00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00l0oooo00<02NX:000000000000
2@3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01T0oooo00<000000?ooo`3oool0
D@3oool006d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1N0?ooo`0300WZ2P3o
ool0oooo0240oooo00<02NX:0?ooo`3oool08`3oool00`000000ZGZO0:UjW`040:UjW`030000003o
ool0oooo00L0oooo00<02NX:0?ooo`3oool03P3oool200WZ2PL0oooo00<02NX:0?ooo`3oool07@3o
ool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<02NX:0?ooo`3oool03`3o
ool01009jPX0oooo0000000000080?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
6P3oool00`000000oooo0?ooo`1A0?ooo`00K@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo05h0oooo00<02NX:0?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0T0?ooo`030000002Y
NYl0ZGZO00@0ZGZO00<000000?ooo`3oool0203oool200WZ2P/0oooo0`09jPX:0?ooo`0300WZ2P3o
ool0oooo01`0oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`0300WZ2P3o
ool0oooo00h0oooo00<02NX:0?ooo`3oool02P3oool01009jPX0oooo0?ooo`3oool200WZ2QD0oooo
0P09jPX70?ooo`030000003oool0oooo0500oooo001]0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0GP3oool00`09jPX0oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo02<0oooo00<0
00000:UjW`2YNYl01P2YNYl00`000000oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00H0oooo0P09
jPX>0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool02P3oool01@09jPX0oooo0?oo
o`3oool02NX:01H0oooo00<02NX:000000000000203oool00`000000oooo0?ooo`1?0?ooo`00K@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05l0oooo00<02NX:0?ooo`3oool07@3o
ool00`09jPX0oooo0?ooo`0S0?ooo`030000002YNYl0ZGZO00L0ZGZO00<000000?ooo`3oool02@3o
ool200WZ2P<0oooo0`09jPXA0?ooo`802NX:6`3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003o
ool0oooo00@0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0:0?ooo`0500WZ2P3o
ool0oooo0?ooo`09jPX05P3oool00`09jPX0oooo0?ooo`090?ooo`030000003oool0oooo04l0oooo
001]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0G`3oool00`09jPX0oooo0?oo
o`0L0?ooo`0300WZ2P3oool0oooo0280oooo00<000000:UjW`2YNYl02@2YNYl00`000000oooo0?oo
o`0:0?ooo`<02NX:5P3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo0180oooo00<0
00000?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00/0oooo00@0
2NX:0?ooo`09jPX02NX:5@3oool200WZ2Pd0oooo00<000000?ooo`3oool0CP3oool006d0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`1N0?ooo`0300WZ2P3oool0oooo01/0oooo00<0
2NX:0?ooo`3oool08P3oool00`000000ZGZO0:UjW`0;0:UjW`030000003oool0oooo00L0oooo0P09
jPX00`3oool02NX:00WZ2P0G0?ooo`0300WZ2P3oool0oooo01L0oooo00<02NX:0?ooo`3oool04P3o
ool00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool02`3o
ool00`09jPX0oooo00WZ2P0F0?ooo`0300WZ2P3oool0oooo00h0oooo00<000000?ooo`3oool0C@3o
ool006d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1N0?ooo`0300WZ2P3oool0
oooo01X0oooo00<02NX:0?ooo`3oool08P3oool00`000000ZGZO0:UjW`0;0:UjW`030000003oool0
oooo00@0oooo0`09jPX50?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool05P3oool0
0`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<02NX:0?ooo`3oool0303oool0
0`09jPX0oooo0?ooo`0<0?ooo`802NX:5P3oool00`09jPX0oooo0?ooo`0?0?ooo`030000003oool0
oooo04d0oooo001]0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0GP3oool00`09
jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo0240oooo00<000000:UjW`2YNYl03@2YNYl00`00
0000oooo0?ooo`0300WZ2PT0oooo0P09jPXF0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?oo
o`3oool04`3oool01@000000oooo0?ooo`3oool02NX:00d0oooo00<02NX:0?ooo`3oool0303oool2
00WZ2QD0oooo0P09jPXC0?ooo`030000003oool0oooo04`0oooo001/0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0GP3oool00`09jPX0oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo
0280oooo00<000000:UjW`2YNYl03P2YNYl00`0000002NX:0?ooo`0=0?ooo`0300WZ2P3oool02NX:
01@0oooo00<02NX:0?ooo`3oool0503oool00`09jPX0oooo0?ooo`0C0?ooo`040000003oool0oooo
00WZ2Pd0oooo00<02NX:0?ooo`3oool0303oool200WZ2QD0oooo00<02NX:0?ooo`3oool04`3oool0
0`000000oooo0?ooo`1<0?ooo`00K03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
05h0oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0Q0?ooo`030000002YNYl0ZGZO
0100ZGZO00<000000?ooo`3oool03@3oool200WZ2QD0oooo0P09jPXD0?ooo`0300WZ2P3oool0oooo
01<0oooo00@000000?ooo`3oool02NX:303oool00`09jPX0oooo0?ooo`0<0?ooo`802NX:3P3oool2
000000D0oooo00<02NX:0?ooo`3oool05@3oool00`000000oooo0?ooo`1;0?ooo`00K03oool00`00
0000oooo0?ooo`020000000300WZ2P3oool0oooo01D0oooo00<000000?ooo`3oool0G@3oool00`09
jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo0240oooo00<000000:UjW`2YNYl04@2YNYl00`00
0000oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool0403oool00`09
jPX0oooo0?ooo`0D0?ooo`030000003oool02NX:00`0oooo00<02NX:0?ooo`3oool0303oool200WZ
2P`0oooo0`09jPX2000000@0oooo00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`1:0?oo
o`00K03oool00`000000oooo0?ooo`02000000030?ooo`09jPX0oooo01H0oooo00<000000?ooo`3o
ool0G@3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo0200oooo00<000000:UjW`2Y
NYl04P2YNYl00`000000oooo0?ooo`0?0?ooo`802NX:5@3oool00`09jPX0oooo0?ooo`0?0?ooo`03
00WZ2P3oool0oooo01@0oooo00<000000?ooo`09jPX02`3oool00`09jPX0oooo0?ooo`0<0?ooo`80
2NX:2P3oool300WZ2PL0oooo0P09jPXJ0?ooo`030000003oool0oooo04X0oooo001/0?ooo`030000
003oool0oooo00@0oooo0P09jPXF0?ooo`030000003oool0oooo05d0oooo00<02NX:0?ooo`3oool0
4`3oool00`09jPX0oooo0?ooo`0P0?ooo`030000002YNYl0ZGZO01@0ZGZO00<000000?ooo`3oool0
403oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool0
503oool00`0000002NX:0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo0P09jPX00`3oool02NX:
0?ooo`070?ooo`802NX:2@3oool00`09jPX0oooo0?ooo`0K0?ooo`030000003oool0oooo04T0oooo
001/0?ooo`030000003oool0oooo00H0oooo00<02NX:0?ooo`3oool0503oool00`000000oooo0?oo
o`1M0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0803oool00`000000ZGZO0:Uj
W`0E0:UjW`030000003oool0oooo0100oooo0P09jPXD0?ooo`0300WZ2P3oool0oooo00d0oooo00<0
2NX:0?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00/0oooo00@0
2NX:0?ooo`3oool02NX:1`3oool200WZ2PX0oooo00<02NX:0?ooo`3oool07@3oool00`000000oooo
0?ooo`180?ooo`00K03oool00`000000oooo0?ooo`070?ooo`0300WZ2P3oool0oooo01@0oooo00<0
00000?ooo`3oool0G03oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo01l0oooo00<0
00000:UjW`2YNYl05`2YNYl00`000000oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo0180oooo00<0
2NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo0P09
jPX=0?ooo`0400WZ2P3oool0oooo00WZ2PD0oooo0`09jPX:0?ooo`802NX:803oool00`000000oooo
0?ooo`180?ooo`00K03oool00`000000oooo0?ooo`080?ooo`802NX:5@3oool00`000000oooo0?oo
o`1L0?ooo`0300WZ2P3oool0oooo0100oooo00@02NX:0?ooo`3oool0oooo0P09jPXM0?ooo`030000
002YNYl0ZGZO0080ZGZO0P00000D0:UjW`030000003oool0oooo0140oooo0P09jPXC0?ooo`802NX:
303oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P000000oooo00L0oooo00<02NX:0?ooo`3oool0
2`3oool200WZ2P<0oooo00@02NX:0?ooo`3oool0oooo0P09jPX<0?ooo`0300WZ2P3oool0oooo0240
oooo00<000000?ooo`3oool0A`3oool006`0oooo00<000000?ooo`3oool02P3oool00`09jPX0oooo
0?ooo`0C0?ooo`030000003oool0oooo05`0oooo00<02NX:0?ooo`3oool03`3oool01009jPX0oooo
0?ooo`3oool20000000300WZ2P3oool0oooo01T0oooo00<000000:UjW`2YNYl00`2YNYl2000001@0
ZGZO00<000000?ooo`3oool04`3oool200WZ2Q<0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0
oooo0?ooo`0C0?ooo`0300WZ2P000000oooo00H0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P3oool02NX:00802NX:3@3oool00`09jPX0oooo0?ooo`0R0?ooo`03
0000003oool0oooo04L0oooo001/0?ooo`030000003oool0oooo00/0oooo0P09jPXD0?ooo`030000
003oool0oooo05`0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo01P0oooo00<000000:UjW`2YNYl06P2YNYl00`000000oooo0?ooo`0D0?ooo`0300WZ
2P3oool0oooo0140oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ
2P3oool0000000H0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`030?ooo`<02NX:
3@3oool200WZ2RH0oooo00<000000?ooo`3oool0AP3oool006/0oooo00<000000?ooo`3oool03P3o
ool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo05d0oooo00<02NX:0?ooo`3oool03@3o
ool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo01H0oooo00<000000:UjW`2YNYl0702Y
NYl00`000000oooo0?ooo`0D0?ooo`802NX:4P3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3o
ool0oooo0180oooo00<02NX:0?ooo`0000001@3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3o
ool0oooo0080oooo0`09jPX>0?ooo`0300WZ2P3oool0oooo02L0oooo00<000000?ooo`3oool0A@3o
ool006/0oooo00<000000?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0
oooo04l0oooo0P00000<0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool01`3oool0
0`09jPX0oooo0?ooo`0D0?ooo`030000002YNYl0ZGZO01h0ZGZO00<000000?ooo`3oool05@3oool0
0`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04@3oool0
1009jPX0oooo0?ooo`0000040?ooo`0300WZ2P3oool0oooo00X0oooo0P09jPX20?ooo`@02NX:3`3o
ool00`09jPX0oooo0?ooo`0X0?ooo`030000003oool0oooo04D0oooo001[0?ooo`030000003oool0
oooo0100oooo0P09jPXB0?ooo`030000003oool0oooo04h0oooo0P00000=0?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0C0?ooo`030000002YNYl0
ZGZO01l0ZGZO00<000000?ooo`3oool05@3oool200WZ2Q40oooo00<02NX:0?ooo`3oool01@3oool0
0`09jPX0oooo0?ooo`0A0?ooo`0400WZ2P3oool0oooo000000<0oooo00<02NX:0?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`0200WZ2P<0oooo00<02NX:0?ooo`3oool02`3oool200WZ2R`0oooo00<0
00000?ooo`3oool0A03oool006/0oooo00<000000?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0@
0?ooo`030000003oool0oooo04h0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`09
0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool04@3oool00`000000ZGZO0:UjW`0P
0:UjW`030000003oool0oooo01L0oooo00<02NX:0?ooo`3oool03`3oool200WZ2P@0oooo00<02NX:
0?ooo`3oool04@3oool01@09jPX0oooo0?ooo`3oool000000080oooo00<02NX:0?ooo`3oool02P3o
ool400WZ2P@0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0]0?ooo`030000003o
ool0oooo04<0oooo001[0?ooo`030000003oool0oooo01<0oooo0P09jPXA0?ooo`030000003oool0
oooo04d0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool0403oool00`000000ZGZO0:UjW`0Q0:UjW`030000003oool0
oooo01L0oooo0P09jPXA0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX04`3oool01`09jPX0oooo0?oo
o`3oool000000?ooo`09jPX02`3oool300WZ2PH0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`0^0?ooo`030000003oool0oooo04<0oooo001[0?ooo`030000003oool0oooo01D0oooo
00<02NX:0?ooo`3oool03`3oool00`000000oooo0?ooo`1=0?ooo`0300WZ2P3oool0oooo00d0oooo
00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00h0oooo
00<000000:UjW`2YNYl08`2YNYl00`000000oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00l0oooo
00@02NX:0?ooo`3oool02NX:4P3oool00`09jPX0oooo0?ooo`030?ooo`030000003oool0oooo00P0
oooo0P09jPX90?ooo`0300WZ2P3oool0oooo00T0oooo0P09jPXb0?ooo`030000003oool0oooo0480
oooo001[0?ooo`030000003oool0oooo01H0oooo00<02NX:0?ooo`3oool03`3oool00`000000oooo
0?ooo`1<0?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo
0?ooo`0=0?ooo`0300WZ2P3oool0oooo00`0oooo00<000000:UjW`2YNYl09@2YNYl00`000000oooo
0?ooo`0H0?ooo`802NX:403oool00`09jPX0oooo00WZ2P0B0?ooo`0700WZ2P3oool0oooo0000003o
ool02NX:000000070?ooo`@02NX:2@3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo
0380oooo00<000000?ooo`3oool0@P3oool006/0oooo00<000000?ooo`3oool05`3oool200WZ2Q00
oooo00<000000?ooo`3oool0C03oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00D0
oooo00<02NX:0?ooo`3oool03P3oool200WZ2P`0oooo00<000000:UjW`2YNYl01@2YNYl00`000000
ZGZO0:UjW`0N0:UjW`030000003oool0oooo01T0oooo00<02NX:0?ooo`3oool03P3oool200WZ2Q40
oooo00P02NX:0?ooo`00000000000?ooo`09jPX0oooo000000D0oooo0P09jPX20?ooo`0300WZ2P3o
ool0oooo00L0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`0d0?ooo`030000003o
ool0oooo0440oooo001[0?ooo`030000003oool0oooo01T0oooo0P09jPX?0?ooo`030000003oool0
oooo04`0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0
oooo0140oooo00<02NX:0?ooo`3oool0203oool00`000000ZGZO0:UjW`050:UjW`800000802YNYl0
0`000000oooo0?ooo`0J0?ooo`802NX:3`3oool00`09jPX0oooo0?ooo`0?0?ooo`0500WZ2P000000
m<BK00000009jPX00P3oool00`000000oooo0?ooo`0300WZ2P80oooo0P09jPX:0?ooo`0300WZ2P3o
ool0oooo00P0oooo00<02NX:0?ooo`3oool0=P3oool00`000000oooo0?ooo`100?ooo`00JP3oool0
0`000000oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo00d0oooo00<000000?ooo`3oool0B`3oool0
0`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool04P3oool0
0`09jPX0oooo0?ooo`070?ooo`030000002YNYl0ZGZO00@0ZGZO0P0000000`3T^JT000000000000O
0:UjW`030000003oool0oooo01/0oooo00<02NX:0?ooo`3oool0303oool300WZ2Ph0oooo00D02NX:
0000003da9/0m<BK00WZ2P030?ooo`0300000009jPX02NX:00@0oooo00<02NX:0?ooo`3oool02@3o
ool00`09jPX0oooo0?ooo`070?ooo`802NX:>@3oool00`000000oooo0?ooo`100?ooo`00JP3oool0
0`000000oooo0?ooo`0M0?ooo`802NX:3P3oool00`000000oooo0?ooo`1;0?ooo`0300WZ2P3oool0
oooo00h0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0E0?ooo`0300WZ2P3oool0oooo00D0oooo00<0
00000:UjW`2YNYl01@2YNYl2000000<0i;VY0P00000N0:UjW`030000003oool0oooo01/0oooo0P09
jPX<0?ooo`0400WZ2P3oool0oooo00WZ2P/0oooo0P0000001P09jPX0m<BK0?C4V`09jPX000000?oo
o`802NX:00<000000?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo
00H0oooo00<02NX:0?ooo`3oool0>P3oool00`000000oooo0?ooo`0o0?ooo`00JP3oool00`000000
oooo0?ooo`0O0?ooo`802NX:3@3oool00`000000oooo0?ooo`1:0?ooo`0300WZ2P3oool0oooo00l0
oooo00<02NX:0?ooo`09jPX05`3oool00`09jPX0oooo0?ooo`040?ooo`030000002YNYl0ZGZO00@0
ZGZO00<000000411Z`0000001@3T^JT00`000000ZGZO0:UjW`0L0:UjW`030000003oool0oooo01`0
oooo00<02NX:0?ooo`3oool0103oool00`09jPX000000?ooo`020?ooo`0500WZ2P3oool0oooo0?oo
o`09jPX0203oool30000000300WZ2P3da9/0m<BK00@02NX:0P3oool00`000000oooo0?ooo`020?oo
o`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0l0?oo
o`030000003oool0oooo03h0oooo001Z0?ooo`030000003oool0oooo0240oooo00<02NX:0?ooo`3o
ool02`3oool00`000000oooo0?ooo`1:0?ooo`0300WZ2P3oool0oooo00l0oooo0P09jPXH0?ooo`03
00WZ2P3oool0oooo0080oooo00<000000:UjW`2YNYl0102YNYl010000000@46[0411Z`0000060>Bi
Z@8000007@2YNYl00`000000oooo0?ooo`0L0?ooo`802NX:103oool00`09jPX000000?ooo`020?oo
o`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool5000000@02NX:00<0m<BK0000
003oool00P3oool00`000000oooo0?ooo`0200WZ2P`0oooo00<02NX:0?ooo`3oool01@3oool200WZ
2Sl0oooo00<000000?ooo`3oool0?P3oool006X0oooo00<000000?ooo`3oool08P3oool200WZ2P`0
oooo00<000000?ooo`3oool0B@3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo01L0
oooo00@02NX:0?ooo`3oool000001P2YNYl2000000<0@46[00<000000>BiZ@3T^JT01@3T^JT20000
01`0ZGZO00<000000?ooo`3oool07@3oool200WZ2P030?ooo`09jPX0oooo00<0oooo00<02NX:0?oo
o`3oool0103oool01009jPX0oooo0?ooo`3oool5000000802NX:103da9/01`000000oooo0?ooo`3o
ool000000?ooo`09jPX03P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo0400oooo
00<000000?ooo`3oool0?@3oool006X0oooo00<000000?ooo`3oool0903oool00`09jPX0oooo0?oo
o`090?ooo`030000003oool0oooo04X0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo00WZ
2P0I0?ooo`0300WZ2P3oool0000000H0ZGZO00<000000411Z`10@J/00P10@J/00`000000i;VY0>Bi
Z@070>BiZ@8000006P2YNYl00`000000oooo0?ooo`0O0?ooo`802NX:103oool00`09jPX0oooo0?oo
o`050?ooo`0300WZ2P0000000000008000001009jPX50?C4V`060000003oool0oooo0?ooo`000000
2NX:3P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo0440oooo00<000000?ooo`3o
ool0?@3oool006X0oooo00<000000?ooo`3oool09@3oool200WZ2PX0oooo00<000000?ooo`3oool0
B@3oool00`09jPX0oooo0?ooo`0>0?ooo`0400WZ2P3oool0oooo00WZ2QT0oooo00<000000:UjW`2Y
NYl0102YNYl00`000000@46[0411Z`030411Z`030000003T^JT0i;VY00T0i;VY0P00000I0:UjW`03
0000003oool0oooo01h0oooo0`09jPX30?ooo`0300WZ2P3oool0oooo00@0oooo0`00000300WZ2P03
0000003da9/02NX:00H0m<BK00D000000?ooo`3oool02NX:0000000>0?ooo`0300WZ2P3oool0oooo
00<0oooo0P09jPY50?ooo`030000003oool0oooo03`0oooo001Z0?ooo`030000003oool0oooo02L0
oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`190?ooo`0300WZ2P3oool0oooo00d0
oooo00@02NX:0?ooo`3oool02NX:6@3oool00`000000ZGZO0:UjW`030:UjW`0300000010@J/0@46[
00@0@46[00<000000>BiZ@3T^JT02`3T^JT00`000000ZGZO0:UjW`0G0:UjW`030000003oool0oooo
01d0oooo00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`030?ooo`8000000P09jPX3
000000030?C4V`09jPX02NX:00H0m<BK00D000000?ooo`09jPX0oooo0000000>0?ooo`0300WZ2P3o
ool0oooo0080oooo00<02NX:0?ooo`3oool08`3oool200WZ2R40oooo00<000000?ooo`3oool0>`3o
ool006X0oooo00<000000?ooo`3oool0:03oool200WZ2PT0oooo00<000000?ooo`3oool0B@3oool0
0`09jPX0oooo0?ooo`0<0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX05`3oool00`000000ZGZO0:Uj
W`030:UjW`8000001P10@J/00`000000i;VY0>BiZ@0<0>BiZ@800000602YNYl00`000000oooo0?oo
o`0K0?ooo`0300WZ2P3oool0oooo0080oooo0`09jPX30?ooo`0400000009jPX02NX:00WZ2P@00000
00<0m<BK00WZ2P09jPX01`3da9/01@0000002NX:0?ooo`3oool0000000d0oooo00<02NX:0?ooo`3o
ool00P3oool00`09jPX0oooo0?ooo`0R0?ooo`802NX:0P00000Q0?ooo`030000003oool0oooo03/0
oooo001Z0?ooo`030000003oool0oooo02X0oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo
0?ooo`180?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`0C0?ooo`030000002YNYl0ZGZO00@0ZGZO00<000000411Z`10@J/01@10@J/00`000000i;VY
0>BiZ@0>0>BiZ@8000005`2YNYl00`000000oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00@0oooo
00<02NX:0?ooo`0000000P09jPX6000000030?C4V`09jPX02NX:00P0m<BK00D02NX:0000003oool0
oooo0000000=0?ooo`0300WZ2P3oool0oooo00802NX:8`3oool200WZ2RH0oooo00<000000?ooo`3o
ool0>P3oool006T0oooo00<000000?ooo`3oool0;03oool200WZ2PP0oooo00<000000?ooo`3oool0
B03oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
4P3oool00`000000ZGZO0:UjW`030:UjW`0300000010@J/0@46[00H0@46[00<000000>BiZ@3T^JT0
403T^JT2000001D0ZGZO00<000000?ooo`3oool06P3oool00`09jPX0oooo0?ooo`040?ooo`<02NX:
1`000000103da9/02NX:0?C4V`09jPX60?C4V`802NX:00D0oooo0000003oool0oooo0000000<0?oo
o`0400WZ2P3oool0oooo00WZ2R<0oooo0P09jPXY0?ooo`030000003oool0oooo03T0oooo001Y0?oo
o`030000003oool0oooo02h0oooo00<02NX:0?ooo`3oool01P3oool00`000000oooo0?ooo`170?oo
o`0300WZ2P3oool02NX:00X0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0@0?oo
o`030000002YNYl0ZGZO00<0ZGZO00<000000411Z`10@J/01`10@J/00`000000i;VY0>BiZ@0B0>Bi
Z@800000502YNYl00`000000oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo0080oooo1009jPX80000
00040?C4V`09jPX0m<BK00WZ2PH0m<BK00D02NX:0?C4V`3da9/0YhRd000000020?ooo`030000003o
ool0oooo00T0oooo00@02NX:0?ooo`3oool02NX:8P3oool200WZ2R/0oooo00<000000?ooo`3oool0
>@3oool006T0oooo00<000000?ooo`3oool0;`3oool200WZ2PL0oooo00<000000?ooo`3oool0A`3o
ool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool03`3o
ool00`000000ZGZO0:UjW`030:UjW`0300000010@J/0@46[00P0@46[00<000000>BiZ@3T^JT04`3T
^JT00`000000ZGZO0:UjW`0B0:UjW`030000003oool0oooo01L0oooo00<02NX:0?ooo`3oool00P09
jPX30000000300WZ2P000000000000D0000000<0m<BK00WZ2P3da9/00P0000050?C4V`0600WZ2P3d
a9/0m<BK0?C4V`2WR;@000000`3oool00`000000oooo0?ooo`080?ooo`<02NX:8@3oool200WZ2Rh0
oooo00<000000?ooo`3oool0>03oool006T0oooo00<000000?ooo`3oool0<@3oool00`09jPX0oooo
0?ooo`050?ooo`030000003oool0oooo04H0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo
0?ooo`080?ooo`0300WZ2P3oool0oooo00d0oooo00<000000:UjW`2YNYl00`2YNYl00`000000@46[
0411Z`090411Z`030000003T^JT0i;VY01@0i;VY0P00000C0:UjW`030000003oool0oooo01D0oooo
1009jPX50000000300WZ2P000000000000@0000000<0m<BK00WZ2P0000000`0000030?C4V`802NX:
1@3da9/01@000000oooo0?ooo`3oool0000000T0oooo0P09jPXQ0?ooo`802NX:3`3oool2000001l0
oooo00<000000?ooo`3oool0>03oool006T0oooo00<000000?ooo`3oool0<P3oool200WZ2PH0oooo
00<000000?ooo`3oool0AP3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo00T0oooo
00<02NX:0?ooo`3oool0303oool00`000000ZGZO0:UjW`020:UjW`0300000010@J/0@46[00X0@46[
00<000000>BiZ@3T^JT05P3T^JT200000180ZGZO00<000000?ooo`3oool04P3oool300WZ2P030?oo
o`000000000000@0000000<02NX:000000000000100000000`3da9/02NX:0?C4V`02000000@0m<BK
00<02NX:0?C4V`3da9/01@3da9/01@000000oooo0?ooo`3oool0000000P0oooo0P09jPXP0?ooo`80
2NX:4@3oool200000200oooo00<000000?ooo`3oool0=`3oool006T0oooo00<000000?ooo`3oool0
=03oool00`09jPX0oooo0?ooo`040?ooo`030000003oool0oooo04H0oooo00<02NX:0?ooo`3oool0
1P3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000:UjW`2YNYl0
0P2YNYl2000000`0@46[00<000000>BiZ@3T^JT0603T^JT200000100ZGZO00<000000?ooo`3oool0
3`3oool300WZ2P80oooo00<02NX:0000000000000P00000200WZ2P0300000009jPX0000000@00000
00<0m<BK00WZ2P3da9/01P3da9/00`09jPX0m<BK0?C4V`060?C4V`050000003oool0oooo0?ooo`00
0000203oool00`09jPX0oooo0?ooo`0M0?ooo`802NX:4`3oool00`09jPX0oooo0?ooo`0P0?ooo`03
0000003oool0oooo03H0oooo001Y0?ooo`030000003oool0oooo03D0oooo0P09jPX50?ooo`030000
003oool0oooo04D0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ
2P3oool0oooo00P0oooo00<000000:UjW`2YNYl00`2YNYl00`000000@46[0411Z`0;0411Z`030000
003T^JT0i;VY01X0i;VY0P00000?0:UjW`030000003oool0oooo00/0oooo0`09jPX30?ooo`800000
1@09jPX8000000030?C4V`09jPX0m<BK00H0m<BK00<02NX:0?C4V`3da9/01`3da9/01@000000oooo
0?ooo`3oool0000000H0oooo0P09jPXN0?ooo`802NX:503oool00`09jPX0oooo0?ooo`0Q0?ooo`03
0000003oool0oooo03H0oooo001Y0?ooo`030000003oool0oooo03L0oooo00<02NX:0?ooo`3oool0
0`3oool00`000000oooo0?ooo`0l0?ooo`<000001P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool0203oool00`000000ZGZO0:UjW`020:UjW`030000
0010@J/0@46[00`0@46[00<000000>BiZ@3T^JT0703T^JT00`000000ZGZO0:UjW`0=0:UjW`030000
003oool0oooo00L0oooo0`09jPX30?ooo`D02NX:300000000`3da9/02NX:0?C4V`050?C4V`802NX:
2P3da9/01@000000oooo0?ooo`3oool0000000D0oooo0P09jPXM0?ooo`802NX:5P3oool00`09jPX0
oooo0?ooo`0R0?ooo`030000003oool0oooo03D0oooo001Y0?ooo`030000003oool0oooo00P0oooo
0P00000200WZ2R`0oooo0P09jPX40?ooo`030000003oool0oooo03/0oooo00<0000009XB002J4P00
0`0000040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo
0?ooo`060?ooo`030000002YNYl0ZGZO0080ZGZO00<000000411Z`10@J/03@10@J/00`000000i;VY
0>BiZ@0M0>BiZ@8000003P2YNYl00`000000oooo0?ooo`030?ooo`<02NX:00<0oooo00WZ2P09jPX0
0`09jPX=000000802NX:00<0000000WZ2P09jPX01P3da9/00`09jPX0m<BK0?C4V`0:0?C4V`050000
003oool0oooo0?ooo`000000103oool00`09jPX0oooo00WZ2P0K0?ooo`802NX:603oool00`09jPX0
oooo0?ooo`0S0?ooo`030000003oool0oooo03@0oooo001Y0?ooo`030000003oool0oooo00P0oooo
0P0000020?ooo`@02NX::P3oool00`09jPX0oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo
0P00000409XB00<0000000<0oooo00WZ2P3oool00`3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ
2P3oool0oooo00D0oooo00@000000:UjW`2YNYl0ZGZO0P00000?0411Z`030000003T^JT0i;VY01l0
i;VY0P00000=0:UjW`030000003oool02NX:00H02NX:0`3oool?000000802NX:00<000000?C4V`3d
a9/01@3da9/00`09jPX0m<BK0?C4V`060?C4V`8000000`3da9/01@000000oooo0?ooo`3oool00000
0080oooo0P09jPX00`3oool02NX:0?ooo`0I0?ooo`802NX:6P3oool00`09jPX0oooo0?ooo`0S0?oo
o`030000003oool0oooo03@0oooo001X0?ooo`030000003oool0oooo0140oooo1@09jPXV0?ooo`80
2NX:0P3oool00`000000oooo0?ooo`0j0?ooo`03000000001hh0000000H0VQ800`0000030?ooo`03
00WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool00`3oool00`000000ZGZO0:UjW`020:UjW`03
00000010@J/0@46[00l0@46[00<000000>BiZ@3T^JT0803T^JT2000000/0ZGZO00@0000000WZ2P09
jPX02NX:1`3oool@000000802NX:00<000000?C4V`3da9/0103da9/00`09jPX0m<BK0?C4V`070?C4
V`8000000`3da9/01`000000oooo0?ooo`3oool000000?ooo`09jPX00`3oool00`09jPX0oooo0?oo
o`0F0?ooo`802NX:6`3oool00`09jPX0oooo0?ooo`0U0?ooo`030000003oool0oooo03<0oooo001X
0?ooo`030000003oool0oooo01H0oooo1009jPXT0?ooo`0400WZ2P3oool0oooo000003`0oooo00<0
00000007SP000000202J4P030000000300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool00P3o
ool01@000000ZGZO0:UjW`2YNYl0000000`0@46[0P0000040411Z`030000003T^JT0i;VY0280i;VY
0P00000:0:UjW`030000003oool0oooo00D0oooo4P00000200WZ2PD0m<BK0P09jPX?0?C4V`060000
003oool0oooo0?ooo`0000002NX:0`3oool00`09jPX0oooo0?ooo`0E0?ooo`802NX:7@3oool00`09
jPX0oooo0?ooo`0V0?ooo`030000003oool0oooo0380oooo001X0?ooo`030000003oool0oooo01X0
oooo1009jPXQ0?ooo`802NX:00<0oooo0000003oool0>P3oool01000000000N>0007SP00000:09XB
000400WZ2P000000000000000140oooo00@02NX:0?ooo`3oool000000`2YNYl00`000000@46[0411
Z`0;0411Z`8000001010@J/00`000000i;VY0>BiZ@0T0>BiZ@030000002YNYl0ZGZO00P0ZGZO00<0
00000?ooo`3oool00P3ooolC000000030?C4V`09jPX02NX:00@0m<BK00<02NX:0?C4V`3da9/03`3d
a9/01@000000oooo0?ooo`09jPX0000000<0oooo00<02NX:0?ooo`3oool0503oool200WZ2Ql0oooo
00<02NX:0?ooo`3oool09P3oool00`000000oooo0?ooo`0b0?ooo`00J03oool00`000000oooo0?oo
o`0N0?ooo`@02NX:7`3oool00`09jPX0oooo0000000j0?ooo`05000000001hh000N>0007SP000000
202J4P000`09jPX0VQ8009XB000209XB00<000003P3oool00`09jPX0oooo000000030:UjW`800000
4`10@J/00`000000i;VY0>BiZ@050>BiZ@8000007P3T^JT2000000T0ZGZO00<000000?ooo`3oool0
4`0000020?C4V`802NX:0`3da9/00`09jPX0m<BK0?C4V`0@0?C4V`050000003oool02NX:0?ooo`00
00000`3oool00`09jPX0oooo0?ooo`0B0?ooo`802NX:8@3oool00`09jPX0oooo0?ooo`0W0?ooo`03
0000003oool0oooo0340oooo001X0?ooo`030000003oool0oooo0280oooo1@09jPXK0?ooo`802NX:
00<000000?ooo`3oool0=`3oool00`00000000N>0007SP020007SP030000002J4P00VQ8000D0VQ80
00<02NX:09XB002J4P001@2J4P04000000/0oooo00<02NX:0000002YNYl00P2YNYl00`000000@46[
0411Z`0B0411Z`030000003T^JT0i;VY00D0i;VY0P00000200WZ2Qh0i;VY0P0000080:UjWa@00000
0`3da9/200WZ2P030?C4V`09jPX02NX:01<0m<BK00D0000000WZ2P3oool0oooo000000020?ooo`03
00WZ2P3oool0oooo0140oooo0P09jPXR0?ooo`0300WZ2P3oool0oooo02P0oooo00<000000?ooo`3o
ool0<@3oool006P0oooo00<000000?ooo`3oool09`3oool400WZ2QT0oooo00<02NX:0000003oool0
=`3oool00`00000000N>0007SP030007SP030000002J4P00VQ8000@0VQ8000<02NX:09XB002J4P00
2@2J4P03000000P0oooo00D0000000WZ2P2YNYl0ZGZO0000000E0411Z`030000003T^JT0i;VY00T0
i;VY0`09jPXM0>BiZ@8000001P2YNYlC000000<0m<BK00@02NX:0?C4V`09jPX02NX:5@3da9/01`00
0000oooo0?ooo`3oool000000?ooo`09jPX04P3oool200WZ2R@0oooo00<02NX:0?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0`0?ooo`00J03oool00`000000oooo0?ooo`0[0?ooo`@02NX:5P3oool2
00WZ2SL0oooo00<000000007SP001hh010001hh00`000000VQ8009XB000309XB000300WZ2P2J4P00
VQ8000`0VQ800`0000050?ooo`040000002YNYl02NX:000001H0@46[00<000000>BiZ@3T^JT0303T
^JT400WZ2Q/0i;VY0P0000050:UjWa400000103da9/00`09jPX0m<BK00WZ2P0D0?C4V`<000000`3o
ool00`000000oooo00WZ2P0@0?ooo`802NX:9P3oool00`09jPX0oooo0?ooo`0Z0?ooo`030000003o
ool0oooo02l0oooo001X0?ooo`030000003oool0oooo02l0oooo1009jPXA0?ooo`8000000P09jPXg
0?ooo`03000000001hh000N>00@000N>00D0000009XB002J4P00VQ8000WZ2P0B09XB00<0000000<0
oooo0000002YNYl00P2YNYl00`000000@46[0411Z`0D0411Z`030000003T^JT0i;VY0100i;VY0`09
jPXJ0>BiZ@030000002YNYl0ZGZO00<0ZGZO2`0000001@09jPX00000000000000000m<BK00802NX:
00<0m<BK00WZ2P09jPX00P09jPX30?C4V`0400WZ2P3da9/0m<BK0?C4V`802NX:1`3da9/300WZ2P04
0?C4V`0000000000000000@0oooo00<000000?ooo`3oool03@3oool200WZ2RP0oooo00<02NX:0?oo
o`3oool0:P3oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`0c0?ooo`@0
2NX:3@3oool2000000040?ooo`09jPX02NX:00WZ2SD0oooo00<000000007SP001hh01@001hh01000
0000VQ8009XB0009jPXE09XB008000000P2YNYl00`000000@46[0411Z`0E0411Z`030000003T^JT0
i;VY01<0i;VY1009jPXG0>BiZ@800000102YNYl:0000000500WZ2P000000YhRd0:N8]009jPX00`2W
R;@300WZ2P@0YhRd00<02NX:0:N8]02WR;@00P09jPX00`000000YhRd0:N8]0050:N8]0802NX:00D0
YhRd00WZ2P3da9/0m<BK000000030?ooo`0300WZ2P000000oooo00`0oooo0P09jPXY0?ooo`0300WZ
2P3oool0oooo02`0oooo00<000000?ooo`3oool0;P3oool006P0oooo00<000000?ooo`3oool0=`3o
ool500WZ2Pd0oooo00<0000000WZ2P09jPX0<`3oool00`00000000N>0007SP060007SP030000002J
4P002NX:01D0VQ8000@000000:UjW`2YNYl000006@10@J/00`000000i;VY0>BiZ@0F0>BiZ@<02NX:
5P3T^JT2000000<0ZGZO2P0000020:N8]00400WZ2P2WR;@0YhRd0:N8]0@02NX:1@2WR;@200WZ2P03
0:N8]009jPX0YhRd00D0YhRd00<0m<BK00WZ2P3da9/01@3da9/01P000000oooo0?ooo`3oool02NX:
000000/0oooo0P09jPX[0?ooo`0300WZ2P3oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool0
06L0oooo00<000000?ooo`3oool0?@3oool400WZ2PX0oooo00@0000000WZ2P09jPX02NX:<@3oool0
0`00000000N>0007SP060007SP0300000009jPX0VQ8001@0VQ8000@000000:UjW`2YNYl000006P10
@J/00`000000i;VY0>BiZ@0I0>BiZ@@02NX:503T^JT2000000030:UjW`000000000000L0000000<0
YhRd00WZ2P09jPX00`2WR;@00`09jPX0YhRd00WZ2P0200WZ2PD0YhRd00@02NX:0:N8]009jPX0YhRd
3@3da9/3000000040?ooo`09jPX0oooo000000T0oooo0P09jPX]0?ooo`0300WZ2P3oool0oooo02d0
oooo00<000000?ooo`3oool0;@3oool006L0oooo00<000000?ooo`3oool0@@3oool400WZ2PL0oooo
00<000000?ooo`09jPX00`09jPX^0?ooo`03000000001hh000N>00L000N>00<02NX:0000002J4P00
4`2J4P0010000000ZGZO0:UjW`00000J0411Z`030000003T^JT0i;VY01d0i;VY0`09jPXC0>BiZ@T0
000000<0YhRd00WZ2P2WR;@00P2WR;@200WZ2P80YhRd0`09jPX30:N8]1<0m<BK0`000000103oool0
2NX:0?ooo`0000070?ooo`802NX:;`3oool00`09jPX0oooo0?ooo`0^0?ooo`030000003oool0oooo
02`0oooo001W0?ooo`030000003oool0oooo04D0oooo1@09jPX30?ooo`050000003oool02NX:00WZ
2P3oool00P09jPX/0?ooo`03000000001hh000N>00L000N>00<02NX:0000002J4P004P2J4P001000
0000ZGZO0:UjW`00000K0411Z`030000003T^JT0i;VY0200i;VY1009jPXA0>BiZ@H0000000<0YhRd
00WZ2P2WR;@00P2WR;@00`09jPX0YhRd0:N8]0020:N8]0<02NX:4`3da9/200000080m<BK00<0oooo
00000009jPX00P3oool00`000000oooo0?ooo`030?ooo`802NX:<03oool00`09jPX0oooo0?ooo`0_
0?ooo`030000003oool0oooo02`0oooo001W0?ooo`030000003oool0oooo04X0oooo1009jPX01000
0000oooo0?ooo`09jPX20?ooo`<02NX::P3oool00`00000000N>0007SP060007SP0300WZ2P001hh0
00000180VQ8000<000000:UjW`0000007010@J/00`000000i;VY0>BiZ@0T0>BiZ@<02NX:3`3T^JT3
0000000300WZ2P2WR;@02NX:00<0YhRd00<02NX:0?C4V`3da9/0103da9/200WZ2Q<0m<BK0P000002
0?C4V`030?ooo`000000oooo0080oooo00@000000?ooo`3oool0oooo0P09jPXb0?ooo`0300WZ2P3o
ool0oooo0300oooo00<000000?ooo`3oool0:`3oool006L0oooo00<000000?ooo`3oool0CP3oool6
00WZ2P<0oooo0P09jPXX0?ooo`03000000001hh000N>00D000N>00D02NX:0007SP001hh000N>0000
000@09XB00030000002YNYl0000001d0@46[00<000000>BiZ@3T^JT09`3T^JT400WZ2Pd0i;VY1000
00020?C4V`0300WZ2P3da9/0m<BK00D0m<BK0P09jPXG0?C4V`030?ooo`000000oooo0080oooo00@0
00000?ooo`3oool02NX:=03oool00`09jPX0oooo0?ooo`0_0?ooo`<00000;03oool006L0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0500WZ2P80oooo0P09jPXV0?ooo`0300000000
1hh000N>00D000N>00<02NX:0007SP001hh00P001hh00`000000VQ8009XB000=09XB00030000002Y
NYl0000001d0@46[00<000000>BiZ@3T^JT0:`3T^JT300WZ2PX0i;VY0P1802h8000000<0m<BK00<0
2NX:0?C4V`09jPX05`3da9/00`2WR;@000000?ooo`020?ooo`0300000009jPX02NX:03D0oooo00<0
2NX:0?ooo`3oool0;03oool300000080oooo00<000000?ooo`3oool0:P3oool006L0oooo00<00000
0?ooo`3oool0903oool200WZ2RX0oooo00<000000?ooo`3oool00P3oool900WZ2R<0oooo00<00000
0007SP001hh01@001hh00`09jPX000N>0007SP030007SP030000002J4P00VQ8000/0VQ8000<00000
0:UjW`0000007P10@J/00`000000i;VY0>BiZ@0^0>BiZ@@02NX:1P3T^JT404P0;P030000002dR:L0
]8RW00<0]8RW0`0000001009jPX0000000WZ2P00000F0?C4V`060:N8]0000000oooo0?ooo`09jPX0
0000=P3oool00`09jPX0oooo0?ooo`0Z0?ooo`<000001@3oool00`000000oooo0?ooo`0Z0?ooo`00
I`3oool00`000000oooo0?ooo`0T0?ooo`8000000P09jPXY0?ooo`030000003oool0oooo00<0oooo
00@02NX:0?ooo`3oool0oooo1@09jPXQ0?ooo`03000000001hh000N>00D000N>00<02NX:0007SP00
1hh010001hh00`000000VQ8009XB000:09XB008000008010@J/00`000000i;VY0>BiZ@0I0>BiZ@03
0000003T^JT0i;VY01D0i;VY0`09jPX20>BiZ@H0B00^0P0000060;B8Y`0400WZ2P2dR:L02NX:09Ng
kPH00000403da9/01P2WR;@0000000WZ2P09jPX0oooo000003H0oooo00<02NX:0?ooo`3oool09`3o
ool3000000P0oooo00<000000?ooo`3oool0:P3oool006L0oooo00<000000?ooo`3oool0:03oool2
00WZ2RP0oooo00<000000?ooo`3oool00`3oool200WZ2PH0oooo1009jPXM0?ooo`03000000001hh0
00N>00@000N>00<02NX:0007SP001hh01P001hh00`000000VQ8009XB000809XB00<000004P10@J/2
000000`0@46[00@000000>BiZ@0000000000<`3T^JT400WZ2PH0B00^0P0000040;B8Y`0300WZ2P2d
R:L02NX:00H0]8RW00<0UkO^0000000000001000000:0?C4V`802NX:0`3oool00`000000oooo0?oo
o`0d0?ooo`0300WZ2P3oool0oooo02@0oooo0`00000;0?ooo`030000003oool0oooo02X0oooo001W
0?ooo`030000003oool0oooo02X0oooo0`09jPXV0?ooo`030000003oool0oooo00@0oooo00<02NX:
0?ooo`3oool01P3oool500WZ2QT0oooo00<000000007SP001hh010001hh00`09jPX000N>0007SP07
0007SP030000002J4P00VQ8000H0VQ8000<000000:UjW`0000004`10@J/2000000P0@46[0P000002
0411Z`040000003T^JT00000000000L02NX:;03T^JT404P0;P<02NX:1@1802h200000080]8RW00<0
2NX:0;B8Y`09jPX03@2dR:L600000080m<BK0P09jPX00`3da9/000000?ooo`020?ooo`030000003o
ool0oooo03@0oooo00<02NX:0?ooo`3oool08@3oool3000000l0oooo00<000000?ooo`3oool0:@3o
ool006H0oooo00<000000?ooo`3oool08P3oool2000000X0oooo0P09jPXU0?ooo`030000003oool0
oooo00@0oooo0P09jPX80?ooo`P02NX:5@3oool00`00000000N>0007SP030007SP0300WZ2P001hh0
00N>00P000N>00<0000009XB002J4P001@2J4P02000001h0@46[0P0000020411Z`030000003T^JT0
i;VY00P0i;VY3P09jPX20>BiZ@030000003T^JT0i;VY01P0i;VY201802h400WZ2P<0B00^0P000000
0`09jPX0]8RW00WZ2P0C0;B8Y`L000000P3oool00`000000oooo0?ooo`0c0?ooo`0300WZ2P3oool0
oooo01l0oooo0`00000B0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo
0280oooo0P00000<0?ooo`802NX:903oool00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo
00P0oooo0P09jPX30?ooo`@02NX:4@3oool00`00000000N>0007SP020007SP0300WZ2P001hh000N>
00X000N>00<000000;:@/`2bT;<00`2bT;<2000002<0@46[00<000000>BiZ@3T^JT05P3T^JT>00WZ
2Pl0i;VY301802h300WZ2P0504P0;P00000000000;B8Y`09jPX04@2dR:L200WZ2PH0]8RW00<0UkO^
0000000000001000000b0?ooo`0300WZ2P3oool0oooo01`0oooo0`00000E0?ooo`030000003oool0
oooo02T0oooo001V0?ooo`030000003oool0oooo02@0oooo0P09jPX<0?ooo`802NX:8`3oool00`00
0000oooo0?ooo`050?ooo`802NX:2P3oool300WZ2P@0oooo1@09jPX<0?ooo`03000000001hh000N>
008000N>00<02NX:0007SP001hh02`001hh00`000000/Y2c0;:@/`0200WZ2P8000008`10@J/00`00
0000i;VY0>BiZ@0H0>BiZ@0300WZ2P3T^JT0i;VY00T0i;VY3`09jPX?04P0;P802NX:0P0000000`09
jPX0]8RW0;B8Y`0=0;B8Y`802NX:2`2dR:L010000000]8RW0;B8Y`2dR:L6000002`0oooo00<02NX:
0?ooo`3oool06@3oool3000001P0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<000000?oo
o`3oool09P3oool200WZ2P`0oooo0P09jPXR0?ooo`030000003oool0oooo00H0oooo00<02NX:0?oo
o`3oool02P3oool200WZ2PL0oooo1009jPX80?ooo`03000000001hh000N>008000N>00<02NX:0007
SP001hh020001hh00`09jPX000N>0007SP0300WZ2P030;:@/`000000000002@0@46[00<000000>Bi
Z@3T^JT05`3T^JT00`09jPX0i;VY0>BiZ@0G0>BiZ@80B00^3P09jPX504P0;P0300WZ2P0000000000
00`0]8RW00<02NX:0;B8Y`2dR:L0302dR:L00`000000]8RW0;B8Y`060;B8Y`L000009@3oool00`09
jPX0oooo0?ooo`0F0?ooo`<000006`3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000
oooo0?ooo`0X0?ooo`<02NX:2`3oool200WZ2R40oooo00<000000?ooo`3oool01P3oool200WZ2P`0
oooo0`09jPX80?ooo`@02NX:103oool01@00000000N>0007SP001hh02NX:010000N>0P09jPX00`00
0000@46[0411Z`0S0411Z`030000003T^JT0i;VY0300i;VY4@1802h>00WZ2P@0]8RW0P09jPX20000
00d0]8RW00<000000;B8Y`2dR:L0302dR:L00`2G]nh0000000000004000001h0oooo00<02NX:0?oo
o`3oool04`3oool4000001h0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<000000?ooo`3o
ool0:`3oool200WZ2P/0oooo0P09jPXP0?ooo`030000003oool0oooo00L0oooo00<02NX:0?ooo`3o
ool0303oool200WZ2PX0oooo1@09jPX30007SP0300WZ2P001hh000N>0080000030001hh2000002L0
@46[00<000000>BiZ@3T^JT05@3T^JT00`000000i;VY0>BiZ@0F0>BiZAL0B00^00<02NX:04P0;P18
02h00P1802h200000080]8RW1P09jPX2000000d0]8RW00<000000;B8Y`2dR:L04`2dR:L6000001P0
oooo00<02NX:0?ooo`3oool0403oool300000280oooo00<000000?ooo`3oool0:@3oool006H0oooo
00<000000?ooo`3oool0;@3oool200WZ2P/0oooo0P09jPXO0?ooo`030000003oool0oooo00L0oooo
0P09jPX>0?ooo`<02NX:303oool01009jPX0000000000009jPX20007SP8000002@001hh300000003
0;A:@@000000@46[02H0@46[00<000000>BiZ@3T^JT0;@3T^JTH04P0;P0300WZ2P1802h0B00^00@0
B00^00@000000;B8Y`09jPX02NX:4`2dR:L00`000000]8RW0;B8Y`0I0;B8Y`H000004P3oool00`09
jPX0oooo0?ooo`0=0?ooo`<000009@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000
oooo0?ooo`0_0?ooo`802NX:2`3oool200WZ2Qh0oooo00<000000?ooo`3oool0203oool00`09jPX0
oooo0?ooo`0>0?ooo`<02NX:2@3oool20000000300WZ2P001hh000N>00X000N>0`0000040;A:@@03
00000010@J/0@46[02@0@46[00<000000>BiZ@3T^JT05@3T^JT00`09jPX0i;VY0>BiZ@0E0>BiZAP0
B00^00<02NX:04P0;P1802h01@1802h2000001@0]8RW00<000000;B8Y`2dR:L07`2dR:L7000000/0
oooo00<02NX:0?ooo`3oool02P3oool3000002T0oooo00<000000?ooo`3oool0:03oool006H0oooo
00<000000?ooo`3oool0<@3oool200WZ2P/0oooo0P09jPXM0?ooo`030000003oool0oooo00P0oooo
0P09jPXA0?ooo`802NX:1`3oool00`00000000N>00WZ2P0:0007SP@000001P2dBT400`000000@46[
0411Z`0S0411Z`030000003T^JT0i;VY02`0i;VY6@1802h00`09jPX0B00^04P0;P0704P0;P800000
4P2dR:L00`000000]8RW0;B8Y`0V0;B8Y`H000000P3oool00`000000oooo00WZ2P0:0?ooo`<00000
;03oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`0c0?ooo`<02NX:2P3o
ool200WZ2Q/0oooo00<000000?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0@0?ooo`<02NX:103o
ool00`00000000N>00WZ2P070007SPD000002@2dBT400`000000@46[0411Z`0R0411Z`030000003T
^JT0i;VY02/0i;VY6@1802h00`09jPX0B00^04P0;P0:04P0;P800000402dR:L00`000000]8RW0;B8
Y`0/0;B8Y`<0000000<0oooo00WZ2P3oool01P3oool3000002l0oooo00<000000?ooo`3oool0:03o
ool006D0oooo00<000000?ooo`3oool0=`3oool200WZ2PX0oooo0P09jPXJ0?ooo`030000003oool0
oooo00X0oooo0P09jPXC0?ooo`802NX:0P3oool00`0000002NX:0007SP050007SP80000000<0WgVW
000000000000302dBT400`000000@46[0411Z`0Q0411Z`030000003T^JT0i;VY02X0i;VY6P1802h0
0`09jPX0B00^04P0;P0<04P0;P8000003P2dR:L00`000000]8RW0;B8Y`0^0;B8Y`030000003oool0
2NX:00@0oooo0`00000b0?ooo`030000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo
03T0oooo0P09jPX:0?ooo`802NX:6@3oool00`000000oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo
0180oooo1009jPX40007SP80000000<0WgVW0000000000003`2dBT400`000000@46[0411Z`0@0411
Z`8000003P10@J/00`000000i;VY0>BiZ@0Y0>BiZAP0B00^0P0000000`1802h02NX:04P0;P0?04P0
;P030000002dR:L0]8RW00/0]8RW00<000000;B8Y`2dR:L0;@2dR:L01@000000oooo0?ooo`09jPX0
oooo00<00000=@3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`0k0?oo
o`802NX:2P3oool200WZ2QP0oooo00<000000?ooo`3oool02`3oool200WZ2QD0oooo0P09jPX30000
0080WgVW00<000000?CC[@2dBT40402dBT400`000000@46[0411Z`0?0411Z`8000007009jPXN0>Bi
ZAP0B00^0P0000000`1802h02NX:04P0;P0@04P0;P<000002P2dR:L00`000000]8RW0;B8Y`0/0;B8
Y`040000003oool0oooo00WZ2P800000>03oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`00
0000oooo0?ooo`0M0?ooo`8000007P3oool200WZ2PX0oooo0P09jPXG0?ooo`030000003oool0oooo
00`0oooo00<02NX:0?ooo`3oool04@3oool01009jPX0000000000009jPX209miY`800000502dBT40
0`000000@46[0411Z`0O0411Z`030000003T^JT0i;VY00X0i;VY;`09jPX:04P0;P0300WZ2P1802h0
B00^0100B00^0P00000:0;B8Y`030000002dR:L0]8RW02/0]8RW100000000`09jPX0oooo0?ooo`0h
0?ooo`030000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo01d0oooo00<0000000WZ
2P09jPX07`3oool200WZ2PX0oooo0`09jPXE0?ooo`030000003oool0oooo00`0oooo00<02NX:0?oo
o`3oool03P3oool400000080WgVW0P00000G0;A:@@0300000010@J/0@46[01h0@46[00<000000>Bi
Z@3T^JT09P3T^JTC04P0;Pl02NX:0P00000:04P0;P80000000<0/[gR0000002dR:L02@2dR:L00`00
0000]8RW0;B8Y`0[0;B8Y`050000003oool0oooo0?ooo`09jPX0>P3oool00`000000oooo0?ooo`0X
0?ooo`00I@3oool00`000000oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo01h0oooo0`09jPX:0?oo
o`802NX:503oool00`000000oooo0?ooo`0<0?ooo`802NX:303oool2000000@0WgVW0P00000I0;A:
@@0300000010@J/0@46[01h0@46[00<000000>BiZ@3T^JT04@3T^JT00`000000i;VY0>BiZ@0A0>Bi
ZAh0B00^00<02NX:04P0;P1802h00P1802h200000080B00^00<02NX:04P0;P1802h00`1802h20000
00<0/[gR00<000000;B8Y`2dR:L0202dR:L00`000000]8RW0;B8Y`0Z0;B8Y`8000000`3oool00`09
jPX0oooo0?ooo`0i0?ooo`030000003oool0oooo02L0oooo001U0?ooo`030000003oool0oooo0240
oooo00<02NX:0?ooo`3oool0803oool200WZ2PX0oooo0P09jPXC0?ooo`030000003oool0oooo00d0
oooo00<02NX:0?ooo`3oool01`3oool2000000@0WgVW0P0000000`3ddjd0]4Y10;A:@@0I0;A:@@03
00000010@J/0@46[01d0@46[00<000000>BiZ@3T^JT0903T^JTO04P0;P0300WZ2P1802h0B00^00<0
B00^00<02NX:04P0;P1802h0101802h2000000D0/[gR00<000000;B8Y`2dR:L0202dR:L00`000000
]8RW0;B8Y`0Y0;B8Y`<000000`3oool00`09jPX0oooo0?ooo`0i0?ooo`030000003oool0oooo02L0
oooo001U0?ooo`030000003oool0oooo0280oooo00<02NX:0?ooo`3oool08@3oool200WZ2PX0oooo
0P09jPXB0?ooo`030000003oool0oooo00d0oooo0P09jPX40?ooo`<000001@2ONJL00`000000m=>]
0;A:@@0M0;A:@@0300000009jPX0@46[01`0@46[0P00000U0>BiZAl0B00^00<02NX:04P0;P1802h0
201802h2000000L0/[gR00<000000;B8Y`2dR:L0202dR:L00`000000]8RW0;B8Y`0X0;B8Y`802NX:
103oool00`09jPX0oooo0?ooo`0j0?ooo`030000003oool0oooo02L0oooo001U0?ooo`030000003o
ool0oooo02<0oooo0P09jPXS0?ooo`802NX:2P3oool200WZ2Q40oooo00<000000?ooo`3oool03P3o
ool01009jPX0oooo00000000000609miY`8000008@2dBT400`000000@46[0411Z`0K0411Z`030000
003T^JT0i;VY0100i;VY00<02NX:0>BiZ@3T^JT0403T^JTP04P0;P0300WZ2P1802h0B00^00H0B00^
0P0000090;:mhP030000002dR:L0]8RW00T0]8RW00<000000;B8Y`2dR:L09@2dR:L200WZ2P030000
003oool0oooo00<0oooo00<02NX:0?ooo`3oool0>P3oool00`000000oooo0?ooo`0W0?ooo`00I@3o
ool00`000000oooo0?ooo`0U0?ooo`0300WZ2P3oool0oooo0280oooo0P09jPX:0?ooo`802NX:403o
ool00`000000oooo0?ooo`0=0?ooo`8000001P2ONJL2000000030?CC[@2dBT40]4Y10240]4Y100<0
00000411Z`10@J/02@10@J/2000000l0@46[00<000000>BiZ@3T^JT08P3T^JTO04P0;P0300000018
02h02NX:00H0B00^0P00000;0;:mhP030000002dR:L0]8RW00T0]8RW00<000000;B8Y`2dR:L08`2d
R:L200WZ2P030;B8Y`000000oooo00D0oooo00<02NX:0?ooo`3oool0>P3oool00`000000oooo0?oo
o`0W0?ooo`00I03oool00`000000oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo02<0oooo0P09jPX:
0?ooo`802NX:3`3oool00`000000oooo0?ooo`090?ooo`<000001P2ONJL2000000030?CC[@2dBT40
]4Y102@0]4Y100<000000411Z`10@J/02010@J/2000000l0@46[00<000000>BiZ@3T^JT08@3T^JTL
04P0;P802NX:101802h00`09jPX0B00^04P0;P0304P0;P030000002b_N80/[gR00`0/[gR00<00000
0;B8Y`2dR:L0202dR:L00`000000]8RW0;B8Y`0Q0;B8Y`802NX:0P2dR:L00`000000oooo0?ooo`05
0?ooo`0300WZ2P3oool0oooo03X0oooo00<000000?ooo`3oool09`3oool006@0oooo00<000000?oo
o`3oool0:03oool00`09jPX0oooo0?ooo`0T0?ooo`<02NX:2@3oool200WZ2Ph0oooo00<000000?oo
o`3oool01P3oool2000000P0WgVW00<000000?CC[@2dBT40:02dBT400`000000@46[0411Z`070411
Z`0300WZ2P10@J/0@46[00l0@46[00<000000>BiZ@3T^JT03P3T^JT00`09jPX0i;VY0>BiZ@0>0>Bi
ZA/0B00^00<02NX:04P0;P1802h01@1802h01009jPX0B00^04P0;P1802h2000000l0/[gR00<00000
0;B8Y`2dR:L0202dR:L00`000000]8RW0;B8Y`0O0;B8Y`802NX:102dR:L00`000000oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo03/0oooo00<000000?ooo`3oool09`3oool006@0oooo00<000000?oo
o`3oool0:@3oool200WZ2RL0oooo0P09jPX90?ooo`802NX:3@3oool00`000000oooo0?ooo`020?oo
o`<00000202ONJL2000002`0]4Y100<000000411Z`10@J/01@10@J/00`09jPX0@46[0411Z`0@0411
Z`030000003T^JT0i;VY01l0i;VY8`1802h01009jPX0B00^00000000000A0;:mhP030000002dR:L0
]8RW00P0]8RW00<000000;B8Y`2dR:L07@2dR:L200WZ2P@0]8RW00<02NX:00000009jPX01P3oool0
0`09jPX0oooo0?ooo`0k0?ooo`030000003oool0oooo02L0oooo001T0?ooo`030000003oool0oooo
02/0oooo00<02NX:0?ooo`3oool09P3oool200WZ2PT0oooo0P09jPX<0?ooo`040000003oool00000
000000T0WgVW0P0000000`3ddjd0]4Y10;A:@@0[0;A:@@030411Z`000000@46[00@0@46[00<02NX:
0411Z`10@J/04@10@J/00`000000i;VY0>BiZ@0=0>BiZ@0300WZ2P3T^JT0i;VY00h0i;VY4P1802h0
1009jPX0B00^04P0;P00000>04P0;P0300WZ2P000000/[gR0180/[gR00<000000;B8Y`2dR:L01@2d
R:L2000000030;B8Y`000000]8RW01d0]8RW00<02NX:0;B8Y`2dR:L0102dR:L00`000000oooo0?oo
o`0400WZ2P80oooo00<02NX:0?ooo`3oool0?03oool00`000000oooo0?ooo`0V0?ooo`00I03oool0
0`000000oooo0?ooo`0/0?ooo`0300WZ2P3oool0oooo02L0oooo0P09jPX90?ooo`802NX:2P3oool2
000000T0WgVW0P0000000`3ddjd0]4Y10;A:@@0^0;A:@@0300000010@J/0@46[00<0@46[00<02NX:
0411Z`10@J/04@10@J/00`000000i;VY0>BiZ@0M0>BiZB<0B00^0P0000000`09jPX0/[gR0;:mhP0B
0;:mhP030000002dR:L0]8RW00D0]8RW0P0000000`2dR:L000000;B8Y`0K0;B8Y`802NX:1P2dR:L0
0`000000oooo0?ooo`050?ooo`@02NX:?@3oool00`000000oooo0?ooo`0V0?ooo`00I03oool00`00
0000oooo0?ooo`0]0?ooo`0300WZ2P3oool0oooo02P0oooo0P09jPX90?ooo`802NX:1@3oool30000
00T0WgVW0P0000000`3ddjd0]4Y10;A:@@0a0;A:@@0500000009jPX0@46[0411Z`09jPX05010@J/0
0`000000i;VY0>BiZ@0L0>BiZB80B00^0P0000020;:mhP0300WZ2P2b_N80/[gR0180/[gR00<00000
0;B8Y`2dR:L0202dR:L00`000000]8RW0;B8Y`0H0;B8Y`802NX:202dR:L00`000000oooo0?ooo`06
0?ooo`0300WZ2P3oool0oooo00D02NX:>03oool00`000000oooo0?ooo`0V0?ooo`00I03oool00`00
0000oooo0?ooo`0^0?ooo`802NX::P3oool300WZ2PP0oooo0P09jPX00`3oool000000000000;09mi
Y`030000003ddjd0]4Y103D0]4Y100<000000411Z`09jPX05@10@J/00`0000002NX:0>BiZ@0K0>Bi
ZB40B00^0P0000040;:mhP0300WZ2P2b_N80/[gR0180/[gR00<000000;B8Y`2dR:L0202dR:L00`00
0000]8RW0;B8Y`0F0;B8Y`802NX:2@2dR:L00`000000oooo0?ooo`070?ooo`0300WZ2P3oool0oooo
00D0oooo1009jPXd0?ooo`030000003oool0oooo02H0oooo001T0?ooo`030000003oool0oooo0300
oooo00<02NX:0?ooo`3oool0:P3oool200WZ2PL0oooo0P00000;09miY`800000>@2dBT400`000000
2NX:0411Z`0D0411Z`030000003T^JT0i;VY00`0i;VY00<02NX:0>BiZ@3T^JT02`3T^JT804P0;P03
00WZ2P1802h0B00^01D0B00^0P0000060;:mhP0300WZ2P2b_N80/[gR0180/[gR00<000000;B8Y`2d
R:L0202dR:L00`000000]8RW0;B8Y`0D0;B8Y`802NX:2P2dR:L00`000000oooo0?ooo`080?ooo`03
00WZ2P3oool0oooo00T0oooo1009jPX`0?ooo`030000003oool0oooo02H0oooo001T0?ooo`030000
003oool0oooo0340oooo00<02NX:0?ooo`3oool0:`3oool200WZ2P80oooo0`00000;09miY`800000
>`2dBT400`09jPX000000411Z`0D0411Z`030000003T^JT0i;VY01X0i;VY1P1802h00`09jPX0B00^
04P0;P0204P0;P8000004@1802h2000000P0/[gR00<02NX:0;:mhP2b_N804P2b_N800`000000]8RW
0;B8Y`080;B8Y`030000002dR:L0]8RW0180]8RW0P09jPX;0;B8Y`030000003oool0oooo00T0oooo
00<02NX:0?ooo`3oool03@3oool400WZ2R`0oooo00<000000?ooo`3oool09P3oool006@0oooo00<0
00000?ooo`3oool0<P3oool00`09jPX0oooo0?ooo`0/0?ooo`800000302ONJL2000003`0]4Y100@0
2NX:0;A:@@2dBT4000005@10@J/00`000000i;VY0>BiZ@0H0>BiZ@`0B00^0P00000?04P0;P800000
2P2b_N800`09jPX0/[gR0;:mhP0B0;:mhP030000002dR:L0]8RW00P0]8RW00<000000;B8Y`2dR:L0
402dR:L200WZ2Pd0]8RW00<000000?ooo`3oool0203oool00`09jPX0oooo0?ooo`0B0?ooo`@02NX:
:03oool00`000000oooo0?ooo`0V0?ooo`00H`3oool00`000000oooo0?ooo`0d0?ooo`802NX::P3o
ool2000000`0WgVW0P0000000`3ddjd0]4Y10;A:@@0k0;A:@@0500WZ2P2dBT40]4Y10;A:@@09jPX0
5010@J/00`000000i;VY0>BiZ@0:0>BiZ@0300WZ2P3T^JT0i;VY00X0i;VY0`1802h00`09jPX0B00^
04P0;P0F04P0;P8000002`2b_N800`09jPX0/[gR0;:mhP0C0;:mhP030000002dR:L0]8RW00P0]8RW
00<000000;B8Y`2dR:L03P2dR:L200WZ2Ph0]8RW00<000000?ooo`3oool02@3oool00`09jPX0oooo
0?ooo`0F0?ooo`@02NX:903oool00`000000oooo0?ooo`0V0?ooo`00H`3oool00`000000oooo0?oo
o`0f0?ooo`0300WZ2P3oool0oooo02@0oooo0`00000=09miY`030000003ddjd0]4Y103d0]4Y100<0
2NX:0;A:@@2dBT400`2dBT400`000000@46[0411Z`0A0411Z`030000003T^JT0i;VY01H0i;VY2018
02h00`09jPX0B00^04P0;P0@04P0;P8000003@2b_N800`09jPX0/[gR0;:mhP0C0;:mhP03000PY`00
0000]8RW00P0]8RW00<000000;B8Y`2dR:L0302dR:L200WZ2Pl0]8RW00<000000?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`0J0?ooo`@02NX:8@3oool00`000000oooo0?ooo`0U0?ooo`00H`3oool0
0`000000oooo0?ooo`0g0?ooo`0300WZ2P3oool0oooo0240oooo0P00000>09miY`800000?`2dBT40
0`09jPX0]4Y10;A:@@040;A:@@0300000009jPX000000140@46[00<0000000WZ2P3T^JT05@3T^JT9
04P0;P0300WZ2P1802h0B00^00h0B00^0P00000?0;:mhP0300WZ2P2b_N80/[gR01<0/[gR00<0022W
0000002dR:L0202dR:L00`000000]8RW0;B8Y`0:0;B8Y`802NX:402dR:L2000000`0oooo00<02NX:
0?ooo`3oool07P3oool500WZ2Q`0oooo00<000000?ooo`3oool09@3oool006<0oooo00<000000?oo
o`3oool0>03oool00`09jPX0oooo0?ooo`0M0?ooo`<000003`2ONJL3000003h0]4Y100<02NX:0;A:
@@2dBT401P2dBT400`000000@46[00WZ2P0@0411Z`030000003T^JT0i;VY01D0i;VY2@1802h00`09
jPX0B00^04P0;P0<04P0;P8000004@2b_N800`09jPX0/[gR0;:mhP0D0;:mhP030000002dR:L0]8RW
00L0]8RW00<000000;B8Y`2dR:L0202dR:L200WZ2Q80]8RW00<000000?ooo`3oool02P3oool00`09
jPX0oooo0?ooo`0T0?ooo`@02NX:603oool00`000000oooo0?ooo`0U0?ooo`00H`3oool00`000000
oooo0?ooo`0i0?ooo`802NX:6`3oool200000180WgVW00<000000:6bi02Q/^@01000000j0;A:@@03
00WZ2P2dBT40]4Y100L0]4Y100<000000411Z`10@J/03`10@J/00`000000i;VY0>BiZ@0D0>BiZ@X0
B00^00<02NX:04P0;P1802h02P1802h2000001<0/[gR00<02NX:0;:mhP2b_N80502b_N800`000000
]8RW0;B8Y`080;B8Y`030000002dR:L0]8RW00D0]8RW0P09jPXC0;B8Y`030000003oool0oooo00/0
oooo00<02NX:0?ooo`3oool0:03oool400WZ2Q@0oooo00<000000?ooo`3oool09@3oool006<0oooo
00<000000?ooo`3oool0>`3oool00`09jPX0oooo0?ooo`0F0?ooo`8000005@2ONJL00`000000XK;T
0:6bi0030:6bi0@00000=@2dBT400`09jPX0]4Y10;A:@@090;A:@@0300000010@J/0@46[00h0@46[
00<000000>BiZ@3T^JT04`3T^JT;04P0;P0300WZ2P1802h0B00^00T0B00^00<000000;:mhP2b_N80
4`2b_N800`09jPX0/[gR0;:mhP060;:mhP800000302b_N800`000000]8RW0;B8Y`080;B8Y`030000
002dR:L0]8RW00<0]8RW0P09jPXD0;B8Y`030000003oool0oooo00`0oooo00<02NX:0?ooo`3oool0
;03oool200000180oooo00<000000?ooo`3oool09@3oool006<0oooo00<000000?ooo`3oool0?03o
ool00`09jPX0oooo0?ooo`0B0?ooo`<000005`2ONJL01@000000XK;T0000000000002NX:00D0XK;T
1000000`0;A:@@0300WZ2P2dBT40]4Y100/0]4Y100<000000411Z`10@J/03@10@J/00`0000002NX:
0>BiZ@0B0>BiZ@`0B00^00<02NX:04P0;P1802h01`1802h2000001H0/[gR00<02NX:0;:mhP2b_N80
1P2b_N82000000`0/[gR00<000000;B8Y`2dR:L0202dR:L010000000]8RW0;B8Y`2dR:L200WZ2QH0
]8RW00<000000?ooo`3oool0303oool00`09jPX0oooo0?ooo`0/0?ooo`8000004P3oool00`000000
oooo0?ooo`0U0?ooo`00H`3oool00`000000oooo0?ooo`0m0?ooo`0300WZ2P3oool0oooo00l0oooo
0P00000J09miY`050000002Q/^@000000000002Q/^@00`09jPX60:6bi0@00000;02dBT400`09jPX0
]4Y10;A:@@0<0;A:@@0300000010@J/0@46[00`0@46[00<000000>BiZ@3T^JT01`3T^JT00`09jPX0
i;VY0>BiZ@070>BiZ@h0B00^00<02NX:04P0;P1802h0101802h2000001P0/[gR00<02NX:0;:mhP2b
_N80502b_N800`000000]8RW0;B8Y`080;B8Y`040000002dR:L0]8RW00WZ2QL0]8RW00<000000?oo
o`3oool0303oool00`09jPX0oooo0?ooo`110?ooo`030000003oool0oooo02D0oooo001S0?ooo`03
0000003oool0oooo03h0oooo0P09jPX=0?ooo`8000007@2ONJL00`000000XK;T0:6bi0040:6bi0<0
2NX:1`2Q/^@500000280]4Y10P0000000`09jPX0]4Y100WZ2P0@0;A:@@0300000009jPX0@46[00`0
@46[00<000000>BiZ@3T^JT0403T^JT>04P0;P0300WZ2P1802h0B00^0080B00^0P00000J0;:mhP03
00WZ2P2b_N80/[gR0180/[gR0P09jPX00`000000]8RW0;B8Y`080;B8Y`0300000009jPX02NX:01L0
]8RW00<000000?ooo`3oool03@3oool00`09jPX0oooo0?ooo`110?ooo`030000003oool0oooo02D0
oooo001S0?ooo`030000003oool0oooo0400oooo00<02NX:0?ooo`3oool01`3oool3000001X0WgVW
0P00000309miY`030000002Q/^@0XK;T00L0XK;T0`09jPX80:6bi0D000007P2dBT42000000030;A:
@@09jPX02NX:0140]4Y100<000000411Z`10@J/02`10@J/00`000000i;VY0>BiZ@0?0>BiZ@l0B00^
00<02NX:04P0;P1802h00P00000L0;:mhP0300WZ2P2b_N80/[gR0180/[gR00<02NX:000000000000
2@2dR:L200WZ2QP0]8RW00<000000?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0j0?ooo`800000
1P3oool00`000000oooo0?ooo`0T0?ooo`00HP3oool00`000000oooo0?ooo`120?ooo`0300WZ2P3o
ool0oooo00D0oooo0P00000L09miY`800000102ONJL00`000000XK;T0:6bi0090:6bi0<02NX:2@2Q
/^@5000001d0]4Y100<02NX:0;A:@@09jPX04@2dBT400`000000@46[0411Z`0:0411Z`0300000009
jPX0i;VY00h0i;VY401802h00`09jPX000000000000N0;:mhP0300WZ2P2b_N80/[gR0140/[gR00@0
2NX:0;:mhP2b_N8000001`2dR:L200WZ2P030;B8Y`000000]8RW01L0]8RW00<000000?ooo`3oool0
3P3oool00`09jPX0oooo0?ooo`0j0?ooo`802NX:1P3oool00`000000oooo0?ooo`0T0?ooo`00HP3o
ool00`000000oooo0?ooo`130?ooo`0300WZ2P3oool0oooo00@0oooo00<0000009miY`2ONJL06P2O
NJL00`09jPX0WgVW09miY`0409miY`030000002Q/^@0XK;T00`0XK;T0`09jPX:0:6bi0D000005`2d
BT4200WZ2P<0]4Y10P09jPX?0;A:@@d0@46[00<0000000WZ2P3T^JT03@3T^JT@04P0;P800000802b
_N800`09jPX0/[gR0;:mhP0@0;:mhP0500WZ2P2b_N80/[gR0;:mhP0000001@2dR:L200WZ2P<0]8RW
00<000000;B8Y`2dR:L05@2dR:L00`000000oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo03P0oooo
0`09jPX80?ooo`030000003oool0oooo02@0oooo001R0?ooo`030000003oool0oooo04@0oooo0P09
jPX50?ooo`030000002ONJL0WgVW01T0WgVW00<02NX:09miY`2ONJL0102ONJL00`000000XK;T0:6b
i00?0:6bi0<02NX:2`2Q/^@5000001<0]4Y100<02NX:0;A:@@2dBT40102dBT4200WZ2Ph0]4Y13010
@J/00`000000i;VY0>BiZ@050>BiZ@0300WZ2P3T^JT0i;VY00@0i;VY3`1802h200000280/[gR00<0
2NX:0;:mhP2b_N803`2b_N800`09jPX0/[gR0;:mhP020;:mhP040000002dR:L0]8RW0;B8Y`802NX:
1@2dR:L00`000000]8RW0;B8Y`0D0;B8Y`030000003oool0oooo00l0oooo00<02NX:0?ooo`3oool0
=@3oool300WZ2P/0oooo00<000000?ooo`3oool0903oool00680oooo00<000000?ooo`3oool0AP3o
ool00`09jPX0oooo0?ooo`030?ooo`030000002ONJL0WgVW01P0WgVW00<02NX:09miY`2ONJL01@2O
NJL00`000000XK;T0:6bi00A0:6bi0<02NX:302Q/^@5000000l0]4Y100<02NX:0;A:@@2dBT401P2d
BT400`09jPX0]4Y10;A:@@0<0;A:@@/0@46[00<000000>BiZ@3T^JT0303T^JT=04P0;P800000902b
_N800`09jPX0/[gR0;:mhP0>0;:mhP0300WZ2P2b_N80/[gR00<0/[gR00@0022W00000009jPX02NX:
1`2dR:L00`000000]8RW0;B8Y`0C0;B8Y`8000004@3oool00`09jPX0oooo0?ooo`0c0?ooo`802NX:
3P3oool00`000000oooo0?ooo`0T0?ooo`00HP3oool00`000000oooo0?ooo`170?ooo`0300WZ2P3o
ool0oooo00<0oooo00<0000009miY`2ONJL05P2ONJL00`09jPX0WgVW09miY`0609miY`030000002Q
/^@0XK;T01@0XK;T0`09jPX=0:6bi0D000002P2dBT4200WZ2PT0]4Y10P09jPX=0;A:@@X0@46[00<0
00000>BiZ@3T^JT02`3T^JT<04P0;P8000004P2b_N8200000180/[gR00<02NX:0;:mhP2b_N803@2b
_N800`09jPX0/[gR0;:mhP040;:mhP03000PY`09jPX0]8RW00P0]8RW00<000000;B8Y`2dR:L04`2d
R:L00`000000oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo0340oooo0`09jPX@0?ooo`030000003o
ool0oooo02@0oooo001R0?ooo`030000003oool0oooo04P0oooo00<02NX:0?ooo`3oool00`3oool0
0`000000WgVW09miY`0E09miY`0300WZ2P2ONJL0WgVW00L0WgVW00<000000:6bi02Q/^@05P2Q/^@3
00WZ2Ph0XK;T1@0000050;A:@@0400WZ2P2dBT40]4Y100WZ2PX0]4Y10P09jPX<0;A:@@T0@46[00<0
00000>BiZ@3T^JT02P3T^JT;04P0;P800000502b_N8200000180/[gR00<02NX:0;:mhP2b_N80302b
_N800`09jPX0/[gR0;:mhP060;:mhP030000002dR:L0]8RW00L0]8RW00<000000;B8Y`2dR:L04P2d
R:L00`000000oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo02h0oooo0`09jPXC0?ooo`030000003o
ool0oooo02@0oooo001R0?ooo`030000003oool0oooo04T0oooo0P09jPX40?ooo`030000002ONJL0
WgVW01<0WgVW00<02NX:09miY`2ONJL0202ONJL00`000000XK;T0:6bi00I0:6bi0<02NX:00<0XK;T
00WZ2P2Q/^@0302Q/^@5000000050;A:@@09jPX0]4Y10;A:@@09jPX0302dBT400`09jPX0]4Y10;A:
@@0:0;A:@@030411Z`09jPX0@46[00H0@46[00<000000>BiZ@3T^JT0203T^JT:04P0;P800000:P2b
_N800`09jPX0/[gR0;:mhP0:0;:mhP0300000009jPX0/[gR00P0/[gR00<000000;B8Y`2dR:L01`2d
R:L00`000000]8RW0;B8Y`0A0;B8Y`030000003oool0oooo0140oooo00<02NX:0?ooo`3oool0;03o
ool200WZ2QH0oooo00<000000?ooo`3oool0903oool00680oooo00<000000?ooo`3oool0B`3oool0
0`09jPX0oooo0?ooo`020?ooo`0300000009jPX0WgVW0180WgVW00<02NX:09miY`2ONJL0202ONJL0
0`000000XK;T0:6bi00L0:6bi0@02NX:3`2Q/^@6000000d0]4Y10P09jPX;0;A:@@P0@46[00<00000
0>BiZ@3T^JT01`3T^JT904P0;P800000;02b_N800`09jPX0/[gR0;:mhP0:0;:mhP0300WZ2P000000
/[gR00P0/[gR00<000000;B8Y`2dR:L01`2dR:L00`000000]8RW0;B8Y`0@0;B8Y`8000004`3oool0
0`09jPX0oooo0?ooo`0Y0?ooo`<02NX:6@3oool00`000000oooo0?ooo`0S0?ooo`00HP3oool00`00
0000oooo0?ooo`1<0?ooo`@02NX:00<0oooo0000002ONJL04P2ONJL00`09jPX0WgVW09miY`0909mi
Y`030000002Q/^@0XK;T01l0XK;T0`09jPX<0:6bi00400WZ2P2Q/^@0XK;T0:6bi0H000002`2dBT42
00WZ2PX0]4Y100<0@46[00WZ2P10@J/01010@J/01@0000002NX:0>BiZ@3T^JT02NX:00@0i;VY2018
02h2000002h0/[gR00<02NX:0;:mhP2b_N802@2b_N800`09jPX0/[gR0;:mhP090;:mhP030000002d
R:L0]8RW00L0]8RW00<000000;B8Y`2dR:L0402dR:L00`000000oooo0?ooo`0A0?ooo`0300WZ2P3o
ool0oooo02L0oooo0`09jPXL0?ooo`030000003oool0oooo02<0oooo001Q0?ooo`030000003oool0
oooo04/0oooo1009jPX40?ooo`030000002ONJL0WgVW00l0WgVW0P00000;09miY`030000002Q/^@0
XK;T0280XK;T1009jPX70:6bi00300WZ2P2Q/^@0XK;T00H0XK;T1P0000090;A:@@0300WZ2P2dBT40
]4Y100L0]4Y11`10@J/00`000000i;VY0>BiZ@060>BiZ@H0B00^0P00000`0;:mhP0300WZ2P2b_N80
/[gR00P0/[gR00<02NX:0;:mhP2b_N802P2b_N800`000000]8RW0;B8Y`070;B8Y`030000002dR:L0
]8RW00l0]8RW00<000000?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0U0?ooo`802NX:7`3oool0
0`000000oooo0?ooo`0S0?ooo`00H@3oool00`000000oooo0?ooo`180?ooo`<02NX:103oool200WZ
2P<0oooo00<0000009miY`2ONJL03P2ONJL2000000`0WgVW00<000000:6bi02Q/^@09@2Q/^@300WZ
2P050:6bi000000000000:6bi009jPX0302Q/^@6000000H0]4Y10P09jPX80;A:@@80@46[00D02NX:
0411Z`10@J/0@46[000000070>BiZ@H0B00^00<000000;:mhP2b_N80:`2b_N82000000<0/[gR00<0
2NX:0;:mhP2b_N801`2b_N800`09jPX0/[gR0;:mhP0;0;:mhP030000002dR:L0]8RW00P0]8RW00<0
00000;B8Y`2dR:L03@2dR:L00`000000oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo0280oooo0`09
jPXQ0?ooo`030000003oool0oooo02<0oooo001Q0?ooo`030000003oool0oooo04D0oooo0`09jPX9
0?ooo`0500WZ2P3oool0oooo0?ooo`0000003`2ONJL00`09jPX0WgVW09miY`0;09miY`030000002Q
/^@0XK;T02P0XK;T00@02NX:0000000000002NX:4@2Q/^@6000000@0]4Y10P09jPX70;A:@@D0@46[
00<0000000WZ2P3T^JT0103T^JT504P0;P800000;P2b_N8200000080/[gR00<02NX:0;:mhP2b_N80
1`2b_N800`09jPX0/[gR0;:mhP0<0;:mhP030000002dR:L0]8RW00P0]8RW00<000000;B8Y`2dR:L0
3@2dR:L00`000000oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01l0oooo0`09jPXT0?ooo`030000
003oool0oooo02<0oooo001Q0?ooo`030000003oool0oooo0480oooo0`09jPX=0?ooo`0500WZ2P3o
ool0oooo0?ooo`0000003@2ONJL00`09jPX0WgVW09miY`0<09miY`030000002Q/^@0XK;T02X0XK;T
0P09jPXE0:6bi0H000000P2dBT4200WZ2PH0]4Y100D0@46[00WZ2P10@J/0@46[000000050>BiZ@@0
B00^0P00000d0;:mhP0300WZ2P2b_N80/[gR00H0/[gR00<02NX:0;:mhP2b_N803@2b_N800`000000
Y;3P0;B8Y`080;B8Y`030000002dR:L0]8RW00`0]8RW00<000000?ooo`3oool04`3oool00`09jPX0
oooo0?ooo`0N0?ooo`802NX:9`3oool00`000000oooo0?ooo`0S0?ooo`00H@3oool00`000000oooo
0?ooo`0o0?ooo`<02NX:4@3oool01@09jPX0oooo0?ooo`3oool0000000`0WgVW00<02NX:09miY`2O
NJL03@2ONJL00`000000XK;T0:6bi00Y0:6bi00300WZ2P2Q/^@0XK;T01P0XK;T1@0000000`2dBT40
2NX:0;A:@@050;A:@@80@46[00H02NX:0000003T^JT0i;VY00WZ2P3T^JT304P0;P800000=P2b_N80
0`09jPX0/[gR0;:mhP050;:mhP0300WZ2P2b_N80/[gR00h0/[gR00<000000;B8Y`2dR:L0202dR:L0
0`000000]8RW0;B8Y`0;0;B8Y`030000003oool0oooo01@0oooo00<02NX:0?ooo`3oool06`3oool3
00WZ2RT0oooo00<000000?ooo`3oool08`3oool00640oooo00<000000?ooo`3oool0?03oool300WZ
2QD0oooo0P09jPX20?ooo`030000002ONJL0WgVW00P0WgVW00<02NX:09miY`2ONJL03P2ONJL00`00
0000XK;T0:6bi00X0:6bi00300WZ2P2Q/^@0XK;T01d0XK;T0`00000200WZ2PD0]4Y100@0@46[00WZ
2P10@J/000000`3T^JT00`1802h000000000000h0;:mhP0300WZ2P2b_N80/[gR00@0/[gR00<02NX:
0;:mhP2b_N803`2b_N800`000000]8RW0;B8Y`080;B8Y`030000002dR:L0]8RW00X0]8RW0P00000F
0?ooo`0300WZ2P3oool0oooo01T0oooo0P09jPX/0?ooo`030000003oool0oooo02<0oooo001Q0?oo
o`030000003oool0oooo03T0oooo0`09jPXJ0?ooo`0400WZ2P3oool0oooo000000T0WgVW00<02NX:
09miY`2ONJL03`2ONJL00`000000XK;T0:6bi00V0:6bi00300WZ2P2Q/^@0XK;T0280XK;T00<00000
00WZ2P09jPX00P0000020;A:@@030411Z`09jPX000000080i;VY0P00000j0;:mhP0300WZ2P2b_N80
/[gR00<0/[gR00<02NX:0;:mhP2b_N80402b_N8010008:L000000;B8Y`2T/>070;B8Y`030000002d
R:L0]8RW00X0]8RW00<000000?ooo`3oool0503oool00`09jPX0oooo0?ooo`0G0?ooo`<02NX:;`3o
ool00`000000oooo0?ooo`0R0?ooo`00H@3oool00`000000oooo0?ooo`0f0?ooo`<02NX:7P3oool0
1009jPX0oooo0?ooo`00000809miY`0300WZ2P2ONJL0WgVW00l0WgVW00<000000:6bi02Q/^@09P2Q
/^@00`09jPX0XK;T0:6bi00E0:6bi00300WZ2P2Q/^@0XK;T00d0XK;T00<02NX:0000000000000P00
00001010@J/0000000000000000l0;:mhP0300WZ2P2b_N80/[gR0080/[gR00<02NX:0;:mhP2b_N80
4P2b_N800`000000]8RW0;B8Y`070;B8Y`030000002dR:L0]8RW00T0]8RW00<000000?ooo`3oool0
5@3oool00`09jPX0oooo0?ooo`0D0?ooo`<02NX:<P3oool00`000000oooo0?ooo`0R0?ooo`00H@3o
ool00`000000oooo0?ooo`0d0?ooo`802NX:8P3oool01009jPX0oooo0?ooo`00000609miY`0300WZ
2P2ONJL0WgVW0100WgVW00<000000:6bi02Q/^@09@2Q/^@00`09jPX0XK;T0:6bi00W0:6bi0802NX:
0P2Q/^@3000000030;:mhP0000002NX:01T0/[gR0P00000O0;:mhP0500WZ2P2b_N80/[gR0;:mhP09
jPX05@2b_N800`000000]8RW0;B8Y`070;B8Y`030000002dR:L0]8RW00P0]8RW00<000000?ooo`3o
ool05P3oool00`09jPX0oooo0?ooo`0B0?ooo`802NX:=@3oool00`000000oooo0?ooo`0R0?ooo`00
H@3oool00`000000oooo0?ooo`0a0?ooo`<02NX:9@3oool200WZ2P030?ooo`000000WgVW00@0WgVW
00<02NX:09miY`2ONJL04@2ONJL00`000000XK;T0:6bi00S0:6bi00300WZ2P2Q/^@0XK;T02X0XK;T
0P09jPX01P0f03l0000000000039IeD0000000WZ2QT0/[gR0P00000O0;:mhP0400WZ2P2b_N80/[gR
00WZ2QH0/[gR00<000000;B8Y`2dR:L01`2dR:L00`000000]8RW0;B8Y`070;B8Y`800000603oool0
0`09jPX0oooo0?ooo`0?0?ooo`<02NX:=`3oool00`000000oooo0?ooo`0R0?ooo`00H03oool00`00
0000oooo0?ooo`0_0?ooo`<02NX::P3oool00`09jPX0oooo0000000309miY`0300WZ2P2ONJL0WgVW
0180WgVW00<000000:6bi02Q/^@08`2Q/^@00`09jPX0XK;T0:6bi00C0:6bi00300WZ2P2Q/^@0XK;T
01D0XK;T00D0=P0o00WZ2P1BGL00GfG1000000020<UWE@0300WZ2P2b_N80/[gR01L0/[gR00<02NX:
0;:mhP2b_N807@2b_N800`09jPX0/[gR00WZ2P0G0;:mhP030000002dR:L0]8RW00L0]8RW00<00000
0;B8Y`2dR:L01`2dR:L00`0000002NX:0?ooo`0F0?ooo`0300WZ2P3oool0oooo00d0oooo0`09jPXj
0?ooo`030000003oool0oooo0280oooo001P0?ooo`030000003oool0oooo02`0oooo0`09jPX^0?oo
o`0300WZ2P3oool000000080WgVW00<02NX:09miY`2ONJL04P2ONJL00`3ddjd000000:6bi00R0:6b
i00300WZ2P2Q/^@0XK;T02X0XK;T0P0f03l01P0000002NX:00WZ2P09jPX0GfG100000080bFME00@0
2NX:0<UWE@39IeD0bFME5@2b_N800`09jPX0/[gR0;:mhP0A0;:mhP8000002P2b_N8200WZ2QP0/[gR
00<000000;B8Y`2dR:L01`2dR:L00`000000]8RW0;B8Y`060;B8Y`040000003oool0oooo00WZ2QH0
oooo00<02NX:0?ooo`3oool02`3oool200WZ2Sd0oooo00<000000?ooo`3oool08P3oool00600oooo
00<000000?ooo`3oool0:@3oool300WZ2S80oooo00D02NX:0?ooo`000000WgVW00WZ2P0E09miY`03
0000002Q/^@0XK;T0240XK;T00<02NX:0:6bi02Q/^@0:@2Q/^@303H0?`040000003P`[X0h<:j059M
`0802NX:00@000000<UWE@00000000001P39IeDA0;:mhP0300WZ2P2b_N80/[gR0140/[gR0P00000:
0;:mhP0300WZ2P2b_N80/[gR01L0/[gR00<000000;B8Y`2dR:L01`2dR:L00`000000]8RW0;B8Y`05
0;B8Y`8000000P3oool00`09jPX0oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo00P0oooo0`09jPXo
0?ooo`030000003oool0oooo0280oooo001P0?ooo`030000003oool0oooo02H0oooo0`09jPXf0?oo
oaT02NX:00<0000000WZ2P2Q/^@0802Q/^@00`09jPX0XK;T0:6bi00X0:6bi0@0=P0o00@000000>32
^P3P`[X0h<:j0`1BGL001009jPX000000000000000090<UWE@h0/[gR00<02NX:0;:mhP2b_N80702b
_N8200WZ2QT0/[gR00<000000;B8Y`2dR:L01`2dR:L00`000000]8RW0;B8Y`040;B8Y`80000000@0
cELU0000003oool02NX:5P3oool00`09jPX0oooo0?ooo`050?ooo`<02NX:@P3oool00`000000oooo
0?ooo`0R0?ooo`00H03oool00`000000oooo0?ooo`0S0?ooo`<02NX:3P3oool[00WZ2P80oooo00<0
2NX:0000002ONJL05@2ONJL00`000000XK;T0:6bi00N0:6bi00300WZ2P2Q/^@0XK;T02L0XK;T1@0f
03l00`000000h<:j0>32^P020>32^P@0DUg00P09jPX>0<UWE@040;:mhP0000002NX:00WZ2PH0/[gR
00<02NX:0;:mhP2b_N806`2b_N800`09jPX0/[gR00WZ2P0I0;:mhP030000002dR:L0]8RW00L0]8RW
00<000000;B8Y`2dR:L0102dR:L01P000000cELU0<eG9@3=EbD0000000WZ2QD0oooo00<02NX:0?oo
o`3oool0103oool200WZ2TH0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3o
ool00P00000?0?ooob<02NX:;@3oool200WZ2P030000002ONJL0WgVW01<0WgVW00<000000:6bi02Q
/^@07P2Q/^@00`09jPX0XK;T0:6bi00V0:6bi0D0=P0o00<02NX:0000003P`[X00`3P`[X5059M`003
05mU`@09jPX02NX:0100bFME1@2b_N800`09jPX0/[gR0;:mhP0K0;:mhP0400WZ2P2b_N80/[gR00WZ
2QT0/[gR00<000000;B8Y`2dR:L01`2dR:L00`000000]8RW0;B8Y`030;B8Y`030000003=EbD0cELU
00<0cELU00<0000000WZ2P3oool04`3oool01009jPX0oooo0?ooo`3oool300WZ2TP0oooo00<00000
0?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool00P00000?00WZ2P`0oooo0`09jPY00?oo
o`0500WZ2P3oool0oooo00WZ2P000000502ONJL00`3ddjd000000:6bi00M0:6bi00300WZ2P2Q/^@0
XK;T0180XK;T00<02NX:0:6bi02Q/^@0402Q/^@703H0?`030000003P`[X0h<:j00<0h<:j1P1BGL00
0`1OIL40000000WZ2P0B0<UWE@80/[gR00<02NX:0;:mhP2b_N806P2b_N801@09jPX0/[gR0;:mhP2b
_N802NX:01T0/[gR00<000000;B8Y`2dR:L0202dR:L01@000000]8RW0;B8Y`2dR:L0000000L0cELU
00<02NX:0?ooo`3oool04P3oool400WZ2T/0oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool06`3oool200WZ2T<0oooo00H02NX:0?ooo`3oool0oooo00WZ2P00000D09miY`03
0000002Q/^@0XK;T01/0XK;T00<02NX:0:6bi02Q/^@04P2Q/^@00`09jPX0XK;T0:6bi00@0:6bi0L0
=P0o00<000000>32^P3P`[X0103P`[X7059M`00405mU`@0000002NX:00WZ2Q80bFME0P09jPXJ0;:m
hP0300WZ2P2b_N80/[gR0080/[gR00<02NX:0;:mhP2b_N805`2b_N800`008:L000000;B8Y`080;B8
Y`050000002dR:L0]8RW0;B8Y`0000001`3=EbD00`09jPX000000?ooo`0@0?ooo`<02NX:CP3oool0
0`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`0H0?ooo`<02NX:A03oool00`09
jPX0oooo0?ooo`040?ooo`0300000009jPX0WgVW0140WgVW00<000000:6bi02Q/^@06`2Q/^@00`09
jPX0XK;T0:6bi00@0:6bi00300WZ2P2Q/^@0XK;T0100XK;T200f03l00`09jPX000000>32^P060>32
^PL0DUg000<0GfG100000039IeD00P09jPX@0<UWE@0300WZ2P39IeD0bFME00<0bFME0P09jPXC0;:m
hP0300WZ2P2b_N80/[gR00<0/[gR00<02NX:0;:mhP2b_N80602b_N800`000000]8RW0;B8Y`070;B8
Y`040000002dR:L0]8RW000000P0cELU00<02NX:0<eG9@0000003P3oool200WZ2P030?ooo`09jPX0
oooo04h0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool05@3oool300WZ
2TL0oooo00@02NX:0?ooo`3oool0oooo0`09jPX00`3oool0000009miY`0B09miY`030000002Q/^@0
XK;T01T0XK;T00<02NX:0:6bi02Q/^@08`2Q/^@903H0?`030000003P`[X0h<:j00H0h<:j1@1BGL00
1@09jPX0DUg005mU`@1OIL4000000080bFME0P09jPX>0<UWE@0300WZ2P39IeD0bFME00D0bFME00<0
2NX:0;:mhP2b_N803`2b_N800`09jPX0/[gR0;:mhP040;:mhP0300WZ2P2b_N80/[gR01P0/[gR00<0
00000;B8Y`2dR:L01`2dR:L00`000000]8RW0000000:0<eG9@0300WZ2P3=EbD0000000X0oooo0`09
jPX30?ooo`0300WZ2P3oool0oooo04d0oooo00<000000?ooo`3oool08@3oool005l0oooo00<00000
0?ooo`3oool04`3oool300WZ2TX0oooo1009jPX40?ooo`0300WZ2P0000002NX:0140WgVW00<00000
0:6bi02Q/^@0602Q/^@00`09jPX0XK;T0:6bi00R0:6bi0X0=P0o00<000000>32^P3P`[X01`3P`[X8
059M`080GfG100D000000<UWE@39IeD0bFME00WZ2P0=0<UWE@0300WZ2P39IeD0bFME00X0bFME00<0
2NX:0;:mhP2b_N802@2b_N800`09jPX0/[gR0;:mhP050;:mhP0300WZ2P2b_N80/[gR01P0/[gR00<0
00000;B8Y`2dR:L01`2dR:L3000000X0cELU00@02NX:0<eG9@3=EbD000001P3oool300WZ2PH0oooo
00<02NX:0?ooo`3oool0C@3oool00`000000oooo0?ooo`0Q0?ooo`00G`3oool00`000000oooo0?oo
o`0@0?ooo`<02NX:B`3oool300WZ2PP0oooo00<02NX:00000009jPX0402ONJL00`000000XK;T0:6b
i00H0:6bi00300WZ2P2Q/^@0XK;T00l0XK;T00<02NX:0000002Q/^@03P2Q/^@<03H0?`030000003P
`[X0h<:j00L0h<:j2@1BGL000`1OIL4000000<UWE@030<UWE@802NX:2`39IeD00`09jPX0bFME0<UW
E@0=0<UWE@P0/[gR00<02NX:0;:mhP2b_N801@2b_N800`09jPX0/[gR0;:mhP0I0;:mhP030000002d
R:L0]8RW00L0]8RW0P00000;0<eG9@0400WZ2P3=EbD0cELU0<eG9@80000000@0oooo00WZ2P09jPX0
2NX:203oool00`09jPX0oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo001O0?ooo`030000
003oool0oooo00d0oooo0`09jPY;0?ooo`<02NX:00<0oooo00WZ2P3oool01@3oool400WZ2P030?oo
o`0000002NX:0100WgVW00<000000:6bi02Q/^@05P2Q/^@00`09jPX0XK;T0:6bi00P0:6bi0`0=P0o
00<000000>32^P3P`[X0203P`[X:059M`00305mU`@000000bFME00@0bFME0P09jPX90<UWE@0300WZ
2P39IeD0bFME0140bFME00D02NX:0;:mhP2b_N802NX:000000070;:mhP0300WZ2P2b_N80/[gR01T0
/[gR00<000000;B8Y`2dR:L01`2dR:L00`000000cELU0<eG9@0:0<eG9@0400WZ2P3=EbD0cELU0<eG
9@80000000<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`1?0?ooo`030000003oool0oooo
0200oooo001O0?ooo`030000003oool0oooo00/0oooo0P09jPY;0?ooo`<02NX:0`3oool00`09jPX0
oooo0?ooo`020?ooo`<02NX:0`3oool01@09jPX0oooo0?ooo`0000002NX:00l0WgVW00<000000:6b
i02Q/^@05@2Q/^@00`09jPX0XK;T0:6bi00?0:6bi00300WZ2P2Q/^@0XK;T00d0XK;T3@0f03l00`00
0000h<:j0>32^P090>32^PD0DUg00P0000001P09jPX0DUg0059M`01BGL00GfG1000000H0bFME0P09
jPX70<UWE@0300WZ2P39IeD0bFME01<0bFME00<02NX:0000000000001`2b_N800`09jPX0/[gR0;:m
hP0I0;:mhP030000002dR:L0]8RW00D0]8RW0`00000=0<eG9@0300WZ2P3=EbD0cELU0080cELU0P00
000:0?ooo`0300WZ2P3oool0oooo04l0oooo00<000000?ooo`3oool0803oool005l0oooo00<00000
0?ooo`3oool0203oool300WZ2TX0oooo0`09jPX60?ooo`0300WZ2P3oool02NX:00802NX:1`3oool0
1009jPX0oooo0?ooo`00000200WZ2Ph0WgVW00<000000:6bi02Q/^@0502Q/^@00`09jPX0XK;T0:6b
i00N0:6bi0d0=P0o00<000000>32^P3P`[X02P3P`[X00`39KV80DUg0059M`002059M`08000001@1B
GL000`1OIL4000000<UWE@060<UWE@0300WZ2P39IeD0bFME00@0bFME00<02NX:0<UWE@39IeD04P39
IeD00`09jPX0bFME00WZ2P020<UWE@H0/[gR00<02NX:0;:mhP2b_N806@2b_N800`000000]8RW0;B8
Y`020;B8Y`H000003@3=EbD00`09jPX0cELU0<eG9@040<eG9@030000003oool0oooo00L0oooo00<0
2NX:0?ooo`3oool0C`3oool00`000000oooo0?ooo`0P0?ooo`00G`3oool00`000000oooo0?ooo`05
0?ooo`<02NX:BP3oool300WZ2PP0oooo0`09jPX:0?ooo`0700WZ2P3oool0oooo0?ooo`000000WgVW
00WZ2P0=09miY`030000002Q/^@0XK;T01<0XK;T00<02NX:0:6bi02Q/^@07@2Q/^@?03H0?`030000
003P`[X0h<:j00/0h<:j301BGL000`1OIL4000000<UWE@060<UWE@802NX:1039IeD00`09jPX0bFME
0<UWE@050<UWE@8000002P39IeD01009jPX0bFME0000000000060<UWE@80/[gR00<02NX:0;:mhP2b
_N806@2b_N800`000000]8RW00000002000000<0]8RW00@000000<eG9@3=EbD00000303=EbD00`09
jPX0cELU0<eG9@050<eG9@030000003oool0oooo00D0oooo00<02NX:0?ooo`3oool0D03oool00`00
0000oooo0?ooo`0P0?ooo`00G`3oool00`000000oooo0?ooo`020?ooo`<02NX:BP3oool300WZ2PP0
oooo1009jPX<0?ooo`0300WZ2P3oool0oooo0080oooo00<0000009miY`09jPX0302ONJL00`000000
XK;T0:6bi00B0:6bi00300WZ2P2Q/^@0XK;T01d0XK;T3`0f03l00`000000h<:j0>32^P0<0>32^PP0
DUg00P09jPX3059M`00305mU`@000000bFME00L0bFME0P09jPX20<UWE@0300WZ2P39IeD0bFME00D0
bFME0P0000090<UWE@0300WZ2P39IeD0bFME008000002039IeD00`09jPX0/[gR0;:mhP0H0;:mhP<0
00001@2dR:L00`000000cELU0<eG9@020<eG9@030000003=EbD0cELU00T0cELU00<02NX:0<eG9@3=
EbD01P3=EbD00`000000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo0500oooo00<000000?ooo`3o
ool0803oool005l0oooo00<000000?ooo`09jPX00P09jPY:0?ooo`<02NX:203oool300WZ2P<0oooo
00<02NX:0?ooo`3oool02`3oool02009jPX0oooo0?ooo`3oool02NX:0000002ONJL02NX:302ONJL0
0`000000XK;T0:6bi00A0:6bi00300WZ2P2Q/^@0XK;T01/0XK;T400f03l00`000000h<:j0>32^P0=
0>32^PT0DUg000<02NX:059M`01BGL000P1BGL000`1OIL4000000<UWE@080<UWE@<02NX:4@39IeD0
0`09jPX0bFME0<UWE@020<UWE@0300WZ2P39IeD0bFME00H0bFME00<02NX:0<UWE@39IeD00P39IeDC
0;:mhP<0000000<0/[gR0000002dR:L0102dR:L00`000000cELU0<eG9@040<eG9@030000003=EbD0
cELU00T0cELU00<02NX:0<eG9@3=EbD01P3=EbD00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0
oooo0500oooo00<000000?ooo`3oool0803oool005h0oooo00<02NX:00000009jPX0BP3oool300WZ
2PP0oooo0`09jPX60?ooo`0300WZ2P3oool0oooo00/0oooo00P02NX:0?ooo`3oool0oooo00WZ2P3o
ool0000009miY`802NX:2P2ONJL00`000000XK;T0:6bi00@0:6bi00300WZ2P2Q/^@0XK;T00d0XK;T
00<02NX:0:6bi02Q/^@02P2Q/^@B03H0?`030000003P`[X0h<:j00d0h<:j3P1BGL0205mU`@030000
0039IeD0bFME00L0bFME0P09jPX@0<UWE@0300WZ2P39IeD0bFME00<0bFME00<02NX:0<UWE@39IeD0
1P39IeD00`09jPX0bFME0<UWE@050<UWE@0300WZ2P2b_N80/[gR00T0/[gR100000040;:mhP030000
002dR:L0]8RW00<0]8RW00<000000<eG9@3=EbD01@3=EbD00`000000cELU0<eG9@080<eG9@0300WZ
2P3=EbD0cELU00L0cELU00D000000?ooo`3oool0oooo00WZ2P1C0?ooo`030000003oool0oooo0200
oooo001M0?ooo`0300WZ2P3oool0000004P0oooo0`09jPX80?ooo`<02NX:203oool00`09jPX0oooo
0?ooo`0<0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00P3oool010000000WgVW09miY`09jPX:09mi
Y`030000002Q/^@0XK;T00l0XK;T00<02NX:0:6bi02Q/^@06@2Q/^@B03H0?`030000003P`[X0h<:j
00h0h<:j00<0bFiR059M`01BGL00301BGL000`1OIL4000000<UWE@080<UWE@0400WZ2P39IeD02NX:
00WZ2Pd0bFME00<02NX:0<UWE@39IeD01039IeD00`09jPX0bFME0<UWE@060<UWE@0300WZ2P39IeD0
bFME00P0bFME1P2b_N83000000T0/[gR00D000000;B8Y`2dR:L0]8RW000000080<eG9@030000003=
EbD0cELU00P0cELU00<02NX:0<eG9@3=EbD0203=EbD010000000oooo0?ooo`09jPYC0?ooo`030000
003oool0oooo0200oooo001N0?ooo`030000003oool0oooo04@0oooo0`09jPX80?ooo`<02NX:2`3o
ool00`09jPX0oooo0?ooo`0<0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00`3oool010000000WgVW
09miY`09jPX909miY`030000002Q/^@0XK;T00h0XK;T00<02NX:0:6bi02Q/^@0602Q/^@C03H0?`03
0000003P`[X0h<:j00l0h<:j00<0bFiR059M`01BGL003@1BGL000`1OIL4000000<UWE@070<UWE@05
00WZ2P39IeD0bFME0<UWE@09jPX02`39IeD00`09jPX0bFME0<UWE@050<UWE@0300WZ2P39IeD0bFME
00H0bFME00<02NX:0<UWE@39IeD02`39IeD3000000`0/[gR00@000000;B8Y`2dR:L000002P3=EbD0
0`000000cELU0<eG9@070<eG9@0300WZ2P3=EbD0cELU00T0cELU00<000000?ooo`09jPX0E03oool0
0`000000oooo0?ooo`0O0?ooo`00GP3oool00`000000oooo0?ooo`110?ooo`<02NX:203oool300WZ
2Pd0oooo00<02NX:0?ooo`3oool03P3oool01009jPX0oooo0?ooo`09jPX40?ooo`040000002ONJL0
WgVW00WZ2PP0WgVW00<000000:6bi02Q/^@03@2Q/^@00`09jPX0XK;T0:6bi00H0:6bi1@0=P0o00<0
00000>32^P3P`[X0403P`[X@059M`00305mU`@000000bFME00H0bFME00<02NX:0<UWE@39IeD00P39
IeD200WZ2PP0bFME00<02NX:0<UWE@39IeD01P39IeD00`09jPX0bFME0<UWE@060<UWE@0300WZ2P39
IeD0bFME00P0bFME0`0000040<UWE@030;:mhP09jPX0/[gR00P0/[gR00@000000;B8Y`0000000000
2`3=EbD00`000000cELU0<eG9@070<eG9@0300WZ2P3=EbD0cELU00T0cELU00<0000000WZ2P3oool0
D`3oool00`000000oooo0?ooo`0O0?ooo`00GP3oool00`000000oooo0?ooo`0n0?ooo`<02NX:203o
ool300WZ2Q00oooo00<02NX:0?ooo`3oool03P3oool01009jPX0oooo0?ooo`09jPX50?ooo`030000
002ONJL0WgVW00802NX:1`2ONJL00`000000XK;T0:6bi00<0:6bi00300WZ2P2Q/^@0XK;T00/0XK;T
00<02NX:0:6bi02Q/^@0202Q/^@E03H0?`030000003P`[X0h<:j0140h<:j4@1BGL000`1OIL400000
0<UWE@050<UWE@0300WZ2P39IeD0bFME00@0bFME0P09jPX50<UWE@0300WZ2P39IeD0bFME00L0bFME
00<02NX:0<UWE@39IeD01P39IeD00`09jPX0bFME0<UWE@050<UWE@<000002`39IeD00`2b_N800000
0;:mhP040;:mhP030000002dR:L0000000d0cELU00<000000<eG9@3=EbD01P3=EbD00`09jPX0cELU
0<eG9@090<eG9@0300WZ2P000000oooo05<0oooo00<000000?ooo`3oool07`3oool005h0oooo00<0
00000?ooo`3oool0?03oool200WZ2PP0oooo0`09jPXC0?ooo`0300WZ2P3oool0oooo00h0oooo00@0
2NX:0?ooo`3oool02NX:1P3oool01@000000WgVW09miY`2ONJL02NX:00H0WgVW00<000000:6bi02Q
/^@02`2Q/^@00`09jPX0XK;T0:6bi00;0:6bi0030000002Q/^@0XK;T00P0XK;T5@0f03l00`000000
h<:j0>32^P0B0>32^Q80DUg000<0GfG100000039IeD01039IeD00`09jPX0bFME0<UWE@060<UWE@05
00WZ2P39IeD0bFME0<UWE@09jPX02P39IeD00`09jPX0bFME0<UWE@060<UWE@0300WZ2P39IeD0bFME
0080bFME0`00000A0<UWE@@0/[gR0P00000?0<eG9@030000003=EbD0cELU00D0cELU00<02NX:0<eG
9@3=EbD02@3=EbD3000005<0oooo00<000000?ooo`3oool07`3oool005h0oooo00<000000?ooo`3o
ool0>@3oool300WZ2PL0oooo0`09jPXE0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`09
jPX01`3oool01@0000002NX:09miY`2ONJL02NX:00@0WgVW0P3@I3d00`000000XK;T0:6bi0090:6b
i00300WZ2P2Q/^@0XK;T01D0XK;T5`0f03l00`000000h<:j0>32^P0B0>32^Q<0DUg000<0GfG10000
0039IeD00`39IeD00`09jPX0bFME0<UWE@070<UWE@<02NX:2`39IeD00`09jPX0bFME0<UWE@060<UW
E@0300WZ2P0000000000008000005`39IeD00`2b_N8000000000000?0<eG9@030000003=EbD0cELU
00D0cELU00<02NX:0<eG9@3=EbD02@3=EbD2000000030<eG9@000000oooo0540oooo00<000000?oo
o`3oool07`3oool005h0oooo00<000000?ooo`3oool0=P3oool300WZ2PL0oooo0`09jPXH0?ooo`03
00WZ2P3oool0oooo0100oooo00<02NX:0?ooo`09jPX01`3oool00`09jPX0000009miY`0209miY`80
2NX:0P2ONJL20=1T?@030000002Q/^@0XK;T00T0XK;T00<02NX:0:6bi02Q/^@04`2Q/^@H03H0?`03
0000003P`[X0h<:j01<0h<:j00<0/k[N059M`01BGL004@1BGL000`1OIL4000000<UWE@020<UWE@03
00WZ2P39IeD0bFME00P0bFME0P09jPX;0<UWE@0300WZ2P39IeD0bFME00@0bFME0`00000L0<UWE@03
0000002cd>h00000008000003@3=EbD00`000000cELU0<eG9@040<eG9@8000003P3=EbD200000500
oooo00<000000?ooo`3oool07`3oool005h0oooo00<000000?ooo`3oool0<`3oool300WZ2PL0oooo
0`09jPXK0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`09jPX01P3oool01009jPX0oooo
0?ooo`00000409miY`0500WZ2P3@I3d0d6@m0=1T?@0000002P2Q/^@00`09jPX0XK;T0:6bi00C0:6b
i1P0=P0o00<000000>32^P3P`[X0503P`[X00`2c^]h0DUg0059M`00:059M`00300WZ2P1BGL00DUg0
00D0DUg000D0gKjj00000039IeD0bFME00WZ2P060<UWE@80000000@0bFME00WZ2P39IeD0bFME0P09
jPX90<UWE@0400WZ2P39IeD0bFME0<UWE@<000000P39IeD00`09jPX0bFME0<UWE@0I0<UWE@800000
102cd>h3000000/0cELU00<000000<eG9@3=EbD00`3=EbD200000100cELU00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0O0?ooo`00GP3oool00`000000oooo0?ooo`0`0?ooo`<02NX:1`3o
ool300WZ2Qd0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo00WZ2P050?ooo`0300WZ2P3o
ool0oooo0080oooo00<0000009miY`2ONJL00P2ONJL01@09jPX0d6@m0=1T?@3@I3d0000000P0XK;T
00<02NX:0:6bi02Q/^@04P2Q/^@J03H0?`030000003P`[X0h<:j01D0h<:j5@1BGL0010000000bFME
0<UWE@09jPX60<UWE@80000000<02NX:0<UWE@39IeD00`39IeD200WZ2PL0bFME00@02NX:00000000
000000001@39IeD00`09jPX0bFME0<UWE@0H0<UWE@030000002bT;<0000000L0/m3^0`0000090<eG
9@030000003=EbD0cELU01D0cELU00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0O0?oo
o`00GP3oool00`000000oooo0?ooo`0]0?ooo`<02NX:1`3oool300WZ2R00oooo00<02NX:0?ooo`3o
ool04P3oool200WZ2P@0oooo00<02NX:0?ooo`3oool00`3oool01009jPX0000000WZ2P2ONJL20=1T
?@0400WZ2P3@I3d0d6@m000000P0XK;T00<02NX:0:6bi02Q/^@04@2Q/^@J03H0?`030000003P`[X0
h<:j01H0h<:j5@1BGL00103M_[X000000<UWE@09jPX70<UWE@0300WZ2P39IeD0bFME00H0bFME00<0
2NX:0000000000000P39IeD30000000300WZ2P39IeD0bFME00D0bFME00<02NX:0<UWE@39IeD05`39
IeD01@000000/Y2c0;:@/`2bT;<0000000T0/m3^0P0000070<eG9@030000003=EbD0cELU01H0cELU
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0N0?ooo`00GP3oool00`000000oooo0?oo
o`0Z0?ooo`<02NX:1`3oool300WZ2R80oooo00<02NX:0?ooo`3oool04`3oool200WZ2P<0oooo00@0
2NX:0?ooo`3oool0oooo0`09jPX20?ooo`030000002ONJL0d6@m0080d6@m0P09jPX00`3@I3d00000
0:6bi0050:6bi00300WZ2P2Q/^@0XK;T00P0XK;T00<02NX:0:6bi02Q/^@01@2Q/^@K03H0?`030000
003P`[X0h<:j01L0h<:j5P1BGL000`2T/>00000000WZ2P060<UWE@0300WZ2P39IeD0bFME00P0bFME
100000030<UWE@0300WZ2P39IeD0bFME00D0bFME00<02NX:0<UWE@39IeD05`39IeD01@000000/Y2c
0;:@/`2bT;<0000000/0/m3^0`0000050<eG9@030000003=EbD0cELU01H0cELU00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`0N0?ooo`00G@3oool00`000000oooo0?ooo`0X0?ooo`<02NX:
1`3oool300WZ2RD0oooo00<02NX:0?ooo`3oool04`3oool200WZ2P80oooo00<02NX:0?ooo`09jPX0
0P09jPX60?ooo`0300000009jPX0d6@m00<0d6@m00<02NX:0000002Q/^@0102Q/^@00`09jPX0XK;T
0:6bi0080:6bi00300WZ2P2Q/^@0XK;T00D0XK;T6`0f03l00`09jPX000000>32^P0H0>32^QL0DUg0
00<0]eEA00000039IeD01039IeD00`09jPX0bFME0<UWE@060<UWE@<000001`39IeD00`09jPX0bFME
0<UWE@040<UWE@0300WZ2P39IeD0bFME01L0bFME00<000000;:@/`2bT;<00P2bT;<010000000/m3^
0;?@kP09jPX;0;?@kP<000000`3=EbD00`000000cELU0<eG9@0F0<eG9@030000003oool0oooo04X0
oooo00<000000?ooo`3oool07P3oool005d0oooo00<000000?ooo`3oool09@3oool300WZ2PL0oooo
0`09jPXX0?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`09jPX00P09jPX80?ooo`802NX:
00<0000000WZ2P3@I3d00`3@I3d00`000000XK;T0:6bi0030:6bi00300WZ2P2Q/^@0XK;T00h0XK;T
7@0f03l00`000000h<:j0>32^P0H0>32^P030;>jgP1BGL00DUg001D0DUg000<02NX:00000039IeD0
0P39IeD00`09jPX0bFME0<UWE@040<UWE@<000002P39IeD00`09jPX0bFME0<UWE@040<UWE@0300WZ
2P39IeD0bFME01H0bFME00<000000;:@/`2bT;<00`2bT;<00`000000/m3^0;?@kP0?0;?@kP<00000
00<0cELU0000003=EbD05`3=EbD00`000000oooo0?ooo`190?ooo`030000003oool0oooo01h0oooo
001M0?ooo`030000003oool0oooo0280oooo0`09jPX70?ooo`<02NX::P3oool00`09jPX0oooo0?oo
o`0D0?ooo`<02NX:2@3oool300WZ2P80oooo00<000000=1T?@3@I3d00`3@I3d01P000000XK;T0:6b
i02Q/^@02NX:0:6bi0800000302Q/^@N03H0?`030000003P`[X0h<:j01T0h<:j00<0/k[N059M`01B
GL005@1BGL000`09jPX0]eEA00000002000000@0bFME0`00000=0<UWE@0300WZ2P39IeD0bFME00@0
bFME00<02NX:0<UWE@39IeD05@39IeD00`000000/Y2c0;:@/`040;:@/`030000002cd>h0/m3^0180
/m3^0`00000H0<eG9@030000003oool0oooo04P0oooo00<000000?ooo`3oool07P3oool005d0oooo
00<000000?ooo`3oool07`3oool300WZ2PL0oooo0`09jPX]0?ooo`0300WZ2P3oool0oooo0140oooo
1@09jPX70?ooo`@02NX:1@3oool00`000000d6@m0=1T?@020=1T?@0400000009jPX0XK;T00WZ2P80
XK;T0P00000;0:6bi1l0=P0o00<000000>32^P3P`[X06@3P`[X00`2c^]h0DUg0059M`00E059M`003
00WZ2P1BGL0000000080000000@0bFME00000000000000004039IeD00`09jPX0bFME0<UWE@040<UW
E@0300WZ2P39IeD0bFME01D0bFME00<000000;:@/`2bT;<01@2bT;<00`000000/m3^0;?@kP0C0;?@
kP0300000009jPX0000001L0cELU00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0N0?oo
o`00G@3oool00`000000oooo0?ooo`0L0?ooo`<02NX:1`3oool300WZ2S00oooo00<02NX:0?ooo`3o
ool03P3oool300WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0`3oool300WZ2P030?ooo`09jPX0oooo
00H0oooo0P0000020=1T?@802NX:00<0000000WZ2P2Q/^@03@2Q/^@P03H0?`030000003P`[X0h<:j
01/0h<:j401BGL000`09jPX0DUg0059M`003059M`00300WZ2P1BGL00DUg000@000004`39IeD00`09
jPX0bFME0<UWE@040<UWE@0300WZ2P39IeD0bFME01@0bFME00<000000;:@/`2bT;<01P2bT;<00`00
0000/m3^0;?@kP020;?@kP0300WZ2P2cd>h0/m3^00l0/m3^00<000000;?@kP0000000P00000@0<eG
9@8000000`3=EbD00`000000oooo0?ooo`160?ooo`030000003oool0oooo01h0oooo001M0?ooo`03
0000003oool0oooo01T0oooo0`09jPX70?ooo`<02NX:<P3oool00`09jPX0oooo0?ooo`0;0?ooo`@0
2NX:103oool00`09jPX0oooo0?ooo`0500WZ2P80oooo0P09jPX70?ooo`80000000<02NX:00000009
jPX00P3@I3d00`0000002NX:0:6bi00<0:6bi200=P0o00<000000>32^P3P`[X0703P`[XF059M`0<0
00000P1BGL000`000000bFME0<UWE@0B0<UWE@0300WZ2P39IeD0bFME00@0bFME00<02NX:0<UWE@39
IeD04`39IeD00`000000/Y2c0;:@/`070;:@/`030000002cd>h0/m3^01D0/m3^00@000000;?@kP2c
d>h0/m3^0`00000=0<eG9@800000103=EbD00`000000oooo0?ooo`150?ooo`030000003oool0oooo
01h0oooo001M0?ooo`030000003oool0oooo01H0oooo0`09jPX70?ooo`<02NX:=@3oool00`09jPX0
oooo0?ooo`080?ooo`<02NX:1`3oool00`09jPX0oooo0?ooo`0300WZ2P@0oooo00<02NX:0?ooo`3o
ool01P3oool300WZ2P<000000P3@I3d00`09jPX0XK;T0:6bi00:0:6bi280=P0o00<000000>32^P3P
`[X0703P`[XA059M`00300WZ2P1BGL0000000080000000<02NX:059M`01BGL000`1BGL000`000000
bFME0<UWE@0A0<UWE@0300WZ2P39IeD0bFME00@0bFME00<02NX:0<UWE@39IeD04P39IeD00`000000
/Y2c0;:@/`080;:@/`030000002cd>h0/m3^01H0/m3^00<000000;?@kP2cd>h00`2cd>h200000180
cELU0P0000160?ooo`030000003oool0oooo01d0oooo001M0?ooo`030000003oool0oooo01<0oooo
0`09jPX70?ooo`<02NX:=`3oool00`09jPX0oooo0?ooo`060?ooo`<02NX:2@3oool400WZ2P030?oo
o`09jPX02NX:00<0oooo00<02NX:0?ooo`3oool00`3oool400WZ2PL0000000<02NX:0=1T?@000000
2P2Q/^@R03H0?`030000003P`[X0h<:j01d0h<:j00<0/k[N059M`01BGL00301BGL04000000<0DUg0
00<02NX:059M`01BGL000`1BGL000`2gEE4000000<UWE@0A0<UWE@0300WZ2P39IeD0bFME00@0bFME
00<02NX:0<UWE@39IeD04P39IeD00`000000/Y2c0;:@/`080;:@/`030000002cd>h0/m3^01L0/m3^
00<000000;?@kP2cd>h0102cd>h300000140cELU00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`0M0?ooo`00G@3oool00`000000oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo00D0oooo0`09
jPXj0?ooo`0300WZ2P3oool0oooo00<0oooo0`09jPX:0?ooo`<02NX:103oool00`09jPX0oooo00WZ
2P0200WZ2P@0oooo0`09jPX20?ooo`P0000000<02NX:0=1T?@000000202Q/^@S03H0?`030000003P
`[X0h<:j01h0h<:j00<0/k[N059M`01BGL002P1BGL04000000D0DUg000<02NX:059M`01BGL00101B
GL000`2gEE4000000<UWE@0@0<UWE@0300WZ2P39IeD0bFME00@0bFME00<02NX:0<UWE@39IeD04@39
IeD00`000000/Y2c0;:@/`090;:@/`030000002cd>h0/m3^01L0/m3^00<000000;?@kP2cd>h01`2c
d>h3000000l0cELU00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0M0?ooo`00G@3oool0
0`000000oooo0?ooo`0G0?ooo`<02NX:?@3oool00`09jPX0oooo0?ooo`0300WZ2PX0oooo1009jPX6
0?ooo`0300WZ2P3oool02NX:00<0oooo0`09jPX20?ooo`802NX:200000001@09jPX000000000003@
I3d0000000D0XK;T900f03l00`000000h<:j0>32^P0O0>32^P030;>jgP1BGL00DUg000H0DUg01000
0003059M`00300WZ2P1BGL00DUg000<0DUg000<02NX:059M`01BGL001@1BGL000`2gEE4000000<UW
E@0?0<UWE@0300WZ2P39IeD0bFME00@0bFME0P00000A0<UWE@030000002bT;<0/Y2c00/0/Y2c00<0
00000;?@kP2cd>h05`2cd>h00`000000/m3^0;?@kP090;?@kP<000003@3=EbD00`000000oooo0?oo
o`110?ooo`030000003oool0oooo01d0oooo001L0?ooo`030000003oool0oooo01D0oooo0`09jPXo
0?ooo`@02NX:2P3oool300WZ2P80oooo00<02NX:0?ooo`3oool01@3oool600WZ2P030?ooo`09jPX0
2NX:00802NX:00<0oooo0000000000001P0000000`09jPX0000000000003000000@0XK;T9@0f03l0
0`000000h<:j0>32^P0P0>32^PD0DUg00`000007059M`00400WZ2P1BGL00DUg000WZ2P80DUg000<0
2NX:059M`01BGL001P1BGL000`2gEE4000000<UWE@0>0<UWE@0300WZ2P39IeD0bFME00@0bFME0P00
000@0<UWE@030000002bT;<0/Y2c00`0/Y2c00<000000;?@kP2cd>h0602cd>h00`000000/m3^0;?@
kP0;0;?@kP800000303=EbD00`000000oooo0?ooo`100?ooo`030000003oool0oooo01d0oooo001L
0?ooo`030000003oool0oooo0180oooo0`09jPY00?ooo`<02NX:2P3oool300WZ2P@0oooo00<02NX:
0?ooo`3oool01@3oool800WZ2P@0oooo2@0000000`09jPX0000000000004000000030:6bi00f03l0
=P0o02@0=P0o00<000000>32^P3P`[X08@3P`[X200WZ2P<000002`1BGL001P09jPX0DUg0059M`009
jPX0DUg000WZ2PT0DUg000<0]eEA00000039IeD03@39IeD00`09jPX0bFME0<UWE@0F0<UWE@030000
002bT;<0/Y2c00`0/Y2c00<000000;?@kP2cd>h06@2cd>h00`000000/m3^0;?@kP0<0;?@kP<00000
2P3=EbD00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01d0oooo001L0?ooo`030000003o
ool0oooo00l0oooo0`09jPXo0?ooo`@02NX:00<0oooo00WZ2P3oool01`3oool300WZ2PD0oooo0P09
jPX60?ooo`D02NX:00<0oooo00WZ2P3oool01P3oool80000000300WZ2P000000000000D000009P0f
03l00`000000h<:j0>32^P0Q0>32^P<000003P1BGL000`09jPX0DUg0059M`002059M`00300WZ2P1B
GL00DUg000P0DUg000<000000<UWE@39IeD03039IeD00`09jPX0bFME0<UWE@0E0<UWE@030000002b
T;<0/Y2c00d0/Y2c00<000000;?@kP2cd>h06P2cd>h00`000000/m3^0;?@kP0>0;?@kP<00000203=
EbD00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01d0oooo001L0?ooo`030000003oool0
oooo00`0oooo0`09jPXo0?ooo`<02NX:1@3oool00`09jPX0oooo0?ooo`030?ooo`<02NX:1`3oool0
0`09jPX0oooo0?ooo`020?ooo`D02NX:0P3oool01009jPX0oooo0?ooo`09jPX60?ooo`P0000000<0
2NX:000000000000100000000`2A^_<0000003H0?`0U03H0?`030000003P`[X0h<:j01h0h<:j0`00
00000`3P`[X0DUg0059M`00;059M`00400WZ2P000000000000WZ2P<0DUg00P09jPX2059M`0800000
1`1BGL000`000000bFME0<UWE@0;0<UWE@0300WZ2P39IeD0bFME01@0bFME00<000000;:@/`2bT;<0
3P2bT;<00`000000/m3^0;?@kP0J0;?@kP030000002cd>h0/m3^0140/m3^0`0000060<eG9@030000
003oool0oooo03d0oooo00<000000?ooo`3oool07@3oool005`0oooo00<000000?ooo`3oool02@3o
ool300WZ2Sl0oooo0`09jPX80?ooo`0300WZ2P3oool0oooo00<02NX:2@3oool00`09jPX0oooo00WZ
2P0400WZ2P030?ooo`09jPX0oooo00<0oooo00@02NX:0?ooo`3oool02NX:1@3oool90000000300WZ
2P000000000000<000000P2A^_<2000002@0=P0o00<000000>32^P3P`[X0703P`[X3000000@0h<:j
00<0F`M4059M`01BGL002@1BGL001@09jPX0DUg00000000000002NX:00<0DUg00P09jPX2059M`080
0000201BGL000`000000bFME0<UWE@0:0<UWE@0300WZ2P39IeD0bFME01<0bFME00<000000;:@/`2b
T;<03`2bT;<00`000000/m3^0;?@kP0K0;?@kP030000002cd>h0/m3^01<0/m3^0P0000050<eG9@03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0703oool005`0oooo00<000000?ooo`3oool0
1P3oool300WZ2Sl0oooo0`09jPX:0?ooo`@02NX:2@3oool700WZ2P<0oooo00<02NX:0?ooo`3oool0
0`3oool01@09jPX0oooo0?ooo`3oool02NX:00<0oooo2@0000000`09jPX0000000000003000000<0
TK[c0P00000S03H0?`030000003P`[X0h<:j01T0h<:j100000070>32^P0305/7A01BGL00DUg000L0
DUg00P09jPX4059M`00300WZ2P1BGL00DUg00080DUg000<02NX:059M`01BGL002`1BGL000`000000
bFME0<UWE@090<UWE@0300WZ2P39IeD0bFME0180bFME00<000000;:@/`2bT;<04@2bT;<00`000000
/m3^0;?@kP0K0;?@kP030000002cd>h0/m3^01@0/m3^0`0000030<eG9@030000003oool0oooo03`0
oooo00<000000?ooo`3oool0703oool005`0oooo00<000000?ooo`3oool00`3oool300WZ2Sl0oooo
0`09jPX;0?ooo`<02NX:203oool400WZ2P040?ooo`09jPX02NX:00WZ2P@0oooo0P09jPX60?ooo`05
00WZ2P3oool0oooo0?ooo`09jPX00`3oool80000000300WZ2P000000000000<00000102A^_<00`00
0000YXNc0000000R03H0?`030000003P`[X0h<:j01H0h<:j0`00000<0>32^PP0DUg000<02NX:059M
`01BGL001@1BGL001@09jPX0DUg0059M`01BGL002NX:00h0DUg000<000000<UWE@39IeD02039IeD0
0`09jPX0bFME0<UWE@0B0<UWE@030000002bT;<0/Y2c0140/Y2c00<000000;?@kP2cd>h0702cd>h0
0`000000/m3^0;?@kP0F0;?@kP<0000000<0cELU0000003oool0?03oool00`000000oooo0?ooo`0L
0?ooo`00G03oool00`000000oooo0?ooo`0300WZ2Sl0oooo0`09jPX:0?ooo`@02NX:0P3oool01009
jPX0oooo00000000000500WZ2P80oooo0`09jPX60?ooo`0300WZ2P3oool0oooo00H0oooo00D02NX:
0?ooo`3oool0oooo00WZ2P020?ooo`T0000000<02NX:0000000000000P000005096jl`030000002V
Qk<000000240=P0o00<000000>32^P3P`[X0503P`[X3000000l0h<:j1`1BGL000`09jPX0DUg0059M
`006059M`00500WZ2P1BGL00DUg0059M`009jPX03P1BGL000`2gEE4000000<UWE@080<UWE@0300WZ
2P39IeD0bFME0140bFME00<000000;:@/`2bT;<04P2bT;<00`000000/m3^0;?@kP0L0;?@kP030000
002cd>h0/m3^008000005`2cd>h4000003/0oooo00<000000?ooo`3oool0703oool005`0oooo00<0
000000WZ2P09jPX0?`3oool300WZ2PX0oooo0`09jPX50?ooo`0300WZ2P3oool0oooo00802NX:103o
ool300WZ2P030?ooo`09jPX0oooo00@0oooo0P09jPX90?ooo`0300WZ2P3oool0oooo0080oooo00<0
2NX:0000000000001`0000001009jPX00000000000000007096jl`040000002VQk<0YXNc000001l0
=P0o00<000000>32^P3P`[X04P3P`[X300000180h<:j1@1BGL0200WZ2PT0DUg000D02NX:059M`01B
GL00DUg000WZ2P0?059M`0030;MED@000000bFME00L0bFME00<02NX:0<UWE@39IeD04039IeD00`00
0000/Y2c0;:@/`0C0;:@/`030000002cd>h0/m3^01d0/m3^00@000000;?@kP00000000006@2cd>h2
000003/0oooo00<000000?ooo`3oool0703oool005X0oooo0P09jPX00`000000oooo0?ooo`0k0?oo
o`@02NX:2P3oool300WZ2PP0oooo00<02NX:0?ooo`3oool00`3oool300WZ2P<0oooo00<02NX:0?oo
o`3oool00`3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0000
000000001P0000001009jPX00000000000000008096jl`040000002VQk<0YXNc000001l0=P0o00<0
00000>32^P3P`[X03`3P`[X3000001D0h<:j101BGL000`09jPX0DUg0059M`009059M`00500WZ2P1B
GL00DUg0059M`009jPX0401BGL000`2gEE4000000<UWE@060<UWE@0300WZ2P39IeD0bFME00l0bFME
00<000000;:@/`2bT;<0502bT;<00`000000/m3^0;?@kP0N0;?@kP030000002cd>h0/m3^01H0/m3^
0`00000m0?ooo`030000003oool0oooo01`0oooo001K0?ooo`030000003oool0oooo03T0oooo0`09
jPX;0?ooo`<02NX:2P3oool01009jPX0oooo0?ooo`3oool300WZ2PD0oooo00<02NX:0?ooo`3oool0
0`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:000000000000
1@0000001009jPX00000000000000009096jl`050000002VQk<0YXNc0:J7/`0000007@0f03l00`00
0000h<:j0>32^P0<0>32^P@00000603P`[X0101K1d@0000000WZ2P09jPX<059M`00500WZ2P1BGL00
DUg0059M`009jPX04@1BGL000`000000bFME0<UWE@050<UWE@0300WZ2P39IeD0bFME00l0bFME00<0
00000;:@/`2bT;<05@2bT;<00`000000/m3^0;?@kP0N0;?@kP030000002cd>h0/m3^0180/m3^0`00
00100?ooo`030000003oool0oooo01`0oooo001K0?ooo`030000003oool0oooo03H0oooo0`09jPX;
0?ooo`<02NX:3@3oool400WZ2PL0oooo00<02NX:0?ooo`3oool00P3oool200WZ2Pd0oooo00@02NX:
0?ooo`3oool0oooo0P0000000`09jPX00000000000040000000300WZ2P000000000000X0TK[c00D0
00000:J7/`2VQk<0YXNc0000000L03H0?`030000003P`[X0h<:j00X0h<:j0`00000L0>32^P0305/7
A009jPX0DUg000d0DUg000@02NX:059M`01BGL002NX:4`1BGL000`000000bFME0<UWE@040<UWE@03
00WZ2P39IeD0bFME00h0bFME00<000000;:@/`2bT;<05P2bT;<00`000000/m3^0;?@kP080;?@kP80
00005@2cd>h00`000000/m3^0;?@kP0?0;?@kP80000000<0/m3^0?ooo`3oool0@03oool00`000000
oooo0?ooo`0L0?ooo`00F`3oool00`000000oooo0?ooo`0c0?ooo`<02NX:2`3oool300WZ2Ph0oooo
0`09jPX80?ooo`0300000009jPX0oooo00<0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo
0?ooo`090000000300WZ2P000000000000/0TK[c0P0000020:J7/`030000000f03l0=P0o01X0=P0o
00<000000>32^P3P`[X01`3P`[X3000001h0h<:j0P09jPX@059M`00300WZ2P1BGL002NX:00@0DUg0
0P09jPX>059M`00300000039IeD0bFME00<0bFME00<02NX:0<UWE@39IeD03@39IeD00`000000/Y2c
0;:@/`0G0;:@/`030000002cd>h0/m3^00P0/m3^0P00000E0;?@kP030000002cd>h0/m3^00`0/m3^
0`0000160?ooo`030000003oool0oooo01/0oooo001K0?ooo`030000003oool0oooo0300oooo0`09
jPX;0?ooo`<02NX:3P3oool300WZ2P030?ooo`09jPX0oooo00P0oooo00<02NX:0000003oool00P3o
ool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0000000P0000000<02NX:0000002A^_<0302A
^_<2000000<0YXNc00<0000003H0?`0f03l0600f03l00`000000h<:j0>32^P050>32^P<00000803P
`[X00`09jPX0h<:j0>32^P0@059M`00300WZ2P1BGL002NX:01D0DUg000<000000<UWE@39IeD00P39
IeD00`09jPX0bFME0<UWE@0<0<UWE@030000002bT;<0/Y2c01P0/Y2c00<000000;?@kP2cd>h0802c
d>h00`000000/m3^0;?@kP080;?@kP<00000B@3oool00`000000oooo0?ooo`0K0?ooo`00F`3oool0
0`000000oooo0?ooo`0]0?ooo`<02NX:2`3oool300WZ2Ph0oooo0`09jPX40?ooo`0300WZ2P3oool0
oooo00X0oooo0P09jPXA0?ooo`0300WZ2P3oool0000000P0000000<02NX:096jl`2A^_<0302A^_<2
000000<0YXNc00<0000003H0?`0f03l05`0f03l00`000000h<:j0>32^P030>32^P<000008P3P`[X0
1009jPX0h<:j0>32^P3P`[X@059M`00300WZ2P1BGL002NX:01H0DUg000<000000<UWE@39IeD00P39
IeD00`09jPX0bFME0<UWE@0;0<UWE@030000002bT;<0/Y2c01P0/Y2c00<000000;?@kP2cd>h02`2c
d>h00`09jPX0/m3^0;?@kP0C0;?@kP030000002cd>h0/m3^00D0/m3^0P0000000`2cd>h0oooo0?oo
o`190?ooo`030000003oool0oooo01/0oooo001K0?ooo`030000003oool0oooo02X0oooo0`09jPX;
0?ooo`<02NX:3@3oool400WZ2PH0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0A
0?ooo`0300WZ2P000000000000L0000000<02NX:096jl`2A^_<03P2A^_<00`000000YXNc0:J7/`02
0:J7/`030000000f03l0=P0o01H0=P0o00<000000>32^P0000000`00000S0>32^P802NX:103P`[X@
059M`00300WZ2P1BGL002NX:01L0DUg000D000000<UWE@39IeD0bFME00WZ2P0<0<UWE@030000002b
T;<0/Y2c01T0/Y2c00<000000;?@kP2cd>h08P2cd>h010000000/m3^0;?@kP2cd>h3000004h0oooo
00<000000?ooo`3oool06`3oool005/0oooo00<000000?ooo`3oool0:03oool200WZ2P/0oooo0`09
jPX=0?ooo`<02NX:2P3oool00`09jPX0oooo0?ooo`080?ooo`802NX:503oool00`09jPX000000000
0005000000802NX:4@2A^_<00`000000YXNc0:J7/`020:J7/`030000000f03l0=P0o01D0=P0o0`00
000V0>32^P0300WZ2P3P`[X0h<:j00@0h<:j401BGL000`09jPX0DUg000WZ2P07059M`00300WZ2P1B
GL00DUg000d0DUg000D0]eEA00000039IeD0bFME00WZ2P0;0<UWE@030000002bT;<0/Y2c01/0/Y2c
00<000000;?@kP2cd>h03@2cd>h2000001<0/m3^0`0000000`2cd>h0oooo0?ooo`1>0?ooo`030000
003oool0oooo01/0oooo001K0?ooo`030000003oool0oooo0340oooo1009jPX=0?ooo`<02NX:3@3o
ool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0000000000001P00
00000`09jPX0TK[c096jl`0?096jl`030000002VQk<0YXNc00<0YXNc00<0000003H0?`0f03l04@0f
03l3000002P0h<:j00<02NX:0000003P`[X01@3P`[X00`3Q]Z/0DUg0059M`00=059M`00300WZ2P1B
GL002NX:01P0DUg000@0]eEA00000039IeD02NX:2P39IeD00`000000/Y2c0;:@/`0L0;:@/`030000
002cd>h0/m3^00`0/m3^00<02NX:0000000000004@2cd>h3000005<0oooo00<000000?ooo`3oool0
6`3oool005/0oooo00<000000?ooo`3oool0;P3oool300WZ2Ph0oooo0`09jPX?0?ooo`0300WZ2P3o
ool0oooo00L0oooo00<02NX:0?ooo`3oool0503oool00`0000002NX:0000000500000003096jl`09
jPX0TK[c0140TK[c00<000000:J7/`2VQk<00`2VQk<00`000000=P0o03H0?`0>03H0?`<000000P0f
03l00`000000h<:j0>32^P0V0>32^P8000001`3P`[X@059M`0802NX:6@1BGL000`000000bFME00WZ
2P0:0<UWE@030000002bT;<0/Y2c01`0/Y2c00<000000;?@kP2cd>h07@2cd>h3000000040;?@kP3o
ool02NX:00000580oooo00<000000?ooo`3oool06`3oool005/0oooo00<000000?ooo`3oool0:`3o
ool300WZ2Ph0oooo0`09jPXB0?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPXF0?ooo`80000000<0
2NX:0000000000000`0000000`2A^_<02NX:096jl`06096jl`800000202A^_<200WZ2P030000002V
Qk<0YXNc00@0YXNc00<0000003H0?`0f03l02P0f03l3000000@0=P0o00<000000>32^P3P`[X0:03P
`[X00`09jPX0h<:j0>32^P050>32^P0300WZ2P1BGL00DUg000d0DUg00P09jPX8059M`00300WZ2P1B
GL00DUg000l0DUg000<0000000WZ2P39IeD02039IeD00`000000/Y2c0;:@/`0M0;:@/`030000002c
d>h0/m3^01/0/m3^0P0000000`2cd>h0oooo0?ooo`020?ooo`0300WZ2P3oool000000540oooo00<0
00000?ooo`3oool06`3oool005X0oooo00<000000?ooo`3oool0:@3oool300WZ2Ph0oooo0`09jPXE
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool05@3oool30000000500WZ2P000000
000000WZ2P0000000P2A^_<00`09jPX0TK[c096jl`05096jl`800000102A^_<600WZ2P030000002V
Qk<0YXNc00@0YXNc00<0000003H0?`0f03l01P0f03l4000000H0=P0o00<000000>32^P3P`[X0:@3P
`[X00`09jPX0h<:j0>32^P050>32^Q00DUg00P09jPXK059M`00300000039IeD0bFME00H0bFME00<0
00000;:@/`2bT;<07P2bT;<00`000000/m3^0;?@kP060;?@kP800000402cd>h3000000030;?@kP3o
ool0oooo00<0oooo00D02NX:0?ooo`3oool0oooo0000001A0?ooo`030000003oool0oooo01X0oooo
001J0?ooo`030000003oool0oooo02H0oooo0`09jPX>0?ooo`<02NX:5`3oool00`09jPX0oooo0?oo
o`030?ooo`802NX:603oool30000000300WZ2P00000000000080000000<0TK[c00WZ2P2A^_<00P2A
^_<<00WZ2PD0TK[c00<000000:J7/`2VQk<01@2VQk<00`000000=P0o03H0?`0203H0?`<000002P0f
03l00`000000h<:j0>32^P0Z0>32^P0300WZ2P3P`[X0h<:j00@0h<:j401BGL0200WZ2Q/0DUg000<0
2NX:00000039IeD01@39IeD00`000000/Y2c0;:@/`0P0;:@/`030000002cd>h0/m3^00D0/m3^0P00
000=0;?@kP<000000`09jPX60?ooo`0300WZ2P3oool0oooo0080oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`0J0?ooo`00FP3oool00`000000oooo0?ooo`0S0?ooo`<02NX:3P3oool3
00WZ2QX0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0G0?ooo`8000001@09jPX0
0`0000002NX:00WZ2P0400WZ2PH0TK[c0`09jPX8096jl`030000002VQk<0YXNc00D0YXNc00<00000
03H0?`0000000P00000<03H0?`030000003P`[X0h<:j02`0h<:j00<02NX:0>32^P3P`[X00`3P`[X@
059M`0802NX:2P1BGL000`09jPX0DUg0059M`00>059M`00300WZ2P1BGL00000000D0bFME00<00000
0;:@/`2bT;<0802bT;<00`000000/m3^0;?@kP0B0;?@kP80000000<0/m3^0?ooo`3oool00`3oool7
00WZ2P@0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0J0?ooo`00FP3oool00`00
0000oooo0?ooo`0P0?ooo`<02NX:3P3oool300WZ2Q`0oooo00<02NX:0?ooo`3oool00P3oool00`09
jPX0oooo0?ooo`0E0?ooo`D02NX:0P0000000`09jPX0TK[c096jl`02096jl`0300WZ2P2A^_<0TK[c
00D0TK[c0`09jPX;096jl`030000002VQk<0YXNc00@0YXNc0`00000>03H0?`030000003P`[X0h<:j
02d0h<:j00<02NX:0>32^P3P`[X00`3P`[X00`3Q]Z/00000059M`00>059M`00300WZ2P1BGL00DUg0
00P0DUg000<02NX:059M`01BGL003P1BGL001009jPX0DUg0059M`00000030<UWE@030000002bT;<0
/Y2c0240/Y2c00<000000;?@kP2cd>h03`2cd>h3000000030;?@kP3oool0oooo00/0oooo1P09jPX0
0`0000002NX:0?ooo`1=0?ooo`030000003oool0oooo01X0oooo001J0?ooo`030000003oool0oooo
01d0oooo0`09jPX=0?ooo`@02NX:7`3oool00`09jPX0oooo0?ooo`0200WZ2Q<0oooo1P09jPX60000
000500WZ2P2A^_<0TK[c096jl`09jPX01@2A^_<300WZ2Ph0TK[c00@000000:J7/`2VQk<0YXNc0`00
00020:J7/`030000000f03l0=P0o00/0=P0o00<000000>32^P3P`[X0;`3P`[X00`09jPX0h<:j0>32
^P030>32^P030000001BGL00DUg000d0DUg000<02NX:059M`01BGL006@1BGL001009jPX0DUg0059M
`01BGL03000002@0/Y2c00<000000;?@kP2cd>h0302cd>h3000000030;?@kP3oool0oooo00h0oooo
00<02NX:0?ooo`3oool0103oool00`0000002NX:00WZ2P0500WZ2TL0oooo00<000000?ooo`3oool0
6P3oool005X0oooo00<000000?ooo`3oool06P3oool300WZ2Pd0oooo0`09jPXS0?ooo`0300WZ2P3o
ool02NX:00l0oooo2P09jPX20?ooo`D0000000D0TK[c00WZ2P2A^_<0TK[c00WZ2P03096jl`<02NX:
4@2A^_<4000000H0YXNc00<0000003H0?`0f03l02P0f03l00`000000h<:j0>32^P0_0>32^P0300WZ
2P3P`[X0h<:j00<0h<:j00<00000059M`01BGL003@1BGL000`09jPX0DUg0059M`00I059M`00700WZ
2P1BGL00DUg0059M`00000002NX:0;:@/`0200000280/Y2c00<000000;?@kP2cd>h02P2cd>h20000
0080/m3^4@3oool00`09jPX0oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo1`09jPY00?oo
o`030000003oool0oooo01X0oooo001J0?ooo`030000003oool0oooo01L0oooo0`09jPX=0?ooo`<0
2NX:9@3oool00`09jPX0oooo00WZ2P0;0?ooo`D02NX:0P3oool400WZ2P80oooo0`09jPX500000080
TK[c00@02NX:096jl`09jPX0TK[c0`09jPXA096jl`@000002@2VQk<00`000000=P0o03H0?`0903H0
?`030000003P`[X0h<:j0340h<:j00<02NX:0>32^P3P`[X00P3P`[X00`09jPX0DUg0059M`00=059M
`00300WZ2P1BGL00DUg001T0DUg000L02NX:059M`000000000000;:@/`09jPX0/Y2c008000008P2b
T;<00`000000/m3^0;?@kP070;?@kP<0000000<0/m3^0?ooo`3oool04P3oool00`09jPX0oooo0?oo
o`060?ooo`030000003oool0oooo00/0oooo1`09jPXi0?ooo`030000003oool0oooo01X0oooo001J
0?ooo`030000003oool0oooo01@0oooo0`09jPX=0?ooo`<02NX::03oool200WZ2PL0oooo1@09jPX4
0?ooo`<02NX:1P3oool6000000@0TK[c1009jPXA096jl`<000000`2A^_<00`000000YXNc0:J7/`08
0:J7/`030000000f03l0=P0o00L0=P0o00<000000>32^P3P`[X0<`3P`[X01P09jPX0h<:j0>32^P3P
`[X0DUg0000000d0DUg00P09jPXK059M`08000000`2bT;<00`09jPX0/Y2c0;:@/`0T0;:@/`030000
002cd>h0/m3^00@0/m3^0P0000000`2cd>h0oooo0?ooo`0200WZ2Q<0oooo00<02NX:0?ooo`3oool0
1`3oool00`000000oooo0?ooo`0A0?ooo`H02NX:<`3oool00`000000oooo0?ooo`0J0?ooo`00FP3o
ool00`000000oooo0?ooo`0B0?ooo`802NX:3@3oool300WZ2RX0oooo0P09jPX30?ooo`D02NX:1P3o
ool300WZ2PX0oooo10000003096jl`@02NX:402A^_<3000000H0TK[c00<000000:J7/`2VQk<0202V
Qk<00`000000=P0o03H0?`0703H0?`030000003P`[X0h<:j03<0h<:j00H02NX:0>32^P3P`[X0h<:j
059M`000000=059M`0802NX:3P1BGL000`000000DUg0059M`009059M`0<00000102bT;<00`09jPX0
/Y2c0;:@/`0S0;:@/`040000002cd>h0/m3^0;?@kP<000001`3oool200WZ2Q40oooo00<02NX:0?oo
o`3oool0203oool00`000000oooo0?ooo`0F0?ooo`L02NX:;@3oool00`000000oooo0?ooo`0I0?oo
o`00FP3oool00`000000oooo0?ooo`0N0?ooo`<02NX:;03oool00`0000002NX:0?ooo`0300WZ2PP0
oooo0`09jPX=0?ooo`<000001009jPX2096jl`0300WZ2P2A^_<0TK[c00`0TK[c0`000009096jl`03
0000002VQk<0YXNc00P0YXNc00<0000003H0?`0f03l01P0f03l00`000000h<:j0>32^P0e0>32^P05
00WZ2P3P`[X0h<:j0>6fZ`0000003@1BGL000`09jPX0DUg000WZ2P0G059M`08000001`2bT;<00`09
jPX0/Y2c0;:@/`0S0;:@/`@0000000<0/m3^0?ooo`3oool02@3oool200WZ2Pl0oooo00<02NX:0?oo
o`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`H02NX:9`3oool00`000000oooo0?ooo`0I0?oo
o`00F@3oool00`000000oooo0?ooo`0L0?ooo`<02NX:;`3oool00`0000002NX:0?ooo`02000000H0
oooo0`09jPX?0?ooo`0400000009jPX0000000WZ2PH0TK[c00<02NX:096jl`2A^_<02@2A^_<30000
00`0TK[c00<000000:J7/`2VQk<02@2VQk<00`000000=P0o03H0?`0403H0?`030000003P`[X0h<:j
03H0h<:j00D02NX:0>32^P3P`[X0hKJ[0000000=059M`00300WZ2P1BGL002NX:01D0DUg00P000009
0;:@/`0300WZ2P2bT;<0/Y2c02<0/Y2c00<000000;?@kP3oool03`3oool200WZ2P`0oooo00<02NX:
0?ooo`3oool02`3oool00`000000oooo0?ooo`0Q0?ooo`H02NX:8@3oool00`000000oooo0?ooo`0I
0?ooo`00F@3oool00`000000oooo0?ooo`0I0?ooo`<02NX:<P3oool00`09jPX0oooo0?ooo`050?oo
o`<02NX:403oool200WZ2P8000001`2A^_<200WZ2PL0TK[c1000000?096jl`030000002VQk<0YXNc
00T0YXNc00<0000003H0?`0f03l0100f03l00`000000h<:j0>32^P0g0>32^P0400WZ2P3P`[X0h<:j
000000d0DUg000<02NX:059M`009jPX0501BGL000`000000DUg00;:@/`090;:@/`0300WZ2P2bT;<0
/Y2c02<0/Y2c00<000000?ooo`3oool04@3oool200WZ2PX0oooo00<02NX:0?ooo`3oool02`3oool0
0`000000oooo0?ooo`0W0?ooo`L02NX:6P3oool00`000000oooo0?ooo`0I0?ooo`00F@3oool00`00
0000oooo0?ooo`0E0?ooo`@02NX:=@3oool00`09jPX0oooo0?ooo`020?ooo`<02NX:403oool300WZ
2P8000001`2A^_<200000003096jl`09jPX0TK[c00<0TK[c0`00000C096jl`030000002VQk<0YXNc
00X0YXNc00<0000003H0?`0f03l00P0f03l00`000000h<:j0>32^P0h0>32^P0400WZ2P3P`[X0h<:j
000000d0DUg000<02NX:059M`009jPX04P1BGL02000000d0/Y2c00<02NX:0;:@/`2bT;<08`2bT;<0
0`000000oooo0?ooo`0B0?ooo`802NX:203oool00`09jPX0oooo0?ooo`0<0?ooo`030000003oool0
oooo02d0oooo1P09jPXD0?ooo`030000003oool0oooo01T0oooo001I0?ooo`030000003oool0oooo
0180oooo0`09jPXi0?ooo`D02NX:403oool300WZ2P<0oooo00<00000096jl`2A^_<01P2A^_<20000
0003096jl`09jPX0TK[c00<000005P2A^_<00`000000YXNc0:J7/`0:0:J7/`050000000f03l0=P0o
03H0?`000000?03P`[X00`09jPX0h<:j0000000=059M`00300WZ2P1BGL002NX:0100DUg00P00000?
0;:@/`0300WZ2P2bT;<0/Y2c02<0/Y2c00<000000?ooo`3oool0503oool200WZ2PH0oooo00<02NX:
0?ooo`3oool03@3oool00`000000oooo0?ooo`0b0?ooo`L02NX:3@3oool00`000000oooo0?ooo`0I
0?ooo`00F@3oool00`000000oooo0?ooo`0?0?ooo`<02NX:>P3oool300WZ2Q40oooo0`09jPX50?oo
o`030000002A^_<0TK[c00T0TK[c0`00000I096jl`800000302VQk<010000000=P0o03H0?`00000m
0>32^P0300WZ2P1BGL00000000X0DUg00P0000001009jPX00000059M`009jPX>059M`0030000001B
GL00/Y2c00l0/Y2c00<02NX:0;:@/`2bT;<08`2bT;<00`000000oooo0?ooo`0F0?ooo`802NX:103o
ool00`09jPX0oooo0?ooo`0>0?ooo`030000003oool0oooo03P0oooo0`09jPX00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01T0oooo001I0?ooo`030000003oool0oooo00`0oooo0`09jPXj
0?ooo`<02NX:00<0oooo00WZ2P3oool03@3oool400WZ2PH0oooo0P000009096jl`<0000000<0TK[c
00WZ2P2A^_<06@2A^_<2000000`0YXNc00<0000003H0?`000000>`3P`[X2000000040>32^P09jPX0
DUg0000000X0DUg00P0000001009jPX00000059M`009jPX<059M`08000004P2bT;<00`09jPX0/Y2c
0;:@/`0S0;:@/`030000003oool0oooo01P0oooo0P09jPX00`3oool02NX:0?ooo`0A0?ooo`030000
003oool0oooo03T0oooo0P0000090?ooo`030000003oool0oooo01T0oooo001I0?ooo`030000003o
ool0oooo00T0oooo0`09jPXj0?ooo`<02NX:0`3oool00`09jPX0oooo0?ooo`0:0?ooo`<02NX:2P3o
ool500000080TK[c10000004096jl`0300WZ2P2A^_<0TK[c01P0TK[c0P00000;0:J7/`802NX:0`00
000j0>32^P8000000P3P`[X00`09jPX00000059M`00;059M`00400WZ2P1BGL00DUg000WZ2PX0DUg0
00<02NX:0000002bT;<01`2bT;<00`09jPX0/Y2c0;:@/`0:0;:@/`0300WZ2P2bT;<0/Y2c0280/Y2c
00<000000?ooo`3oool06P3oool200WZ2Q80oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0H0?ooo`00F@3oool00`000000oooo0?ooo`060?ooo`<02NX:>P3oool300WZ2PH0oooo00<0
2NX:0?ooo`3oool01`3oool300WZ2Q40oooo20000003096jl`0300WZ2P2A^_<0TK[c01P0TK[c0P00
000:0:J7/`0300WZ2P2VQk<0YXNc00<0YXNc1@00000i0>32^P0300WZ2P000000DUg000/0DUg000@0
2NX:059M`01BGL002NX:201BGL020000000300WZ2P2bT;<0/Y2c01@0/Y2c00<02NX:0;:@/`2bT;<0
8P2bT;<00`000000oooo0?ooo`0K0?ooo`<02NX:4@3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo01P0oooo001I0?ooo`030000003oool0oooo00<0oooo0`09jPXj0?ooo`<02NX:2@3o
ool00`09jPX0oooo0?ooo`040?ooo`<02NX:4@3oool3000000H0oooo0P2A^_<30000000400WZ2P00
00000000000001P0TK[c00<000000:J7/`2VQk<01P2VQk<200WZ2PX0YXNc00<0/bd0000000000000
0P00000f0>32^P802NX:2`1BGL001009jPX0DUg0059M`009jPX7059M`0050000001BGL00/Y2c0;:@
/`09jPX05@2bT;<00`09jPX0/Y2c0;:@/`0S0;:@/`030000003oool0oooo01X0oooo00<02NX:0?oo
o`3oool00P09jPX@0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0603oool005P0
oooo00@000000?ooo`3oool0oooo0`09jPXi0?ooo`@02NX:2`3oool00`09jPX0oooo0?ooo`020?oo
o`<02NX:4@3oool3000000h0oooo00@02NX:0?ooo`2A^_<0TK[c2000000@096jl`030000002VQk<0
YXNc00D0YXNc00<02NX:0:J7/`2VQk<03P2VQk<00`2c;@0000000000000300000340h<:j00<00000
00WZ2P1BGL002P1BGL001009jPX0DUg0059M`009jPX5059M`0@02NX:0P2bT;<00`09jPX0/Y2c0;:@
/`030;:@/`0300WZ2P2bT;<0/Y2c00d0/Y2c00<02NX:0;:@/`2bT;<0202bT;<2000001T0/Y2c00<0
00000?ooo`3oool06P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:3`3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo01P0oooo001H0?ooo`0400000009jPX02NX:00WZ2ST0oooo0`09
jPX?0?ooo`0300WZ2P3oool02NX:00802NX:4@3oool300000140oooo00D02NX:0?ooo`3oool0oooo
00WZ2P030?ooo`<0TK[c20000004096jl`8000000`2A^_<00`000000YXNc0:J7/`030:J7/`802NX:
5P2VQk<00`2c;@00000000000002000002d0h<:j00<0000000WZ2P1BGL002P1BGL001@09jPX0DUg0
059M`01BGL002NX:0080DUg00P0000040;:@/`H02NX:4P2bT;<00`09jPX0/Y2c0;:@/`080;:@/`80
00006@2bT;<00`000000oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPX>0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0603oool005L0oooo0P09jPXi0?ooo`<02NX:
4@3oool300WZ2Q00oooo1000000D0?ooo`0400WZ2P3oool02NX:00WZ2PX0oooo102A^_<5000000D0
2NX:00<000000:J7/`2VQk<00P2VQk<00`09jPX0YXNc0:J7/`0J0:J7/`030;<]00000000000000<0
0000:03P`[X00`1BGL00000000WZ2P09059M`00300WZ2P1BGL00DUg00080DUg000@02NX:00000000
0000DUg0202bT;<00`09jPX0/Y2c0;:@/`0300WZ2Q00/Y2c00<02NX:0;:@/`2bT;<08P2bT;<00`00
00002NX:00WZ2P0200WZ2QL0oooo00<02NX:0?ooo`3oool01`3oool200WZ2P`0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`0H0?ooo`00F03oool00`000000oooo0?ooo`0d0?ooo`<0
2NX:403oool500WZ2Pl0oooo0`00000H0?ooo`802NX:2`3oool500WZ2P<0oooo102A^_<400000080
YXNc0P09jPXQ0:J7/`80/bd01000000T0>32^P030>6fZ`0000002NX:00T0DUg000<02NX:059M`01B
GL000P1BGL000`09jPX0DUg00;:@/`090;:@/`0400WZ2P2bT;<0/Y2c0;:@/`800000402bT;<00`09
jPX0/Y2c0;:@/`0R0;:@/`030000003oool0oooo0080oooo2009jPX?0?ooo`0300WZ2P3oool0oooo
00T0oooo0P09jPX;0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0603oool005P0
oooo00<000000?ooo`3oool0<@3oool300WZ2Q00oooo0`09jPX40?ooo`0300WZ2P3oool0oooo00X0
oooo0`00000J0?ooo`802NX:1`3oool500WZ2Ph0oooo00@0TK[c0000002VQk<02NX:9`2VQk<20;<]
00D00000803P`[X00`000000DUg000WZ2P08059M`00300WZ2P1BGL00DUg00080000000<02NX:0000
000000002@2bT;<00`09jPX0/Y2c0000000C0;:@/`0300WZ2P2bT;<0/Y2c0280/Y2c00<000000?oo
o`3oool02P3oool800WZ2PL0oooo00<02NX:0?ooo`3oool02`3oool200WZ2PX0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0H0?ooo`00F03oool00`000000oooo0?ooo`0^0?ooo`<0
2NX:403oool300WZ2PH0oooo00<02NX:0?ooo`3oool0203oool3000001`0oooo00@02NX:0?ooo`09
jPX0oooo1P09jPXC0?ooo`<02NX:;@2VQk<20;<]00D000006`3P`[X00`000000DUg000WZ2P08059M
`00300WZ2P00000000000080/Y2c00<02NX:0000000000002P2bT;<00`09jPX0/Y2c0;:@/`0B0;:@
/`0300WZ2P2bT;<0/Y2c02<0/Y2c00<000000?ooo`3oool04@3oool800WZ2Pl0oooo0P09jPX90?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool05`3oool005P0oooo00<000000?ooo`3o
ool0:`3oool300WZ2Q00oooo0`09jPX90?ooo`0300WZ2P3oool0oooo00D0oooo0`00000N0?ooo`D0
2NX:5P3oool400WZ2P030000002VQk<0YXNc0340YXNc0P2c;@04000001L0h<:j00@00000059M`01B
GL002NX:1`1BGL000`09jPX0/Y2c0;:@/`020;:@/`0300WZ2P2bT;<0/Y2c00X0/Y2c00<02NX:0;:@
/`2bT;<04`2bT;<00`09jPX0/Y2c0;:@/`0R0;:@/`030000003oool0oooo01L0oooo2@09jPX:0?oo
o`0300WZ2P3oool0oooo00H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0G0?oo
o`00F03oool00`000000oooo0?ooo`0Y0?ooo`802NX:403oool300WZ2P`0oooo00<02NX:0?ooo`3o
ool00P3oool3000001`0oooo1@09jPX30?ooo`0300WZ2P3oool0oooo0180oooo0`09jPX01@3oool0
2NX:00WZ2P3oool0000003P0YXNc00<0/bd00000000000000`00000B0>32^P8000000P1BGL000`09
jPX0DUg0059M`002059M`0<000001@2bT;<00`09jPX0/Y2c0;:@/`080;:@/`0300000009jPX0/Y2c
01@0/Y2c00<02NX:0;:@/`2bT;<08P2bT;<00`000000oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo
00H0oooo2009jPX30?ooo`802NX:1`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
01L0oooo001H0?ooo`030000003oool0oooo03P0oooo0`09jPX>0?ooo`0300WZ2P3oool0000000<0
00006P3oool500WZ2P030?ooo`09jPX02NX:00D0oooo00<02NX:0?ooo`3oool03`3oool300WZ2P<0
oooo00D02NX:0?ooo`3oool0oooo0000000m0:J7/`030;<]000000000000008000003P3P`[X01@00
0000DUg0059M`01BGL002NX:0080DUg00P0000000`2bT;<00000000000050;:@/`0300WZ2P2bT;<0
/Y2c00X0/Y2c00<02NX:0;:@/`2bT;<04P2bT;<00`09jPX0/Y2c0;:@/`0R0;:@/`0300000009jPX0
oooo01L0oooo00<02NX:0?ooo`3oool03P3oool800WZ2PD0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0G0?ooo`00F03oool00`000000oooo0?ooo`0d0?ooo`@02NX:403oool30000
01/0oooo0`09jPX50?ooo`802NX:1P3oool00`09jPX0oooo0?ooo`0;0?ooo`@02NX:103oool200WZ
2P@0oooo00<000000:J7/`2VQk<0?`2VQk<0102c;@00000000000009jPX2000000T0h<:j00<0DUg0
0000001BGL000P1BGL000`09jPX000000;:@/`090;:@/`0300WZ2P2bT;<0/Y2c00X0/Y2c00<02NX:
0;:@/`2bT;<04P2bT;<00`09jPX0/Y2c0;:@/`0R0;:@/`0300000009jPX0oooo01L0oooo00<02NX:
0?ooo`3oool05@3oool700WZ2P030000003oool0oooo03`0oooo00<000000?ooo`3oool05`3oool0
05L0oooo00<000000?ooo`3oool0<P3oool300WZ2Q40oooo0`0000000`09jPX0oooo0?ooo`0K0?oo
o`800000103oool200WZ2PP0oooo00<02NX:0?ooo`3oool0203oool300WZ2PL0oooo00<02NX:0?oo
o`3oool0103oool00`000000YXNc0:J7/`120:J7/`0300WZ2P2VQk<0/bd000@000001P3P`[X01@00
0000DUg0059M`00000002NX:00/0/Y2c00<02NX:0;:@/`2bT;<02P2bT;<00`09jPX0/Y2c0;:@/`0C
0;:@/`0300WZ2P2bT;<0/Y2c0280/Y2c00<0000000WZ2P3oool05@3oool00`09jPX0oooo0?ooo`0H
0?ooo`802NX:103oool00`0000002NX:00WZ2P0400WZ2SL0oooo00<000000?ooo`3oool05`3oool0
05L0oooo00<000000?ooo`3oool0;`3oool300WZ2Q40oooo0`0000030?ooo`0300WZ2P3oool0oooo
0200oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`050?ooo`<02NX:203oool200WZ
2PL0oooo00<000000:J7/`2VQk<0@@2VQk<00`09jPX0YXNc0:J7/`050:J7/`D0000000@0h<:j0000
0000000000000P2bT;<00`09jPX0/Y2c0;:@/`080;:@/`0300WZ2P2bT;<0/Y2c00D0/Y2c00<02NX:
0;:@/`2bT;<00`2bT;<00`09jPX0/Y2c0;:@/`0B0;:@/`0300WZ2P2bT;<0/Y2c0280/Y2c00<00000
00WZ2P3oool05@3oool00`09jPX0oooo0?ooo`0J0?ooo`802NX:0P3oool00`000000oooo0?ooo`04
0?ooo`P02NX:;`3oool00`000000oooo0?ooo`0G0?ooo`00E`3oool00`000000oooo0?ooo`0/0?oo
o`<02NX:4@3oool3000000H0oooo00<02NX:0?ooo`3oool07P3oool200WZ2P/0oooo00<02NX:0?oo
o`3oool00P3oool300WZ2PX0oooo00<02NX:0?ooo`3oool01`3oool00`000000YXNc0:J7/`110:J7
/`0300WZ2P2VQk<0YXNc00X0YXNc100000030;:@/`0300WZ2P2bT;<0/Y2c00P0/Y2c00<02NX:0;:@
/`2bT;<02P2bT;<00`09jPX0/Y2c0;:@/`0B0;:@/`0300WZ2P2bT;<0/Y2c0280/Y2c00<000000?oo
o`09jPX05@3oool00`09jPX0oooo0?ooo`0L0?ooo`802NX:00<0oooo0000003oool0303oool700WZ
2RP0oooo00<000000?ooo`3oool05`3oool005L0oooo00<000000?ooo`3oool0:03oool400WZ2Q00
oooo100000080?ooo`0300WZ2P3oool0oooo01h0oooo00<02NX:0000003oool02`3oool500WZ2P/0
oooo0P09jPX:0?ooo`030000002VQk<0YXNc0440YXNc00<02NX:0:J7/`2VQk<0202VQk<200000004
0259`P000000k=Jn0>cF_P<0000000<02NX:0;:@/`2bT;<0202bT;<00`09jPX0/Y2c0;:@/`0:0;:@
/`0300WZ2P2bT;<0/Y2c0180/Y2c00<02NX:0;:@/`2bT;<08P2bT;<00`000000oooo00WZ2P0E0?oo
o`0300WZ2P3oool0oooo01h0oooo0P09jPX00`000000oooo0?ooo`0A0?ooo`L02NX:8P3oool00`00
0000oooo0?ooo`0F0?ooo`00E`3oool00`000000oooo0?ooo`0U0?ooo`<02NX:4@3oool3000000`0
oooo00<02NX:0?ooo`3oool07P3oool2000000X0oooo0`09jPX>0?ooo`0300WZ2P3oool0oooo00X0
oooo00<000000:J7/`2VQk<0@02VQk<00`09jPX0YXNc0:J7/`080:J7/`050000000QBL808DW20259
`P0000001@3/e[h00`0000002NX:000000080;:@/`0300WZ2P2bT;<0/Y2c00/0/Y2c0P00000C0;:@
/`0300WZ2P2bT;<0/Y2c0240/Y2c00@000000?ooo`3oool02NX:503oool00`09jPX0oooo0?ooo`0P
0?ooo`0300WZ2P000000oooo01P0oooo1`09jPX20?ooo`8000005`3oool00`000000oooo0?ooo`0F
0?ooo`00E`3oool00`000000oooo0?ooo`0R0?ooo`<02NX:4@3oool3000000l0oooo00<02NX:0?oo
o`3oool09`3oool300WZ2P80oooo00<02NX:0?ooo`3oool02P3oool200WZ2Pd0oooo00<000000:J7
/`2VQk<0@02VQk<00`09jPX0YXNc0:J7/`060:J7/`8000001@0QBL800`000000k=Jn0>cF_P030>cF
_P0300WZ2P3/e[h0000000<00000102bT;<00`09jPX0/Y2c0;:@/`0;0;:@/`8000004`2bT;<00`09
jPX0/Y2c0;:@/`0Q0;:@/`040000003oool0oooo00WZ2Q<0oooo00<02NX:0?ooo`3oool08`3oool0
0`0000002NX:0?ooo`0M0?ooo`@02NX:5`3oool00`000000oooo0?ooo`0F0?ooo`00E`3oool00`00
0000oooo0?ooo`0N0?ooo`@02NX:4@3oool300000140oooo00<02NX:0?ooo`3oool0903oool400WZ
2PD0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`0=0?ooo`030000002VQk<0YXNc
03l0YXNc00<02NX:0:J7/`2VQk<01@2VQk<2000000H08DW20P09jPX60>cF_P0400WZ2P3/e[h0k=Jn
0>cF_P@0000000<0/Y2c00WZ2P2bT;<08@2bT;<00`09jPX0/Y2c0;:@/`0R0;:@/`040000003oool0
oooo00WZ2Q80oooo00<02NX:0?ooo`3oool08`3oool00`000000oooo00WZ2P0h0?ooo`030000003o
ool0oooo01H0oooo001G0?ooo`030000003oool0oooo01/0oooo0`09jPXB0?ooo`<00000503oool0
0`09jPX0oooo0?ooo`0Q0?ooo`<02NX:2@3oool00`09jPX0oooo0?ooo`070?ooo`802NX:403oool0
0`000000YXNc0:J7/`0o0:J7/`0300WZ2P2VQk<0YXNc00<0YXNc0P0000090259`P0300000009jPX0
k=Jn00@0k=Jn00<02NX:0>cF_P3/e[h0103/e[h30000000300WZ2P2bT;<0/Y2c01l0/Y2c00<02NX:
0;:@/`2bT;<08P2bT;<010000000oooo0?ooo`09jPXB0?ooo`0300WZ2P3oool0oooo02@0oooo00@0
00000?ooo`09jPX02NX:=P3oool00`000000oooo0?ooo`0F0?ooo`00E`3oool00`000000oooo0?oo
o`0H0?ooo`<02NX:4@3oool4000001H0oooo00<02NX:0?ooo`3oool07`3oool300WZ2P`0oooo00<0
2NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0@0?ooo`030000002VQk<0YXNc03l0YXNc00@0
2NX:0:J7/`2VQk<0YXNc0P00000;0259`P0300000009jPX0k=Jn00D0k=Jn00<02NX:0>cF_P3/e[h0
1P3/e[h00`09jPX0000000000002000001h0/Y2c00<02NX:0;:@/`2bT;<08@2bT;<01@000000oooo
0?ooo`3oool02NX:0140oooo00<02NX:0?ooo`3oool09@3oool00`000000oooo0?ooo`0200WZ2S@0
oooo00<000000?ooo`3oool05P3oool005L0oooo00<000000?ooo`3oool05@3oool300WZ2Q40oooo
0`00000J0?ooo`0300WZ2P3oool0oooo01`0oooo0`09jPX?0?ooo`0300WZ2P3oool0oooo00D0oooo
00<02NX:0?ooo`3oool04@3oool00`000000YXNc0:J7/`0n0:J7/`0500WZ2P2VQk<0YXNc0:J7/`00
00002P0QBL82000000030259`P000000k=Jn00L0k=Jn00<02NX:0>cF_P3/e[h01@3/e[h00`09jPX0
k=Jn0>cF_P05000001/0/Y2c00<02NX:0;:@/`2bT;<08@2bT;<01@000000oooo0?ooo`3oool02NX:
0140oooo00<02NX:0?ooo`3oool09P3oool010000000oooo0?ooo`3oool200WZ2S80oooo00<00000
0?ooo`3oool05P3oool005H0oooo00<000000?ooo`3oool0503oool200WZ2Q40oooo0`00000M0?oo
o`0300WZ2P3oool0oooo01P0oooo1009jPXB0?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPXD0?oo
o`800000?`2VQk<01009jPX0YXNc00000000000;0259`P8000000P0QBL800`000000k=Jn0>cF_P05
0>cF_P0300WZ2P3/e[h0k=Jn00D0k=Jn00<02NX:0>cF_P3/e[h00`3/e[h5000001P0/Y2c00<02NX:
0;:@/`2bT;<08@2bT;<00`000000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:
0?ooo`3oool0:03oool00`000000oooo0?ooo`020?ooo`802NX:<03oool00`000000oooo0?ooo`0F
0?ooo`00EP3oool00`000000oooo0?ooo`0T0?ooo`<000007`3oool00`09jPX0oooo0?ooo`0F0?oo
o`<02NX:5P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01@0oooo0P00000n0:J7
/`0300WZ2P000000000000d08DW200D02NX:0259`P0QBL808DW2000000080>cF_P0300WZ2P3/e[h0
k=Jn00@0k=Jn0P0000050>cF_P0300WZ2P3/e[h0k=Jn00D00000502bT;<00`09jPX0/Y2c0;:@/`0R
0;:@/`030000003oool0oooo0080oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0X
0?ooo`030000003oool0oooo00@0oooo0P09jPX_0?ooo`030000003oool0oooo01D0oooo001F0?oo
o`030000003oool0oooo0240oooo0`00000R0?ooo`0300WZ2P3oool0oooo01<0oooo0`09jPXI0?oo
o`0300WZ2P3oool0oooo00802NX:5`3oool2000003d0YXNc00<0000000WZ2P0QBL803@0QBL800`09
jPX08DW20259`P020259`P030000003/e[h0k=Jn00H0k=Jn00<02NX:0>cF_P3/e[h0103/e[h20000
00D0k=Jn00<02NX:0>cF_P3/e[h00`3/e[h500000180/Y2c00<02NX:0;:@/`2bT;<08@2bT;<00`00
0000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool0:@3oool00`00
0000oooo0?ooo`050?ooo`802NX:;@3oool00`000000oooo0?ooo`0E0?ooo`00EP3oool00`000000
oooo0?ooo`0M0?ooo`@00000903oool00`09jPX0oooo0?ooo`0@0?ooo`@02NX:703oool00`09jPX0
oooo00WZ2P0J0?ooo`030000002VQk<0YXNc03X0YXNc00<000000259`P09jPX03@0QBL800`09jPX0
8DW20259`P030259`P030000003/e[h0k=Jn00L0k=Jn00<02NX:0>cF_P3/e[h02`3/e[h00`09jPX0
k=Jn0>cF_P050>cF_PD000003`2bT;<00`09jPX0/Y2c0;:@/`0Q0;:@/`030000003oool0oooo00<0
oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0Z0?ooo`030000003oool0oooo00H0
oooo0P09jPX[0?ooo`030000003oool0oooo01D0oooo001F0?ooo`030000003oool0oooo01X0oooo
0`00000X0?ooo`0300WZ2P3oool0oooo00d0oooo0`09jPXP0?ooo`802NX:6`3oool00`000000YXNc
0:J7/`0h0:J7/`80000000<08DW200WZ2P0QBL80300QBL800`09jPX08DW20259`P050259`P030000
003/e[h0k=Jn00H0k=Jn00<02NX:0>cF_P3/e[h02`3/e[h00`09jPX0k=Jn0>cF_P090>cF_PD00000
2`2bT;<00`09jPX0/Y2c0;:@/`0Q0;:@/`030000003oool0oooo00<0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0[0?ooo`030000003oool0oooo00L0oooo0P09jPXY0?ooo`030000
003oool0oooo01D0oooo001F0?ooo`030000003oool0oooo01L0oooo0`00000[0?ooo`0300WZ2P3o
ool0oooo00X0oooo0`09jPXR0?ooo`802NX:703oool00`000000YXNc0:J7/`0f0:J7/`8000000`0Q
BL800`09jPX08DW20259`P0:0259`P0300WZ2P0QBL808DW200H08DW200<000000>cF_P3/e[h01`3/
e[h00`09jPX0k=Jn0>cF_P0:0>cF_P0300WZ2P3/e[h0k=Jn00`0k=Jn1@0000080;:@/`0300WZ2P2b
T;<0/Y2c0240/Y2c00<000000?ooo`3oool0103oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3o
ool0oooo02`0oooo00<000000?ooo`3oool02@3oool200WZ2RL0oooo00<000000?ooo`3oool05@3o
ool005H0oooo00<000000?ooo`3oool0503oool3000002d0oooo00<02NX:0?ooo`3oool0203oool3
00WZ2R<0oooo0P09jPX00`3oool02NX:0?ooo`0K0?ooo`030000002VQk<0YXNc03@0YXNc0P000004
0259`P0300WZ2P0QBL808DW200X08DW200<02NX:0259`P0QBL801`0QBL800`000000k=Jn0>cF_P07
0>cF_P0300WZ2P3/e[h0k=Jn00/0k=Jn00<02NX:0>cF_P3/e[h03P3/e[h5000000H0/Y2c00<02NX:
0;:@/`2bT;<0802bT;<00`000000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo02@0oooo00<00000
0?ooo`3oool05@3oool005H0oooo00<000000?ooo`3oool04@3oool300000300oooo00<02NX:0?oo
o`3oool0103oool400WZ2RD0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0L0?ooo`030000002VQk<0
YXNc0380YXNc0P0000000`3oool08DW20259`P030259`P0300WZ2P0QBL808DW200T08DW200<02NX:
0259`P0QBL80200QBL800`000000k=Jn0>cF_P080>cF_P0300WZ2P3/e[h0k=Jn00X0k=Jn00<02NX:
0>cF_P3/e[h03P3/e[h010000000oooo0?ooo`3oool4000000<0/Y2c00<02NX:0;:@/`2bT;<08@2b
T;<00`000000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0:0?ooo`802NX:903oool00`000000oooo0?ooo`0E0?ooo`00EP3oool0
0`000000oooo0?ooo`0>0?ooo`<00000<`3oool01009jPX0oooo0?ooo`3oool300WZ2RL0oooo0P09
jPX40?ooo`0300WZ2P3oool0oooo01X0oooo00<000000:J7/`2VQk<0<@2VQk<010000000oooo0?oo
o`3oool50259`P0300WZ2P0QBL808DW200P08DW200<02NX:0259`P0QBL802@0QBL800`000000k=Jn
0>cF_P090>cF_P0300WZ2P3/e[h0k=Jn00X0k=Jn00<02NX:0>cF_P3/e[h0303/e[h00`000000oooo
0?ooo`050?ooo`@0000000<02NX:0;:@/`2bT;<08@2bT;<00`000000oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0;`3oool00`000000oooo0?ooo`0;0?ooo`802NX:
8P3oool00`000000oooo0?ooo`0E0?ooo`00EP3oool00`000000oooo0?ooo`0:0?ooo`@00000=@3o
ool00`09jPX0oooo00WZ2P0200WZ2RT0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?oo
o`0J0?ooo`030000002VQk<0YXNc02l0YXNc0P0000050?ooo`<08DW200<02NX:0259`P0QBL80200Q
BL800`09jPX08DW20259`P0;0259`P030000003/e[h0k=Jn00P0k=Jn00<02NX:0>cF_P3/e[h02P3/
e[h00`09jPX0k=Jn0>cF_P0<0>cF_P030000003oool0oooo00T0oooo00@02NX:0000000000000000
802bT;<00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0
<@3oool00`000000oooo0?ooo`0<0?ooo`802NX:8@3oool00`000000oooo0?ooo`0D0?ooo`00E@3o
ool00`000000oooo0?ooo`080?ooo`<00000>03oool300WZ2RX0oooo0P09jPX70?ooo`0300WZ2P3o
ool0oooo01X0oooo00<000000:J7/`2VQk<0;@2VQk<2000000P0oooo0P0QBL800`09jPX08DW20259
`P070259`P0300WZ2P0QBL808DW200`08DW200<000000>cF_P3/e[h02@3/e[h00`09jPX0k=Jn0>cF
_P0:0>cF_P0300WZ2P3/e[h0k=Jn00X0k=Jn00<000000?ooo`3oool02P3oool00`09jPX0oooo0?oo
o`04000001d0/Y2c00<000000?ooo`3oool01@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3o
ool0oooo0340oooo00<000000?ooo`3oool03P3oool200WZ2Ql0oooo00<000000?ooo`3oool0503o
ool005D0oooo00<000000?ooo`3oool01@3oool3000003L0oooo1@09jPX[0?ooo`0300WZ2P3oool0
oooo00L0oooo00<02NX:0?ooo`3oool06P3oool00`000000YXNc0:J7/`0[0:J7/`8000002P3oool0
0`2ZO:402NX:0259`P080259`P0300WZ2P0QBL808DW200d08DW200<000000>cF_P3/e[h02@3/e[h0
0`09jPX0k=Jn0>cF_P0:0>cF_P0300WZ2P3/e[h0k=Jn00X0k=Jn00<000000?ooo`3oool02`3oool0
0`09jPX0oooo0?ooo`030?ooo`@000006@2bT;<00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0
oooo00D0oooo00<02NX:0?ooo`3oool0<P3oool00`000000oooo0?ooo`0?0?ooo`802NX:7@3oool0
0`000000oooo0?ooo`0D0?ooo`00E@3oool00`000000oooo0?ooo`020?ooo`<00000=`3oool300WZ
2P@0oooo00<02NX:0?ooo`3oool09`3oool200WZ2PX0oooo00<02NX:0?ooo`3oool06P3oool00`00
0000YXNc0:J7/`0Z0:J7/`030000003oool0oooo00/0oooo00<02NX:0259`P0QBL801@0QBL8200WZ
2Q008DW200<000000>cF_P3/e[h02P3/e[h00`09jPX0k=Jn0>cF_P0:0>cF_P0300WZ2P3/e[h0k=Jn
00P0k=Jn00<000000?ooo`3oool0303oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool00000
00<000005P2bT;<00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?oo
o`3oool0<`3oool00`000000oooo0?ooo`0@0?ooo`802NX:6`3oool00`000000oooo0?ooo`0D0?oo
o`00E@3oool00`000000oooo00000002000003L0oooo0`09jPX70?ooo`0300WZ2P3oool0oooo02H0
oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0J0?ooo`030000002VQk<0YXNc02P0
YXNc0P00000>0?ooo`0300WZ2P0QBL808DW200D08DW200<02NX:0259`P0QBL803`0QBL800`000000
k=Jn0>cF_P0:0>cF_P0300WZ2P3/e[h0k=Jn00X0k=Jn00<02NX:0>cF_P3/e[h0203/e[h00`000000
oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00P3oool4000001@0
/Y2c00<000000?ooo`3oool01P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo03@0
oooo00<000000?ooo`3oool04@3oool200WZ2QT0oooo00<000000?ooo`3oool0503oool005D0oooo
0P00000f0?ooo`@02NX:2@3oool00`09jPX0oooo0?ooo`0U0?ooo`802NX:3@3oool00`09jPX0oooo
0?ooo`0J0?ooo`030000002VQk<0YXNc02H0YXNc0P00000?0?ooo`0300WZ2P3oool0oooo00D08DW2
00<02NX:0259`P0QBL804@0QBL800`000000k=Jn0>cF_P0:0>cF_P0300WZ2P3/e[h0k=Jn00T0k=Jn
00<02NX:0>cF_P3/e[h01`3/e[h00`000000oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00D0oooo
00<02NX:0?ooo`3oool01@3oool400000100/Y2c00<000000?ooo`3oool01P3oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo03H0oooo00<000000?ooo`3oool04P3oool200WZ2QL0oooo
00<000000?ooo`3oool0503oool005L0oooo00<000000?ooo`3oool0<03oool300WZ2Pd0oooo00<0
2NX:0?ooo`3oool0903oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo01X0oooo00<0
00000:J7/`2VQk<0902VQk<20000000300WZ2P3oool0oooo00h0oooo00@02NX:0?ooo`3oool0ZWbQ
0`0QBL800`09jPX08DW20259`P0B0259`P030000003/e[h0k=Jn00X0k=Jn00<02NX:0>cF_P3/e[h0
2P3/e[h00`09jPX0k=Jn0>cF_P060>cF_P030000003oool0oooo00h0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`080?ooo`@000003@2bT;<00`000000oooo0?ooo`070?ooo`0300WZ
2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0=P3oool00`000000oooo0?ooo`0D0?ooo`802NX:
5@3oool00`000000oooo0?ooo`0D0?ooo`00F03oool00`000000oooo0?ooo`0/0?ooo`<02NX:3`3o
ool00`09jPX0oooo0?ooo`0S0?ooo`802NX:403oool00`09jPX0oooo0?ooo`0J0?ooo`030000002V
Qk<0YXNc0280YXNc0P0000020?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool00P3o
ool20259`P0300WZ2P0QBL808DW201<08DW200<000000>cF_P3/e[h02`3/e[h00`09jPX0k=Jn0>cF
_P090>cF_P0300WZ2P3/e[h0k=Jn00D0k=Jn00<000000?ooo`3oool03`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00`0oooo0`00000:0;:@/`030000003oool0oooo00L0oooo00<0
2NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0g0?ooo`030000003oool0oooo01D0oooo00<0
2NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`0D0?ooo`00F@3oool00`000000oooo0?ooo`0X
0?ooo`<02NX:4P3oool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:
0?ooo`3oool06P3oool00`000000YXNc0:J7/`0Q0:J7/`050000003oool0oooo0?ooo`09jPX0403o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P0QBL808DW201@08DW200<000000>cF_P3/e[h0303/
e[h00`09jPX0k=Jn0>cF_P090>cF_P0300WZ2P3/e[h0k=Jn00<0k=Jn00<000000?ooo`3oool0403o
ool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00h0oooo100000060;:@/`030000003o
ool0oooo00P0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0j0?ooo`030000003oool0oooo01D0oooo
0P09jPXC0?ooo`030000003oool0oooo01<0oooo001J0?ooo`030000003oool0oooo02D0oooo0P09
jPXE0?ooo`0300WZ2P3oool0oooo0200oooo0P09jPXC0?ooo`0300WZ2P3oool0oooo01X0oooo00<0
00000:J7/`2VQk<07`2VQk<2000000@0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?oo
o`020?ooo`0300WZ2P3oool08DW201H08DW200<000000>cF_P3/e[h02`3/e[h00`09jPX0k=Jn0>cF
_P090>cF_P0300WZ2P3/e[h0k=Jn00<0k=Jn00<000000?ooo`3oool0403oool00`09jPX0oooo0?oo
o`050?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool0100000040;:@/`030000003o
ool0oooo00L0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0k0?ooo`030000003oool0oooo01H0oooo
0P09jPXA0?ooo`030000003oool0oooo01<0oooo001K0?ooo`800000>`3oool00`09jPX0oooo0?oo
o`0P0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool06P3oool00`000000YXNc0:J7
/`0M0:J7/`8000001@3oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo0080oooo00@0
2NX:0?ooo`3oool0ZWbQ5P0QBL800`000000k=Jn0>cF_P0<0>cF_P0300WZ2P3/e[h0k=Jn00T0k=Jn
00D02NX:0>cF_P3/e[h0k=Jn0000000D0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool03P3oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo0`0000000`2bT;<000000?ooo`090?oo
o`0300WZ2P3oool02NX:03d0oooo00<000000?ooo`3oool05`3oool200WZ2Pl0oooo00<000000?oo
o`3oool04`3oool005d0oooo00<000000?ooo`3oool0>03oool00`09jPX0oooo0?ooo`0N0?ooo`80
2NX:5P3oool00`09jPX0oooo0?ooo`0J0?ooo`030000002VQk<0YXNc01/0YXNc0P0000000`3oool0
2NX:0?ooo`040?ooo`0300WZ2P3oool0oooo00h0oooo00D02NX:0?ooo`3oool0oooo00WZ2P040?oo
oaH08DW200<000000>cF_P3/e[h0303/e[h00`09jPX0k=Jn0>cF_P090>cF_P0500WZ2P3/e[h0k=Jn
0>cF_P000000503oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00d0oooo00D02NX:
0?ooo`3oool0oooo00WZ2P050?ooo`8000002P3oool01009jPX0oooo00WZ2P00000l0?ooo`030000
003oool0oooo01T0oooo0P09jPX=0?ooo`030000003oool0oooo01<0oooo001N0?ooo`030000003o
ool0oooo03L0oooo00<02NX:0?ooo`3oool07@3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3o
ool0oooo01/0oooo00<000000:J7/`2VQk<06P2VQk<01@000000oooo0?ooo`3oool02NX:00D0oooo
00<02NX:0?ooo`3oool03@3oool01@09jPX0oooo0?ooo`3oool02NX:00H0oooo5@0QBL800`000000
k=Jn0>cF_P0=0>cF_P0300WZ2P3/e[h0k=Jn00P0k=Jn00@02NX:0>cF_P3/e[h000005@3oool00`09
jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00h0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0A
0?ooo`0300WZ2P000000000003d0oooo00<000000?ooo`3oool06P3oool2000000/0oooo00<00000
0?ooo`3oool04`3oool005l0oooo00<000000?ooo`3oool0=@3oool00`09jPX0oooo0?ooo`0L0?oo
o`802NX:603oool00`09jPX0oooo0?ooo`0K0?ooo`030000002VQk<0YXNc01P0YXNc0P0000040?oo
o`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool03P3oool01009jPX0oooo0?ooo`09jPX8
0?oooa@08DW200<000000>cF_P3/e[h03@3/e[h00`09jPX0k=Jn0>cF_P090>cF_P0300WZ2P3/e[h0
000001D0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0>0?ooo`0500WZ2P3oool0
oooo0?ooo`09jPX04P3oool00`09jPX0oooo0?ooo`0m0?ooo`030000003oool0oooo01T0oooo0P00
000;0?ooo`030000003oool0oooo01<0oooo001P0?ooo`800000=@3oool00`09jPX0oooo0?ooo`0K
0?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX000000:J7/`0G
0:J7/`8000001@3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:
0?ooo`09jPX02@3oool00`2ZO:408DW20259`P0B0259`P030000003/e[h0k=Jn00d0k=Jn00<02NX:
0>cF_P3/e[h0203/e[h00`09jPX000000?ooo`0F0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:
0?ooo`3oool03@3oool01@09jPX0oooo0?ooo`3oool02NX:0180oooo00<02NX:0?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01<0oooo001R0?ooo`030000003oool0
oooo0340oooo00<02NX:0?ooo`3oool06`3oool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0
oooo01T0oooo00<02NX:0?ooo`0000005P2VQk<2000000L0oooo00<02NX:0?ooo`3oool00P3oool0
0`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool02NX:00/0oooo500QBL800`000000k=Jn0>cF_P0=
0>cF_P0300WZ2P3/e[h0k=Jn00T0k=Jn00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`05
0?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0@
0?ooo`0300WZ2P3oool0oooo03d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0C
0?ooo`00H`3oool00`000000oooo0?ooo`0`0?ooo`0300WZ2P3oool0oooo01T0oooo0P09jPXL0?oo
o`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool00P00000C0:J7/`8000002@3oool00`09
jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00h0oooo0P09jPX=0?oooa<08DW200<000000>cF
_P3/e[h03P3/e[h00`09jPX0k=Jn0>cF_P070>cF_P0300000009jPX0oooo01H0oooo00<02NX:0?oo
o`3oool01@3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?oo
o`3oool0403oool00`09jPX0oooo0?ooo`0n0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool04P3oool006@0oooo00<000000?ooo`3oool0;`3oool00`09jPX0oooo0?ooo`0H0?ooo`03
00WZ2P3oool0oooo01`0oooo00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`020?ooo`03
0000002VQk<0YXNc0100YXNc00<000000?ooo`3oool02@3oool01@09jPX0oooo0?ooo`3oool02NX:
0100oooo0P09jPX?0?oooa808DW200<000000>cF_P3/e[h03`3/e[h00`09jPX0k=Jn0>cF_P060>cF
_P030000003oool02NX:01H0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0=0?oo
o`0500WZ2P3oool0oooo0?ooo`09jPX04`3oool00`09jPX0oooo0?ooo`0n0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool04P3oool006D0oooo00<000000?ooo`3oool0;@3oool00`09
jPX0oooo0?ooo`0G0?ooo`802NX:7`3oool00`09jPX0oooo0?ooo`0E0?ooo`802NX:1@3oool00`00
0000YXNc0:J7/`0>0:J7/`<000002`3oool01@09jPX0oooo0?ooo`3oool02NX:0100oooo00<02NX:
0?ooo`3oool03P3oool00`2ZO:402NX:0259`P0@0259`P030000003/e[h0k=Jn00h0k=Jn00<02NX:
0>cF_P3/e[h01@3/e[h010000000oooo0?ooo`09jPXG0?ooo`8000001P3oool00`09jPX0oooo0?oo
o`0=0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?oo
o`0o0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04P3oool006H0oooo0P00000]
0?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0D
0?ooo`0300WZ2P3oool0oooo00D0oooo00<000000:J7/`2VQk<0302VQk<200000080oooo00<00000
0?ooo`3oool02@3oool01@09jPX0oooo0?ooo`3oool02NX:00l0oooo0P09jPXA0?ooo`0300WZ2P0Q
BL808DW200l08DW200<000000>cF_P3/e[h03`3/e[h00`09jPX0k=Jn0>cF_P040>cF_P050000003o
ool0oooo0?ooo`09jPX05P3oool2000000H0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo
0?ooo`020?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool0?`3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0180oooo001X0?ooo`030000003oool0oooo02T0oooo00<0
2NX:0?ooo`3oool05@3oool200WZ2R80oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?oo
o`060?ooo`030000002VQk<0YXNc00X0YXNc0P0000040?ooo`030000003oool0oooo00P0oooo00D0
2NX:0?ooo`3oool0oooo00WZ2P0?0?ooo`802NX:4P3oool00`09jPX08DW20259`P0?0259`P030000
003/e[h0k=Jn00l0k=Jn0P0000040>cF_P030000003oool0oooo0080oooo00<02NX:0?ooo`3oool0
703oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0
4@3oool00`09jPX0oooo0?ooo`0o0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
4P3oool006T0oooo00<000000?ooo`3oool0:03oool00`09jPX0oooo0?ooo`0D0?ooo`0300WZ2P3o
ool0oooo0280oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`070?ooo`030000002V
Qk<0YXNc00T0YXNc00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`0500WZ2P3o
ool0oooo0?ooo`09jPX03P3oool00`09jPX0oooo00WZ2P0A0?ooo`0300WZ2P3oool0oooo01008DW2
00<000000>cF_P3/e[h03`3/e[h2000000@0k=Jn00<000000?ooo`3oool00P3oool00`09jPX0oooo
0?ooo`0M0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`0A0?ooo`0300WZ2P3oool0oooo03l0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0B0?ooo`00JP3oool00`000000oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo0180oooo0P09
jPXU0?ooo`0300WZ2P3oool0oooo0100oooo0P09jPX:0?ooo`030000002VQk<0YXNc00L0YXNc0P00
00070?ooo`030000003oool0oooo00P0oooo00@02NX:0?ooo`3oool02NX:3P3oool00`09jPX0oooo
00WZ2P0B0?ooo`0400WZ2P3oool0oooo0:YlX@l08DW200<000000>cF_P3/e[h0503/e[h00`000000
oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01`0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool0@03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0180oooo001[0?ooo`8000009P3oool00`09jPX0oooo
0?ooo`0B0?ooo`0300WZ2P3oool0oooo02D0oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo
0?ooo`0:0?ooo`030000002VQk<0YXNc00D0YXNc0P0000090?ooo`030000003oool0oooo00P0oooo
00@02NX:0?ooo`3oool02NX:3@3oool01009jPX0oooo0?ooo`09jPXB0?ooo`0400WZ2P3oool0oooo
0?oooa008DW200<000000>cF_P3/e[h04`3/e[h00`000000oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo01`0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0
oooo0180oooo00<02NX:0?ooo`3oool0@03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0180oooo001]0?ooo`030000003oool0oooo02<0oooo00<02NX:0?ooo`3oool0403oool200WZ
2RP0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0;0?ooo`030000002VQk<0YXNc
00<0YXNc0P00000;0?ooo`030000003oool0oooo00P0oooo00<02NX:0?ooo`09jPX03@3oool01@09
jPX0oooo0?ooo`3oool02NX:0140oooo00<02NX:0?ooo`3oool00`3oool?0259`P030000003/e[h0
k=Jn0180k=Jn00<000000?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0
oooo00`0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0
oooo0440oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0A0?ooo`00KP3oool00`00
0000oooo0?ooo`0Q0?ooo`8000004@3oool00`09jPX0oooo0?ooo`0X0?ooo`0300WZ2P3oool0oooo
00`0oooo0P09jPX>0?ooo`040000002VQk<0YXNc0:J7/`8000003@3oool00`000000oooo0?ooo`08
0?ooo`0300WZ2P3oool02NX:00`0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0B0?ooo`0300WZ2P3o
ool0oooo00@0oooo3P0QBL800`000000k=Jn0>cF_P0A0>cF_P030000003oool0oooo00L0oooo00<0
2NX:0?ooo`3oool0703oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00<0oooo00<0
2NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`100?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool04@3oool006l0oooo00<000000?ooo`3oool0803oool200000100oooo00<02NX:
0?ooo`3oool0:@3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00h0oooo00@00000
0:J7/`2VQk<000003`3oool00`000000oooo0?ooo`080?ooo`0300WZ2P3oool02NX:00/0oooo00<0
2NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo00@0oooo00<0
ZWbQ0259`P0QBL802`0QBL800`000000k=Jn0>cF_P0A0>cF_P030000003oool0oooo00P0oooo00<0
2NX:0?ooo`3oool06`3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00<0oooo00<0
2NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`100?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool04@3oool00700oooo00<000000?ooo`3oool0;`3oool200WZ2R`0oooo00<02NX:
0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0?0?ooo`<00000403oool00`000000oooo0?ooo`07
0?ooo`0300WZ2P3oool02NX:00/0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0?
0?ooo`0300WZ2P3oool0oooo00H0oooo3@0QBL800`000000k=Jn0>cF_P0@0>cF_P030000003oool0
oooo00T0oooo00<02NX:0?ooo`3oool0703oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`110?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool04@3oool00740oooo0P00000^0?ooo`0300WZ2P3oool0oooo
02`0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`0@0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool01`3oool00`09jPX0oooo00WZ2P0:0?ooo`0300WZ2P3oool0oooo
00<0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`070?ooo`d08DW200<000000>cF
_P3/e[h03`3/e[h00`000000oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0?oo
o`3oool0303oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?oo
o`3oool0@@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0140oooo001c0?ooo`03
0000003oool0oooo02T0oooo0P09jPX_0?ooo`0300WZ2P3oool0oooo00L0oooo0P09jPXV0?ooo`03
0000003oool0oooo00L0oooo0P09jPX:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0403oool00`09jPX0oooo0?ooo`080?ooo``08DW200<000000>cF_P3/e[h03P3/e[h00`000000
oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0
oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0@@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0140oooo001d0?ooo`030000003oool0oooo02L0oooo
00<02NX:0?ooo`3oool0;`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo02H0oooo
00<000000?ooo`3oool01`3oool200WZ2PT0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`0@0?ooo`0300WZ2P3oool0oooo00T0oooo00<0ZWbQ0259`P0QBL802@0QBL800`000000k=Jn
0>cF_P0>0>cF_P030000003oool0oooo00/0oooo00<02NX:0?ooo`3oool0703oool00`09jPX0oooo
0?ooo`0;0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0503oool00`09jPX0oooo
0?ooo`110?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04@3oool007D0oooo00<0
00000?ooo`3oool0903oool200WZ2S80oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?oo
o`0W0?ooo`030000003oool0oooo00L0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?oo
o`050?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool02P3oool;0259`P030000003/
e[h0k=Jn00d0k=Jn00<000000?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0K0?ooo`0300WZ2P3o
ool0oooo00/0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3o
ool0oooo0480oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0A0?ooo`00MP3oool0
0`000000oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo0380oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`0X0?ooo`030000003oool0oooo00L0oooo00<02NX:0?ooo`3oool01P3oool0
0`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool02`3oool;
0259`P030000003/e[h0k=Jn00`0k=Jn00<000000?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0K
0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0D
0?ooo`0300WZ2P3oool0oooo0480oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0@
0?ooo`00M`3oool200000200oooo0P09jPXe0?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX[0?oo
o`030000003oool0oooo00H0oooo0P09jPX70?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?oo
o`3oool0403oool00`09jPX0oooo0?ooo`0=0?ooo`X08DW200<000000>cF_P3/e[h02`3/e[h00`00
0000oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool0@`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0100oooo001i0?ooo`030000003oool0oooo01`0
oooo00<02NX:0?ooo`3oool0=@3oool01@09jPX0oooo0?ooo`3oool02NX:02d0oooo00<000000?oo
o`3oool01P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?oo
o`3oool0403oool00`09jPX0oooo0?ooo`0=0?ooo`X08DW200<000000>cF_P3/e[h02`3/e[h00`00
0000oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0100oooo001j0?ooo`030000003oool0oooo01T0
oooo0P09jPXh0?ooo`0400WZ2P3oool0oooo00WZ2Rh0oooo00<000000?ooo`3oool01P3oool00`09
jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool04@3oool00`09
jPX0oooo0?ooo`0>0?ooo`T08DW200<000000>cF_P3/e[h02P3/e[h00`000000oooo0?ooo`0A0?oo
o`0300WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`030?oo
o`0300000009jPX0oooo01D0oooo00<02NX:0?ooo`3oool0@`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0100oooo001k0?ooo`030000003oool0oooo01L0oooo00<02NX:0?ooo`3o
ool0>03oool00`09jPX0oooo00WZ2P0_0?ooo`030000003oool0oooo00D0oooo0P09jPX50?ooo`03
00WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0?0?ooo`P0
8DW200<000000>cF_P3/e[h02P3/e[h00`000000oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo01X0
oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`030?ooo`8000005`3oool00`09jPX0
oooo0?ooo`130?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0403oool007`0oooo
0P00000F0?ooo`0300WZ2P3oool0oooo03T0oooo0P09jPX`0?ooo`030000003oool0oooo00D0oooo
0P09jPX40?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo
0?ooo`0?0?ooo`030:YlX@0QBL808DW200H08DW200<000000>cF_P3/e[h0203/e[h00`000000oooo
0?ooo`0C0?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo
0?ooo`0M0?ooo`0300WZ2P3oool0oooo04<0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0@0?ooo`00OP3oool00`000000oooo0?ooo`0A0?ooo`802NX:>`3oool200WZ2S40oooo00<0
00000?ooo`3oool0103oool00`09jPX0oooo00WZ2P030?ooo`0300WZ2P3oool0oooo00T0oooo00<0
2NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0A0?ooo`P08DW200<000000>cF_P3/e[h0203/
e[h00`000000oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3oool02`3o
ool00`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo04@0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0@0?ooo`00O`3oool00`000000oooo0?ooo`0?0?ooo`0300WZ2P3oool0
oooo03X0oooo00<02NX:0?ooo`09jPX0<@3oool00`000000oooo0?ooo`040?ooo`802NX:0`3oool0
0`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool04P3oool7
0259`P030000003/e[h0k=Jn00L0k=Jn00<000000?ooo`3oool0503oool00`09jPX0oooo0?ooo`0J
0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool07@3oool00`09jPX0oooo0?ooo`13
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0403oool00800oooo00<000000?oo
o`3oool0303oool200WZ2S/0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo02l0oooo00<000000?oo
o`3oool0103oool200WZ2P80oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0B0?oo
o`0300WZ2P3oool0oooo01<0oooo1P0QBL800`000000k=Jn0>cF_P070>cF_P030000003oool0oooo
01D0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo
01d0oooo00<02NX:0?ooo`3oool0A03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00l0oooo00210?ooo`030000003oool0oooo00P0oooo0P0000000`09jPX0oooo0?ooo`0j0?ooo`03
00WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0;`3oool00`000000oooo0?ooo`030?ooo`05
00WZ2P3oool02NX:0?ooo`09jPX03@3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo
01@0oooo00<0ZWbQ0259`P0QBL80100QBL800`000000k=Jn0>cF_P050>cF_P030000003oool0oooo
01H0oooo0P00000K0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool07P3oool00`09
jPX0oooo0?ooo`140?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03`3oool00880
oooo0P0000080?ooo`800000?03oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo02l0
oooo00<000000?ooo`3oool00`3oool01009jPX0oooo00WZ2P09jPX>0?ooo`0300WZ2P3oool0oooo
0140oooo00<02NX:0?ooo`3oool05@3oool60259`P030000003/e[h0k=Jn00D0k=Jn00<000000?oo
o`3oool05P3oool2000001/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0N0?oo
o`0300WZ2P3oool0oooo04D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0?0?oo
o`00Q03oool00`000000oooo0?ooo`120?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0;`3oool00`000000oooo0?ooo`020?ooo`0400WZ2P3oool0oooo00WZ2Ph0oooo00<02NX:0?oo
o`3oool04P3oool00`09jPX0oooo0?ooo`0F0?ooo`D08DW200<000000>cF_P3/e[h0103/e[h00`00
0000oooo0?ooo`0e0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool07P3oool00`09
jPX0oooo0?ooo`140?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03`3oool008D0
oooo00<000000?ooo`3oool0?`3oool200WZ2PL0oooo00<02NX:0?ooo`3oool0;`3oool00`000000
oooo0?ooo`020?ooo`0400WZ2P3oool02NX:00WZ2Ph0oooo00<02NX:0?ooo`3oool04@3oool00`09
jPX0oooo0?ooo`0H0?ooo`@08DW200<000000>cF_P3/e[h00`3/e[h00`000000oooo0?ooo`0f0?oo
o`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool07P3oool00`09jPX0oooo0?ooo`150?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool03`3oool008H0oooo00<000000?ooo`3o
ool0?@3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo02l0oooo00T000000?ooo`3o
ool0oooo00WZ2P3oool02NX:0?ooo`09jPX03@3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3o
ool0oooo01P0oooo00D0ZWbQ0259`P0QBL808DW2000000050>cF_P030000003oool0oooo03H0oooo
00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo04D0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`00Q`3oool2000003`0oooo00<0
2NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0_0?ooo`040000003oool0oooo0?ooo`802NX:
00<0oooo00WZ2P3oool03@3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo01T0oooo
100QBL801@000000k=Jn0>cF_P3/e[h0000003X0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0
oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo04H0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0?0?ooo`00R@3oool00`000000oooo0?ooo`0f0?ooo`80000000<02NX:0?ooo`3oool0
2@3oool00`09jPX0oooo0?ooo`0_0?ooo`050000003oool0oooo00000009jPX00P3oool00`09jPX0
oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool06`3oool30259`P05
0000003/e[h0k=Jn0>cF_P000000>P3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo
0200oooo00<02NX:0?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00l0oooo002:0?ooo`030000003oool0oooo03D0oooo0P00000<0?ooo`0300WZ2P3oool0oooo02l0
oooo00D000000?ooo`3oool02NX:000000020?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool04P3oool00`09jPX0oooo0?ooo`0L0?ooo`808DW200@000000>cF_P3/e[h00000>`3oool0
0`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo01l0oooo00<02NX:0?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00h0oooo002;0?ooo`030000003oool0oooo
0480oooo00<02NX:0?ooo`3oool0;`3oool20000000300WZ2P3oool0oooo0080oooo00<02NX:0?oo
o`3oool02`3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo01`0oooo0P0QBL801000
0000k=Jn0>cF_P00000l0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool0803oool0
0`09jPX0oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool0
08`0oooo00<000000?ooo`3oool0@@3oool00`09jPX0oooo0?ooo`0^0?ooo`<000001@3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool07P3oool0100Q
BL8000000>cF_P00000m0?ooo`802NX:2P3oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P3oool0
oooo04H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`00S@3oool20000
0440oooo00<02NX:0?ooo`3oool0;P3oool00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo
00X0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0O0?ooo`030259`P0000000000
03d0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo
04L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`00S`3oool00`000000
oooo0?ooo`0n0?ooo`0300WZ2P3oool0oooo02h0oooo00<000000?ooo`3oool0103oool00`09jPX0
oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0803oool00`000000
oooo0?ooo`0m0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool08P3oool00`09jPX0
oooo0?ooo`170?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00900oooo
00<000000?ooo`3oool0?@3oool00`09jPX0oooo0?ooo`0^0?ooo`030000003oool0oooo00@0oooo
00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo0640oooo
00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo04L0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`00T@3oool00`000000oooo0?oo
o`0l0?ooo`0300WZ2P3oool0oooo02h0oooo00<000000?ooo`3oool0103oool00`09jPX0oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0H@3oool00`09jPX0oooo0?oo
o`090?ooo`0300WZ2P3oool0oooo0280oooo00<02NX:0?ooo`3oool0A`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00h0oooo002B0?ooo`030000003oool0oooo03/0oooo00<02NX:
0?ooo`3oool0;P3oool00`000000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:
0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`1R0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:
0?ooo`3oool08P3oool00`09jPX0oooo0?ooo`180?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03P3oool009<0oooo0P00000k0?ooo`0300WZ2P3oool0oooo02h0oooo00<000000?oo
o`3oool0103oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?oo
o`3oool0H`3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo02<0oooo00<02NX:0?oo
o`3oool0B03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo002E0?ooo`03
0000003oool0oooo03P0oooo00<02NX:0?ooo`3oool0;P3oool00`000000oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`1S0?ooo`03
00WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool08`3oool00`09jPX0oooo0?ooo`180?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool009H0oooo00<000000?ooo`3oool0
=`3oool00`09jPX0oooo0?ooo`0^0?ooo`030000003oool0oooo00<0oooo00<02NX:0?ooo`3oool0
2@3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo06@0oooo00<02NX:0?ooo`3oool0
203oool00`09jPX0oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo04P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0=0?ooo`00U`3oool00`000000oooo0?ooo`0f0?ooo`0300WZ2P3o
ool0oooo02h0oooo00<000000?ooo`3oool00`3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3o
ool0oooo01<0oooo00<02NX:0?ooo`3oool0I03oool2000000T0oooo00<02NX:0?ooo`3oool08`3o
ool00`09jPX0oooo0?ooo`190?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3o
ool009P0oooo0P00000f0?ooo`0300WZ2P3oool0oooo02h0oooo00<000000?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0I@3oool2
000000T0oooo00<02NX:0?ooo`3oool0903oool00`09jPX0oooo0?ooo`190?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03@3oool009X0oooo00<000000?ooo`3oool0<`3oool00`09
jPX0oooo0?ooo`0^0?ooo`030000003oool0oooo00<0oooo00<02NX:0?ooo`3oool0203oool00`09
jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo0700oooo00<02NX:0?ooo`3oool0903oool00`09
jPX0oooo0?ooo`1:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool009/0
oooo00<000000?ooo`3oool0<P3oool00`09jPX0oooo0?ooo`0^0?ooo`030000003oool0oooo00<0
oooo00<02NX:0?ooo`3oool01`3oool2000001D0oooo00<02NX:0?ooo`3oool0L03oool00`09jPX0
oooo0?ooo`0U0?ooo`0300WZ2P3oool0oooo04T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0=0?ooo`00W03oool00`000000oooo0?ooo`0a0?ooo`0300WZ2P3oool0oooo02h0oooo
00<000000?ooo`3oool00`3oool00`09jPX0oooo0?ooo`070?ooo`800000503oool00`09jPX0oooo
0?ooo`1b0?ooo`0300WZ2P3oool0oooo02D0oooo00<02NX:0?ooo`3oool0B@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00d0oooo002M0?ooo`030000003oool0oooo0300oooo00<0
2NX:0?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01h0oooo00<0
2NX:0?ooo`3oool0LP3oool00`09jPX0oooo0?ooo`0U0?ooo`0300WZ2P3oool0oooo04X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`00WP3oool200000300oooo00<02NX:
0?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01h0oooo00<02NX:
0?ooo`3oool0LP3oool00`09jPX0oooo0?ooo`0V0?ooo`0300WZ2P3oool0oooo04X0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`00X03oool00`000000oooo0?ooo`0]0?oo
o`0300WZ2P3oool0oooo02h0oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0M0?oo
o`0300WZ2P3oool0oooo07<0oooo00<02NX:0?ooo`3oool09P3oool00`09jPX0oooo0?ooo`1;0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00:40oooo00<000000?ooo`3o
ool0;03oool00`09jPX000000?ooo`0^0?ooo`030000003oool0oooo0080oooo00<02NX:0?ooo`3o
ool07@3oool00`09jPX0oooo0?ooo`1c0?ooo`0300WZ2P3oool0oooo02L0oooo0P00001;0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00:80oooo00<000000?ooo`3oool0
:`3oool2000002l0oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0M0?ooo`0300WZ
2P3oool0oooo07@0oooo00<02NX:0?ooo`3oool09P3oool2000004`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0<0?ooo`00X`3oool2000005`0oooo00<000000?ooo`3oool00P3o
ool00`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo07@0oooo0P00001g0?ooo`050000003o
ool0oooo0?ooo`0000003P3oool00:D0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?oo
o`020?ooo`0300WZ2P3oool0oooo01`0oooo00<02NX:0?ooo`3oool0M03oool2000007P0oooo00@0
00000?ooo`3oool000003P3oool00:H0oooo00<000000?ooo`3oool0F03oool01@000000oooo0?oo
o`3oool02NX:01l0oooo00<02NX:0?ooo`3oool0kP3oool010000000oooo0?ooo`00000>0?ooo`00
Y`3oool00`000000oooo0?ooo`1G0?ooo`050000003oool0oooo0?ooo`09jPX07P3oool00`09jPX0
oooo0?ooo`3`0?ooo`040000003oool0oooo000000d0oooo002X0?ooo`030000003oool0oooo05H0
oooo00D000000?ooo`3oool0oooo00WZ2P0N0?ooo`0300WZ2P3oool0oooo0?40oooo00<000000?oo
o`0000003@3oool00:T0oooo0P00001F0?ooo`050000003oool0oooo0?ooo`09jPX07P3oool00`09
jPX0oooo0?ooo`3b0?ooo`8000003@3oool00:/0oooo00<000000?ooo`3oool0D`3oool01@000000
oooo0?ooo`3oool02NX:01d0oooo00<02NX:0?ooo`3oool0lP3oool3000000d0oooo002/0?ooo`03
0000003oool0oooo0580oooo00D000000?ooo`3oool0oooo00WZ2P0M0?ooo`0300WZ2P3oool0oooo
0>h0oooo1000000@0?ooo`00[@3oool00`000000oooo0?ooo`1A0?ooo`040000003oool0oooo00WZ
2Qh0oooo00<02NX:0?ooo`3oool0jP3oool4000001@0oooo002^0?ooo`800000D@3oool010000000
oooo0?ooo`09jPXM0?ooo`0300WZ2P3oool0oooo0>L0oooo1000000H0?ooo`00/03oool00`000000
oooo0?ooo`1>0?ooo`040000003oool0oooo00WZ2Qd0oooo00<02NX:0?ooo`3oool0h`3oool40000
01`0oooo002a0?ooo`030000003oool0oooo04d0oooo00@000000?ooo`3oool02NX:7@3oool00`09
jPX0oooo0?ooo`3O0?ooo`@00000803oool00;80oooo00<000000?ooo`3oool0C03oool010000000
oooo0?ooo`09jPXM0?ooo`0300WZ2P3oool0oooo0=/0oooo1000000T0?ooo`00/`3oool00`000000
oooo0?ooo`1;0?ooo`040000003oool0oooo00WZ2Q`0oooo00<02NX:0?ooo`3oool0f03oool40000
02P0oooo002d0?ooo`800000B`3oool00`000000oooo00WZ2P0M0?ooo`0300WZ2P3oool0oooo0=@0
oooo1000000/0?ooo`00]P3oool00`000000oooo0?ooo`180?ooo`030000003oool02NX:01d0oooo
00<02NX:0?ooo`3oool0d03oool400000300oooo002g0?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`09jPX0703oool00`09jPX0oooo0?ooo`3=0?ooo`@00000=03oool00;P0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo00WZ2P0L0?ooo`0300WZ2P3oool0oooo0<T0oooo1000000h
0?ooo`00^@3oool2000004H0oooo00<000000?ooo`09jPX0703oool00`09jPX0oooo0?ooo`350?oo
o`@00000?03oool00;/0oooo00<000000?ooo`3oool0@`3oool00`000000oooo00WZ2P0K0?ooo`03
00WZ2P3oool0oooo0<80oooo100000100?ooo`00_03oool00`000000oooo0?ooo`120?ooo`030000
003oool02NX:01/0oooo00<02NX:0?ooo`3oool0_P3oool4000004@0oooo002m0?ooo`030000003o
ool0oooo0440oooo00<0000000WZ2P3oool06`3oool00`09jPX0oooo0?ooo`2j0?ooo`@00000B03o
ool00;h0oooo00<000000?ooo`3oool0@03oool00`0000002NX:0?ooo`0J0?ooo`0300WZ2P3oool0
oooo0;L0oooo1000001<0?ooo`00_`3oool200000400oooo00<0000000WZ2P3oool06P3oool00`09
jPX0oooo0?ooo`2b0?ooo`D00000D03oool00<40oooo00<000000?ooo`3oool0?@3oool00`000000
2NX:0?ooo`0J0?ooo`0300WZ2P3oool0oooo0:h0oooo1000001E0?ooo`00`P3oool00`000000oooo
0?ooo`0l0?ooo`0300000009jPX0oooo01T0oooo00<02NX:0?ooo`3oool0Z`3oool4000005T0oooo
00330?ooo`030000003oool0oooo03/0oooo00<0000000WZ2P3oool06@3oool00`09jPX0oooo0?oo
o`2W0?ooo`@00000G@3oool00<@0oooo0P00000k0?ooo`0300WZ2P3oool0oooo01T0oooo00<02NX:
0?ooo`3oool0X`3oool400000640oooo00360?ooo`030000003oool0oooo03P0oooo00<02NX:0?oo
o`3oool0603oool00`09jPX0oooo0?ooo`2P0?ooo`@00000I@3oool00<L0oooo00<000000?ooo`3o
ool0=`3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo09`0oooo1000001Y0?ooo`00
b03oool00`000000oooo0?ooo`0f0?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool0
V03oool4000006d0oooo00390?ooo`030000003oool0oooo03D0oooo00<02NX:0?ooo`3oool05P3o
ool00`0000002NX:0?ooo`2F0?ooo`@00000L@3oool00<X0oooo0P00000e0?ooo`0300WZ2P3oool0
oooo01H0oooo00<0000000WZ2P3oool0TP3oool4000007D0oooo003<0?ooo`030000003oool0oooo
0340oooo00<02NX:0000003oool0Z03oool4000007T0oooo003=0?ooo`030000003oool0oooo0300
oooo00<02NX:0000003oool0Y03oool4000007d0oooo003>0?ooo`030000003oool0oooo02l0oooo
00<02NX:0000003oool0X03oool400000840oooo003?0?ooo`800000;`3oool00`09jPX000000?oo
o`2L0?ooo`@00000Q@3oool00=40oooo00<000000?ooo`3oool0;03oool00`09jPX000000?ooo`2H
0?ooo`@00000R@3oool00=80oooo00<000000?ooo`3oool0:`3oool00`09jPX000000?ooo`2D0?oo
o`@00000S@3oool00=<0oooo00<000000?ooo`3oool0:P3oool00`09jPX000000?ooo`2@0?ooo`@0
0000T@3oool00=@0oooo0P00000Y0?ooo`0300WZ2P3oool0000008d0oooo1000002E0?ooo`00eP3o
ool00`000000oooo0?ooo`0V0?ooo`0300WZ2P3oool0000008T0oooo1000002I0?ooo`00e`3oool0
0`000000oooo0?ooo`0U0?ooo`0300WZ2P3oool0000008D0oooo1000002M0?ooo`00f03oool00`00
0000oooo0?ooo`0T0?ooo`0300WZ2P3oool000000840oooo1000002Q0?ooo`00f@3oool00`000000
oooo0?ooo`0S0?ooo`0300WZ2P3oool0000007d0oooo1000002U0?ooo`00fP3oool2000002<0oooo
00<02NX:0000003oool0N@3oool400000:T0oooo003L0?ooo`030000003oool0oooo01l0oooo00<0
2NX:0?ooo`000000MP3oool400000:d0oooo003M0?ooo`030000003oool0oooo01d0oooo0P000000
0`3oool000000?ooo`1a0?ooo`@00000/@3oool00=h0oooo00<000000?ooo`3oool0703oool20000
00030?ooo`000000oooo06d0oooo1000002e0?ooo`00g`3oool2000001l0oooo00<000000?ooo`3o
ool0J03oool400000;T0oooo003Q0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
I03oool400000;d0oooo003R0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0H03o
ool400000<40oooo003S0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0G03oool4
00000<D0oooo003T0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0F03oool40000
0<T0oooo003U0?ooo`8000006@3oool00`000000oooo0?ooo`1D0?ooo`@00000c@3oool00>L0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1@0?ooo`@00000d@3oool00>P0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`1<0?ooo`@00000e@3oool00>T0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`180?ooo`@00000f@3oool00>X0oooo0P00000D0?oo
o`030000003oool0oooo04<0oooo1@00003M0?ooo`00k03oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo03l0oooo1000003R0?ooo`00k@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo03/0oooo1000003V0?ooo`00kP3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo03L0oooo1000003Z0?ooo`00k`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo03<0oooo1000003^0?ooo`00l03oool2000000h0oooo00<000000?ooo`3oool0;`3oool40000
0?80oooo003b0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0:`3oool400000?H0
oooo003c0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool09`3oool400000?X0oooo
003d0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08`3oool400000?h0oooo003e
0?ooo`8000002@3oool00`000000oooo0?ooo`0O0?ooo`@00000o`3oool30?ooo`00m`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo1000003o0?ooo`L0oooo003h0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool05`3oool400000?l0oooo2`3oool00?T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`@00000o`3oool?0?ooo`00nP3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo1000003o0?oooa<0oooo003k
0?ooo`8000000`3oool00`000000oooo0?ooo`0;0?ooo`@00000o`3ooolG0?ooo`00o@3oool01000
0000oooo0?ooo`0000090?ooo`@00000o`3ooolK0?ooo`00oP3oool00`000000oooo000000050?oo
o`@00000o`3ooolO0?ooo`00o`3oool2000000030?ooo`000000000000800000o`3ooolS0?ooo`00
o`3oool10?ooo`800000o`3ooolW0?ooo`00o`3ooooo0?ooobX0oooo003o0?ooool0oooo:P3oool0
0?l0ooooo`3ooolZ0?ooo`00o`3ooooo0?ooobX0oooo003o0?ooool0oooo:P3oool00?l0ooooo`3o
oolZ0?ooo`00o`3ooooo0?ooobX0oooo003o0?ooool0oooo:P3oool00?l0ooooo`3ooolZ0?ooo`00
o`3ooooo0?ooobX0oooo003o0?ooool0oooo:P3oool00?l0ooooo`3ooolZ0?ooo`00o`3ooooo0?oo
obX0oooo003o0?ooool0oooo:P3oool00?l0ooooo`3ooolZ0?ooo`00o`3ooooo0?ooobX0oooo003o
0?ooool0oooo:P3oool00?l0ooooo`3ooolZ0?ooo`00o`3ooooo0?ooobX0oooo003o0?ooool0oooo
:P3oool00?l0ooooo`3ooolZ0?ooo`00o`3ooooo0?ooobX0oooo003o0?ooool0oooo:P3oool00?l0
ooooo`3ooolZ0?ooo`00o`3ooooo0?ooobX0oooo003o0?ooool0oooo:P3oool00?l0ooooo`3ooolZ
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 551.812}, {549.062, 0}} -> {0.0170137, -2.1764*^-5, \
0.00170103, 0.00170103}},
  CellTags->"CustomPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[stelsys,PlotType->TopView];", "Input",
  CellTags->"CustomPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.595238 0.190476 0.4 0.190476 [
[ 0 0 0 0 ]
[ 1 .8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.77002 .52698 m
.59524 .4 L
.65713 .59048 L
.77002 .52698 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.77002 .52698 m
.59524 .4 L
.65713 .59048 L
.77002 .52698 L
s
.5 g
.77002 .52698 m
.65713 .59048 L
.79552 .4 L
.77002 .52698 L
F
0 g
.77002 .52698 m
.65713 .59048 L
.79552 .4 L
.77002 .52698 L
s
.5 g
.77002 .52698 m
.79552 .4 L
.59524 .4 L
.77002 .52698 L
F
0 g
.77002 .52698 m
.79552 .4 L
.59524 .4 L
.77002 .52698 L
s
.5 g
.52848 .60546 m
.59524 .4 L
.43321 .51772 L
.52848 .60546 L
F
0 g
.52848 .60546 m
.59524 .4 L
.43321 .51772 L
.52848 .60546 L
s
.5 g
.52848 .60546 m
.43321 .51772 L
.65713 .59048 L
.52848 .60546 L
F
0 g
.52848 .60546 m
.43321 .51772 L
.65713 .59048 L
.52848 .60546 L
s
.5 g
.52848 .60546 m
.65713 .59048 L
.59524 .4 L
.52848 .60546 L
F
0 g
.52848 .60546 m
.65713 .59048 L
.59524 .4 L
.52848 .60546 L
s
.5 g
.3792 .4 m
.59524 .4 L
.43321 .28228 L
.3792 .4 L
F
0 g
.3792 .4 m
.59524 .4 L
.43321 .28228 L
.3792 .4 L
s
.5 g
.3792 .4 m
.43321 .28228 L
.43321 .51772 L
.3792 .4 L
F
0 g
.3792 .4 m
.43321 .28228 L
.43321 .51772 L
.3792 .4 L
s
.5 g
.3792 .4 m
.43321 .51772 L
.59524 .4 L
.3792 .4 L
F
0 g
.3792 .4 m
.43321 .51772 L
.59524 .4 L
.3792 .4 L
s
.5 g
.52848 .19454 m
.59524 .4 L
.65713 .20952 L
.52848 .19454 L
F
0 g
.52848 .19454 m
.59524 .4 L
.65713 .20952 L
.52848 .19454 L
s
.5 g
.52848 .19454 m
.65713 .20952 L
.43321 .28228 L
.52848 .19454 L
F
0 g
.52848 .19454 m
.65713 .20952 L
.43321 .28228 L
.52848 .19454 L
s
.5 g
.52848 .19454 m
.43321 .28228 L
.59524 .4 L
.52848 .19454 L
F
0 g
.52848 .19454 m
.43321 .28228 L
.59524 .4 L
.52848 .19454 L
s
.5 g
.77002 .27302 m
.59524 .4 L
.79552 .4 L
.77002 .27302 L
F
0 g
.77002 .27302 m
.59524 .4 L
.79552 .4 L
.77002 .27302 L
s
.5 g
.77002 .27302 m
.79552 .4 L
.65713 .20952 L
.77002 .27302 L
F
0 g
.77002 .27302 m
.79552 .4 L
.65713 .20952 L
.77002 .27302 L
s
.5 g
.77002 .27302 m
.65713 .20952 L
.59524 .4 L
.77002 .27302 L
F
0 g
.77002 .27302 m
.65713 .20952 L
.59524 .4 L
.77002 .27302 L
s
.5 g
.87804 .60546 m
.79552 .4 L
.65713 .59048 L
.87804 .60546 L
F
0 g
.87804 .60546 m
.79552 .4 L
.65713 .59048 L
.87804 .60546 L
s
.5 g
.87804 .60546 m
.65713 .59048 L
.75727 .51772 L
.87804 .60546 L
F
0 g
.87804 .60546 m
.65713 .59048 L
.75727 .51772 L
.87804 .60546 L
s
.5 g
.87804 .60546 m
.75727 .51772 L
.79552 .4 L
.87804 .60546 L
F
0 g
.87804 .60546 m
.75727 .51772 L
.79552 .4 L
.87804 .60546 L
s
.5 g
.48722 .73245 m
.65713 .59048 L
.43321 .51772 L
.48722 .73245 L
F
0 g
.48722 .73245 m
.65713 .59048 L
.43321 .51772 L
.48722 .73245 L
s
.5 g
.48722 .73245 m
.43321 .51772 L
.53335 .59048 L
.48722 .73245 L
F
0 g
.48722 .73245 m
.43321 .51772 L
.53335 .59048 L
.48722 .73245 L
s
.5 g
.48722 .73245 m
.53335 .59048 L
.65713 .59048 L
.48722 .73245 L
F
0 g
.48722 .73245 m
.53335 .59048 L
.65713 .59048 L
.48722 .73245 L
s
.5 g
.24568 .4 m
.43321 .51772 L
.43321 .28228 L
.24568 .4 L
F
0 g
.24568 .4 m
.43321 .51772 L
.43321 .28228 L
.24568 .4 L
s
.5 g
.24568 .4 m
.43321 .28228 L
.39496 .4 L
.24568 .4 L
F
0 g
.24568 .4 m
.43321 .28228 L
.39496 .4 L
.24568 .4 L
s
.5 g
.24568 .4 m
.39496 .4 L
.43321 .51772 L
.24568 .4 L
F
0 g
.24568 .4 m
.39496 .4 L
.43321 .51772 L
.24568 .4 L
s
.5 g
.48722 .06755 m
.43321 .28228 L
.65713 .20952 L
.48722 .06755 L
F
0 g
.48722 .06755 m
.43321 .28228 L
.65713 .20952 L
.48722 .06755 L
s
.5 g
.48722 .06755 m
.65713 .20952 L
.53335 .20952 L
.48722 .06755 L
F
0 g
.48722 .06755 m
.65713 .20952 L
.53335 .20952 L
.48722 .06755 L
s
.5 g
.48722 .06755 m
.53335 .20952 L
.43321 .28228 L
.48722 .06755 L
F
0 g
.48722 .06755 m
.53335 .20952 L
.43321 .28228 L
.48722 .06755 L
s
.5 g
.87804 .19454 m
.65713 .20952 L
.79552 .4 L
.87804 .19454 L
F
0 g
.87804 .19454 m
.65713 .20952 L
.79552 .4 L
.87804 .19454 L
s
.5 g
.87804 .19454 m
.79552 .4 L
.75727 .28228 L
.87804 .19454 L
F
0 g
.87804 .19454 m
.79552 .4 L
.75727 .28228 L
.87804 .19454 L
s
.5 g
.87804 .19454 m
.75727 .28228 L
.65713 .20952 L
.87804 .19454 L
F
0 g
.87804 .19454 m
.75727 .28228 L
.65713 .20952 L
.87804 .19454 L
s
.5 g
.70326 .73245 m
.75727 .51772 L
.65713 .59048 L
.70326 .73245 L
F
0 g
.70326 .73245 m
.75727 .51772 L
.65713 .59048 L
.70326 .73245 L
s
.5 g
.70326 .73245 m
.65713 .59048 L
.53335 .59048 L
.70326 .73245 L
F
0 g
.70326 .73245 m
.65713 .59048 L
.53335 .59048 L
.70326 .73245 L
s
.5 g
.70326 .73245 m
.53335 .59048 L
.75727 .51772 L
.70326 .73245 L
F
0 g
.70326 .73245 m
.53335 .59048 L
.75727 .51772 L
.70326 .73245 L
s
.5 g
.31244 .60546 m
.53335 .59048 L
.43321 .51772 L
.31244 .60546 L
F
0 g
.31244 .60546 m
.53335 .59048 L
.43321 .51772 L
.31244 .60546 L
s
.5 g
.31244 .60546 m
.43321 .51772 L
.39496 .4 L
.31244 .60546 L
F
0 g
.31244 .60546 m
.43321 .51772 L
.39496 .4 L
.31244 .60546 L
s
.5 g
.31244 .60546 m
.39496 .4 L
.53335 .59048 L
.31244 .60546 L
F
0 g
.31244 .60546 m
.39496 .4 L
.53335 .59048 L
.31244 .60546 L
s
.5 g
.31244 .19454 m
.39496 .4 L
.43321 .28228 L
.31244 .19454 L
F
0 g
.31244 .19454 m
.39496 .4 L
.43321 .28228 L
.31244 .19454 L
s
.5 g
.31244 .19454 m
.43321 .28228 L
.53335 .20952 L
.31244 .19454 L
F
0 g
.31244 .19454 m
.43321 .28228 L
.53335 .20952 L
.31244 .19454 L
s
.5 g
.31244 .19454 m
.53335 .20952 L
.39496 .4 L
.31244 .19454 L
F
0 g
.31244 .19454 m
.53335 .20952 L
.39496 .4 L
.31244 .19454 L
s
.5 g
.70326 .06755 m
.53335 .20952 L
.65713 .20952 L
.70326 .06755 L
F
0 g
.70326 .06755 m
.53335 .20952 L
.65713 .20952 L
.70326 .06755 L
s
.5 g
.70326 .06755 m
.65713 .20952 L
.75727 .28228 L
.70326 .06755 L
F
0 g
.70326 .06755 m
.65713 .20952 L
.75727 .28228 L
.70326 .06755 L
s
.5 g
.70326 .06755 m
.75727 .28228 L
.53335 .20952 L
.70326 .06755 L
F
0 g
.70326 .06755 m
.75727 .28228 L
.53335 .20952 L
.70326 .06755 L
s
.5 g
.9448 .4 m
.75727 .28228 L
.79552 .4 L
.9448 .4 L
F
0 g
.9448 .4 m
.75727 .28228 L
.79552 .4 L
.9448 .4 L
s
.5 g
.9448 .4 m
.79552 .4 L
.75727 .51772 L
.9448 .4 L
F
0 g
.9448 .4 m
.79552 .4 L
.75727 .51772 L
.9448 .4 L
s
.5 g
.9448 .4 m
.75727 .51772 L
.75727 .28228 L
.9448 .4 L
F
0 g
.9448 .4 m
.75727 .51772 L
.75727 .28228 L
.9448 .4 L
s
.5 g
.662 .60546 m
.75727 .51772 L
.53335 .59048 L
.662 .60546 L
F
0 g
.662 .60546 m
.75727 .51772 L
.53335 .59048 L
.662 .60546 L
s
.5 g
.662 .60546 m
.53335 .59048 L
.59524 .4 L
.662 .60546 L
F
0 g
.662 .60546 m
.53335 .59048 L
.59524 .4 L
.662 .60546 L
s
.5 g
.662 .60546 m
.59524 .4 L
.75727 .51772 L
.662 .60546 L
F
0 g
.662 .60546 m
.59524 .4 L
.75727 .51772 L
.662 .60546 L
s
.5 g
.42046 .52698 m
.53335 .59048 L
.39496 .4 L
.42046 .52698 L
F
0 g
.42046 .52698 m
.53335 .59048 L
.39496 .4 L
.42046 .52698 L
s
.5 g
.42046 .52698 m
.39496 .4 L
.59524 .4 L
.42046 .52698 L
F
0 g
.42046 .52698 m
.39496 .4 L
.59524 .4 L
.42046 .52698 L
s
.5 g
.42046 .52698 m
.59524 .4 L
.53335 .59048 L
.42046 .52698 L
F
0 g
.42046 .52698 m
.59524 .4 L
.53335 .59048 L
.42046 .52698 L
s
.5 g
.42046 .27302 m
.39496 .4 L
.53335 .20952 L
.42046 .27302 L
F
0 g
.42046 .27302 m
.39496 .4 L
.53335 .20952 L
.42046 .27302 L
s
.5 g
.42046 .27302 m
.53335 .20952 L
.59524 .4 L
.42046 .27302 L
F
0 g
.42046 .27302 m
.53335 .20952 L
.59524 .4 L
.42046 .27302 L
s
.5 g
.42046 .27302 m
.59524 .4 L
.39496 .4 L
.42046 .27302 L
F
0 g
.42046 .27302 m
.59524 .4 L
.39496 .4 L
.42046 .27302 L
s
.5 g
.662 .19454 m
.53335 .20952 L
.75727 .28228 L
.662 .19454 L
F
0 g
.662 .19454 m
.53335 .20952 L
.75727 .28228 L
.662 .19454 L
s
.5 g
.662 .19454 m
.75727 .28228 L
.59524 .4 L
.662 .19454 L
F
0 g
.662 .19454 m
.75727 .28228 L
.59524 .4 L
.662 .19454 L
s
.5 g
.662 .19454 m
.59524 .4 L
.53335 .20952 L
.662 .19454 L
F
0 g
.662 .19454 m
.59524 .4 L
.53335 .20952 L
.662 .19454 L
s
.5 g
.81128 .4 m
.75727 .28228 L
.75727 .51772 L
.81128 .4 L
F
0 g
.81128 .4 m
.75727 .28228 L
.75727 .51772 L
.81128 .4 L
s
.5 g
.81128 .4 m
.75727 .51772 L
.59524 .4 L
.81128 .4 L
F
0 g
.81128 .4 m
.75727 .51772 L
.59524 .4 L
.81128 .4 L
s
.5 g
.81128 .4 m
.59524 .4 L
.75727 .28228 L
.81128 .4 L
F
0 g
.81128 .4 m
.59524 .4 L
.75727 .28228 L
.81128 .4 L
s
.97619 .78095 m
.97619 .01905 L
.97619 .01905 L
.97619 .78095 L
.97619 .78095 L
s
.97619 .01905 m
.21429 .01905 L
.21429 .01905 L
.97619 .01905 L
.97619 .01905 L
s
.21429 .01905 m
.21429 .78095 L
.21429 .78095 L
.21429 .01905 L
.21429 .01905 L
s
.21429 .78095 m
.97619 .78095 L
.97619 .78095 L
.21429 .78095 L
.21429 .78095 L
s
.97619 .01905 m
.97619 .78095 L
.21429 .78095 L
.21429 .01905 L
.97619 .01905 L
s
.97619 .78095 m
.97619 .01905 L
.21429 .01905 L
.21429 .78095 L
.97619 .78095 L
s
.039 .916 .04 r
.02381 .25714 m
.46472 .25714 L
s
0 0 0 r
2 Mabswid
.46472 .25714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .35238 m
.39552 .35238 L
s
0 0 0 r
2 Mabswid
.39552 .35238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .44762 m
.39552 .44762 L
s
0 0 0 r
2 Mabswid
.39552 .44762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25714 m
.37391 .25714 L
s
0 0 0 r
2 Mabswid
.37391 .25714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .35238 m
.39333 .35238 L
s
0 0 0 r
2 Mabswid
.39333 .35238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .44762 m
.39333 .44762 L
s
0 0 0 r
2 Mabswid
.39333 .44762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25714 m
.43996 .25714 L
s
0 0 0 r
2 Mabswid
.43996 .25714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .35238 m
.40567 .35238 L
s
0 0 0 r
2 Mabswid
.40567 .35238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .44762 m
.40567 .44762 L
s
0 0 0 r
2 Mabswid
.40567 .44762 Mdot
.039 .916 .04 r
.5 Mabswid
.46472 .25714 m
.71746 .28016 L
s
0 0 0 r
2 Mabswid
.71746 .28016 Mdot
.039 .916 .04 r
.5 Mabswid
.46472 .25714 m
.49776 .25614 L
s
0 0 0 r
2 Mabswid
.49776 .25614 Mdot
.039 .916 .04 r
.5 Mabswid
.39552 .35238 m
.70962 .38099 L
s
0 0 0 r
2 Mabswid
.70962 .38099 Mdot
.039 .916 .04 r
.5 Mabswid
.39552 .35238 m
.42857 .35138 L
s
0 0 0 r
2 Mabswid
.42857 .35138 Mdot
.039 .916 .04 r
.5 Mabswid
.39552 .44762 m
.70962 .41901 L
s
0 0 0 r
2 Mabswid
.70962 .41901 Mdot
.039 .916 .04 r
.5 Mabswid
.39552 .44762 m
.42857 .44862 L
s
0 0 0 r
2 Mabswid
.42857 .44862 Mdot
.039 .916 .04 r
.5 Mabswid
.37391 .25714 m
.48962 .23909 L
s
0 0 0 r
2 Mabswid
.48962 .23909 Mdot
.039 .916 .04 r
.5 Mabswid
.37391 .25714 m
.21429 .53565 L
s
0 0 0 r
2 Mabswid
.21429 .53565 Mdot
.039 .916 .04 r
.5 Mabswid
.39333 .35238 m
.7789 .53492 L
s
0 0 0 r
2 Mabswid
.7789 .53492 Mdot
.039 .916 .04 r
.5 Mabswid
.39333 .35238 m
.40774 .3358 L
s
0 0 0 r
2 Mabswid
.40774 .3358 Mdot
.039 .916 .04 r
.5 Mabswid
.39333 .44762 m
.7789 .26508 L
s
0 0 0 r
2 Mabswid
.7789 .26508 Mdot
.039 .916 .04 r
.5 Mabswid
.39333 .44762 m
.40774 .4642 L
s
0 0 0 r
2 Mabswid
.40774 .4642 Mdot
.039 .916 .04 r
.5 Mabswid
.43996 .25714 m
.45282 .25793 L
s
0 0 0 r
2 Mabswid
.45282 .25793 Mdot
.039 .916 .04 r
.5 Mabswid
.43996 .25714 m
.21429 .15035 L
s
0 0 0 r
2 Mabswid
.21429 .15035 Mdot
.039 .916 .04 r
.5 Mabswid
.40567 .35238 m
.76693 .35238 L
s
0 0 0 r
2 Mabswid
.76693 .35238 Mdot
.039 .916 .04 r
.5 Mabswid
.40567 .35238 m
.43182 .35238 L
s
0 0 0 r
2 Mabswid
.43182 .35238 Mdot
.039 .916 .04 r
.5 Mabswid
.40567 .44762 m
.76693 .44762 L
s
0 0 0 r
2 Mabswid
.76693 .44762 Mdot
.039 .916 .04 r
.5 Mabswid
.40567 .44762 m
.43182 .44762 L
s
0 0 0 r
2 Mabswid
.43182 .44762 Mdot
.039 .916 .04 r
.5 Mabswid
.71746 .28016 m
.73949 .33371 L
s
0 0 0 r
2 Mabswid
.73949 .33371 Mdot
.039 .916 .04 r
.5 Mabswid
.49776 .25614 m
.69559 .29863 L
s
0 0 0 r
2 Mabswid
.69559 .29863 Mdot
.039 .916 .04 r
.5 Mabswid
.49776 .25614 m
.42384 .01905 L
s
0 0 0 r
2 Mabswid
.42384 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.70962 .38099 m
.73666 .2859 L
s
0 0 0 r
2 Mabswid
.73666 .2859 Mdot
.039 .916 .04 r
.5 Mabswid
.42857 .35138 m
.79257 .42957 L
s
0 0 0 r
2 Mabswid
.79257 .42957 Mdot
.039 .916 .04 r
.5 Mabswid
.42857 .35138 m
.39058 .22953 L
s
0 0 0 r
2 Mabswid
.39058 .22953 Mdot
.039 .916 .04 r
.5 Mabswid
.70962 .41901 m
.73666 .5141 L
s
0 0 0 r
2 Mabswid
.73666 .5141 Mdot
.039 .916 .04 r
.5 Mabswid
.42857 .44862 m
.79257 .37043 L
s
0 0 0 r
2 Mabswid
.79257 .37043 Mdot
.039 .916 .04 r
.5 Mabswid
.42857 .44862 m
.39058 .57047 L
s
0 0 0 r
2 Mabswid
.39058 .57047 Mdot
.039 .916 .04 r
.5 Mabswid
.48962 .23909 m
.75918 .29985 L
s
0 0 0 r
2 Mabswid
.75918 .29985 Mdot
.039 .916 .04 r
.5 Mabswid
.7789 .53492 m
.84728 .56498 L
s
0 0 0 r
2 Mabswid
.84728 .56498 Mdot
.039 .916 .04 r
.5 Mabswid
.40774 .3358 m
.5743 .19158 L
s
0 0 0 r
2 Mabswid
.5743 .19158 Mdot
.039 .916 .04 r
.5 Mabswid
.40774 .3358 m
.21429 .34154 L
s
0 0 0 r
2 Mabswid
.21429 .34154 Mdot
.039 .916 .04 r
.5 Mabswid
.7789 .26508 m
.84728 .23502 L
s
0 0 0 r
2 Mabswid
.84728 .23502 Mdot
.039 .916 .04 r
.5 Mabswid
.40774 .4642 m
.5743 .60842 L
s
0 0 0 r
2 Mabswid
.5743 .60842 Mdot
.039 .916 .04 r
.5 Mabswid
.40774 .4642 m
.21429 .45846 L
s
0 0 0 r
2 Mabswid
.21429 .45846 Mdot
.039 .916 .04 r
.5 Mabswid
.45282 .25793 m
.75037 .28374 L
s
0 0 0 r
2 Mabswid
.75037 .28374 Mdot
.039 .916 .04 r
.5 Mabswid
.76693 .35238 m
.79061 .36333 L
s
0 0 0 r
2 Mabswid
.79061 .36333 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .35238 m
.72603 .35238 L
s
0 0 0 r
2 Mabswid
.72603 .35238 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .35238 m
.32947 .35238 L
s
0 0 0 r
2 Mabswid
.32947 .35238 Mdot
.039 .916 .04 r
.5 Mabswid
.76693 .44762 m
.79061 .43667 L
s
0 0 0 r
2 Mabswid
.79061 .43667 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .44762 m
.72603 .44762 L
s
0 0 0 r
2 Mabswid
.72603 .44762 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .44762 m
.32947 .44762 L
s
0 0 0 r
2 Mabswid
.32947 .44762 Mdot
.039 .916 .04 r
.5 Mabswid
.73949 .33371 m
.75322 .37787 L
s
0 0 0 r
2 Mabswid
.75322 .37787 Mdot
.039 .916 .04 r
.5 Mabswid
.73949 .33371 m
.70595 .26691 L
s
0 0 0 r
2 Mabswid
.70595 .26691 Mdot
.039 .916 .04 r
.5 Mabswid
.69559 .29863 m
.97619 .31826 L
s
0 0 0 r
2 Mabswid
.97619 .31826 Mdot
.039 .916 .04 r
.5 Mabswid
.69559 .29863 m
.61269 .18724 L
s
0 0 0 r
2 Mabswid
.61269 .18724 Mdot
.039 .916 .04 r
.5 Mabswid
.73666 .2859 m
.666 .01905 L
s
0 0 0 r
2 Mabswid
.666 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.73666 .2859 m
.67264 .28107 L
s
0 0 0 r
2 Mabswid
.67264 .28107 Mdot
.039 .916 .04 r
.5 Mabswid
.79257 .42957 m
.95772 .50352 L
s
0 0 0 r
2 Mabswid
.95772 .50352 Mdot
.039 .916 .04 r
.5 Mabswid
.79257 .42957 m
.78433 .43222 L
s
0 0 0 r
2 Mabswid
.78433 .43222 Mdot
.039 .916 .04 r
.5 Mabswid
.39058 .22953 m
.38746 .21059 L
s
0 0 0 r
2 Mabswid
.38746 .21059 Mdot
.039 .916 .04 r
.5 Mabswid
.39058 .22953 m
.32312 .01905 L
s
0 0 0 r
2 Mabswid
.32312 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.73666 .5141 m
.666 .78095 L
s
0 0 0 r
2 Mabswid
.666 .78095 Mdot
.039 .916 .04 r
.5 Mabswid
.73666 .5141 m
.67264 .51893 L
s
0 0 0 r
2 Mabswid
.67264 .51893 Mdot
.039 .916 .04 r
.5 Mabswid
.79257 .37043 m
.95772 .29648 L
s
0 0 0 r
2 Mabswid
.95772 .29648 Mdot
.039 .916 .04 r
.5 Mabswid
.79257 .37043 m
.78433 .36778 L
s
0 0 0 r
2 Mabswid
.78433 .36778 Mdot
.039 .916 .04 r
.5 Mabswid
.39058 .57047 m
.38746 .58941 L
s
0 0 0 r
2 Mabswid
.38746 .58941 Mdot
.039 .916 .04 r
.5 Mabswid
.39058 .57047 m
.32312 .78095 L
s
0 0 0 r
2 Mabswid
.32312 .78095 Mdot
.039 .916 .04 r
.5 Mabswid
.75918 .29985 m
.97619 .40599 L
s
0 0 0 r
2 Mabswid
.97619 .40599 Mdot
.039 .916 .04 r
.5 Mabswid
.75918 .29985 m
.74058 .3062 L
s
0 0 0 r
2 Mabswid
.74058 .3062 Mdot
.039 .916 .04 r
.5 Mabswid
.84728 .56498 m
.83608 .58999 L
s
0 0 0 r
2 Mabswid
.83608 .58999 Mdot
.039 .916 .04 r
.5 Mabswid
.5743 .19158 m
.63589 .14963 L
s
0 0 0 r
2 Mabswid
.63589 .14963 Mdot
.039 .916 .04 r
.5 Mabswid
.84728 .23502 m
.83608 .21001 L
s
0 0 0 r
2 Mabswid
.83608 .21001 Mdot
.039 .916 .04 r
.5 Mabswid
.5743 .60842 m
.63589 .65037 L
s
0 0 0 r
2 Mabswid
.63589 .65037 Mdot
.039 .916 .04 r
.5 Mabswid
.75037 .28374 m
.83352 .29342 L
s
0 0 0 r
2 Mabswid
.83352 .29342 Mdot
.039 .916 .04 r
.5 Mabswid
.79061 .36333 m
.77294 .3768 L
s
0 0 0 r
2 Mabswid
.77294 .3768 Mdot
.039 .916 .04 r
.5 Mabswid
.72603 .35238 m
.76072 .3068 L
s
0 0 0 r
2 Mabswid
.76072 .3068 Mdot
.039 .916 .04 r
.5 Mabswid
.32947 .35238 m
.32577 .35238 L
s
0 0 0 r
2 Mabswid
.32577 .35238 Mdot
.039 .916 .04 r
.5 Mabswid
.32947 .35238 m
.21429 .35238 L
s
0 0 0 r
2 Mabswid
.21429 .35238 Mdot
.039 .916 .04 r
.5 Mabswid
.79061 .43667 m
.77294 .4232 L
s
0 0 0 r
2 Mabswid
.77294 .4232 Mdot
.039 .916 .04 r
.5 Mabswid
.72603 .44762 m
.76072 .4932 L
s
0 0 0 r
2 Mabswid
.76072 .4932 Mdot
.039 .916 .04 r
.5 Mabswid
.32947 .44762 m
.32577 .44762 L
s
0 0 0 r
2 Mabswid
.32577 .44762 Mdot
.039 .916 .04 r
.5 Mabswid
.32947 .44762 m
.21429 .44762 L
s
0 0 0 r
2 Mabswid
.21429 .44762 Mdot
.039 .916 .04 r
.5 Mabswid
.70595 .26691 m
.72066 .26148 L
s
0 0 0 r
2 Mabswid
.72066 .26148 Mdot
.039 .916 .04 r
.5 Mabswid
.61269 .18724 m
.52425 .01905 L
s
0 0 0 r
2 Mabswid
.52425 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.67264 .28107 m
.60801 .30639 L
s
0 0 0 r
2 Mabswid
.60801 .30639 Mdot
.039 .916 .04 r
.5 Mabswid
.67264 .28107 m
.67439 .66283 L
s
0 0 0 r
2 Mabswid
.67439 .66283 Mdot
.039 .916 .04 r
.5 Mabswid
.78433 .43222 m
.75706 .37187 L
s
0 0 0 r
2 Mabswid
.75706 .37187 Mdot
.039 .916 .04 r
.5 Mabswid
.38746 .21059 m
.28446 .15643 L
s
0 0 0 r
2 Mabswid
.28446 .15643 Mdot
.039 .916 .04 r
.5 Mabswid
.67264 .51893 m
.60801 .49361 L
s
0 0 0 r
2 Mabswid
.60801 .49361 Mdot
.039 .916 .04 r
.5 Mabswid
.67264 .51893 m
.67439 .13717 L
s
0 0 0 r
2 Mabswid
.67439 .13717 Mdot
.039 .916 .04 r
.5 Mabswid
.78433 .36778 m
.75706 .42813 L
s
0 0 0 r
2 Mabswid
.75706 .42813 Mdot
.039 .916 .04 r
.5 Mabswid
.38746 .58941 m
.28446 .64357 L
s
0 0 0 r
2 Mabswid
.28446 .64357 Mdot
.039 .916 .04 r
.5 Mabswid
.74058 .3062 m
.6574 .43656 L
s
0 0 0 r
2 Mabswid
.6574 .43656 Mdot
.039 .916 .04 r
.5 Mabswid
.83608 .58999 m
.70353 .78095 L
s
0 0 0 r
2 Mabswid
.70353 .78095 Mdot
.039 .916 .04 r
.5 Mabswid
.83608 .58999 m
.82621 .55687 L
s
0 0 0 r
2 Mabswid
.82621 .55687 Mdot
.039 .916 .04 r
.5 Mabswid
.63589 .14963 m
.6875 .13211 L
s
0 0 0 r
2 Mabswid
.6875 .13211 Mdot
.039 .916 .04 r
.5 Mabswid
.83608 .21001 m
.70353 .01905 L
s
0 0 0 r
2 Mabswid
.70353 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.83608 .21001 m
.82621 .24313 L
s
0 0 0 r
2 Mabswid
.82621 .24313 Mdot
.039 .916 .04 r
.5 Mabswid
.63589 .65037 m
.6875 .66789 L
s
0 0 0 r
2 Mabswid
.6875 .66789 Mdot
.039 .916 .04 r
.5 Mabswid
.83352 .29342 m
.97619 .28515 L
s
0 0 0 r
2 Mabswid
.97619 .28515 Mdot
.039 .916 .04 r
.5 Mabswid
.83352 .29342 m
.81947 .27857 L
s
0 0 0 r
2 Mabswid
.81947 .27857 Mdot
.039 .916 .04 r
.5 Mabswid
.77294 .3768 m
.75507 .40479 L
s
0 0 0 r
2 Mabswid
.75507 .40479 Mdot
.039 .916 .04 r
.5 Mabswid
.76072 .3068 m
.91519 .01905 L
s
0 0 0 r
2 Mabswid
.91519 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.76072 .3068 m
.64755 .3461 L
s
0 0 0 r
2 Mabswid
.64755 .3461 Mdot
.039 .916 .04 r
.5 Mabswid
.32577 .35238 m
.32381 .42943 L
s
0 0 0 r
2 Mabswid
.32381 .42943 Mdot
.039 .916 .04 r
.5 Mabswid
.77294 .4232 m
.75507 .39521 L
s
0 0 0 r
2 Mabswid
.75507 .39521 Mdot
.039 .916 .04 r
.5 Mabswid
.76072 .4932 m
.91519 .78095 L
s
0 0 0 r
2 Mabswid
.91519 .78095 Mdot
.039 .916 .04 r
.5 Mabswid
.76072 .4932 m
.64755 .4539 L
s
0 0 0 r
2 Mabswid
.64755 .4539 Mdot
.039 .916 .04 r
.5 Mabswid
.32577 .44762 m
.32381 .37057 L
s
0 0 0 r
2 Mabswid
.32381 .37057 Mdot
.039 .916 .04 r
.5 Mabswid
.72066 .26148 m
.44702 .51894 L
s
0 0 0 r
2 Mabswid
.44702 .51894 Mdot
.039 .916 .04 r
.5 Mabswid
.60801 .30639 m
.51439 .33449 L
s
0 0 0 r
2 Mabswid
.51439 .33449 Mdot
.039 .916 .04 r
.5 Mabswid
.60801 .30639 m
.68475 .34904 L
s
0 0 0 r
2 Mabswid
.68475 .34904 Mdot
.039 .916 .04 r
.5 Mabswid
.67439 .66283 m
.67119 .68875 L
s
0 0 0 r
2 Mabswid
.67119 .68875 Mdot
.039 .916 .04 r
.5 Mabswid
.75706 .37187 m
.69955 .29065 L
s
0 0 0 r
2 Mabswid
.69955 .29065 Mdot
.039 .916 .04 r
.5 Mabswid
.75706 .37187 m
.68171 .534 L
s
0 0 0 r
2 Mabswid
.68171 .534 Mdot
.039 .916 .04 r
.5 Mabswid
.60801 .49361 m
.51439 .46551 L
s
0 0 0 r
2 Mabswid
.51439 .46551 Mdot
.039 .916 .04 r
.5 Mabswid
.60801 .49361 m
.68475 .45096 L
s
0 0 0 r
2 Mabswid
.68475 .45096 Mdot
.039 .916 .04 r
.5 Mabswid
.67439 .13717 m
.67119 .11125 L
s
0 0 0 r
2 Mabswid
.67119 .11125 Mdot
.039 .916 .04 r
.5 Mabswid
.75706 .42813 m
.69955 .50935 L
s
0 0 0 r
2 Mabswid
.69955 .50935 Mdot
.039 .916 .04 r
.5 Mabswid
.75706 .42813 m
.68171 .266 L
s
0 0 0 r
2 Mabswid
.68171 .266 Mdot
.039 .916 .04 r
.5 Mabswid
.6574 .43656 m
.64673 .4479 L
s
0 0 0 r
2 Mabswid
.64673 .4479 Mdot
.039 .916 .04 r
.5 Mabswid
.6574 .43656 m
.56925 .1565 L
s
0 0 0 r
2 Mabswid
.56925 .1565 Mdot
.039 .916 .04 r
.5 Mabswid
.82621 .55687 m
.68644 .25864 L
s
0 0 0 r
2 Mabswid
.68644 .25864 Mdot
.039 .916 .04 r
.5 Mabswid
.6875 .13211 m
.9442 .01905 L
s
0 0 0 r
2 Mabswid
.9442 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.6875 .13211 m
.67135 .13298 L
s
0 0 0 r
2 Mabswid
.67135 .13298 Mdot
.039 .916 .04 r
.5 Mabswid
.82621 .24313 m
.68644 .54136 L
s
0 0 0 r
2 Mabswid
.68644 .54136 Mdot
.039 .916 .04 r
.5 Mabswid
.6875 .66789 m
.9442 .78095 L
s
0 0 0 r
2 Mabswid
.9442 .78095 Mdot
.039 .916 .04 r
.5 Mabswid
.6875 .66789 m
.67135 .66702 L
s
0 0 0 r
2 Mabswid
.67135 .66702 Mdot
.039 .916 .04 r
.5 Mabswid
.81947 .27857 m
.74464 .22317 L
s
0 0 0 r
2 Mabswid
.74464 .22317 Mdot
.039 .916 .04 r
.5 Mabswid
.75507 .40479 m
.61163 .55325 L
s
0 0 0 r
2 Mabswid
.61163 .55325 Mdot
.039 .916 .04 r
.5 Mabswid
.75507 .40479 m
.75192 .38835 L
s
0 0 0 r
2 Mabswid
.75192 .38835 Mdot
.039 .916 .04 r
.5 Mabswid
.64755 .3461 m
.63359 .39288 L
s
0 0 0 r
2 Mabswid
.63359 .39288 Mdot
.039 .916 .04 r
.5 Mabswid
.32381 .42943 m
.35762 .55947 L
s
0 0 0 r
2 Mabswid
.35762 .55947 Mdot
.039 .916 .04 r
.5 Mabswid
.75507 .39521 m
.61163 .24675 L
s
0 0 0 r
2 Mabswid
.61163 .24675 Mdot
.039 .916 .04 r
.5 Mabswid
.75507 .39521 m
.75192 .41165 L
s
0 0 0 r
2 Mabswid
.75192 .41165 Mdot
.039 .916 .04 r
.5 Mabswid
.64755 .4539 m
.63359 .40712 L
s
0 0 0 r
2 Mabswid
.63359 .40712 Mdot
.039 .916 .04 r
.5 Mabswid
.32381 .37057 m
.35762 .24053 L
s
0 0 0 r
2 Mabswid
.35762 .24053 Mdot
.039 .916 .04 r
.5 Mabswid
.44702 .51894 m
.40248 .56573 L
s
0 0 0 r
2 Mabswid
.40248 .56573 Mdot
.039 .916 .04 r
.5 Mabswid
.51439 .33449 m
.52202 .25263 L
s
0 0 0 r
2 Mabswid
.52202 .25263 Mdot
.039 .916 .04 r
.5 Mabswid
.67119 .68875 m
.70099 .67461 L
s
0 0 0 r
2 Mabswid
.70099 .67461 Mdot
.039 .916 .04 r
.5 Mabswid
.69955 .29065 m
.65117 .2408 L
s
0 0 0 r
2 Mabswid
.65117 .2408 Mdot
.039 .916 .04 r
.5 Mabswid
.68171 .534 m
.72028 .56118 L
s
0 0 0 r
2 Mabswid
.72028 .56118 Mdot
.039 .916 .04 r
.5 Mabswid
.51439 .46551 m
.52202 .54737 L
s
0 0 0 r
2 Mabswid
.52202 .54737 Mdot
.039 .916 .04 r
.5 Mabswid
.67119 .11125 m
.70099 .12539 L
s
0 0 0 r
2 Mabswid
.70099 .12539 Mdot
.039 .916 .04 r
.5 Mabswid
.69955 .50935 m
.65117 .5592 L
s
0 0 0 r
2 Mabswid
.65117 .5592 Mdot
.039 .916 .04 r
.5 Mabswid
.68171 .266 m
.72028 .23882 L
s
0 0 0 r
2 Mabswid
.72028 .23882 Mdot
.039 .916 .04 r
.5 Mabswid
.64673 .4479 m
.5792 .50522 L
s
0 0 0 r
2 Mabswid
.5792 .50522 Mdot
.039 .916 .04 r
.5 Mabswid
.64673 .4479 m
.70101 .48697 L
s
0 0 0 r
2 Mabswid
.70101 .48697 Mdot
.039 .916 .04 r
.5 Mabswid
.56925 .1565 m
.52619 .01905 L
s
0 0 0 r
2 Mabswid
.52619 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.68644 .25864 m
.59794 .2689 L
s
0 0 0 r
2 Mabswid
.59794 .2689 Mdot
.039 .916 .04 r
.5 Mabswid
.67135 .13298 m
.61825 .236 L
s
0 0 0 r
2 Mabswid
.61825 .236 Mdot
.039 .916 .04 r
.5 Mabswid
.68644 .54136 m
.59794 .5311 L
s
0 0 0 r
2 Mabswid
.59794 .5311 Mdot
.039 .916 .04 r
.5 Mabswid
.67135 .66702 m
.61825 .564 L
s
0 0 0 r
2 Mabswid
.61825 .564 Mdot
.039 .916 .04 r
.5 Mabswid
.74464 .22317 m
.52478 .54999 L
s
0 0 0 r
2 Mabswid
.52478 .54999 Mdot
.039 .916 .04 r
.5 Mabswid
.75192 .38835 m
.73845 .31826 L
s
0 0 0 r
2 Mabswid
.73845 .31826 Mdot
.039 .916 .04 r
.5 Mabswid
.63359 .39288 m
.41732 .51232 L
s
0 0 0 r
2 Mabswid
.41732 .51232 Mdot
.039 .916 .04 r
.5 Mabswid
.35762 .55947 m
.37255 .58183 L
s
0 0 0 r
2 Mabswid
.37255 .58183 Mdot
.039 .916 .04 r
.5 Mabswid
.75192 .41165 m
.73845 .48174 L
s
0 0 0 r
2 Mabswid
.73845 .48174 Mdot
.039 .916 .04 r
.5 Mabswid
.63359 .40712 m
.41732 .28768 L
s
0 0 0 r
2 Mabswid
.41732 .28768 Mdot
.039 .916 .04 r
.5 Mabswid
.35762 .24053 m
.37255 .21817 L
s
0 0 0 r
2 Mabswid
.37255 .21817 Mdot
.039 .916 .04 r
.5 Mabswid
.40248 .56573 m
.3816 .53636 L
s
0 0 0 r
2 Mabswid
.3816 .53636 Mdot
.039 .916 .04 r
.5 Mabswid
.52202 .25263 m
.43111 .31303 L
s
0 0 0 r
2 Mabswid
.43111 .31303 Mdot
.039 .916 .04 r
.5 Mabswid
.70099 .67461 m
.80355 .55316 L
s
0 0 0 r
2 Mabswid
.80355 .55316 Mdot
.039 .916 .04 r
.5 Mabswid
.65117 .2408 m
.39175 .34618 L
s
0 0 0 r
2 Mabswid
.39175 .34618 Mdot
.039 .916 .04 r
.5 Mabswid
.52202 .54737 m
.43111 .48697 L
s
0 0 0 r
2 Mabswid
.43111 .48697 Mdot
.039 .916 .04 r
.5 Mabswid
.70099 .12539 m
.80355 .24684 L
s
0 0 0 r
2 Mabswid
.80355 .24684 Mdot
.039 .916 .04 r
.5 Mabswid
.65117 .5592 m
.39175 .45382 L
s
0 0 0 r
2 Mabswid
.39175 .45382 Mdot
.039 .916 .04 r
.5 Mabswid
.5792 .50522 m
.63937 .62627 L
s
0 0 0 r
2 Mabswid
.63937 .62627 Mdot
.039 .916 .04 r
.5 Mabswid
.59794 .2689 m
.48307 .30591 L
s
0 0 0 r
2 Mabswid
.48307 .30591 Mdot
.039 .916 .04 r
.5 Mabswid
.59794 .2689 m
.69463 .298 L
s
0 0 0 r
2 Mabswid
.69463 .298 Mdot
.039 .916 .04 r
.5 Mabswid
.61825 .236 m
.46832 .54851 L
s
0 0 0 r
2 Mabswid
.46832 .54851 Mdot
.039 .916 .04 r
.5 Mabswid
.59794 .5311 m
.48307 .49409 L
s
0 0 0 r
2 Mabswid
.48307 .49409 Mdot
.039 .916 .04 r
.5 Mabswid
.59794 .5311 m
.69463 .502 L
s
0 0 0 r
2 Mabswid
.69463 .502 Mdot
.039 .916 .04 r
.5 Mabswid
.61825 .564 m
.46832 .25149 L
s
0 0 0 r
2 Mabswid
.46832 .25149 Mdot
.039 .916 .04 r
.5 Mabswid
.52478 .54999 m
.29113 .78095 L
s
0 0 0 r
2 Mabswid
.29113 .78095 Mdot
.039 .916 .04 r
.5 Mabswid
.73845 .31826 m
.7374 .31633 L
s
0 0 0 r
2 Mabswid
.7374 .31633 Mdot
.039 .916 .04 r
.5 Mabswid
.41732 .51232 m
.21429 .62007 L
s
0 0 0 r
2 Mabswid
.21429 .62007 Mdot
.039 .916 .04 r
.5 Mabswid
.37255 .58183 m
.39416 .56354 L
s
0 0 0 r
2 Mabswid
.39416 .56354 Mdot
.039 .916 .04 r
.5 Mabswid
.73845 .48174 m
.7374 .48367 L
s
0 0 0 r
2 Mabswid
.7374 .48367 Mdot
.039 .916 .04 r
.5 Mabswid
.41732 .28768 m
.21429 .17993 L
s
0 0 0 r
2 Mabswid
.21429 .17993 Mdot
.039 .916 .04 r
.5 Mabswid
.37255 .21817 m
.39416 .23646 L
s
0 0 0 r
2 Mabswid
.39416 .23646 Mdot
.039 .916 .04 r
.5 Mabswid
.3816 .53636 m
.34933 .43983 L
s
0 0 0 r
2 Mabswid
.34933 .43983 Mdot
.039 .916 .04 r
.5 Mabswid
.43111 .31303 m
.41691 .34476 L
s
0 0 0 r
2 Mabswid
.41691 .34476 Mdot
.039 .916 .04 r
.5 Mabswid
.80355 .55316 m
.80524 .55009 L
s
0 0 0 r
2 Mabswid
.80524 .55009 Mdot
.039 .916 .04 r
.5 Mabswid
.80355 .55316 m
.95769 .78095 L
s
0 0 0 r
2 Mabswid
.95769 .78095 Mdot
.039 .916 .04 r
.5 Mabswid
.39175 .34618 m
.21429 .41217 L
s
0 0 0 r
2 Mabswid
.21429 .41217 Mdot
.039 .916 .04 r
.5 Mabswid
.43111 .48697 m
.41691 .45524 L
s
0 0 0 r
2 Mabswid
.41691 .45524 Mdot
.039 .916 .04 r
.5 Mabswid
.80355 .24684 m
.80524 .24991 L
s
0 0 0 r
2 Mabswid
.80524 .24991 Mdot
.039 .916 .04 r
.5 Mabswid
.80355 .24684 m
.95769 .01905 L
s
0 0 0 r
2 Mabswid
.95769 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.39175 .45382 m
.21429 .38783 L
s
0 0 0 r
2 Mabswid
.21429 .38783 Mdot
.039 .916 .04 r
.5 Mabswid
.63937 .62627 m
.68192 .61894 L
s
0 0 0 r
2 Mabswid
.68192 .61894 Mdot
.039 .916 .04 r
.5 Mabswid
.69463 .298 m
.71503 .24838 L
s
0 0 0 r
2 Mabswid
.71503 .24838 Mdot
.039 .916 .04 r
.5 Mabswid
.46832 .54851 m
.22509 .78095 L
s
0 0 0 r
2 Mabswid
.22509 .78095 Mdot
.039 .916 .04 r
.5 Mabswid
.69463 .502 m
.71503 .55162 L
s
0 0 0 r
2 Mabswid
.71503 .55162 Mdot
.039 .916 .04 r
.5 Mabswid
.46832 .25149 m
.22509 .01905 L
s
0 0 0 r
2 Mabswid
.22509 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.7374 .31633 m
.65246 .34426 L
s
0 0 0 r
2 Mabswid
.65246 .34426 Mdot
.039 .916 .04 r
.5 Mabswid
.7374 .31633 m
.81605 .14654 L
s
0 0 0 r
2 Mabswid
.81605 .14654 Mdot
.039 .916 .04 r
.5 Mabswid
.39416 .56354 m
.4616 .50794 L
s
0 0 0 r
2 Mabswid
.4616 .50794 Mdot
.039 .916 .04 r
.5 Mabswid
.7374 .48367 m
.65246 .45574 L
s
0 0 0 r
2 Mabswid
.65246 .45574 Mdot
.039 .916 .04 r
.5 Mabswid
.7374 .48367 m
.81605 .65346 L
s
0 0 0 r
2 Mabswid
.81605 .65346 Mdot
.039 .916 .04 r
.5 Mabswid
.39416 .23646 m
.4616 .29206 L
s
0 0 0 r
2 Mabswid
.4616 .29206 Mdot
.039 .916 .04 r
.5 Mabswid
.34933 .43983 m
.34751 .34623 L
s
0 0 0 r
2 Mabswid
.34751 .34623 Mdot
.039 .916 .04 r
.5 Mabswid
.34933 .43983 m
.21429 .47037 L
s
0 0 0 r
2 Mabswid
.21429 .47037 Mdot
.039 .916 .04 r
.5 Mabswid
.41691 .34476 m
.22612 .78095 L
s
0 0 0 r
2 Mabswid
.22612 .78095 Mdot
.039 .916 .04 r
.5 Mabswid
.41691 .34476 m
.42641 .3259 L
s
0 0 0 r
2 Mabswid
.42641 .3259 Mdot
.039 .916 .04 r
.5 Mabswid
.80524 .55009 m
.57657 .42919 L
s
0 0 0 r
2 Mabswid
.57657 .42919 Mdot
.039 .916 .04 r
.5 Mabswid
.41691 .45524 m
.22612 .01905 L
s
0 0 0 r
2 Mabswid
.22612 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.41691 .45524 m
.42641 .4741 L
s
0 0 0 r
2 Mabswid
.42641 .4741 Mdot
.039 .916 .04 r
.5 Mabswid
.80524 .24991 m
.57657 .37081 L
s
0 0 0 r
2 Mabswid
.57657 .37081 Mdot
.039 .916 .04 r
.5 Mabswid
.68192 .61894 m
.75653 .58998 L
s
0 0 0 r
2 Mabswid
.75653 .58998 Mdot
.039 .916 .04 r
.5 Mabswid
.68192 .61894 m
.3794 .44639 L
s
0 0 0 r
2 Mabswid
.3794 .44639 Mdot
.039 .916 .04 r
.5 Mabswid
.71503 .24838 m
.72689 .18243 L
s
0 0 0 r
2 Mabswid
.72689 .18243 Mdot
.039 .916 .04 r
.5 Mabswid
.71503 .55162 m
.72689 .61757 L
s
0 0 0 r
2 Mabswid
.72689 .61757 Mdot
.039 .916 .04 r
.5 Mabswid
.65246 .34426 m
.65846 .36593 L
s
0 0 0 r
2 Mabswid
.65846 .36593 Mdot
.039 .916 .04 r
.5 Mabswid
.4616 .50794 m
.60639 .39396 L
s
0 0 0 r
2 Mabswid
.60639 .39396 Mdot
.039 .916 .04 r
.5 Mabswid
.65246 .45574 m
.65846 .43407 L
s
0 0 0 r
2 Mabswid
.65846 .43407 Mdot
.039 .916 .04 r
.5 Mabswid
.4616 .29206 m
.60639 .40604 L
s
0 0 0 r
2 Mabswid
.60639 .40604 Mdot
.039 .916 .04 r
.5 Mabswid
.34751 .34623 m
.3635 .34935 L
s
0 0 0 r
2 Mabswid
.3635 .34935 Mdot
.039 .916 .04 r
.5 Mabswid
.42641 .3259 m
.75977 .23161 L
s
0 0 0 r
2 Mabswid
.75977 .23161 Mdot
.039 .916 .04 r
.5 Mabswid
.57657 .42919 m
.45425 .36624 L
s
0 0 0 r
2 Mabswid
.45425 .36624 Mdot
.039 .916 .04 r
.5 Mabswid
.57657 .42919 m
.6012 .44315 L
s
0 0 0 r
2 Mabswid
.6012 .44315 Mdot
.039 .916 .04 r
.5 Mabswid
.42641 .4741 m
.75977 .56839 L
s
0 0 0 r
2 Mabswid
.75977 .56839 Mdot
.039 .916 .04 r
.5 Mabswid
.57657 .37081 m
.45425 .43376 L
s
0 0 0 r
2 Mabswid
.45425 .43376 Mdot
.039 .916 .04 r
.5 Mabswid
.57657 .37081 m
.6012 .35685 L
s
0 0 0 r
2 Mabswid
.6012 .35685 Mdot
.039 .916 .04 r
.5 Mabswid
.75653 .58998 m
.77885 .56658 L
s
0 0 0 r
2 Mabswid
.77885 .56658 Mdot
.039 .916 .04 r
.5 Mabswid
.75653 .58998 m
.94745 .78095 L
s
0 0 0 r
2 Mabswid
.94745 .78095 Mdot
.039 .916 .04 r
.5 Mabswid
.3794 .44639 m
.38276 .44738 L
s
0 0 0 r
2 Mabswid
.38276 .44738 Mdot
.039 .916 .04 r
.5 Mabswid
.65846 .36593 m
.66718 .42054 L
s
0 0 0 r
2 Mabswid
.66718 .42054 Mdot
.039 .916 .04 r
.5 Mabswid
.65846 .36593 m
.52898 .25533 L
s
0 0 0 r
2 Mabswid
.52898 .25533 Mdot
.039 .916 .04 r
.5 Mabswid
.60639 .39396 m
.77859 .46789 L
s
0 0 0 r
2 Mabswid
.77859 .46789 Mdot
.039 .916 .04 r
.5 Mabswid
.65846 .43407 m
.66718 .37946 L
s
0 0 0 r
2 Mabswid
.66718 .37946 Mdot
.039 .916 .04 r
.5 Mabswid
.65846 .43407 m
.52898 .54467 L
s
0 0 0 r
2 Mabswid
.52898 .54467 Mdot
.039 .916 .04 r
.5 Mabswid
.60639 .40604 m
.77859 .33211 L
s
0 0 0 r
2 Mabswid
.77859 .33211 Mdot
.039 .916 .04 r
.5 Mabswid
.3635 .34935 m
.7939 .40723 L
s
0 0 0 r
2 Mabswid
.7939 .40723 Mdot
.039 .916 .04 r
.5 Mabswid
.75977 .23161 m
.81063 .22502 L
s
0 0 0 r
2 Mabswid
.81063 .22502 Mdot
.039 .916 .04 r
.5 Mabswid
.6012 .44315 m
.61939 .57425 L
s
0 0 0 r
2 Mabswid
.61939 .57425 Mdot
.039 .916 .04 r
.5 Mabswid
.75977 .56839 m
.81063 .57498 L
s
0 0 0 r
2 Mabswid
.81063 .57498 Mdot
.039 .916 .04 r
.5 Mabswid
.6012 .35685 m
.61939 .22575 L
s
0 0 0 r
2 Mabswid
.61939 .22575 Mdot
.039 .916 .04 r
.5 Mabswid
.77885 .56658 m
.81923 .50402 L
s
0 0 0 r
2 Mabswid
.81923 .50402 Mdot
.039 .916 .04 r
.5 Mabswid
.38276 .44738 m
.42277 .45357 L
s
0 0 0 r
2 Mabswid
.42277 .45357 Mdot
.039 .916 .04 r
.5 Mabswid
.66718 .42054 m
.66108 .56521 L
s
0 0 0 r
2 Mabswid
.66108 .56521 Mdot
.039 .916 .04 r
.5 Mabswid
.52898 .25533 m
.45313 .2789 L
s
0 0 0 r
2 Mabswid
.45313 .2789 Mdot
.039 .916 .04 r
.5 Mabswid
.77859 .46789 m
.97619 .61361 L
s
0 0 0 r
2 Mabswid
.97619 .61361 Mdot
.039 .916 .04 r
.5 Mabswid
.66718 .37946 m
.66108 .23479 L
s
0 0 0 r
2 Mabswid
.66108 .23479 Mdot
.039 .916 .04 r
.5 Mabswid
.52898 .54467 m
.45313 .5211 L
s
0 0 0 r
2 Mabswid
.45313 .5211 Mdot
.039 .916 .04 r
.5 Mabswid
.77859 .33211 m
.97619 .18639 L
s
0 0 0 r
2 Mabswid
.97619 .18639 Mdot
.039 .916 .04 r
.5 Mabswid
.7939 .40723 m
.78062 .41125 L
s
0 0 0 r
2 Mabswid
.78062 .41125 Mdot
.039 .916 .04 r
.5 Mabswid
.81063 .22502 m
.82711 .23759 L
s
0 0 0 r
2 Mabswid
.82711 .23759 Mdot
.039 .916 .04 r
.5 Mabswid
.61939 .57425 m
.61991 .59384 L
s
0 0 0 r
2 Mabswid
.61991 .59384 Mdot
.039 .916 .04 r
.5 Mabswid
.81063 .57498 m
.82711 .56241 L
s
0 0 0 r
2 Mabswid
.82711 .56241 Mdot
.039 .916 .04 r
.5 Mabswid
.61939 .22575 m
.61991 .20616 L
s
0 0 0 r
2 Mabswid
.61991 .20616 Mdot
.039 .916 .04 r
.5 Mabswid
.81923 .50402 m
.83604 .4253 L
s
0 0 0 r
2 Mabswid
.83604 .4253 Mdot
.039 .916 .04 r
.5 Mabswid
.81923 .50402 m
.42418 .48609 L
s
0 0 0 r
2 Mabswid
.42418 .48609 Mdot
.039 .916 .04 r
.5 Mabswid
.42277 .45357 m
.56605 .42435 L
s
0 0 0 r
2 Mabswid
.56605 .42435 Mdot
.039 .916 .04 r
.5 Mabswid
.66108 .56521 m
.66794 .58054 L
s
0 0 0 r
2 Mabswid
.66794 .58054 Mdot
.039 .916 .04 r
.5 Mabswid
.45313 .2789 m
.43869 .3283 L
s
0 0 0 r
2 Mabswid
.43869 .3283 Mdot
.039 .916 .04 r
.5 Mabswid
.66108 .23479 m
.66794 .21946 L
s
0 0 0 r
2 Mabswid
.66794 .21946 Mdot
.039 .916 .04 r
.5 Mabswid
.45313 .5211 m
.43869 .4717 L
s
0 0 0 r
2 Mabswid
.43869 .4717 Mdot
.039 .916 .04 r
.5 Mabswid
.78062 .41125 m
.77757 .39171 L
s
0 0 0 r
2 Mabswid
.77757 .39171 Mdot
.039 .916 .04 r
.5 Mabswid
.82711 .23759 m
.97619 .38694 L
s
0 0 0 r
2 Mabswid
.97619 .38694 Mdot
.039 .916 .04 r
.5 Mabswid
.61991 .59384 m
.64164 .59624 L
s
0 0 0 r
2 Mabswid
.64164 .59624 Mdot
.039 .916 .04 r
.5 Mabswid
.82711 .56241 m
.97619 .41306 L
s
0 0 0 r
2 Mabswid
.97619 .41306 Mdot
.039 .916 .04 r
.5 Mabswid
.61991 .20616 m
.64164 .20376 L
s
0 0 0 r
2 Mabswid
.64164 .20376 Mdot
.039 .916 .04 r
.5 Mabswid
.83604 .4253 m
.83206 .35483 L
s
0 0 0 r
2 Mabswid
.83206 .35483 Mdot
.039 .916 .04 r
.5 Mabswid
.42418 .48609 m
.21429 .46964 L
s
0 0 0 r
2 Mabswid
.21429 .46964 Mdot
.039 .916 .04 r
.5 Mabswid
.56605 .42435 m
.56572 .41772 L
s
0 0 0 r
2 Mabswid
.56572 .41772 Mdot
.039 .916 .04 r
.5 Mabswid
.66794 .58054 m
.66343 .58445 L
s
0 0 0 r
2 Mabswid
.66343 .58445 Mdot
.039 .916 .04 r
.5 Mabswid
.66794 .58054 m
.39864 .50413 L
s
0 0 0 r
2 Mabswid
.39864 .50413 Mdot
.039 .916 .04 r
.5 Mabswid
.43869 .3283 m
.39996 .52134 L
s
0 0 0 r
2 Mabswid
.39996 .52134 Mdot
.039 .916 .04 r
.5 Mabswid
.66794 .21946 m
.66343 .21555 L
s
0 0 0 r
2 Mabswid
.66343 .21555 Mdot
.039 .916 .04 r
.5 Mabswid
.66794 .21946 m
.39864 .29587 L
s
0 0 0 r
2 Mabswid
.39864 .29587 Mdot
.039 .916 .04 r
.5 Mabswid
.43869 .4717 m
.39996 .27866 L
s
0 0 0 r
2 Mabswid
.39996 .27866 Mdot
.039 .916 .04 r
.5 Mabswid
.77757 .39171 m
.72608 .01905 L
s
0 0 0 r
2 Mabswid
.72608 .01905 Mdot
.039 .916 .04 r
.5 Mabswid
.77757 .39171 m
.78681 .42714 L
s
0 0 0 r
2 Mabswid
.78681 .42714 Mdot
.039 .916 .04 r
.5 Mabswid
.64164 .59624 m
.67266 .57992 L
s
0 0 0 r
2 Mabswid
.67266 .57992 Mdot
.039 .916 .04 r
.5 Mabswid
.64164 .20376 m
.67266 .22008 L
s
0 0 0 r
2 Mabswid
.67266 .22008 Mdot
.039 .916 .04 r
.5 Mabswid
.83206 .35483 m
.79787 .35119 L
s
0 0 0 r
2 Mabswid
.79787 .35119 Mdot
.039 .916 .04 r
.5 Mabswid
.56572 .41772 m
.7235 .38666 L
s
0 0 0 r
2 Mabswid
.7235 .38666 Mdot
.039 .916 .04 r
.5 Mabswid
.66343 .58445 m
.60093 .62132 L
s
0 0 0 r
2 Mabswid
.60093 .62132 Mdot
.039 .916 .04 r
.5 Mabswid
.39864 .50413 m
.43347 .54128 L
s
0 0 0 r
2 Mabswid
.43347 .54128 Mdot
.039 .916 .04 r
.5 Mabswid
.66343 .21555 m
.60093 .17868 L
s
0 0 0 r
2 Mabswid
.60093 .17868 Mdot
.039 .916 .04 r
.5 Mabswid
.39864 .29587 m
.43347 .25872 L
s
0 0 0 r
2 Mabswid
.43347 .25872 Mdot
.039 .916 .04 r
.5 Mabswid
.78681 .42714 m
.53541 .64271 L
s
0 0 0 r
2 Mabswid
.53541 .64271 Mdot
.039 .916 .04 r
.5 Mabswid
.67266 .57992 m
.90638 .45957 L
s
0 0 0 r
2 Mabswid
.90638 .45957 Mdot
.039 .916 .04 r
.5 Mabswid
.67266 .22008 m
.90638 .34043 L
s
0 0 0 r
2 Mabswid
.90638 .34043 Mdot
.039 .916 .04 r
.5 Mabswid
.79787 .35119 m
.75942 .34786 L
s
0 0 0 r
2 Mabswid
.75942 .34786 Mdot
.039 .916 .04 r
.5 Mabswid
.79787 .35119 m
.50143 .33066 L
s
0 0 0 r
2 Mabswid
.50143 .33066 Mdot
.039 .916 .04 r
.5 Mabswid
.7235 .38666 m
.71648 .24466 L
s
0 0 0 r
2 Mabswid
.71648 .24466 Mdot
.039 .916 .04 r
.5 Mabswid
.60093 .62132 m
.43183 .68184 L
s
0 0 0 r
2 Mabswid
.43183 .68184 Mdot
.039 .916 .04 r
.5 Mabswid
.43347 .54128 m
.65413 .71002 L
s
0 0 0 r
2 Mabswid
.65413 .71002 Mdot
.039 .916 .04 r
.5 Mabswid
.60093 .17868 m
.43183 .11816 L
s
0 0 0 r
2 Mabswid
.43183 .11816 Mdot
.039 .916 .04 r
.5 Mabswid
.43347 .25872 m
.65413 .08998 L
s
0 0 0 r
2 Mabswid
.65413 .08998 Mdot
.039 .916 .04 r
.5 Mabswid
.75942 .34786 m
.43848 .32974 L
s
0 0 0 r
2 Mabswid
.43848 .32974 Mdot
.039 .916 .04 r
.5 Mabswid
.50143 .33066 m
.23569 .20876 L
s
0 0 0 r
2 Mabswid
.23569 .20876 Mdot
.039 .916 .04 r
.5 Mabswid
.71648 .24466 m
.71784 .24438 L
s
0 0 0 r
2 Mabswid
.71784 .24438 Mdot
.039 .916 .04 r
.5 Mabswid
.43848 .32974 m
.42081 .30753 L
s
0 0 0 r
2 Mabswid
.42081 .30753 Mdot
.039 .916 .04 r
.5 Mabswid
.71784 .24438 m
.84533 .2641 L
s
0 0 0 r
2 Mabswid
.84533 .2641 Mdot
.039 .916 .04 r
.5 Mabswid
.42081 .30753 m
.25246 .01905 L
s
0 0 0 r
2 Mabswid
.25246 .01905 Mdot
0 0 m
1 0 L
1 .8 L
0 .8 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{601.75, 481.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009I0001hB000`400?l00000o`00003oo`3ooooo
0?oooe/0oooo003o0?ooool0ooooF`3oool00?l0ooooo`3ooomK0?ooo`00o`3ooooo0?oooe/0oooo
003o0?ooool0ooooF`3oool00?l0ooooo`3ooomK0?ooo`00o`3ooooo0?oooe/0oooo003o0?ooool0
ooooF`3oool00?l0ooooo`3ooomK0?ooo`00o`3ooooo0?oooe/0oooo003o0?ooool0ooooF`3oool0
0840oooo00<000000?ooo`3oool00P3oool3000000h0oooo0P00000X0?ooo`800000>`3oool20000
03X0oooo0`00001B0?ooo`8000005@3oool2000000/0oooo0P00001`0?ooo`8000003`3oool20000
00H0oooo0P00000:0?ooo`030000003oool0oooo00`0oooo00200?ooool00000c000000>0?ooo`00
P03oool00`000000oooo0?ooo`040?ooo`0300WZ2P3oool02NX:00d0oooo00<02NX:0?ooo`3oool0
:03oool00`09jPX0oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`09jPX0
D`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0
KP3oool00`09jPX0oooo0?ooo`0<0?ooo`802NX:2@3oool00`09jPX0oooo0?ooo`080?ooo`030000
003oool0oooo00`0oooo00200?ooo`030000003oool0oooo00D0oooo00<02NX:0?ooo`09jPX03@3o
ool00`09jPX0oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool0>P3o
ool200WZ2U<0oooo00<02NX:0?ooo`3oool0503oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3o
ool0oooo06d0oooo00<02NX:0?ooo`3oool02P3oool300WZ2PX0oooo00<02NX:0?ooo`3oool02@3o
ool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`050?ooo`0400WZ2P3oool0
oooo00WZ2P`0oooo00<02NX:0?ooo`3oool0:03oool00`09jPX0oooo0?ooo`0i0?ooo`0300WZ2P3o
ool0oooo03T0oooo00<02NX:0?ooo`09jPX0D`3oool00`09jPX0oooo0?ooo`0D0?ooo`0300WZ2P3o
ool0oooo00T0oooo00<02NX:0?ooo`3oool0K@3oool00`09jPX0oooo0?ooo`080?ooo`802NX:303o
ool00`09jPX0oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0
oooo00H0oooo00@02NX:0?ooo`3oool02NX:303oool00`09jPX0oooo0?ooo`0W0?ooo`0300WZ2P3o
ool0oooo03T0oooo00<02NX:0?ooo`3oool0>P3oool200WZ2U<0oooo00<02NX:0?ooo`3oool0503o
ool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo06`0oooo00<02NX:0?ooo`3oool01`3o
ool200WZ2Ph0oooo00<02NX:0?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool0
0`000000oooo0?ooo`060?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0303oool00`09jPX0oooo0?oo
o`0V0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool0>P3oool200WZ2U<0oooo00<0
2NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo06/0oooo00<0
2NX:0?ooo`3oool0103oool300WZ2Pl0oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo0?oo
o`0<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:
0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:
0?ooo`3oool0>P3oool200WZ2U80oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`08
0?ooo`0300WZ2P3oool0oooo06X0oooo00<02NX:0?ooo`3oool00`3oool200WZ2Q40oooo00<02NX:
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`070?oo
o`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`0V0?oo
o`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool0>P3oool200WZ2U<0oooo00<02NX:0?oo
o`3oool05P3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo06T0oooo00<02NX:0?oo
o`3oool00P3oool200WZ2Q<0oooo00<02NX:0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`00P03oool00`000000oooo0?ooo`070?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3o
ool0203oool00`09jPX0oooo0?ooo`0V0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3o
ool0>`3oool00`09jPX0oooo0?ooo`1A0?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3o
ool01`3oool00`09jPX0oooo0?ooo`1Y0?ooo`0300WZ2P3oool02NX:00802NX:503oool00`09jPX0
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo00P0oooo
00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo02H0oooo
00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0k0?ooo`0300WZ2P3oool0oooo0500oooo
00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo06P0oooo
0`09jPXF0?ooo`0300WZ2P3oool0oooo00h0oooo00<000000?ooo`3oool0303oool00800oooo00<0
00000?ooo`3oool0203oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00P0oooo00<0
2NX:0?ooo`3oool09@3oool00`09jPX0oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo03/0oooo00<0
2NX:0?ooo`3oool0D03oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00D0oooo00<0
2NX:0?ooo`3oool0I`3oool200WZ2QP0oooo00<02NX:0?ooo`3oool03P3oool00`000000oooo0?oo
o`0<0?ooo`00P03oool00`000000oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:
0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0U0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:
0?ooo`3oool0>`3oool200WZ2U80oooo00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`05
0?ooo`0300WZ2P3oool0oooo06@0oooo1009jPXH0?ooo`0300WZ2P3oool0oooo00l0oooo00<00000
0?ooo`3oool0303oool00800oooo00<000000?ooo`3oool02@3oool00`09jPX0oooo0?ooo`050?oo
o`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool09@3oool00`09jPX0oooo0?ooo`0i0?oo
o`0300WZ2P3oool0oooo03/0oooo00<02NX:0?ooo`3oool0D03oool00`09jPX0oooo0?ooo`0H0?oo
o`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0H@3oool200WZ2P<0oooo00<02NX:0?oo
o`3oool05@3oool00`09jPX0oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00200?ooo`03
0000003oool0oooo00X0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`060?ooo`03
00WZ2P3oool0oooo02D0oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0k0?ooo`80
2NX:D@3oool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0G`3oool200WZ2P@0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`0A0?ooo`03
0000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo00X0oooo00<02NX:0?ooo`3oool0
1P3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo02@0oooo00<02NX:0?ooo`3oool0
>@3oool00`09jPX0oooo0?ooo`0k0?ooo`802NX:DP3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0G03oool300WZ2PH0oooo00<02NX:0?ooo`3oool0
5@3oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003o
ool0oooo00X0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3o
ool0oooo02D0oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0j0?ooo`0300WZ2P3o
ool02NX:0540oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3o
ool0oooo05X0oooo0P09jPX80?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool04P3o
ool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00L0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0T0?ooo`0300WZ2P3oool0
oooo03T0oooo00<02NX:0?ooo`3oool0>`3oool200WZ2U40oooo00<02NX:0?ooo`3oool06P3oool0
0`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo05P0oooo0P09jPX:0?ooo`0300WZ2P3oool0
oooo01@0oooo00<02NX:0?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`00
0000oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool01@3oool00`09
jPX0oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool0>`3oool00`09
jPX0oooo00WZ2P1@0?ooo`0300WZ2P3oool0oooo01/0oooo00D02NX:0?ooo`3oool0oooo00WZ2P1H
0?ooo`802NX:2`3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo01<0oooo00<00000
0?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0303oool00`09jPX0oooo0?ooo`080?oo
o`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0903oool00`09jPX0oooo0?ooo`0i0?oo
o`0300WZ2P3oool0oooo03X0oooo00<02NX:0?ooo`09jPX0D@3oool00`09jPX0oooo0?ooo`0J0?oo
o`0500WZ2P3oool0oooo0?ooo`09jPX0E@3oool300WZ2Pd0oooo00<02NX:0?ooo`3oool0503oool0
0`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo
00`0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo
02<0oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0k0?ooo`0300WZ2P3oool02NX:
0500oooo00<02NX:0?ooo`3oool06`3oool01@09jPX0oooo0?ooo`3oool02NX:0580oooo0P09jPX?
0?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool05@3oool00`000000oooo0?ooo`0<
0?ooo`00P03oool00`000000oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00T0oooo0P09jPX40?oo
o`0300WZ2P3oool0oooo02<0oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0k0?oo
o`0300WZ2P3oool02NX:0500oooo00<02NX:0?ooo`3oool0703oool01009jPX0oooo0?ooo`09jPY@
0?ooo`802NX:403oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo01D0oooo00<00000
0?ooo`3oool0303oool00800oooo00<000000?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool08`3oool00`09jPX0oooo0?ooo`0h0?oo
o`0300WZ2P3oool0oooo03/0oooo00@02NX:0?ooo`3oool02NX:C`3oool00`09jPX0oooo0?ooo`0L
0?ooo`0400WZ2P3oool0oooo00WZ2Td0oooo0`09jPXB0?ooo`0300WZ2P3oool0oooo01@0oooo00<0
2NX:0?ooo`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0=
0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0R
0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool0>`3oool00`09jPX0oooo00WZ2P1@
0?ooo`0300WZ2P3oool0oooo01`0oooo00<02NX:0?ooo`09jPX0B`3oool200WZ2Q@0oooo00<02NX:
0?ooo`3oool0503oool00`09jPX0oooo0?ooo`0G0?ooo`030000003oool0oooo00`0oooo00200?oo
o`030000003oool0oooo00h0oooo00<02NX:0?ooo`3oool0303oool01@09jPX0oooo0?ooo`3oool0
2NX:02@0oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0k0?ooo`0400WZ2P3oool0
oooo00WZ2Tl0oooo00<02NX:0?ooo`3oool07@3oool200WZ2TT0oooo0P09jPXF0?ooo`0300WZ2P3o
ool0oooo01@0oooo00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool0
0`000000oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo00d0oooo00D02NX:0?ooo`3oool0oooo00WZ
2P0S0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool0>`3oool01@09jPX0oooo0?oo
o`3oool02NX:04h0oooo00<02NX:0?ooo`3oool07@3oool200WZ2TH0oooo0`09jPXG0?ooo`0300WZ
2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool0603oool00`000000oooo0?ooo`0<0?ooo`00P03o
ool00`000000oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo00d0oooo00@02NX:0?ooo`3oool02NX:
903oool00`09jPX0oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo03X0oooo00D02NX:0?ooo`3oool0
oooo00WZ2P1>0?ooo`0300WZ2P3oool0oooo01h0oooo00<02NX:0?ooo`3oool0@P3oool200WZ2QX0
oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0I0?ooo`030000003oool0oooo00`0
oooo00200?ooo`030000003oool0oooo00l0oooo00<02NX:0?ooo`3oool03P3oool01009jPX0oooo
0?ooo`09jPXS0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool0>`3oool01@09jPX0
oooo0?ooo`3oool02NX:04h0oooo00<02NX:0?ooo`3oool07P3oool00`09jPX0oooo0?ooo`0o0?oo
o`802NX:6`3oool00`09jPX0oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo01T0oooo00<000000?oo
o`3oool0303oool00800oooo00<000000?ooo`3oool0403oool00`09jPX0oooo0?ooo`0>0?ooo`03
00WZ2P3oool02NX:02<0oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0k0?ooo`05
00WZ2P3oool0oooo0?ooo`09jPX0CP3oool00`09jPX0oooo0?ooo`0N0?ooo`802NX:?@3oool300WZ
2Qd0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0J0?ooo`030000003oool0oooo
00`0oooo00200?ooo`030000003oool0oooo0100oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0
oooo00WZ2P0S0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool0>P3oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P3oool0oooo04/0oooo00<02NX:0?ooo`3oool07P3oool200WZ2S/0
oooo0P09jPXO0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool06`3oool00`000000
oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo00l0oooo
00<02NX:0?ooo`09jPX08P3oool00`09jPX0oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo01X0oooo
0P00000O0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0C@3oool00`09jPX0oooo0?ooo`0;0?ooo`80
00004@3oool00`09jPX0oooo00WZ2P0h0?ooo`802NX:8@3oool00`09jPX0oooo0?ooo`0C0?ooo`03
00WZ2P3oool0oooo01/0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0
4@3oool00`09jPX0oooo0?ooo`0@0?ooo`802NX:8P3oool00`09jPX0oooo0?ooo`0i0?ooo`0300WZ
2P3oool0oooo01X0oooo00<0000007moO`0000007P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ
2P3oool0oooo04/0oooo00<02NX:0?ooo`3oool02@3oool00`000000Ogmo0000000A0?ooo`0400WZ
2P3oool0oooo00WZ2S@0oooo0`09jPXR0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3o
ool0703oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0A0?ooo`0300WZ
2P3oool0oooo0140oooo0P09jPXR0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool0
6@3oool010000000Ogmo07moO`00000M0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3o
ool0B`3oool00`09jPX0oooo0?ooo`080?ooo`040000001oOgl0Ogmo00000140oooo00@02NX:0?oo
o`3oool02NX:<P3oool200WZ2RD0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0M
0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo0180oooo00<02NX:0?oo
o`3oool04@3oool00`09jPX0oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?oo
o`3oool0603oool00`000000Ogmo0000000207moO`030000003oool0oooo01/0oooo00<02NX:0?oo
o`3oool00P3oool00`09jPX0oooo0?ooo`1:0?ooo`0300WZ2P3oool0oooo00L0oooo00<0000007mo
O`1oOgl00P1oOgl00`000000oooo0?ooo`0>0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0;`3oool2
00WZ2RH0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0N0?ooo`030000003oool0
oooo00`0oooo00200?ooo`030000003oool0oooo0180oooo00<02NX:0?ooo`3oool04P3oool00`09
jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool0603oool00`00
0000Ogmo0000000307moO`030000003oool0oooo01X0oooo00<02NX:0?ooo`3oool00P3oool00`09
jPX0oooo0?ooo`1;0?ooo`0300WZ2P3oool0oooo00D0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0?0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0:`3oool300WZ2RL0oooo00<02NX:
0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0N0?ooo`030000003oool0oooo00`0oooo00200?oo
o`030000003oool0oooo01<0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0O0?oo
o`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool05`3oool00`000000Ogmo0000000407mo
O`8000006P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo04X0oooo00<02NX:0?oo
o`3oool00`3oool2000000H0Ogmo00<000000?ooo`3oool03`3oool00`09jPX0oooo0?ooo`020?oo
o`0300WZ2P3oool0oooo02H0oooo0P09jPXZ0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?oo
o`3oool07`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0C0?ooo`03
00WZ2P3oool0oooo0180oooo0P09jPXP0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3o
ool05`3oool010000000Ogmo07moO`00000507moO`030000003oool0oooo01P0oooo00<02NX:0?oo
o`3oool00P3oool00`09jPX0oooo0?ooo`1:0?ooo`0300WZ2P3oool0oooo0080oooo00<0000007mo
O`1oOgl01P1oOgl00`000000oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?oo
o`3oool0903oool200WZ2R/0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0P0?oo
o`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo01@0oooo00<02NX:0?ooo`3o
ool04P3oool200WZ2Ql0oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0F0?ooo`05
0000001oOgl0Ogmo07moO`0000001P1oOgl00`000000oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo
00<0oooo00<02NX:0?ooo`3oool0B@3oool01@09jPX0oooo0?ooo`3oool0000000X0Ogmo00<00000
0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0240oooo0P09jPX]
0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0803oool00`000000oooo0?ooo`0<
0?ooo`00P03oool00`000000oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?oo
o`09jPX07`3oool00`09jPX0oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo01D0oooo00D0000007mo
O`1oOgl0Ogmo0000000707moO`030000003oool0oooo01H0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`190?ooo`0300WZ2P3oool0000000/0Ogmo00<000000?ooo`3oool03P3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01d0oooo0`09jPX^0?ooo`0300WZ2P3oool0
oooo0180oooo00<02NX:0?ooo`3oool08@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`00
0000oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`09jPX07P3oool00`09
jPX0oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo01D0oooo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0507moO`030000003oool0oooo01D0oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0oooo0?ooo`190?ooo`0300WZ2P000000Ogmo00/0Ogmo00<000000?ooo`3oool03P3oool00`09
jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01/0oooo0P09jPXa0?ooo`0300WZ2P3oool0oooo
0140oooo00<02NX:0?ooo`3oool08P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000
oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo0180oooo00@02NX:0?ooo`3oool02NX:7@3oool00`09
jPX0oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo01D0oooo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0607moO`8000005P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo
04L0oooo00<0000000WZ2P1oOgl0301oOgl00`000000oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo
00D0oooo00<02NX:0?ooo`3oool0603oool200WZ2S80oooo00<02NX:0?ooo`3oool04P3oool00`09
jPX0oooo0?ooo`0R0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo01D0
oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0200WZ2Q`0oooo00<02NX:0?ooo`3o
ool0>@3oool00`09jPX0oooo0?ooo`0C0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0201oOgl00`000000oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0AP3oool00`000000Ogmo00WZ2P0>07moO`030000003oool0oooo00d0oooo00<02NX:0?ooo`3o
ool01P3oool00`09jPX0oooo0?ooo`0D0?ooo`<02NX:=03oool00`09jPX0oooo0?ooo`0A0?ooo`03
00WZ2P3oool0oooo02<0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0
5P3oool00`09jPX0oooo0?ooo`0C0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX06`3oool00`09jPX0
oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo01<0oooo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0807moO`030000003oool0oooo0180oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0
oooo0?ooo`140?ooo`050000001oOgl0Ogmo07moO`09jPX03@1oOgl00`000000oooo0?ooo`0>0?oo
o`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool04P3oool200WZ2SH0oooo00<02NX:0?oo
o`3oool04@3oool00`09jPX0oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo00200?ooo`03
0000003oool0oooo01H0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`020?ooo`03
00WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0C0?ooo`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0B0?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0=03oool00`09jPX000000000000<0?ooo`03
0000001oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl02`1oOgl00`000000oooo0?ooo`0>0?ooo`03
00WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool03`3oool200WZ2SP0oooo00<02NX:0?ooo`3o
ool04@3oool00`09jPX0oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000
003oool0oooo01L0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ
2P3oool0oooo01L0oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0C0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`0A0?ooo`0300WZ
2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0<P3oool01009jPX0oooo00000000000;0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl02`1oOgl00`000000oooo0?ooo`0>0?ooo`03
00WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool02`3oool300WZ2ST0oooo00<02NX:0?ooo`3o
ool04@3oool00`09jPX0oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000
003oool0oooo01L0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo01L0oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0A0?ooo`030000
001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl02P1oOgl200000140oooo00<02NX:0?ooo`3oool0
1@3oool00`09jPX0oooo0?ooo`0a0?ooo`0300WZ2P3oool0oooo00/0oooo0P00000607moO`0300WZ
2P1oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool03@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ
2P3oool0oooo00P0oooo0P09jPXk0?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool0
9P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0H0?ooo`0300WZ2P3o
ool0oooo01<0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3o
ool0oooo03T0oooo00<02NX:0?ooo`3oool04@3oool00`000000Ogmo07moO`0607moO`030000001o
Ogl0Ogmo00`0Ogmo00<000000?ooo`3oool03`3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3o
ool0oooo02h0oooo0P09jPX=0?ooo`030000001oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl02`1o
Ogl00`000000oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool01P3o
ool200WZ2Sd0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0V0?ooo`030000003o
ool0oooo00`0oooo00200?ooo`030000003oool0oooo01P0oooo00<02NX:0?ooo`3oool0503oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0>@3oool0
0`09jPX0oooo0?ooo`0A0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl03@1oOgl0
0`000000oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0;@3oool0
0`09jPX0oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl02`1oOgl0
0`000000oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00P3oool3
00WZ2Sh0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0W0?ooo`030000003oool0
oooo00`0oooo00200?ooo`030000003oool0oooo01P0oooo00<02NX:0?ooo`3oool0503oool00`09
jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0>@3oool00`09
jPX0oooo0?ooo`0@0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl03@1oOgl00`00
0000oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0:`3oool00`09
jPX0oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl02`1oOgl00`00
0000oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00X0oooo00@02NX:0?ooo`09jPX02NX:@@3oool0
0`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo02P0oooo00<000000?ooo`3oool0303oool0
0800oooo00<000000?ooo`3oool06@3oool00`09jPX0oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo
00@0oooo00<02NX:0?ooo`3oool0503oool00`09jPX0oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo
00l0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0>07moO`030000003oool0oooo
00`0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0Z0?ooo`0300WZ2P3oool0oooo
00`0oooo00<0000007moO`1oOgl02P1oOgl00`09jPX0Ogmo07moO`0<07moO`030000003oool0oooo
00d0oooo00<02NX:0?ooo`3oool02@3oool200WZ2T80oooo00<02NX:0?ooo`3oool04@3oool00`09
jPX0oooo0?ooo`0X0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo01T0
oooo00<02NX:0?ooo`3oool0503oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo01<0
oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00P0
Ogmo00<0000007moO`1oOgl03`1oOgl2000000d0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0
oooo0?ooo`0W0?ooo`802NX:3@3oool2000000h0Ogmo00<02NX:07moO`1oOgl02`1oOgl00`000000
oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00H0oooo0`09jPX00`3oool02NX:0?ooo`110?ooo`03
00WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0:@3oool00`000000oooo0?ooo`0<0?ooo`00
P03oool00`000000oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool0
1@3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool0
3P3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo0100Ogmo00<000000?ooo`3oool0
2P3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo02H0oooo00<02NX:0?ooo`3oool0
303oool00`000000Ogmo07moO`0>07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0
3@3oool00`09jPX0oooo0?ooo`040?ooo`802NX:1@3oool00`09jPX0oooo0?ooo`0n0?ooo`0300WZ
2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0:P3oool00`000000oooo0?ooo`0<0?ooo`00P03o
ool00`000000oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool01P3o
ool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool03P3o
ool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3oool02@3o
ool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo02@0oooo00<02NX:0?ooo`3oool0303o
ool00`000000Ogmo07moO`0?07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool03@3o
ool00`09jPX0oooo0?ooo`020?ooo`802NX:1`3oool00`09jPX0oooo0?ooo`0n0?ooo`0300WZ2P3o
ool0oooo00l0oooo00<02NX:0?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool0
0`000000oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool01P3oool0
0`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool03@3oool0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool02@3oool0
0`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo0240oooo0P09jPX>0?ooo`030000001oOgl0
Ogmo0140Ogmo00<02NX:07moO`1oOgl02`1oOgl00`000000oooo0?ooo`0<0?ooo`0300WZ2P3oool0
oooo00802NX:2P3oool00`09jPX0oooo0?ooo`0l0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0K0?oo
o`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0A0?oo
o`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool0303oool00`000000Ogmo07moO`0;07mo
O`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0203oool00`09jPX0oooo0?ooo`070?oo
o`0300WZ2P3oool0oooo0200oooo00<02NX:0?ooo`3oool03@3oool00`000000Ogmo07moO`0B07mo
O`0300WZ2P1oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0303oool300WZ2Pd0oooo00<02NX:0?oo
o`3oool0>`3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo02`0oooo00<000000?oo
o`3oool0303oool00800oooo00<000000?ooo`3oool0703oool00`09jPX0oooo0?ooo`0D0?ooo`03
00WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`0i0?ooo`03
00WZ2P3oool0oooo00`0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0C07moO`80
0000203oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01h0oooo00<02NX:0?ooo`3o
ool0303oool2000000T0Ogmo0P00000:07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<000000?ooo`3o
ool02P3oool300WZ2Q00oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0?0?ooo`03
00WZ2P3oool0oooo02d0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0
703oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool0
3`3oool00`09jPX0oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo00`0oooo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0E07moO`030000003oool0oooo00H0oooo00<02NX:0?ooo`3oool0
1`3oool00`09jPX0oooo0?ooo`0L0?ooo`802NX:3P3oool00`000000Ogmo07moO`0907moO`030000
0009jPX02NX:00T0Ogmo00<02NX:07moO`1oOgl02`1oOgl00`000000oooo0?ooo`080?ooo`802NX:
0`3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool0
3`3oool00`09jPX0oooo0?ooo`0]0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003o
ool0oooo01`0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3o
ool0oooo00l0oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0:0?ooo`030000001o
Ogl0Ogmo00d0Ogmo00<0000007moO`1oOgl05@1oOgl00`000000oooo0?ooo`050?ooo`0300WZ2P3o
ool0oooo00P0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`0=0?ooo`030000001o
Ogl0Ogmo00/0Ogmo00@02NX:07moO`09jPX02NX:201oOgl00`09jPX0Ogmo07moO`0;07moO`030000
003oool0oooo00@0oooo0`09jPX50?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool0
=`3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo02h0oooo00<000000?ooo`3oool0
303oool00800oooo00<000000?ooo`3oool07@3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3o
ool0oooo00P0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0i0?ooo`0300WZ2P3o
ool0oooo00X0oooo00<0000007moO`1oOgl03@1oOgl00`000000Ogmo07moO`0F07moO`030000003o
ool0oooo00@0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3o
ool0oooo00d0oooo00<0000007moO`1oOgl0301oOgl01009jPX0Ogmo07moO`1oOgl300WZ2PD0Ogmo
00<02NX:07moO`1oOgl02`1oOgl00`000000oooo0?ooo`020?ooo`802NX:203oool00`09jPX0oooo
0?ooo`0?0?ooo`0300WZ2P3oool0oooo03D0oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo
0?ooo`0_0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo01d0oooo00<0
2NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo00d0oooo00<0
2NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00d0Ogmo00<0
000007moO`1oOgl05`1oOgl00`000000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00P0oooo00<0
2NX:0?ooo`3oool05P3oool200WZ2Pl0oooo00<0000007moO`1oOgl03@1oOgl00`09jPX0Ogmo07mo
O`0407moO`802NX:0`1oOgl00`09jPX0Ogmo07moO`0;07moO`030000003oool0oooo00802NX:2P3o
ool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo03D0oooo00<02NX:0?ooo`3oool03`3o
ool00`09jPX0oooo0?ooo`0_0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0
oooo01h0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0
oooo00d0oooo00<02NX:0?ooo`3oool0:P3oool20000000300WZ2P3oool0oooo00X0oooo00<02NX:
0?ooo`3oool02@3oool00`000000Ogmo07moO`0>07moO`030000001oOgl0Ogmo01L0Ogmo0P000004
0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`0=
0?ooo`800000401oOgl00`09jPX0Ogmo07moO`0607moO`802NX:00<0Ogmo00WZ2P1oOgl0301oOgl3
00WZ2P`0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`0c0?ooo`0300WZ2P3oool0
oooo00l0oooo00<02NX:0?ooo`3oool0<03oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`00
0000oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool02@3oool200WZ
2Pd0oooo00<02NX:0?ooo`3oool0:P3oool2000000040?ooo`09jPX02NX:00WZ2PT0oooo00<02NX:
0?ooo`3oool0203oool00`000000Ogmo07moO`0?07moO`030000001oOgl0Ogmo01T0Ogmo00D00000
0?ooo`3oool0oooo00WZ2P0;0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool03@3o
ool00`000000Ogmo07moO`0A07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo0`09jPX:07moO`802NX:00<0
Ogmo0000003oool0303oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo0380oooo00<0
2NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0a0?ooo`030000003oool0oooo00`0oooo0020
0?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0<03oool300WZ2PH0oooo00<02NX:
0?ooo`3oool0203oool00`000000Ogmo07moO`0?07moO`030000001oOgl0Ogmo01X0Ogmo00@00000
0?ooo`3oool02NX:2`3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo00d0oooo00<0
000007moO`1oOgl04P1oOgl00`09jPX0Ogmo07moO`0907moO`<02NX:1P1oOgl200WZ2P<0Ogmo00<0
00000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo0340oooo00<0
2NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0a0?ooo`030000003oool0oooo00`0oooo0020
0?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0<P3oool300WZ2P<0oooo00<02NX:
0?ooo`3oool0203oool00`000000Ogmo07moO`0@07moO`030000001oOgl0Ogmo01X0Ogmo00@00000
0?ooo`3oool02NX:2`3oool00`09jPX0oooo0?ooo`0?0?ooo`802NX:3`3oool00`000000Ogmo07mo
O`0C07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl00P09jPX0101oOgl02NX:00WZ
2P09jPX507moO`030000003oool0oooo00`0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo
0?ooo`0`0?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool0<P3oool00`000000oooo
0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo01D0oooo00<0
2NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo03D0oooo0`09
jPX00`3oool02NX:0?ooo`080?ooo`030000001oOgl0Ogmo0100Ogmo00<0000007moO`1oOgl06`1o
Ogl00`000000oooo00WZ2P0;0?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool03P3o
ool00`000000Ogmo07moO`0D07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00H02NX:07moO`1oOgl0Ogmo
00000009jPX807moO`030000003oool0oooo00`0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0
oooo0?ooo`0^0?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool0<`3oool00`000000
oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo01H0oooo
00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo03P0oooo
0P09jPX80?ooo`030000001oOgl0Ogmo0140Ogmo00<0000007moO`1oOgl0701oOgl00`0000002NX:
0?ooo`0;0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool03@3oool2000001L0Ogmo
00<02NX:07moO`1oOgl02P1oOgl300WZ2P0300000009jPX0Ogmo00P0Ogmo00<000000?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo02d0oooo00<02NX:0?ooo`3oool0
3P3oool00`09jPX0oooo0?ooo`0c0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003o
ool0oooo0200oooo00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3o
ool0oooo00L0oooo00<02NX:0?ooo`3oool0>@3oool400WZ2PD0oooo00<0000007moO`1oOgl04P1o
Ogl00`000000Ogmo07moO`0M07moO`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool02P3o
ool200WZ2Pl0oooo00<0000007moO`1oOgl05`1oOgl00`09jPX0Ogmo07moO`0807moO`<02NX:101o
Ogl00`09jPX0Ogmo07moO`0607moO`030000003oool0oooo00/0oooo00<02NX:0?ooo`3oool04`3o
ool00`09jPX0oooo0?ooo`0/0?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool0=03o
ool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0Q0?ooo`0300WZ2P3oool0
oooo01H0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0
oooo03T0oooo00<02NX:0?ooo`3oool00`09jPX20?ooo`030000001oOgl0Ogmo0180Ogmo00<00000
07moO`1oOgl07@1oOgl00`09jPX000000?ooo`0:0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:
0?ooo`3oool03P3oool00`000000Ogmo07moO`0H07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo0P09jPX2
07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`000000oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool0:`3oool00`09jPX0oooo0?ooo`0=
0?ooo`0300WZ2P3oool0oooo03D0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?oo
o`3oool08@3oool00`09jPX0oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?oo
o`3oool01P3oool00`09jPX0oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo00<0oooo0`09jPXD07mo
O`030000001oOgl0Ogmo01d0Ogmo00<02NX:07moO`0000002`3oool00`09jPX0oooo0?ooo`060?oo
o`0300WZ2P3oool0oooo00h0oooo00<0000007moO`1oOgl05`1oOgl20000000407moO`09jPX0Ogmo
07moO`D02NX:00D0000007moO`1oOgl0Ogmo00WZ2P0607moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo02T0oooo00<0
2NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0e0?ooo`030000003oool0oooo00`0oooo0020
0?ooo`030000003oool0oooo0280oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0>
0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`04
0?ooo`030000001oOgl02NX:00802NX:4P1oOgl00`000000Ogmo07moO`0M07moO`0300WZ2P1oOgl0
000000X0oooo00<02NX:0?ooo`3oool0103oool200WZ2Q00oooo00<0000007moO`1oOgl0601oOgl0
0`0000002NX:00WZ2P0600WZ2P0307moO`000000000000@0Ogmo00<02NX:07moO`1oOgl0101oOgl0
0`09jPX0Ogmo07moO`0407moO`030000003oool0oooo00X0oooo00<02NX:0?ooo`3oool05@3oool0
0`09jPX0oooo0?ooo`0Y0?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo
01L0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo
03T0oooo00<02NX:0?ooo`3oool00`3oool00`000000Ogmo07moO`0207moO`802NX:401oOgl00`00
0000Ogmo07moO`0M07moO`0300WZ2P1oOgl0Ogmo008000002@3oool00`09jPX0oooo0?ooo`020?oo
o`0300WZ2P3oool0oooo00h0oooo0P00000L07moO`0300WZ2P1oOgl02NX:00802NX:2P1oOgl00`09
jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo02L0oooo00<02NX:0?ooo`3oool03@3oool00`09
jPX0oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo02<0
oooo00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo00@0
oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`030?ooo`030000001oOgl0Ogmo00@0
Ogmo0`09jPX=07moO`030000001oOgl0Ogmo01d0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000
oooo0?ooo`060?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0403oool00`000000Ogmo07moO`0K07mo
O`@02NX:301oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool02`3oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo02D0oooo00<02NX:0?oo
o`3oool03@3oool00`09jPX0oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo00200?ooo`03
0000003oool0oooo02<0oooo00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`0?0?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`030?ooo`03
0000001oOgl0Ogmo00L0Ogmo0`09jPX;07moO`030000001oOgl0Ogmo01`0Ogmo00<02NX:07moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`060?ooo`<02NX:403oool00`000000Ogmo07moO`0I07moO`@0
2NX:00<0Ogmo0000000000003@1oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo0080
Ogmo00<000000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo02D0
oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0h0?ooo`030000003oool0oooo00`0
oooo00200?ooo`030000003oool0oooo02@0oooo00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo
0?ooo`0?0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0>@3oool01@09jPX0oooo
0?ooo`3oool0000000d0Ogmo0`09jPX807moO`030000001oOgl0Ogmo01d0Ogmo00<02NX:07moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00l0oooo00<0000007moO`1o
Ogl05`1oOgl300WZ2P80Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0=07moO`0300WZ2P1oOgl0Ogmo
00H0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo
01L0oooo00<02NX:0?ooo`3oool08`3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo
03T0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0903oool00`09jPX0
oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0
oooo0?ooo`0i0?ooo`0500WZ2P3oool0oooo0?ooo`000000401oOgl300WZ2PD0Ogmo00<0000007mo
O`1oOgl07@1oOgl00`09jPX0Ogmo07moO`0407moO`030000003oool0oooo00<0oooo00<02NX:0?oo
o`09jPX03`3oool00`000000Ogmo07moO`0F07moO`802NX:1@1oOgl01@09jPX0Ogmo07moO`1oOgl0
2NX:00d0Ogmo00<02NX:07moO`1oOgl01`1oOgl01@09jPX0Ogmo07moO`1oOgl0000000`0oooo00<0
2NX:0?ooo`3oool0603oool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo00`0oooo00<0
2NX:0?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0T
0?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool0403oool01@09jPX0oooo0?ooo`3o
ool02NX:03/0oooo00D02NX:0?ooo`3oool0oooo0000000C07moO`802NX:101oOgl00`000000Ogmo
07moO`0L07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo0P0000020?ooo`0400WZ2P3oool0oooo00WZ2Pd0
oooo0P00000F07moO`<02NX:1P1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00/0
Ogmo00<02NX:07moO`1oOgl0201oOgl01009jPX0Ogmo07moO`00000<0?ooo`0300WZ2P3oool0oooo
01T0oooo00<02NX:0?ooo`3oool0803oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo
03X0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool09@3oool00`09jPX0
oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo0140oooo00D02NX:0?ooo`3oool0oooo00WZ2P0k0?oo
o`0400WZ2P3oool0oooo000001D0Ogmo0`09jPX00`1oOgl0000007moO`0N07moO`0300WZ2P1oOgl0
Ogmo00H0Ogmo0P09jPX40?ooo`0300WZ2P3oool0oooo00T0oooo00<0000007moO`1oOgl04`1oOgl3
00WZ2PT0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0<07moO`0300WZ2P1oOgl0
Ogmo00P0Ogmo00<02NX:07moO`000000303oool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0
oooo0200oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0k0?ooo`030000003oool0
oooo00`0oooo00200?ooo`030000003oool0oooo02D0oooo00<02NX:0?ooo`3oool0603oool00`09
jPX0oooo0?ooo`0A0?ooo`0400WZ2P3oool0oooo00WZ2S/0oooo00<02NX:0?ooo`0000006@1oOgl3
00WZ2Qh0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo000000040?ooo`0300WZ2P3oool0
oooo00P0oooo00<0000007moO`1oOgl04@1oOgl300WZ2P/0Ogmo00<02NX:07moO`1oOgl00`1oOgl0
0`09jPX0Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00@02NX:07moO`1oOgl000002`3o
ool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00/0oooo0P00000A0?ooo`0300WZ2P3o
ool0oooo00`0oooo00<02NX:0?ooo`3oool0?03oool00`000000oooo0?ooo`0<0?ooo`00P03oool0
0`000000oooo0?ooo`0V0?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool04@3oool0
0`09jPX0oooo00WZ2P0k0?ooo`0300WZ2P3oool0000001/0Ogmo00@0000000WZ2P09jPX02NX:6`1o
Ogl00`09jPX0Ogmo07moO`0407moO`0500WZ2P1oOgl0Ogmo07moO`000000103oool00`09jPX0oooo
0?ooo`060?ooo`030000001oOgl0Ogmo00h0Ogmo00@0000000WZ2P09jPX02NX:3P1oOgl00`09jPX0
Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX0
Ogmo0000000<0?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3oool02P3oool200000140
oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0l0?ooo`030000003oool0oooo00`0
oooo00200?ooo`8000009`3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo0180oooo
00<02NX:0?ooo`09jPX0>`3oool00`09jPX0000007moO`0J07moO`040000001oOgl0Ogmo07moO`<0
2NX:6@1oOgl01009jPX0Ogmo07moO`1oOgl200WZ2PD0Ogmo00D000000?ooo`3oool0oooo00WZ2P07
0?ooo`030000001oOgl0Ogmo00h0Ogmo0P09jPX00`000000Ogmo07moO`0=07moO`0300WZ2P1oOgl0
Ogmo00@0Ogmo00<02NX:07moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0:07moO`0300WZ2P000000
oooo00/0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0
oooo00l0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0m0?ooo`030000003oool0
oooo00`0oooo00200?ooo`8000000P09jPXV0?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?oo
o`3oool04P3oool200WZ2S/0oooo00<02NX:0000001oOgl06P1oOgl00`000000Ogmo07moO`0407mo
O`<02NX:5P1oOgl01009jPX0Ogmo07moO`09jPX807moO`8000000P3oool00`09jPX0oooo0?ooo`02
0?ooo`800000401oOgl00`09jPX0Ogmo07moO`0@07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:
07moO`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0:07moO`0300WZ2P3oool0oooo00X0oooo00<02NX:
0?ooo`3oool06`3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00l0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0n0?ooo`030000003oool0oooo00`0oooo00200?oo
o`040000003oool0oooo0?ooo`802NX:903oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0
oooo01<0oooo0P09jPXj0?ooo`0300WZ2P1oOgl0Ogmo01/0Ogmo00<0000007moO`1oOgl01P1oOgl2
00WZ2Q@0Ogmo00<02NX:07moO`09jPX02`1oOgl010000000oooo0?ooo`09jPX20?ooo`030000001o
Ogl0Ogmo00h0Ogmo0P09jPXB07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl03@1o
Ogl00`09jPX0Ogmo07moO`0;07moO`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool0703o
ool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo00l0oooo00<02NX:0?ooo`3oool0303o
ool00`09jPX0oooo0?ooo`0n0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0
oooo00<0oooo0P09jPXR0?ooo`0300WZ2P3oool0oooo01T0oooo00<02NX:0?ooo`3oool04`3oool2
00WZ2ST0oooo00<0000000WZ2P1oOgl06`1oOgl00`000000Ogmo07moO`0807moO`<02NX:4@1oOgl2
00WZ2Pd0Ogmo00D000000?ooo`09jPX0oooo0000000@07moO`0300WZ2P1oOgl0Ogmo0180Ogmo00<0
2NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0=07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<0
000000WZ2P3oool02@3oool00`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo00L0oooo00<0
2NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo03l0oooo00<0
00000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool01@3oool300WZ2Ql0oooo00<00000
00WZ2P3oool06P3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool02NX:03P0oooo00<00000
00WZ2P1oOgl06`1oOgl00`000000Ogmo07moO`0;07moO`<02NX:3@1oOgl01009jPX0Ogmo00WZ2P00
000=07moO`030000003oool02NX:00l0Ogmo0P09jPXD07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<0
2NX:07moO`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0;07moO`0300000009jPX0oooo00T0oooo00<0
2NX:0?ooo`3oool07@3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00l0oooo00<0
2NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`100?ooo`030000003oool0oooo00`0oooo0020
0?ooo`030000003oool0oooo00P0oooo0P09jPXM0?ooo`0400000009jPX02NX:00WZ2QT0oooo00<0
2NX:0?ooo`3oool04P3oool01009jPX0oooo0?ooo`09jPXg0?ooo`0300000009jPX0Ogmo01`0Ogmo
00<0000007moO`1oOgl03@1oOgl300WZ2PT0Ogmo00<02NX:07moO`1oOgl00P00000>07moO`030000
0009jPX0Ogmo00d0Ogmo00<02NX:07moO`1oOgl0501oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ
2P1oOgl0Ogmo00h0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`000000oooo00WZ2P090?ooo`0300WZ
2P3oool0oooo01h0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ
2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool0@03oool00`000000oooo0?ooo`0<0?ooo`00P03o
ool00`000000oooo0?ooo`0:0?ooo`802NX:7@3oool01009jPX0oooo00WZ2P09jPXH0?ooo`0300WZ
2P3oool0oooo0180oooo00@02NX:0?ooo`3oool02NX:=@3oool00`000000Ogmo00WZ2P0M07moO`03
0000001oOgl0Ogmo0100Ogmo0`09jPX407moO`802NX:0`1oOgl00`09jPX0Ogmo07moO`0;07moO`80
00000P1oOgl00`09jPX0Ogmo07moO`0907moO`802NX:5P1oOgl00`09jPX0Ogmo07moO`0707moO`03
00WZ2P1oOgl0Ogmo00h0Ogmo00<02NX:07moO`1oOgl02`1oOgl00`000000oooo00WZ2P090?ooo`03
00WZ2P3oool0oooo01h0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0?0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0@@3oool00`000000oooo0?ooo`0<0?ooo`00
P03oool00`000000oooo0?ooo`0<0?ooo`802NX:6`3oool01009jPX0oooo0?ooo`3oool200WZ2QH0
oooo00<02NX:0?ooo`3oool04P3oool01@09jPX0oooo0?ooo`3oool02NX:03@0oooo00@0000007mo
O`1oOgl02NX:701oOgl00`000000Ogmo07moO`0C07moO`802NX:00<0Ogmo00WZ2P1oOgl01@1oOgl0
0`09jPX0Ogmo07moO`0907moO`030000001oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl0201oOgl0
0`09jPX0Ogmo07moO`0E07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl03P1oOgl0
0`09jPX0Ogmo07moO`0;07moO`040000003oool0oooo00WZ2PP0oooo00<02NX:0?ooo`3oool07P3o
ool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool02`3o
ool00`09jPX0oooo0?ooo`120?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0
oooo00h0oooo0P09jPXJ0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0503oool0
0`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0<@3oool0
10000000Ogmo07moO`09jPXM07moO`030000001oOgl0Ogmo01@0Ogmo0`09jPX507moO`0300WZ2P1o
Ogl0Ogmo00P0Ogmo00<0000007moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0507moO`802NX:601o
Ogl00`09jPX0Ogmo07moO`0807moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00<02NX:07moO`1oOgl02`1o
Ogl01@000000oooo0?ooo`3oool02NX:00L0oooo00<02NX:0?ooo`3oool07`3oool01@09jPX0oooo
0?ooo`3oool02NX:0100oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`120?ooo`03
0000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo0100oooo0P09jPXH0?ooo`0300WZ
2P3oool0oooo00<0oooo0P09jPXE0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0
0`3oool00`09jPX0oooo0?ooo`0`0?ooo`040000001oOgl0Ogmo00WZ2Qd0Ogmo00<0000007moO`1o
Ogl04`1oOgl01009jPX0Ogmo07moO`1oOgl300WZ2P80Ogmo00<02NX:07moO`1oOgl01`1oOgl00`00
0000Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl05`1oOgl00`09
jPX0Ogmo07moO`0907moO`0300WZ2P1oOgl0Ogmo00l0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`00
0000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0803oool00`09
jPX0oooo00WZ2P0@0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0@`3oool00`00
0000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0B0?ooo`802NX:5`3oool00`09jPX0
oooo0?ooo`040?ooo`802NX:4`3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo00<0
oooo00<02NX:0?ooo`3oool0;P3oool00`000000Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo01X0
Ogmo00<0000007moO`1oOgl04@1oOgl200WZ2PL0Ogmo1009jPX707moO`030000001oOgl0Ogmo00L0
Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPXJ07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<02NX:07mo
O`1oOgl03`1oOgl00`09jPX0Ogmo07moO`0;07moO`050000003oool0oooo0?ooo`09jPX01P3oool0
0`09jPX0oooo0?ooo`0P0?ooo`0300WZ2P3oool02NX:0100oooo00<02NX:0?ooo`3oool02P3oool0
0`09jPX0oooo0?ooo`140?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo
01@0oooo0P09jPXE0?ooo`0300WZ2P3oool0oooo00H0oooo0P09jPXB0?ooo`0300WZ2P3oool0oooo
0100oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo
0080Ogmo00<02NX:07moO`1oOgl06`1oOgl00`000000Ogmo07moO`0?07moO`0300WZ2P1oOgl0Ogmo
00X0Ogmo0`09jPX307moO`8000002P1oOgl01009jPX0Ogmo07moO`09jPXK07moO`0300WZ2P1oOgl0
Ogmo00X0Ogmo00<02NX:07moO`1oOgl03`1oOgl00`09jPX0Ogmo07moO`0;07moO`030000003oool0
oooo0080oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P3oool0
oooo00h0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`150?ooo`030000003oool0
oooo00`0oooo00200?ooo`030000003oool0oooo01H0oooo0`09jPXB0?ooo`0300WZ2P3oool0oooo
00P0oooo0P09jPX@0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool01@3oool00`09
jPX0oooo0?ooo`0/0?ooo`030000001oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl06`1oOgl00`00
0000Ogmo07moO`0>07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<02NX:07moO`1oOgl00P09jPX00`00
0000Ogmo07moO`0;07moO`802NX:701oOgl00`09jPX0Ogmo07moO`0:07moO`0300WZ2P1oOgl0Ogmo
00l0Ogmo00<02NX:07moO`1oOgl02`1oOgl00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo
0080oooo00<02NX:0?ooo`3oool08@3oool200WZ2Pl0oooo00<02NX:0?ooo`3oool02P3oool00`09
jPX0oooo0?ooo`150?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo01T0
oooo0P09jPXA0?ooo`0300WZ2P3oool0oooo00T0oooo0P09jPX?0?ooo`0300WZ2P3oool0oooo0100
oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0[0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<02NX:07moO`1oOgl06P1oOgl00`000000Ogmo07moO`0<07moO`802NX:3`1oOgl01009jPX0
Ogmo07moO`00000300WZ2PX0Ogmo0P09jPXL07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<02NX:07mo
O`1oOgl0401oOgl00`09jPX0Ogmo07moO`0:07moO`030000003oool0oooo00@0oooo00<02NX:0?oo
o`3oool00P3oool00`09jPX0oooo0?ooo`0O0?ooo`0400WZ2P3oool0oooo00WZ2Pd0oooo00<02NX:
0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`160?ooo`030000003oool0oooo00`0oooo00200?oo
o`030000003oool0oooo01/0oooo0P09jPX?0?ooo`0300WZ2P3oool0oooo00/0oooo0P09jPX=0?oo
o`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0Y0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl06`1oOgl00`000000Ogmo07moO`0:07mo
O`0300WZ2P1oOgl0Ogmo00l0Ogmo00<02NX:07moO`000000101oOgl300WZ2PH0Ogmo00@02NX:07mo
O`1oOgl02NX:6`1oOgl00`09jPX0Ogmo07moO`0;07moO`0300WZ2P1oOgl0Ogmo0100Ogmo00<02NX:
07moO`1oOgl02`1oOgl00`000000oooo0?ooo`040?ooo`0500WZ2P3oool0oooo0?ooo`09jPX08@3o
ool01009jPX0oooo0?ooo`09jPX=0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool0
A`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0M0?ooo`802NX:3P3o
ool00`09jPX0oooo0?ooo`0<0?ooo`802NX:303oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3o
ool0oooo00L0oooo00<02NX:0?ooo`3oool0:03oool00`000000Ogmo07moO`0407moO`0300WZ2P1o
Ogl0Ogmo01/0Ogmo00<0000007moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0@07moO`0300WZ2P00
0000Ogmo00L0Ogmo0`09jPX00`1oOgl02NX:00WZ2P0307moO`0300WZ2P1oOgl0Ogmo01P0Ogmo00<0
2NX:07moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0@07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<0
00000?ooo`3oool01@3oool01009jPX0oooo0?ooo`09jPXP0?ooo`0300WZ2P3oool0oooo0080oooo
00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo04L0oooo
00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool07`3oool200WZ2P`0oooo00<0
2NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00l0oooo00<0
2NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0W0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0
2NX:07moO`1oOgl06P1oOgl00`000000Ogmo07moO`0707moO`802NX:4P1oOgl20000000300WZ2P1o
Ogl0Ogmo00T0Ogmo0`09jPX407moO`0300WZ2P1oOgl0Ogmo01L0Ogmo00<02NX:07moO`1oOgl0301o
Ogl00`09jPX0Ogmo07moO`0A07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool01@3o
ool01009jPX0oooo0?ooo`09jPXP0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
1`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo04P0oooo00<000000?ooo`3oool0
303oool00800oooo00<000000?ooo`3oool08@3oool200WZ2P/0oooo00<02NX:0?ooo`3oool03P3o
ool200WZ2PX0oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3o
ool0oooo02H0oooo00<0000007moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0K07moO`030000001o
Ogl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl04@1oOgl010000000Ogmo07moO`09jPX907moO`802NX:
0`1oOgl00`09jPX0000007moO`0207moO`0300WZ2P1oOgl0Ogmo01D0Ogmo00<02NX:07moO`1oOgl0
3@1oOgl00`09jPX0Ogmo07moO`0A07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
1P3oool00`09jPX0oooo00WZ2P0O0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
1`3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo04T0oooo00<000000?ooo`3oool0
303oool00800oooo0P00000T0?ooo`802NX:2@3oool00`09jPX0oooo0?ooo`0@0?ooo`802NX:2@3o
ool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool09@3o
ool00`000000Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo01/0Ogmo00<0000007moO`1oOgl0101o
Ogl00`09jPX0Ogmo07moO`0A07moO`050000001oOgl0Ogmo07moO`09jPX0201oOgl00`09jPX0Ogmo
07moO`0307moO`80000000@02NX:07moO`1oOgl02NX:5`1oOgl00`09jPX0Ogmo07moO`0=07moO`03
00WZ2P1oOgl0Ogmo0140Ogmo00<02NX:07moO`1oOgl02P1oOgl00`000000oooo0?ooo`070?ooo`80
2NX:7`3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3o
ool02P3oool00`09jPX0oooo0?ooo`190?ooo`030000003oool0oooo00`0oooo00200?ooo`800000
0P09jPXT0?ooo`802NX:203oool00`09jPX0oooo0?ooo`0A0?ooo`802NX:1`3oool00`09jPX0oooo
0?ooo`0?0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool08`3oool00`000000Ogmo
07moO`0707moO`0300WZ2P1oOgl0Ogmo01X0Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2Q<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0307moO`802NX:2@1oOgl200WZ2P0307mo
O`09jPX0Ogmo01@0Ogmo00<02NX:07moO`1oOgl03P1oOgl00`09jPX0Ogmo07moO`0A07moO`0300WZ
2P1oOgl0Ogmo00P0Ogmo0P0000000`1oOgl000000?ooo`080?ooo`0300WZ2P3oool0oooo01`0oooo
00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00T0oooo
00<02NX:0?ooo`3oool0BP3oool00`000000oooo0?ooo`0<0?ooo`00P03oool010000000oooo0?oo
o`3oool200WZ2R@0oooo0`09jPX50?ooo`0300WZ2P3oool0oooo01<0oooo0P09jPX60?ooo`0300WZ
2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0R0?ooo`030000
001oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl06`1oOgl010000000Ogmo07moO`09jPXD07moO`03
0000001oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0;07moO`80
2NX:5@1oOgl00`09jPX0Ogmo07moO`0>07moO`0300WZ2P1oOgl0Ogmo0180Ogmo00<02NX:07moO`1o
Ogl01`1oOgl20000000307moO`000000oooo00T0oooo00<02NX:0?ooo`3oool06`3oool00`09jPX0
oooo0?ooo`070?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0
oooo0?ooo`1;0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo00<0oooo
0P09jPXU0?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`0E0?ooo`802NX:1@3oool00`09jPX0oooo
0?ooo`0=0?ooo`0300WZ2P3oool0oooo00/0oooo0P09jPXR0?ooo`030000001oOgl0Ogmo00L0Ogmo
00<02NX:07moO`1oOgl06`1oOgl00`000000Ogmo00WZ2P0C07moO`8000001`1oOgl00`09jPX0Ogmo
07moO`0200WZ2Q00Ogmo00<02NX:07moO`1oOgl04@1oOgl00`09jPX0Ogmo07moO`0?07moO`0300WZ
2P1oOgl0Ogmo0180Ogmo00<02NX:07moO`1oOgl01`1oOgl01009jPX0Ogmo07moO`00000:0?ooo`80
2NX:6`3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3o
ool02@3oool00`09jPX0oooo0?ooo`1:0?ooo`8000003P3oool00800oooo00<000000?ooo`3oool0
1@3oool00`09jPX0oooo0?ooo`0T0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`0F0?ooo`802NX:
0`3oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool0
7`3oool00`000000Ogmo07moO`0807moO`0300WZ2P1oOgl0Ogmo01X0Ogmo00<0000000WZ2P1oOgl0
4P1oOgl00`000000Ogmo07moO`0807moO`802NX:4P1oOgl300WZ2Q40Ogmo00<02NX:07moO`1oOgl0
3`1oOgl00`09jPX0Ogmo07moO`0B07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00@02NX:07moO`1oOgl0
00002P3oool00`09jPX0oooo00WZ2P0J0?ooo`0300WZ2P3oool0oooo00X0oooo00@02NX:0?ooo`3o
ool02NX:2`3oool00`09jPX0oooo0?ooo`1;0?ooo`8000003P3oool00800oooo00<000000?ooo`3o
ool01P3oool200WZ2RH0oooo0`09jPXJ0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`0=0?ooo`03
00WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool07@3oool00`000000Ogmo07moO`0907moO`03
00WZ2P1oOgl0Ogmo01T0Ogmo0P09jPX00`000000Ogmo07moO`0@07moO`030000001oOgl0Ogmo00P0
Ogmo0P09jPXC07moO`0300000009jPX0Ogmo00802NX:3P1oOgl00`09jPX0Ogmo07moO`0@07moO`03
00WZ2P1oOgl0Ogmo0180Ogmo00<02NX:07moO`1oOgl01`1oOgl01@09jPX0Ogmo07moO`1oOgl00000
00T0oooo00<02NX:0?ooo`09jPX06@3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool02NX:
00X0oooo00<02NX:0?ooo`3oool0B`3oool00`09jPX0oooo0000000>0?ooo`00P03oool00`000000
oooo0?ooo`080?ooo`802NX:9P3oool200WZ2Q/0oooo0`09jPX?0?ooo`0300WZ2P3oool0oooo00h0
oooo00<02NX:0?ooo`3oool0703oool00`000000Ogmo07moO`0907moO`0300WZ2P1oOgl0Ogmo01P0
Ogmo00@02NX:07moO`1oOgl000004@1oOgl00`000000Ogmo07moO`0807moO`0300WZ2P1oOgl02NX:
01@0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0=07moO`0300WZ2P1oOgl0Ogmo0100Ogmo00<02NX:
07moO`1oOgl04`1oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<00000
0?ooo`3oool01`3oool01009jPX0oooo0?ooo`09jPXH0?ooo`0300WZ2P3oool0oooo00`0oooo0P09
jPX;0?ooo`0300WZ2P3oool0oooo04X0oooo00@02NX:0?ooo`3oool000003P3oool00800oooo00<0
00000?ooo`3oool02P3oool200WZ2RD0oooo0`09jPXK0?ooo`802NX:3`3oool00`09jPX0oooo0?oo
o`0>0?ooo`0300WZ2P3oool0oooo01/0oooo00<0000007moO`1oOgl02@1oOgl00`09jPX0Ogmo07mo
O`0G07moO`0500WZ2P1oOgl0Ogmo07moO`000000401oOgl00`000000Ogmo07moO`0707moO`802NX:
00<0000007moO`09jPX05@1oOgl01009jPX0Ogmo07moO`1oOgl200WZ2PX0Ogmo00<02NX:07moO`1o
Ogl04@1oOgl00`09jPX0Ogmo07moO`0C07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1o
Ogl00P1oOgl00`000000oooo0?ooo`070?ooo`0500WZ2P3oool0oooo0?ooo`09jPX05`3oool00`09
jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0B@3oool200WZ
2P<0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0303oool200WZ2R@0
oooo00@02NX:0?ooo`09jPX02NX:6P3oool200WZ2Ph0oooo00<02NX:0?ooo`3oool03`3oool00`09
jPX0oooo0?ooo`0J0?ooo`030000001oOgl0Ogmo00X0Ogmo00<02NX:07moO`1oOgl0501oOgl200WZ
2PD0Ogmo00<0000007moO`1oOgl02`1oOgl2000000T0Ogmo00@02NX:07moO`00000000000P1oOgl0
0`09jPX0Ogmo07moO`0C07moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P09jPX807moO`0300WZ2P1oOgl0
Ogmo0140Ogmo00<02NX:07moO`1oOgl04`1oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0
Ogmo0080Ogmo00<000000?ooo`3oool01`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0
oooo01<0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo00WZ2P080?ooo`0300WZ2P3oool0
oooo04T0oooo00<02NX:0?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`00
0000oooo0?ooo`0>0?ooo`802NX:8P3oool01009jPX0oooo0?ooo`3oool200WZ2PP000004@3oool3
00WZ2P`0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`0H0?ooo`030000001oOgl0
Ogmo00/0Ogmo00<02NX:07moO`1oOgl04`1oOgl00`09jPX0Ogmo07moO`0507moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0
Ogmo01@0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0
Ogmo00H0Ogmo1P00000607moO`0300WZ2P1oOgl0Ogmo01<0Ogmo00<02NX:07moO`1oOgl01@1oOgl0
0`09jPX0Ogmo07moO`0307moO`030000003oool0oooo00L0oooo00<02NX:0?ooo`3oool00P3oool0
0`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo00`0oooo00@02NX:0?ooo`3oool02NX:203o
ool00`09jPX0oooo0?ooo`0=0?ooo`P00000<`3oool00`09jPX0oooo0?ooo`040?ooo`030000003o
ool0oooo00`0oooo00200?ooo`030000003oool0oooo0100oooo0P09jPXP0?ooo`0300WZ2P3oool0
oooo00<0oooo0`09jPX507moO`l000000`3oool01009jPX0oooo00WZ2P09jPX:0?ooo`0300WZ2P3o
ool0oooo0140oooo00<02NX:0?ooo`3oool05`3oool00`000000Ogmo07moO`0;07moO`0300WZ2P1o
Ogl0Ogmo0180Ogmo00<02NX:07moO`1oOgl01P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0D07moO`0300WZ2P1o
Ogl0Ogmo00@0Ogmo0P09jPX407moO`0300WZ2P000000000000H00000101oOgl00`000000Ogmo0000
000507moO`0300WZ2P1oOgl0Ogmo01@0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07mo
O`0307moO`030000003oool0oooo00L0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`0@0?ooo`0300WZ2P3oool0oooo00d0oooo00D02NX:0?ooo`3oool0oooo00WZ2P060?ooo`0300WZ
2P3oool0000000h000001@1oOgl00`000000Ogmo0000000a0?ooo`802NX:1`3oool00`000000oooo
0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0B0?ooo`802NX:7`3oool00`09jPX0oooo0?oo
o`030?ooo`040000001oOgl02NX:00WZ2Q80Ogmo0`0000001009jPX0000000000000000200WZ2PH0
00000`3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo01H0oooo00<0000007moO`1o
Ogl0301oOgl00`09jPX0Ogmo07moO`0?07moO`802NX:2P1oOgl00`000000Ogmo07moO`0707moO`03
0000001oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`09jPX0Ogmo07moO`0D07moO`04
00WZ2P1oOgl0Ogmo07moO`@000000P09jPX00`0000002NX:07moO`0<07moO`040000001oOgl0Ogmo
000000@0Ogmo00<02NX:07moO`1oOgl0501oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool01`3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0
oooo0100oooo00<02NX:0?ooo`3oool02`3oool00`0000002NX:000000040000000300WZ2P000000
00000080000000<02NX:0000000000004`1oOgl00`000000Ogmo0000000a0?ooo`0300WZ2P3oool0
oooo00L0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0503oool00`09
jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo00<0oooo00@0000007moO`1oOgl0Ogmo0P09jPXD
07moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P09jPX407moO`<0000000<02NX:0000000000002@000009
0?ooo`0300WZ2P3oool0oooo01D0oooo00<0000007moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0>
07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`08
07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl03`1oOgl60000000300WZ2P000000
000000H0Ogmo0P09jPX<07moO`030000001oOgl0Ogmo0080Ogmo00D0000007moO`1oOgl0Ogmo00WZ
2P0F07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0101oOgl00`000000oooo0?oo
o`070?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX000000000
000<0000000307moO`09jPX0Ogmo00@0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0D07moO`800000
0P1oOgl00`000000oooo0?ooo`0^0?ooo`0300WZ2P3oool0oooo00P0oooo00<000000?ooo`3oool0
303oool00800oooo00<000000?ooo`3oool05@3oool200WZ2Qd0oooo00<02NX:0?ooo`3oool00P3o
ool00`000000Ogmo07moO`0307moO`802NX:4P1oOgl00`09jPX0Ogmo07moO`0407moO`802NX:1@1o
Ogl00`09jPX0Ogmo07moO`0907moO`X0000000<02NX:0000000000000P00000A0?ooo`030000001o
Ogl0Ogmo00d0Ogmo00<02NX:07moO`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00@0Ogmo0P00000:07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl01P1o
Ogl9000000L0Ogmo00<02NX:07moO`1oOgl01@1oOgl300WZ2P/0Ogmo00<0000007moO`1oOgl00`1o
Ogl010000000Ogmo07moO`09jPXF07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0
1@1oOgl00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:000000000000
3@0000000`09jPX0Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00@02NX:07moO`1oOgl0
2NX:4`1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo02`0oooo0P09jPX;0?ooo`03
0000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo01L0oooo0P09jPXK0?ooo`0300WZ
2P3oool0oooo00<0oooo00<0000007moO`1oOgl0101oOgl200WZ2Q40Ogmo00<02NX:07moO`1oOgl0
1@1oOgl200WZ2P@0Ogmo00<02NX:07moO`1oOgl04`1oOgl01009jPX0Ogmo07moO`1oOgl>000000<0
oooo00<0000007moO`1oOgl03P1oOgl00`09jPX0Ogmo07moO`0:07moO`802NX:3`1oOgl00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo00P0Ogmo0P09jPX=07moO`0300WZ2P000000000000D0
0000401oOgl00`09jPX0Ogmo07moO`0507moO`802NX:00<0000000WZ2P09jPX02@1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl02NX:01L0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0
Ogmo07moO`0507moO`040000003oool0oooo0?ooo`D0000000<02NX:0000000000001P0000000`09
jPX0Ogmo07moO`0;07moO`0300WZ2P1oOgl0Ogmo00d0Ogmo00<02NX:07moO`1oOgl01P1oOgl200WZ
2Q80Ogmo0P00000407moO`030000003oool0oooo02`0oooo00<02NX:0?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0I0?ooo`802NX:6P3oool00`09jPX0
oooo0?ooo`020?ooo`030000001oOgl0Ogmo00H0Ogmo0P09jPX@07moO`0300WZ2P1oOgl0Ogmo00H0
Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0F07moO`0300WZ2P1oOgl0Ogmo00h0Ogmo3`00000507mo
O`0300WZ2P1oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl03`1oOgl01@000000Ogmo07moO`1oOgl0
000000X0Ogmo00<02NX:07moO`1oOgl0101oOgl90000000300WZ2P1oOgl0Ogmo0180Ogmo0P000002
07moO`L02NX:0P1oOgl20000000307moO`09jPX02NX:00H0Ogmo00<0000007moO`1oOgl01P1oOgl0
0`0000002NX:07moO`0F07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl01@1oOgl4
000000D0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`09jPX0Ogmo07moO`0:07moO`0300WZ2P1oOgl0
Ogmo00`0Ogmo00<02NX:07moO`1oOgl01`1oOgl200WZ2Q40Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`0Z0?ooo`802NX:3P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`00
0000oooo0?ooo`0K0?ooo`802NX:603oool00`09jPX0oooo0?ooo`030?ooo`030000001oOgl0Ogmo
00L0Ogmo0P09jPX>07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo0P09jPX00`1oOgl02NX:07moO`0F07mo
O`0300WZ2P1oOgl0Ogmo01`0Ogmo1@0000000`09jPX00000000000070000000307moO`09jPX0Ogmo
0140Ogmo00@0000007moO`1oOgl000002P1oOgl00`09jPX0000000000005000000T0Ogmo00<02NX:
07moO`1oOgl04P1oOgl01P0000002NX:00WZ2P09jPX0Ogmo00WZ2P@0Ogmo00<02NX:07moO`1oOgl0
101oOgl300WZ2P@0Ogmo00<0000007moO`1oOgl01`1oOgl00`09jPX0Ogmo07moO`0E07moO`0300WZ
2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl01@1oOgl00`000000Ogmo07moO`0707moO`0300WZ
2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0=07moO`0300WZ
2P1oOgl0Ogmo00L0Ogmo0P09jPX@07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
:P3oool00`09jPX0oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003o
ool0oooo00X0oooo0P00000A0?ooo`802NX:5`3oool00`09jPX0oooo0?ooo`020?ooo`030000001o
Ogl0Ogmo00T0Ogmo0P09jPX=07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo0`09jPXG07moO`0300WZ2P1o
Ogl0Ogmo0240Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09jPX000000000000<000000H0Ogmo0P00
000207moO`P0000000<02NX:07moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0B07moO`0300WZ2P1o
Ogl0Ogmo0080Ogmo00@02NX:07moO`1oOgl02NX:2@1oOgl300WZ2P80Ogmo00<0000007moO`1oOgl0
1`1oOgl00`09jPX0000007moO`0F07moO`0400WZ2P1oOgl0Ogmo00WZ2PT0Ogmo00<0000007moO`1o
Ogl01P1oOgl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<02NX:07moO`1o
Ogl0301oOgl00`09jPX0Ogmo07moO`0707moO`0400WZ2P1oOgl0Ogmo00WZ2Pd0Ogmo0P00000707mo
O`030000003oool0oooo02T0oooo00<02NX:0?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?oo
o`00P03oool00`000000oooo0?ooo`0:0?ooo`8000000P09jPXA0?ooo`802NX:5@3oool00`09jPX0
oooo0?ooo`020?ooo`030000001oOgl0Ogmo00/0Ogmo0`09jPX:07moO`0300WZ2P1oOgl0Ogmo00X0
Ogmo0P09jPX2000001D0Ogmo00<02NX:07moO`1oOgl0801oOgl00`09jPX0Ogmo07moO`0407moO`80
2NX:3`1oOgl:000000L0Ogmo00<02NX:07moO`1oOgl04@1oOgl00`09jPX0Ogmo07moO`0B07moO`03
00WZ2P1oOgl0Ogmo0080Ogmo00@02NX:07moO`1oOgl02NX:2`1oOgl300WZ2PX0Ogmo00<02NX:07mo
O`0000005P1oOgl01009jPX0Ogmo07moO`09jPX907moO`030000001oOgl0Ogmo00H0Ogmo00<02NX:
07moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00d0Ogmo00<02NX:
07moO`1oOgl01P1oOgl01P09jPX0Ogmo07moO`1oOgl0000000WZ2P/0Ogmo00<0000007moO`1oOgl0
1`1oOgl00`000000oooo0?ooo`0W0?ooo`802NX:4P3oool00`000000oooo0?ooo`0<0?ooo`00P03o
ool00`000000oooo0?ooo`0>0?ooo`802NX:4@3oool200WZ2Q<0oooo00<02NX:0?ooo`3oool00`3o
ool00`000000Ogmo07moO`0=07moO`802NX:2@1oOgl00`09jPX0Ogmo07moO`0907moO`0400WZ2P1o
Ogl02NX:000001H0Ogmo00<02NX:07moO`1oOgl07`1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ
2P1oOgl0Ogmo0180Ogmo0P0000000`1oOgl0000007moO`0807moO`0300WZ2P1oOgl0Ogmo0180Ogmo
00<02NX:07moO`1oOgl04P1oOgl00`09jPX0Ogmo07moO`0307moO`802NX:3@1oOgl300WZ2PT0Ogmo
00@02NX:07moO`1oOgl000005@1oOgl01009jPX0Ogmo07moO`09jPX907moO`030000001oOgl0Ogmo
00H0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo
00`0Ogmo00<02NX:07moO`1oOgl01`1oOgl01P09jPX0Ogmo07moO`1oOgl0000000WZ2PX0Ogmo00<0
000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo0180oooo00<0
00000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0403oool300WZ2Q00oooo00<02NX:
0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`020?ooo`030000001oOgl0Ogmo00l0Ogmo0P09jPX7
07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo0P09jPXH07moO`0300WZ2P1oOgl0Ogmo01l0Ogmo00D02NX:
07moO`1oOgl0Ogmo00WZ2P0D07moO`050000001oOgl0Ogmo07moO`0000001`1oOgl200WZ2QH0Ogmo
00<02NX:07moO`1oOgl04@1oOgl00`09jPX0Ogmo07moO`0307moO`802NX:3P1oOgl0100000002NX:
00WZ2P09jPX707moO`0500WZ2P1oOgl0Ogmo07moO`000000501oOgl01009jPX0Ogmo07moO`09jPX9
07moO`030000001oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`09jPX0Ogmo07moO`03
07moO`0300WZ2P1oOgl0Ogmo00d0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`03
07moO`802NX:1`1oOgl2000000X0Ogmo00<000000?ooo`3oool09P3oool00`09jPX0oooo0?ooo`0C
0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo01<0oooo0P09jPX?0?oo
o`802NX:4@3oool00`09jPX0oooo0?ooo`030?ooo`030000001oOgl0Ogmo0100Ogmo0P09jPX607mo
O`0300WZ2P1oOgl0Ogmo00T0Ogmo0P09jPXI07moO`0300WZ2P1oOgl0Ogmo01h0Ogmo00@02NX:07mo
O`09jPX02NX:4`1oOgl2000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0F
07moO`0300WZ2P1oOgl0Ogmo0140Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo00WZ2P0<
07moO`040000001oOgl0Ogmo07moO`<02NX:1@1oOgl00`09jPX0Ogmo07moO`0207moO`030000001o
Ogl0Ogmo0180Ogmo00<02NX:07moO`09jPX02P1oOgl00`000000Ogmo07moO`0507moO`0300WZ2P1o
Ogl0Ogmo00/0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0<07moO`0300WZ2P1o
Ogl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo00WZ2P0607moO`030000001o
Ogl0Ogmo00T0Ogmo00<000000?ooo`3oool09@3oool200WZ2QH0oooo00<000000?ooo`3oool0303o
ool00800oooo00<000000?ooo`3oool05@3oool200WZ2Pl0oooo0P09jPX@0?ooo`0300WZ2P3oool0
oooo0080oooo00<0000007moO`1oOgl04P1oOgl200WZ2PD0Ogmo00<02NX:07moO`1oOgl0201oOgl2
00WZ2QX0Ogmo00<02NX:07moO`1oOgl07@1oOgl200WZ2Q<0Ogmo0P00000707moO`030000001oOgl0
Ogmo0080Ogmo00<02NX:07moO`1oOgl05`1oOgl00`09jPX0Ogmo07moO`0A07moO`0300WZ2P1oOgl0
Ogmo0080Ogmo00@02NX:07moO`1oOgl02NX:301oOgl00`000000Ogmo07moO`0207moO`0400WZ2P00
00002NX:00WZ2P<0Ogmo00<02NX:07moO`1oOgl00`1oOgl200000180Ogmo0P09jPX;07moO`030000
001oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl0301oOgl01009jPX0Ogmo07moO`09jPX>07moO`03
00WZ2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo00WZ2P0407moO`80
0000301oOgl00`000000oooo0?ooo`0T0?ooo`0300WZ2P3oool0oooo01H0oooo00<000000?ooo`3o
ool0303oool00800oooo00<000000?ooo`3oool05`3oool200WZ2Pl0oooo0P09jPX>0?ooo`0300WZ
2P3oool0oooo0080oooo00<0000007moO`1oOgl0501oOgl200WZ2P<0Ogmo00<02NX:07moO`1oOgl0
0P09jPX707moO`802NX:6P1oOgl200WZ2Qd0Ogmo0P09jPXA07moO`8000002@1oOgl01@000000Ogmo
07moO`1oOgl02NX:01/0Ogmo00<02NX:07moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0207moO`05
00WZ2P1oOgl0Ogmo07moO`09jPX02`1oOgl00`000000Ogmo07moO`0407moO`0600WZ2P0000002NX:
00WZ2P1oOgl02NX:1`1oOgl00`000000Ogmo07moO`0?07moO`802NX:2`1oOgl00`000000Ogmo07mo
O`0507moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00@02NX:07moO`1oOgl02NX:3P1oOgl00`09jPX0Ogmo
07moO`0607moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00@02NX:07moO`1oOgl02NX:0P1oOgl00`000000
Ogmo07moO`0<07moO`030000003oool0oooo02<0oooo00<02NX:0?ooo`3oool05`3oool00`000000
oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0I0?ooo`802NX:3`3oool200WZ2Pd0oooo
00<02NX:0?ooo`3oool00P3oool00`000000Ogmo07moO`0E07moO`802NX:0P1oOgl01@09jPX0Ogmo
0000000000002NX:00H0Ogmo0P09jPXL07moO`0300WZ2P1oOgl0Ogmo01P0Ogmo0P09jPX00`1oOgl0
2NX:07moO`0>07moO`800000301oOgl00`000000Ogmo00WZ2P0L07moO`0300WZ2P1oOgl0Ogmo0100
Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0507moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<0000007mo
O`1oOgl0101oOgl300WZ2P0407moO`0000002NX:00WZ2PP0Ogmo00<0000007moO`1oOgl03P1oOgl2
00WZ2P/0Ogmo00<0000007moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0<07moO`0300WZ2P1oOgl0
2NX:00d0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0407moO`0700WZ2P1oOgl0
Ogmo07moO`09jPX0Ogmo0000000>07moO`030000003oool0oooo0280oooo0P09jPXJ0?ooo`030000
003oool0oooo00`0oooo00200?ooo`030000003oool0oooo01/0oooo0P09jPX?0?ooo`802NX:2`3o
ool00`09jPX0oooo0?ooo`020?ooo`030000001oOgl0Ogmo01L0Ogmo1009jPX307moO`0300WZ2P1o
Ogl0Ogmo00<0Ogmo0P09jPXM07moO`0300WZ2P1oOgl0Ogmo01H0Ogmo00D02NX:07moO`1oOgl0Ogmo
00WZ2P0>07moO`030000001oOgl0Ogmo00`0Ogmo00<0000000WZ2P1oOgl0701oOgl00`09jPX0Ogmo
07moO`0@07moO`0500WZ2P1oOgl0Ogmo07moO`09jPX01@1oOgl00`09jPX0Ogmo07moO`0707moO`04
0000001oOgl0Ogmo07moO`<02NX:0P1oOgl01009jPX0Ogmo00000000000300WZ2PL0Ogmo00<00000
07moO`1oOgl03P1oOgl00`09jPX0Ogmo07moO`0:07moO`030000001oOgl0Ogmo00D0Ogmo00<02NX:
07moO`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:
07moO`1oOgl0101oOgl01P09jPX0Ogmo07moO`1oOgl0000000WZ2Pl0Ogmo00<000000?ooo`3oool0
8@3oool00`09jPX0oooo0?ooo`0J0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003o
ool0oooo01d0oooo0`09jPX>0?ooo`802NX:2P3oool00`09jPX0oooo0?ooo`020?ooo`030000001o
Ogl0Ogmo01P0Ogmo0`09jPX307moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0701o
Ogl00`09jPX0Ogmo07moO`0D07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl02@1o
Ogl2000000l0Ogmo00<02NX:07moO`1oOgl0701oOgl00`09jPX0Ogmo07moO`0@07moO`0400WZ2P1o
Ogl0Ogmo00WZ2PL0Ogmo00<02NX:07moO`1oOgl01P1oOgl400WZ2P@0Ogmo00<02NX:07moO`1oOgl0
0P1oOgl00`09jPX0Ogmo07moO`0200WZ2PH0Ogmo00<0000007moO`1oOgl03@1oOgl00`09jPX0Ogmo
07moO`0:07moO`8000000P09jPX407moO`0300WZ2P1oOgl0Ogmo00d0Ogmo0P09jPX<07moO`0300WZ
2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl01@1oOgl01P09jPX0Ogmo07moO`000000Ogmo00WZ
2Ph0Ogmo00<000000?ooo`3oool08@3oool00`09jPX0oooo0?ooo`0K0?ooo`030000003oool0oooo
00`0oooo00200?ooo`030000003oool0oooo0200oooo0P09jPX>0?ooo`802NX:203oool00`09jPX0
oooo0?ooo`020?ooo`030000001oOgl0Ogmo01P0Ogmo00<02NX:07moO`09jPX00P09jPX207moO`03
00WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl07@1oOgl00`09jPX0Ogmo07moO`0A07moO`80
2NX:1P1oOgl00`09jPX0Ogmo07moO`0707moO`8000003`1oOgl200WZ2P0307moO`000000Ogmo01d0
Ogmo00<02NX:07moO`1oOgl03P1oOgl01@0000002NX:07moO`1oOgl02NX:00P0Ogmo00<02NX:07mo
O`1oOgl00P1oOgl300WZ2PP0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0207mo
O`802NX:1@1oOgl00`000000Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo0P0000000`09
jPX0Ogmo00WZ2P0307moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00@02NX:07moO`1oOgl02NX:2P1oOgl6
00WZ2P<0Ogmo00<02NX:07moO`1oOgl01@1oOgl01009jPX0Ogmo07moO`00000207moO`0300WZ2P1o
Ogl0Ogmo00`0Ogmo00<000000?ooo`3oool07`3oool200WZ2Qh0oooo00<000000?ooo`3oool0303o
ool00800oooo00<000000?ooo`3oool08P3oool200WZ2Ph0oooo00<02NX:0?ooo`3oool01@3oool0
0`09jPX0oooo0?ooo`030?ooo`030000001oOgl0Ogmo01H0Ogmo00@02NX:07moO`1oOgl02NX:0P1o
Ogl200WZ2P0307moO`09jPX02NX:0080Ogmo0P09jPXO07moO`0300WZ2P1oOgl0Ogmo00l0Ogmo00<0
2NX:07moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0507moO`800000401oOgl01@09jPX0Ogmo07mo
O`1oOgl0000001h0Ogmo00<02NX:07moO`1oOgl03P1oOgl0100000002NX:07moO`09jPX:07moO`@0
2NX:0P1oOgl00`000000Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1o
Ogl0101oOgl200WZ2P@0Ogmo00<0000007moO`1oOgl02P1oOgl200WZ2P`0Ogmo00<0000000WZ2P1o
Ogl00P1oOgl01009jPX0Ogmo07moO`09jPX>07moO`0500WZ2P1oOgl0Ogmo07moO`09jPX00P1oOgl8
00WZ2P<0Ogmo0P0000001009jPX0Ogmo07moO`09jPX707moO`0300WZ2P000000000000@0Ogmo00<0
2NX:07moO`1oOgl02P1oOgl00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo01h0oooo00<0
00000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0903oool200WZ2Pd0oooo0P09jPX6
0?ooo`0300WZ2P3oool0oooo0080oooo00<0000007moO`1oOgl05@1oOgl00`09jPX0Ogmo07moO`02
07moO`0400WZ2P1oOgl0Ogmo07moO`802NX:00H0Ogmo00WZ2P1oOgl0Ogmo00WZ2P00000O07moO`03
00WZ2P1oOgl0Ogmo00d0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`09jPX0Ogmo07moO`0307moO`80
00004@1oOgl00`09jPX0Ogmo07moO`0207moO`030000001oOgl0Ogmo01`0Ogmo00<02NX:07moO`1o
Ogl03`1oOgl00`09jPX0Ogmo00WZ2P0707moO`@02NX:1@1oOgl00`000000Ogmo07moO`0507moO`03
00WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl01P1oOgl200WZ2P<0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`09jPX0Ogmo00WZ2P0;07moO`0300WZ2P000000Ogmo00<0Ogmo0`09jPX=07moO`P0
2NX:1`1oOgl00`09jPX0Ogmo07moO`0407moO`802NX:201oOgl00`09jPX0Ogmo07moO`0407moO`03
00WZ2P1oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool07P3oool00`09jPX0oooo0?ooo`0O0?ooo`03
0000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo02H0oooo0P09jPX=0?ooo`802NX:
103oool00`09jPX0oooo0?ooo`020?ooo`030000001oOgl0Ogmo01D0Ogmo00<02NX:07moO`1oOgl0
0P1oOgl00`09jPX0Ogmo07moO`0307moO`<02NX:00<0Ogmo00WZ2P000000801oOgl00`09jPX0Ogmo
07moO`0;07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00D02NX:07moO`1oOgl0Ogmo0000000B07moO`03
00WZ2P1oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0701oOgl00`09jPX0Ogmo07moO`0>07moO`80
2NX:101oOgl400WZ2P@0Ogmo00D02NX:07moO`1oOgl0Ogmo0000000807moO`0300WZ2P1oOgl0Ogmo
00<0Ogmo00<02NX:07moO`1oOgl0201oOgl01@09jPX0Ogmo07moO`1oOgl0000000X0Ogmo00<02NX:
07moO`09jPX02`1oOgl00`09jPX0000007moO`0507moO`0300WZ2P1oOgl0Ogmo00@0Ogmo2009jPX5
07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl01@1oOgl200WZ2PH0Ogmo0P000000
0`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0703oool2
00WZ2R80oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0:03oool200WZ
2Pd0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo0080oooo00<0000007moO`1oOgl04`1oOgl00`09
jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00@0Ogmo0`09jPXR07moO`0300WZ2P1oOgl0Ogmo
00P0Ogmo0P09jPX<07moO`0400WZ2P1oOgl0000000000180Ogmo00<02NX:07moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0L07moO`0300WZ2P1oOgl0Ogmo00h0Ogmo0P09jPX0101oOgl02NX:00WZ2P09
jPX907moO`0400WZ2P1oOgl0Ogmo000000L0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo
07moO`0907moO`802NX:0P1oOgl00`000000Ogmo07moO`0707moO`0300WZ2P1oOgl02NX:00X0Ogmo
00<02NX:07moO`0000001`1oOgl00`09jPX0000000WZ2P0300WZ2PH0Ogmo00<02NX:07moO`1oOgl0
1@1oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl0
0P09jPX307moO`030000001oOgl02NX:00P0Ogmo00<02NX:07moO`1oOgl0201oOgl00`000000oooo
0?ooo`0L0?ooo`0300WZ2P3oool0oooo0280oooo00<000000?ooo`3oool0303oool00800oooo00<0
00000?ooo`3oool0:P3oool300WZ2P`0oooo0P09jPX00`3oool02NX:0?ooo`030?ooo`030000001o
Ogl0Ogmo01<0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0607moO`802NX:8P1o
Ogl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<02NX:0000001oOgl04P1o
Ogl00`09jPX0Ogmo07moO`0607moO`030000001oOgl0Ogmo01`0Ogmo00<02NX:07moO`1oOgl03@1o
Ogl400WZ2Pd0Ogmo00<02NX:07moO`0000001`1oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1o
Ogl0Ogmo00/0Ogmo0P09jPX00`1oOgl0000007moO`0707moO`0300WZ2P1oOgl02NX:00T0Ogmo00@0
2NX:07moO`1oOgl00000101oOgl400WZ2P8000002@1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ
2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ
2P1oOgl000000080Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0807moO`030000
003oool0oooo01X0oooo0P09jPXU0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003o
ool0oooo02d0oooo0P09jPX<0?ooo`<02NX:103oool00`000000Ogmo07moO`0A07moO`0300WZ2P1o
Ogl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl01P1oOgl300WZ2R40Ogmo00<02NX:07moO`1oOgl0101o
Ogl00`09jPX0Ogmo07moO`0;07moO`80000000<0Ogmo00WZ2P1oOgl04@1oOgl00`09jPX0Ogmo07mo
O`0807moO`030000001oOgl0Ogmo01`0Ogmo00<02NX:07moO`1oOgl02@1oOgl500WZ2Pl0Ogmo00<0
2NX:0000001oOgl01@1oOgl00`0000002NX:07moO`0607moO`0300WZ2P1oOgl0Ogmo00d0Ogmo0P09
jPX00`000000Ogmo07moO`0507moO`0400WZ2P1oOgl0Ogmo00WZ2PP0Ogmo00@02NX:07moO`1oOgl0
Ogmo1009jPX307moO`0400WZ2P1oOgl0Ogmo00WZ2PL0Ogmo00<02NX:07moO`1oOgl0201oOgl01@09
jPX0Ogmo07moO`1oOgl02NX:00H0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`0000002NX:07moO`02
07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo0P09jPX00`000000Ogmo07moO`0507moO`030000003oool0
oooo01X0oooo00<02NX:0?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`00
0000oooo0?ooo`0_0?ooo`802NX:303oool200WZ2P<0oooo00<0000007moO`1oOgl0401oOgl00`09
jPX0Ogmo07moO`0807moO`0300WZ2P1oOgl0Ogmo00D0Ogmo1P09jPXO07moO`0400WZ2P1oOgl0Ogmo
07moO`802NX:301oOgl2000000<0Ogmo00<02NX:07moO`1oOgl03P1oOgl200WZ2P/0Ogmo00<00000
07moO`1oOgl0701oOgl00`09jPX0Ogmo07moO`0507moO`@02NX:0P1oOgl00`0000002NX:07moO`0@
07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo0P00000707moO`0300WZ2P1oOgl0Ogmo00l0Ogmo0P09jPX5
07moO`0500WZ2P1oOgl0Ogmo07moO`09jPX01`1oOgl00`09jPX0Ogmo00WZ2P0200WZ2P030000001o
Ogl0Ogmo00@0Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPX507moO`0300WZ2P1oOgl0Ogmo00T0Ogmo
00<02NX:07moO`09jPX01P1oOgl00`09jPX0Ogmo07moO`0307moO`040000001oOgl0Ogmo00WZ2P80
00001`1oOgl200WZ2P0307moO`000000000000L0Ogmo00<000000?ooo`3oool06@3oool00`09jPX0
oooo0?ooo`0V0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo0340oooo
0P09jPX;0?ooo`<02NX:00<0oooo0000001oOgl04@1oOgl00`09jPX0Ogmo07moO`0807moO`0300WZ
2P1oOgl0Ogmo00D0Ogmo00@02NX:0000000000002NX:0P1oOgl200WZ2Qh0Ogmo00<02NX:07moO`09
jPX03@1oOgl010000000Ogmo07moO`1oOgl20000000300WZ2P1oOgl0Ogmo00d0Ogmo00<02NX:07mo
O`1oOgl02`1oOgl00`000000Ogmo07moO`0L07moO`0400WZ2P1oOgl0Ogmo07moO`@02NX:1`1oOgl0
0`09jPX0Ogmo07moO`0?07moO`0300000009jPX0Ogmo00D0Ogmo00<02NX:07moO`1oOgl01@1oOgl0
0`09jPX0Ogmo07moO`0A07moO`802NX:0`1oOgl200WZ2P80000000<02NX:07moO`1oOgl00`1oOgl4
00WZ2P<0Ogmo00<0000007moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0307moO`0500WZ2P1oOgl0
Ogmo07moO`09jPX0301oOgl200WZ2PL0Ogmo00@02NX:07moO`1oOgl0Ogmo0P00000407moO`802NX:
101oOgl300WZ2P`0Ogmo00<000000?ooo`3oool05`3oool200WZ2RT0oooo00<000000?ooo`3oool0
303oool00800oooo00<000000?ooo`3oool0<`3oool200WZ2PT0oooo00<02NX:0?ooo`3oool00P09
jPX00`000000Ogmo07moO`0=07moO`0300000009jPX0Ogmo00/0Ogmo00<02NX:07moO`1oOgl01@1o
Ogl01009jPX0Ogmo07moO`09jPX307moO`802NX:7@1oOgl00`09jPX0Ogmo07moO`0:07moO`800000
0P1oOgl200WZ2P0400000009jPX02NX:00WZ2Pd0Ogmo00<02NX:07moO`1oOgl03@1oOgl00`000000
Ogmo07moO`0L07moO`<02NX:2P1oOgl200WZ2Q00Ogmo00@0000007moO`00000000001@1oOgl00`09
jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo01<0Ogmo0P09jPX00`1oOgl02NX:07moO`020000
000307moO`09jPX0Ogmo00<02NX:00<0Ogmo00WZ2P1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`0300WZ2P1oOgl0Ogmo00@0Ogmo00@02NX:07moO`1oOgl02NX:3@1oOgl00`09jPX0Ogmo07moO`04
07moO`0500WZ2P1oOgl0Ogmo07moO`0000001`1oOgl200WZ2P0307moO`09jPX02NX:00h0Ogmo00<0
00000?ooo`3oool05`3oool00`09jPX0oooo0?ooo`0Y0?ooo`030000003oool0oooo00`0oooo0020
0?ooo`030000003oool0oooo03D0oooo0P09jPX70?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:
07moO`1oOgl03@1oOgl00`09jPX0000007moO`0;07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00D02NX:
07moO`1oOgl0Ogmo00WZ2P0407moO`802NX:6@1oOgl200WZ2P0307moO`09jPX0Ogmo00L0Ogmo1`09
jPX507moO`H02NX:1`1oOgl00`09jPX0Ogmo07moO`0>07moO`030000001oOgl0Ogmo01P0Ogmo1@09
jPX<07moO`802NX:401oOgl010000000Ogmo00WZ2P09jPX507moO`0300WZ2P1oOgl0Ogmo00D0Ogmo
00<02NX:07moO`1oOgl0501oOgl00`0000002NX:00WZ2P0207moO`@02NX:0`1oOgl00`09jPX0Ogmo
07moO`0507moO`030000001oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl01@1oOgl200WZ2Pd0Ogmo
00<02NX:07moO`09jPX0101oOgl01@09jPX0Ogmo07moO`1oOgl0000000L0Ogmo00@02NX:07moO`09
jPX02NX:401oOgl00`000000oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo02X0oooo00<000000?oo
o`3oool0303oool00800oooo00<000000?ooo`3oool0=`3oool200WZ2PH0oooo00<02NX:0?ooo`3o
ool00P3oool200WZ2Pd0Ogmo00<02NX:07moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0407moO`03
00WZ2P1oOgl0Ogmo0080Ogmo0P09jPX407moO`802NX:5P1oOgl00`09jPX0Ogmo07moO`0207moO`P0
2NX:00<0000007moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0307moO`@02NX:0P1oOgl00`09jPX0
Ogmo07moO`0?07moO`030000001oOgl0Ogmo01D0Ogmo0`09jPX407moO`0300WZ2P1oOgl0Ogmo00T0
Ogmo00<02NX:07moO`09jPX03`1oOgl300WZ2P0307moO`09jPX02NX:00@0Ogmo00<02NX:07moO`1o
Ogl01@1oOgl00`09jPX0Ogmo07moO`0C07moO`802NX:0`0000001009jPX0Ogmo07moO`09jPX307mo
O`0300WZ2P1oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0507mo
O`802NX:301oOgl01009jPX0Ogmo07moO`09jPX307moO`0400WZ2P1oOgl00000000000L0Ogmo00<0
000000WZ2P09jPX00P1oOgl00`09jPX0Ogmo07moO`0<07moO`030000003oool0oooo01D0oooo0P09
jPX]0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo03T0oooo0`09jPX3
0?ooo`0300WZ2P3oool0oooo0080oooo00@0000007moO`09jPX02NX:2`1oOgl00`09jPX0Ogmo07mo
O`0=07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07mo
O`0307moO`802NX:4`1oOgl800WZ2P@0Ogmo00<0000007moO`1oOgl0301oOgl00`09jPX0Ogmo07mo
O`0607moO`D02NX:401oOgl00`000000Ogmo07moO`0@07moO`@02NX:201oOgl00`09jPX0Ogmo07mo
O`0807moO`0300WZ2P1oOgl02NX:00d0Ogmo0P09jPX00`000000Ogmo07moO`0207moO`802NX:0`1o
Ogl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo0180Ogmo0`09jPX2000000D02NX:0`1o
Ogl00`09jPX0Ogmo07moO`0607moO`030000001oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl0101o
Ogl01009jPX0Ogmo07moO`09jPX:07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00D02NX:07moO`09jPX0
Ogmo0000000707moO`802NX:00<0000000WZ2P1oOgl00`1oOgl00`09jPX0Ogmo07moO`0;07moO`03
0000003oool0oooo01@0oooo00<02NX:0?ooo`3oool0;@3oool00`000000oooo0?ooo`0<0?ooo`00
P03oool00`000000oooo0?ooo`0l0?ooo`802NX:0P3oool01@09jPX0oooo0?ooo`3oool0000000<0
Ogmo0P09jPX807moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0
Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00@0Ogmo0P09jPX:07moO`L02NX:201oOgl01009jPX0
Ogmo00000000000?07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo0P09jPX407moO`@02NX:301oOgl00`00
0000Ogmo07moO`0=07moO`<02NX:301oOgl00`09jPX0Ogmo07moO`0507moO`80000000<02NX:07mo
O`09jPX02`1oOgl300WZ2P80Ogmo00<0000007moO`1oOgl00`1oOgl200WZ2P80Ogmo00<02NX:07mo
O`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0?07moO`<02NX:0`1oOgl200WZ2P040000001oOgl0Ogmo
07moO`L02NX:1P1oOgl00`000000Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00@02NX:
07moO`1oOgl0Ogmo0P09jPX807moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:0000000000001P1o
Ogl200WZ2P80Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0:07moO`030000003o
ool0oooo01<0oooo00<02NX:0?ooo`3oool0;P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool0
0`000000oooo0?ooo`0n0?ooo`<02NX:103oool00`000000Ogmo07moO`0207moO`802NX:1P1oOgl0
0`09jPX0Ogmo07moO`0?07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl01@1oOgl0
0`09jPX0Ogmo07moO`0507moO`802NX:00<0Ogmo00WZ2P09jPX01@09jPX407moO`0300WZ2P1oOgl0
Ogmo00P0Ogmo00<0000000WZ2P1oOgl0401oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0
Ogmo00P0Ogmo1@09jPX707moO`030000001oOgl0Ogmo00T0Ogmo1009jPX?07moO`0300WZ2P1oOgl0
Ogmo00D0Ogmo0P0000000`09jPX0Ogmo00WZ2P0907moO`802NX:1@1oOgl00`000000Ogmo07moO`04
07moO`0400WZ2P1oOgl0Ogmo00WZ2PL0Ogmo00<02NX:07moO`1oOgl02`1oOgl600WZ2P@0Ogmo0P09
jPX00`1oOgl0000007moO`0207moO`<02NX:0`1oOgl600WZ2P0307moO`000000Ogmo00@0Ogmo00<0
2NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<0
2NX:07moO`1oOgl0101oOgl00`09jPX0000007moO`0407moO`802NX:101oOgl00`09jPX0Ogmo07mo
O`0507moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool04P3oool200WZ2S40oooo00<0
00000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0@03oool200WZ2P<0oooo00<00000
07moO`1oOgl0101oOgl200WZ2P@0Ogmo00<02NX:07moO`1oOgl03`1oOgl00`09jPX0Ogmo07moO`04
07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo0P09jPX00`1oOgl02NX:00WZ2P0700WZ2PP0Ogmo00<02NX:
07moO`1oOgl01`1oOgl200000080Ogmo00<02NX:07moO`1oOgl03`1oOgl00`09jPX0Ogmo07moO`02
07moO`0300WZ2P1oOgl0Ogmo00h0Ogmo1009jPX407moO`030000001oOgl0Ogmo00D0Ogmo0`09jPXD
07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo0P09jPX00`1oOgl02NX:07moO`0507moO`<02NX:1P1oOgl0
0`000000Ogmo07moO`0607moO`0300WZ2P1oOgl02NX:00L0Ogmo00<02NX:07moO`1oOgl0201oOgl3
00WZ2P<0Ogmo00<02NX:07moO`1oOgl0101oOgl01@0000002NX:07moO`1oOgl000000080Ogmo0P09
jPX00`1oOgl02NX:07moO`0707moO`H02NX:00<0Ogmo00WZ2P1oOgl0101oOgl00`09jPX0Ogmo07mo
O`0507moO`802NX:101oOgl00`09jPX0Ogmo07moO`0307moO`0500000009jPX02NX:0000001oOgl0
0`09jPX507moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`000000oooo
0?ooo`0A0?ooo`0300WZ2P3oool0oooo0340oooo00<000000?ooo`3oool0303oool00800oooo00<0
00000?ooo`3oool0@@3oool300WZ2P80oooo00<0000007moO`1oOgl01@1oOgl200WZ2P80Ogmo00<0
2NX:07moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0307moO`0400WZ2P1oOgl0Ogmo07moO`L02NX:
2@1oOgl200WZ2PD0Ogmo00<02NX:07moO`1oOgl01P1oOgl2000000@0Ogmo00<0000000WZ2P1oOgl0
3`1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00X0Ogmo0P00000907moO`D02NX:0`1oOgl400WZ2QL0
Ogmo00<02NX:07moO`1oOgl01@1oOgl01009jPX0Ogmo00WZ2P09jPX407moO`802NX:2@1oOgl00`00
0000Ogmo07moO`0707moO`802NX:1`1oOgl00`09jPX0Ogmo07moO`0407moO`@02NX:101oOgl200WZ
2PH0Ogmo00<02NX:07moO`09jPX00`1oOgl00`000000Ogmo00WZ2P0307moO`802NX:1`1oOgl00`00
0000Ogmo07moO`0207moO`P02NX:2@1oOgl01009jPX0Ogmo07moO`09jPX407moO`0400000009jPX0
2NX:07moO`80000000<02NX:07moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0807moO`0300WZ2P1o
Ogl0Ogmo00D0Ogmo00<000000?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0b0?ooo`030000003o
ool0oooo00`0oooo00200?ooo`030000003oool0oooo0440oooo00<02NX:0?ooo`3oool00P09jPX0
0`000000Ogmo07moO`0707moO`802NX:4`1oOgl00`09jPX0Ogmo07moO`0700WZ2PL0Ogmo00<02NX:
07moO`1oOgl0201oOgl200WZ2P0307moO`09jPX02NX:00P0Ogmo00<0000007moO`1oOgl0101oOgl2
00000100Ogmo00@02NX:07moO`1oOgl02NX:2P1oOgl200WZ2P030000001oOgl0Ogmo00/0Ogmo00<0
000000WZ2P09jPX00P09jPXJ07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00H02NX:07moO`1oOgl0Ogmo
00WZ2P1oOgl300WZ2P/0Ogmo00<0000007moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0507moO`04
00WZ2P1oOgl0Ogmo07moO`<02NX:1`1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl02NX:
00@0Ogmo00<02NX:07moO`09jPX0101oOgl200WZ2PD0Ogmo00<0000007moO`1oOgl00`1oOgl00`09
jPX0Ogmo07moO`0207moO`L02NX:1@1oOgl00`09jPX0Ogmo00WZ2P0307moO`802NX:0P1oOgl200WZ
2PT0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`09jPX0Ogmo07moO`0407moO`030000003oool0oooo
00l0oooo0P09jPXe0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo0480
oooo00@02NX:0?ooo`3oool0oooo0`09jPX807moO`802NX:3P1oOgl700WZ2P@0Ogmo00<02NX:07mo
O`1oOgl0201oOgl00`09jPX0Ogmo07moO`0907moO`802NX:1`1oOgl2000000T0Ogmo00<02NX:07mo
O`1oOgl03@1oOgl00`0000002NX:00WZ2P0:07moO`0300WZ2P1oOgl02NX:0080Ogmo0P09jPX00`00
0000Ogmo07moO`0407moO`@02NX:00@0000007moO`1oOgl0Ogmo1@09jPXE07moO`0300WZ2P1oOgl0
Ogmo00@0Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPX=07moO`030000001oOgl0Ogmo00T0Ogmo0P09
jPX607moO`@02NX:2@1oOgl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1oOgl02NX:00@0Ogmo00<0
2NX:00000009jPX01P1oOgl200WZ2P@0Ogmo00<0000007moO`1oOgl00`1oOgl01@09jPX0Ogmo07mo
O`1oOgl02NX:00H0Ogmo2009jPX00`1oOgl02NX:00WZ2P0207moO`802NX:2`1oOgl00`09jPX0Ogmo
07moO`0;07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool03P3oool00`09jPX0oooo
0?ooo`0e0?ooo`030000003oool0oooo00`0oooo000>0?ooooT02NX:00<0000000WZ2P09jPX01@09
jPX2000000D02NX:00<0000000WZ2P09jPX04@09jPX0100000002NX:00WZ2P09jPX707moO`802NX:
0P1oOgl300WZ2P0407moO`000000000000WZ2P80Ogmo0`09jPX407moO`030000001oOgl0Ogmo00H0
Ogmo1009jPXB07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`09jPX00`09jPX00`1oOgl0
2NX:07moO`0;07moO`030000001oOgl0Ogmo00T0Ogmo0`09jPX207moO`@02NX:2P1oOgl200WZ2PT0
Ogmo00@02NX:07moO`1oOgl02NX:0`1oOgl01009jPX0Ogmo07moO`09jPX807moO`802NX:0P1oOgl0
0`000000Ogmo07moO`0307moO`0400WZ2P1oOgl0Ogmo00WZ2P`0Ogmo2009jPX<07moO`0300WZ2P1o
Ogl0Ogmo00d0Ogmo00D02NX:07moO`1oOgl0Ogmo0000000@0?ooo`0300WZ2P3oool0oooo03H0oooo
00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0@`3oool01@09jPX0oooo0?oo
o`3oool0000000<0Ogmo0P09jPX407moO`0400WZ2P1oOgl0Ogmo07moO`802NX:1P1oOgl00`09jPX0
000007moO`0707moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl02`1oOgl00`09jPX0
Ogmo07moO`0307moO`0400000009jPX0Ogmo07moO`8000000P1oOgl2000000802NX:00<0000000WZ
2P09jPX01@09jPX01P000000Ogmo07moO`1oOgl02NX:07moO`/02NX:00<0Ogmo00WZ2P09jPX00`1o
Ogl500WZ2P0307moO`09jPX0Ogmo00@02NX:101oOgl400WZ2PL0Ogmo00<0000007moO`1oOgl02P1o
Ogl500WZ2Pd0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2P80Ogmo00D02NX:07moO`1oOgl0Ogmo
00WZ2P0;07moO`030000001oOgl0Ogmo00T0Ogmo1@09jPX307moO`0300WZ2P1oOgl0Ogmo00D02NX:
0P1oOgl00`09jPX0Ogmo07moO`0907moO`0400WZ2P1oOgl0Ogmo00WZ2P80Ogmo00H02NX:07moO`1o
Ogl0Ogmo00WZ2P00000907moO`802NX:00<0000007moO`1oOgl00`1oOgl01009jPX0Ogmo07moO`09
jPX<07moO`D02NX:0`1oOgl600WZ2PH0Ogmo00<02NX:07moO`1oOgl03P1oOgl01009jPX0Ogmo07mo
O`00000>0?ooo`802NX:>@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?oo
o`130?ooo`0300WZ2P3oool0oooo0080oooo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`09
jPX0Ogmo00D0Ogmo0P09jPX307moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl00P1o
Ogl00`09jPX0Ogmo07moO`0;07moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P00000407moO`800000301o
Ogl<00WZ2PD0Ogmo4009jPX00`1oOgl02NX:07moO`0300WZ2P<0Ogmo00<02NX:07moO`1oOgl01P1o
Ogl00`000000Ogmo07moO`0>07moO`@02NX:2@1oOgl00`09jPX0Ogmo07moO`0300WZ2P<0Ogmo00<0
2NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0707moO`030000001oOgl0Ogmo00P0Ogmo1009
jPX00`1oOgl02NX:00WZ2P0600WZ2P<0Ogmo0P0000000`1oOgl02NX:07moO`0:07moO`0500WZ2P1o
Ogl0Ogmo07moO`09jPX00P1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P000000Ogmo00T0Ogmo
0P09jPX407moO`0300WZ2P1oOgl02NX:00`0Ogmo1009jPX207moO`802NX:1`1oOgl700WZ2Q40Ogmo
00<02NX:0000003oool03@3oool00`09jPX0oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo
00200?ooo`030000003oool0oooo04@0oooo00D02NX:0?ooo`3oool0oooo0000000607moO`802NX:
201oOgl200WZ2P0307moO`09jPX0Ogmo00X0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo
07moO`0<07moO`0500WZ2P1oOgl0Ogmo07moO`09jPX0101oOgl00`000000Ogmo07moO`0A07moO`03
00WZ2P1oOgl0Ogmo00@0Ogmo3009jPX00`1oOgl02NX:00WZ2P0<00WZ2P@0Ogmo00<02NX:07moO`1o
Ogl01@1oOgl00`000000Ogmo07moO`0B07moO`D02NX:101oOgl300WZ2P0307moO`09jPX0Ogmo00<0
Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0607moO`030000001oOgl0Ogmo00@0
Ogmo2P09jPX01@1oOgl02NX:07moO`1oOgl02NX:00H0Ogmo0P09jPX<07moO`0400WZ2P1oOgl0Ogmo
07moO`<02NX:00<0000007moO`1oOgl00P1oOgl01009jPX0Ogmo00000000000907moO`0300000009
jPX02NX:0080Ogmo00<02NX:07moO`09jPX02P1oOgl400WZ2PH0Ogmo00<02NX:07moO`1oOgl02@1o
Ogl800WZ2P`0Ogmo00<02NX:0?ooo`3oool02P3oool200WZ2S`0oooo00<000000?ooo`3oool0303o
ool00800oooo00<000000?ooo`3oool0A03oool01@09jPX0oooo0?ooo`3oool0000000L0Ogmo0`09
jPX807moO`802NX:301oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00l0Ogmo0`09jPX307moO`800000
501oOgl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1oOgl0Ogmo00@0Ogmo3P09jPX207moO``02NX:
00<0Ogmo0000001oOgl0601oOgl400WZ2P0507moO`09jPX0Ogmo07moO`09jPX0101oOgl00`09jPX0
Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<0000000WZ2P09jPX01P09jPX507moO`08
00WZ2P1oOgl0Ogmo00WZ2P1oOgl02NX:07moO`09jPX507moO`0300WZ2P1oOgl02NX:00`0Ogmo00<0
2NX:07moO`09jPX00`09jPX2000000@0Ogmo00D02NX:07moO`1oOgl0Ogmo0000000807moO`030000
001oOgl0Ogmo00@02NX:2@1oOgl400WZ2PT0Ogmo00<02NX:07moO`1oOgl0201oOgl00`09jPX0Ogmo
07moO`0507moO`H02NX:0P1oOgl200000080Ogmo00<0000000WZ2P3oool02@3oool00`09jPX0oooo
0?ooo`0l0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo04D0oooo00D0
2NX:0?ooo`3oool0oooo0000000607moO`0300WZ2P1oOgl0Ogmo00<02NX:101oOgl00`09jPX0Ogmo
07moO`0200WZ2P/0Ogmo00@02NX:07moO`1oOgl02NX:401oOgl200WZ2P0307moO`000000000001L0
Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0207moO`<02NX:00<0Ogmo00WZ2P1o
Ogl01009jPX407moO`0300WZ2P1oOgl0Ogmo00/02NX:0`1oOgl:00WZ2Q00Ogmo0`09jPX207moO`D0
2NX:101oOgl00`09jPX0Ogmo07moO`0507moO`/02NX:2P1oOgl01P09jPX0Ogmo07moO`1oOgl02NX:
07moO`802NX:0`1oOgl00`0000002NX:07moO`0207moO`0300WZ2P1oOgl0Ogmo00P0Ogmo0`09jPX0
101oOgl02NX:00WZ2P09jPX607moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl01@1o
Ogl00`000000Ogmo07moO`0207moO`802NX:1`1oOgl300WZ2P80000000<02NX:07moO`1oOgl0201o
Ogl200WZ2PL0Ogmo00<02NX:07moO`1oOgl0301oOgl200WZ2P80000000D0Ogmo0000003oool0oooo
00WZ2P080?ooo`0300WZ2P3oool0oooo03d0oooo00<000000?ooo`3oool0303oool00800oooo00<0
00000?ooo`3oool0A@3oool01@09jPX0oooo0?ooo`3oool0000000D0Ogmo00<02NX:07moO`1oOgl0
101oOgl200WZ2P80Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2PT0Ogmo00D02NX:07moO`1oOgl0
Ogmo00WZ2P0>07moO`0400WZ2P1oOgl0000000WZ2QT0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09
jPX0Ogmo07moO`0300WZ2P80Ogmo1009jPX807moO`0300WZ2P1oOgl0Ogmo00/0Ogmo3009jPX00`1o
Ogl02NX:00WZ2P0900WZ2P<0Ogmo0P09jPX707moO`802NX:00<0Ogmo00WZ2P09jPX03009jPX207mo
O`<02NX:3P1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl02NX:00<0Ogmo00<02NX:0000
001oOgl00P1oOgl00`09jPX0Ogmo07moO`0607moO`0300000009jPX02NX:0080Ogmo00@02NX:07mo
O`09jPX02NX:1`1oOgl00`09jPX0Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00P1oOgl400WZ2P<0Ogmo0`09jPX0101oOgl0000000000009jPX=07moO`0300WZ2P1o
Ogl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl04@1oOgl01@000000oooo0?ooo`3oool02NX:00D0oooo
0P09jPY00?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo04D0oooo00<0
2NX:0?ooo`3oool00P3oool00`000000Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00H0Ogmo0P09
jPX707moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00@02NX:07moO`1oOgl02NX:3@1oOgl00`09jPX00000
0000000207moO`0300WZ2P1oOgl0Ogmo01L0Ogmo00<02NX:07moO`1oOgl00P1oOgl400WZ2P80Ogmo
1009jPX;07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00@02NX:07moO`1oOgl0Ogmo1009jPX307moOa@0
2NX:0P0000000`09jPX0Ogmo00WZ2P0;00WZ2P<0Ogmo1009jPX207moO`030000001oOgl0Ogmo00`0
Ogmo00<02NX:07moO`1oOgl00P1oOgl01009jPX0Ogmo00WZ2P09jPX207moO`0300WZ2P1oOgl0Ogmo
00<0Ogmo00<02NX:07moO`1oOgl01@1oOgl02@0000002NX:07moO`1oOgl02NX:07moO`09jPX0Ogmo
00WZ2P0707moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl010000000Ogmo
07moO`1oOgl200WZ2P80Ogmo1009jPX207moO`040000001oOgl0Ogmo00WZ2Ph0Ogmo0P09jPX307mo
O`0300WZ2P1oOgl0Ogmo0140Ogmo00<000000?ooo`3oool00`3oool01@09jPX0oooo0?ooo`3oool0
2NX:0480oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0AP3oool01@09
jPX0oooo0?ooo`3oool0000000@0Ogmo00<02NX:07moO`1oOgl01`1oOgl300WZ2PH0Ogmo0P09jPX7
07moO`0400WZ2P1oOgl0Ogmo00WZ2P`0Ogmo00<02NX:0000001oOgl0101oOgl00`09jPX0Ogmo07mo
O`0F07moO`0300WZ2P1oOgl0Ogmo00<02NX:0P1oOgl500WZ2Pd0Ogmo00<02NX:07moO`1oOgl03@1o
Ogl01@09jPX0Ogmo07moO`1oOgl000000080Ogmo1@09jPX807moOaP02NX:0P1oOgl400WZ2P80Ogmo
00@02NX:07moO`1oOgl000003P1oOgl00`09jPX0Ogmo07moO`0307moO`802NX:00D0Ogmo00WZ2P1o
Ogl0Ogmo00WZ2P0407moO`0300WZ2P1oOgl0Ogmo00H0Ogmo0`09jPX01@1oOgl02NX:07moO`1oOgl0
2NX:00L0Ogmo00<02NX:07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`060000001oOgl0
Ogmo00WZ2P1oOgl02NX:0P1oOgl300WZ2P0307moO`00000000000080Ogmo00<02NX:07moO`1oOgl0
3`1oOgl01009jPX0Ogmo07moO`09jPXC07moO`030000003oool0oooo00@0oooo00<02NX:0?ooo`09
jPX0@`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`160?ooo`0500WZ
2P3oool0oooo0?ooo`000000101oOgl00`09jPX0Ogmo07moO`0607moO`0400WZ2P1oOgl0Ogmo07mo
O`802NX:1P1oOgl200WZ2PH0Ogmo00@02NX:07moO`1oOgl02NX:2P1oOgl00`09jPX0000007moO`06
07moO`802NX:5P1oOgl300WZ2P0307moO`09jPX02NX:00802NX:0P1oOgl00`09jPX0Ogmo07moO`0=
07moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00@02NX:07moO`1oOgl000001`1oOgl800WZ2PH0Ogmo0`09
jPX407moOaH02NX:3`1oOgl00`09jPX0Ogmo07moO`0407moO`0600WZ2P1oOgl0Ogmo00WZ2P1oOgl0
2NX:1@1oOgl00`09jPX0Ogmo07moO`0507moO`802NX:0P1oOgl01009jPX0Ogmo07moO`09jPX807mo
O`0300WZ2P1oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl01@000000Ogmo07moO`09jPX0
Ogmo00<02NX:0`1oOgl200WZ2P<0Ogmo00<02NX:07moO`1oOgl0401oOgl200WZ2Q@0Ogmo00<00000
0?ooo`3oool0103oool200WZ2T@0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?oo
o`3oool0A`3oool01@09jPX0oooo0?ooo`3oool000000080Ogmo00<02NX:07moO`1oOgl01`1oOgl0
0`09jPX0Ogmo07moO`0307moO`802NX:1P1oOgl200WZ2P@0Ogmo00@02NX:07moO`1oOgl02NX:2@1o
Ogl00`09jPX0000007moO`0907moO`0300WZ2P1oOgl0Ogmo0100Ogmo0`09jPX0101oOgl02NX:00WZ
2P09jPX407moO`802NX:401oOgl00`09jPX0Ogmo07moO`0?07moO`0300WZ2P1oOgl0000000X0Ogmo
1`09jPX0101oOgl02NX:00WZ2P09jPX707moO`0400WZ2P1oOgl02NX:07moO`D02NX:101oOglC00WZ
2PD0Ogmo00<02NX:07moO`1oOgl0101oOgl01`09jPX0Ogmo07moO`1oOgl02NX:07moO`09jPX0101o
Ogl00`09jPX0Ogmo07moO`0407moO`802NX:00<0Ogmo00WZ2P09jPX00`1oOgl00`09jPX0Ogmo07mo
O`0607moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00H0000007moO`1oOgl0Ogmo0000001oOgl400WZ2P@0
Ogmo00<0000007moO`1oOgl00`09jPXD07moO`802NX:4P1oOgl00`000000oooo0?ooo`040?ooo`04
00WZ2P3oool0oooo00WZ2T<0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3o
ool0A`3oool01@09jPX0oooo0?ooo`3oool000000080Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09
jPX0Ogmo07moO`0607moO`<02NX:1@1oOgl200WZ2P<0Ogmo00<02NX:07moO`09jPX0201oOgl01009
jPX0000007moO`00000:07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo2009jPX507moO`0300WZ2P1oOgl0
Ogmo0100Ogmo00<02NX:07moO`1oOgl0401oOgl200WZ2PL0Ogmo0`09jPX507moO`H02NX:1P1oOgl0
0`09jPX0Ogmo07moO`0400WZ2P0307moO`09jPX02NX:00802NX:2P1oOgl0100000002NX:07moO`1o
OglB00WZ2P0307moO`09jPX02NX:00<0Ogmo0P09jPX407moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00@0
2NX:07moO`1oOgl02NX:101oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00H0Ogmo
00@0000007moO`1oOgl0Ogmo0`09jPX0101oOgl02NX:07moO`1oOgl2000000D0Ogmo0P09jPXB07mo
O`0400WZ2P1oOgl0Ogmo00WZ2Q40Ogmo00<000000?ooo`3oool00`3oool00`09jPX0oooo0?ooo`02
0?ooo`0300WZ2P3oool0oooo0400oooo00<000000?ooo`3oool0303oool00800oooo00<000000?oo
o`3oool0B03oool01`09jPX0oooo0?ooo`3oool0000007moO`09jPX01`1oOgl00`09jPX0Ogmo07mo
O`0:07moO`802NX:1@1oOgl200WZ2P80Ogmo00<02NX:07moO`09jPX01P1oOgl00`09jPX0Ogmo0000
000207moO`030000001oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl0201oOgl600WZ2P80Ogmo00@0
2NX:07moO`1oOgl02NX:0P1oOgl200WZ2Q<0Ogmo00<02NX:07moO`1oOgl04P1oOgl00`09jPX0Ogmo
07moO`0207moO`802NX:1@1oOgl300WZ2PH0Ogmo1@09jPX01P1oOgl02NX:00WZ2P09jPX0Ogmo00WZ
2P<0Ogmo00@02NX:07moO`1oOgl0Ogmo0`09jPX607moO`040000001oOgl0Ogmo00WZ2PL0Ogmo1009
jPX207moOa402NX:0P1oOgl00`09jPX0Ogmo07moO`0207moO`0400WZ2P1oOgl0Ogmo07moO`802NX:
0`1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<0000000WZ2P09jPX0
0P09jPX207moO`0300WZ2P1oOgl0000000H0Ogmo00<02NX:07moO`1oOgl00P09jPX@07moO`0500WZ
2P1oOgl0Ogmo07moO`09jPX03`1oOgl00`000000oooo0?ooo`020?ooo`802NX:1P3oool00`09jPX0
oooo0?ooo`0o0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo04P0oooo
00H02NX:0?ooo`3oool0oooo00000009jPX807moO`0300WZ2P1oOgl0Ogmo00`0Ogmo0P09jPX507mo
O`80000000<02NX:07moO`09jPX01@1oOgl01009jPX0Ogmo07moO`00000307moO`8000002@1oOgl2
00WZ2P80Ogmo0P0000000`1oOgl02NX:00WZ2P0300WZ2PD0Ogmo00L02NX:07moO`1oOgl0Ogmo00WZ
2P1oOgl02NX:01D0Ogmo00<02NX:07moO`1oOgl04P1oOgl00`0000002NX:00WZ2P0200WZ2P@0Ogmo
0`09jPX;07moO`T02NX:0`1oOgl00`09jPX0Ogmo07moO`0407moO`@02NX:0P1oOgl01@000000Ogmo
07moO`1oOgl02NX:00X0Ogmo1@09jPX407moO`0300WZ2P1oOgl0Ogmo01802NX:00<0Ogmo00WZ2P1o
Ogl00P1oOgl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1oOgl0Ogmo00D0Ogmo0`09jPX00`1oOgl0
2NX:07moO`0207moO`0300WZ2P000000Ogmo00D0Ogmo00<02NX:07moO`1oOgl00`1oOgl200WZ2Pd0
Ogmo00<02NX:07moO`1oOgl00P1oOgl00`0000002NX:07moO`0=07moO`050000003oool0oooo0?oo
o`09jPX02@3oool00`09jPX0oooo0?ooo`0n0?ooo`030000003oool0oooo00`0oooo00200?ooo`03
0000003oool0oooo04T0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0707moO`0300WZ2P1oOgl0Ogmo
00l0Ogmo0P09jPX307moO`8000000`09jPX507moO`0300WZ2P1oOgl0000000H0Ogmo00<0000007mo
O`1oOgl0201oOgl00`09jPX0Ogmo0000000400WZ2PL0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ
2QH0Ogmo00<02NX:07moO`1oOgl04P1oOgl300WZ2P<0Ogmo0`09jPX:07moO`@02NX:0`1oOgl00`09
jPX0Ogmo07moO`0207moO`D02NX:2P1oOgl300WZ2P@0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09
jPX0Ogmo07moO`0200WZ2P80000000@02NX:07moO`1oOgl02NX:0`1oOgl200WZ2P@0Ogmo00<02NX:
07moO`09jPX03009jPX807moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0`09jPX207moO`0700000009jPX0
Ogmo07moO`000000Ogmo00WZ2P0607moO`0300WZ2P1oOgl0Ogmo00D0Ogmo0P09jPX;07moO`0300WZ
2P1oOgl0Ogmo0080Ogmo0P00000=07moO`050000003oool0oooo0?ooo`09jPX02`3oool00`09jPX0
oooo0?ooo`0m0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo04T0oooo
00D02NX:0?ooo`3oool0oooo00WZ2P0707moO`0300WZ2P1oOgl0Ogmo0140Ogmo0P09jPX207moO`03
00WZ2P1oOgl02NX:00802NX:0`1oOgl01009jPX0Ogmo07moO`00000707moO`800000201oOgl400WZ
2PP0Ogmo0P09jPX407moO`0300WZ2P1oOgl02NX:01H0Ogmo00<02NX:07moO`1oOgl03`1oOgl300WZ
2P0307moO`0000002NX:00<02NX:2P1oOgl300WZ2PH0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09
jPX0Ogmo00WZ2P0500WZ2PL0Ogmo00<0000007moO`09jPX00`09jPX00`1oOgl02NX:07moO`0907mo
O`0300WZ2P1oOgl0Ogmo0080Ogmo2009jPX207moO`802NX:0`1oOgl200WZ2P0507moO`09jPX0Ogmo
07moO`09jPX00`1oOgl01@09jPX0Ogmo00WZ2P09jPX0Ogmo00l02NX:101oOgl01009jPX000000000
0000000207moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0201oOgl200WZ2PP0Ogmo
00<02NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0:07moO`040000003oool02NX:00WZ2Pd0
oooo00<02NX:0?ooo`3oool0?03oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo
0?ooo`190?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01P1oOgl00`09jPX0Ogmo07moO`0D07moO`<0
2NX:0P1oOgl300WZ2P0307moO`09jPX0Ogmo0080Ogmo00<0000007moO`1oOgl01`1oOgl010000000
Ogmo07moO`1oOgl400WZ2P80Ogmo0P09jPX707moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P09jPX307mo
O`0300WZ2P1oOgl0Ogmo01<0Ogmo00<02NX:07moO`1oOgl03@1oOgl200WZ2P80Ogmo0`09jPX207mo
O`0300WZ2P1oOgl0Ogmo00D0Ogmo1009jPX907moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07mo
O`09jPX01@1oOgl500WZ2P80Ogmo00<0000007moO`1oOgl00`1oOgl300WZ2PT0Ogmo00<02NX:07mo
O`09jPX00P09jPX00`1oOgl02NX:00WZ2P0407moO`h02NX:1@1oOgl00`09jPX0Ogmo00WZ2P0907mo
O`0300WZ2P1oOgl02NX:00/02NX:00@0000007moO`1oOgl02NX:1@1oOgl00`09jPX0Ogmo07moO`0:
07moO`802NX:1P1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<00000
00WZ2P3oool03`3oool00`09jPX0oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo00200?oo
o`030000003oool0oooo04X0oooo00D02NX:0?ooo`09jPX0oooo0000000507moO`0300WZ2P1oOgl0
Ogmo01H0Ogmo0`09jPX00`1oOgl02NX:07moO`0200WZ2P<0Ogmo00<0000007moO`1oOgl0201oOgl3
00WZ2PH0Ogmo0`09jPX507moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl00`1oOgl0
0`09jPX0Ogmo07moO`0B07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo0`09jPX0101oOgl02NX:00WZ2P09
jPX207moO`040000001oOgl0Ogmo07moO`802NX:0P1oOgl300WZ2P`0Ogmo00<02NX:07moO`1oOgl0
1@1oOgl00`09jPX0Ogmo00WZ2P0:07moO`D02NX:1P1oOgl300WZ2PD0Ogmo0`09jPX407moO`802NX:
1@1oOgl00`09jPX0Ogmo07moO`0700WZ2P0307moO`09jPX0Ogmo00d02NX:101oOgl400WZ2PD0Ogmo
00D0000000WZ2P000000Ogmo0000000900WZ2Pl0Ogmo0P09jPX407moO`0300WZ2P1oOgl0Ogmo00L0
Ogmo00<02NX:07moO`1oOgl01`1oOgl00`0000002NX:0?ooo`0A0?ooo`0300WZ2P3oool0oooo0340
oooo2009jPX2000000h0oooo00200?ooo`030000003oool0oooo04X0oooo00D02NX:0?ooo`09jPX0
oooo0000000407moO`0300WZ2P1oOgl0Ogmo01P0Ogmo00<02NX:07moO`09jPX00P09jPX207moO`80
2NX:0P00000607moO`@02NX:00<0Ogmo0000000000001P1oOgl01009jPX0Ogmo07moO`09jPX307mo
O`0400WZ2P1oOgl0Ogmo07moO`802NX:1`1oOgl00`09jPX0Ogmo07moO`0A07moO`0300WZ2P1oOgl0
Ogmo00T0Ogmo0P09jPX0101oOgl02NX:00WZ2P09jPX607moO`030000001oOgl0Ogmo00@02NX:3`1o
Ogl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl02NX:00/0Ogmo00@0000007moO`1oOgl0Ogmo
1009jPX307moO`0300WZ2P1oOgl02NX:00@02NX:00<0Ogmo00WZ2P1oOgl0101oOgl200WZ2PD0Ogmo
00D02NX:07moO`1oOgl02NX:07moO`0200WZ2P0307moO`09jPX02NX:00802NX:1`1oOgl300WZ2P@0
Ogmo1P09jPX00`000000Ogmo07moO`0507moO`0800WZ2P1oOgl0Ogmo07moO`000000Ogmo00000009
jPX407moO`T02NX:2@1oOgl200WZ2P0307moO`09jPX0Ogmo00X0Ogmo00<02NX:07moO`1oOgl01@1o
Ogl200WZ2Q@0oooo00<02NX:0?ooo`3oool07`3ooolA00WZ2PP0oooo0P00000>0?ooo`00P03oool0
0`000000oooo0?ooo`1;0?ooo`802NX:0P3oool010000000Ogmo07moO`09jPXK07moO`0300WZ2P1o
Ogl0Ogmo00<02NX:0`1oOgl00`09jPX0000007moO`0207moO`<02NX:1`1oOgl00`000000Ogmo07mo
O`0307moO`0700WZ2P1oOgl0Ogmo07moO`09jPX0Ogmo00WZ2P0307moO`0300WZ2P1oOgl0Ogmo00L0
Ogmo00<02NX:07moO`1oOgl04@1oOgl00`09jPX0Ogmo07moO`0607moO`H02NX:2@1oOgl300WZ2P<0
Ogmo00<02NX:07moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0707moO`802NX:2`1oOgl00`000000
Ogmo07moO`0507moO`P02NX:00@0Ogmo00WZ2P09jPX02NX:1@1oOgl200WZ2PH0Ogmo00@02NX:07mo
O`1oOgl02NX:0P1oOgl01@09jPX0Ogmo00WZ2P09jPX0Ogmo00D02NX:0P1oOgl300WZ2P@0Ogmo1009
jPX00`1oOgl02NX:07moO`0507moO`0300000009jPX0Ogmo00<0Ogmo00@0000007moO`1oOgl02NX:
0P0000000`1oOgl02NX:07moO`0807moO`P02NX:0`1oOgl200WZ2P`0Ogmo00<02NX:07moO`1oOgl0
0`1oOgl00`09jPX000000?ooo`0E0?ooo`0300WZ2P3oool0oooo00d0oooo4@09jPXJ0?ooo`030000
003oool0oooo00`0oooo00200?ooo`030000003oool0oooo04/0oooo0P09jPX20?ooo`040000001o
Ogl0Ogmo00WZ2Q/0Ogmo00H02NX:07moO`09jPX0Ogmo00WZ2P1oOgl200WZ2P0307moO`0000002NX:
00<02NX:2`1oOgl200000080Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0200WZ
2P/0Ogmo00<02NX:07moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0407moO`D02NX:201oOgl400WZ
2P030000001oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl02`1oOgl00`09jPX0Ogmo07moO`0707mo
O`802NX:2`1oOgl00`000000Ogmo07moO`0807moO`L02NX:00<0Ogmo00WZ2P09jPX00`09jPX00`1o
Ogl02NX:00WZ2P0707moO`<02NX:0`1oOgl300WZ2PH0Ogmo1@09jPX00`1oOgl02NX:00WZ2P0300WZ
2P<0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`000000Ogmo00WZ2P0507moO`030000001oOgl02NX:
0080Ogmo00<0000000WZ2P1oOgl0401oOgl900WZ2PT0Ogmo00<02NX:07moO`1oOgl00P09jPX00`1o
Ogl000000?ooo`0D0?oooa402NX::`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000
oooo0?ooo`1;0?ooo`802NX:0P3oool00`000000Ogmo00WZ2P0L07moO`802NX:0`1oOgl00`09jPX0
Ogmo00WZ2P0200WZ2P<0Ogmo0P09jPX<07moO`030000001oOgl02NX:00<0Ogmo0P09jPX00`000000
2NX:00WZ2P0=07moO`0300WZ2P1oOgl0Ogmo0100Ogmo00@02NX:07moO`1oOgl0Ogmo1@09jPX807mo
O`<02NX:1@1oOgl00`000000Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<02NX:07mo
O`1oOgl0201oOgl200WZ2PX0Ogmo00<0000007moO`1oOgl01P1oOgl300WZ2P<0Ogmo00@02NX:07mo
O`1oOgl0Ogmo1009jPX207moO`<02NX:1P1oOgl01@09jPX0Ogmo00WZ2P1oOgl02NX:0080Ogmo0`09
jPX907moO`H02NX:101oOgl00`09jPX0Ogmo07moO`0207moO`80000000<0Ogmo00WZ2P1oOgl01@1o
Ogl01P000000Ogmo07moO`09jPX0Ogmo00WZ2P8000004`1oOgl01P09jPX0Ogmo07moO`1oOgl02NX:
07moO`P02NX:0P1oOgl200WZ2P<0Ogmo00<000000?ooo`3oool00P3ooolA00WZ2P<0oooo00<02NX:
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`1;0?oo
o`802NX:0`3oool00`0000002NX:07moO`0K07moO`802NX:00<0Ogmo00WZ2P09jPX00P09jPX207mo
O`0300000009jPX02NX:00<0Ogmo00<02NX:07moO`1oOgl02P1oOgl01@0000002NX:07moO`1oOgl0
2NX:0080Ogmo0P0000000`1oOgl02NX:07moO`0<07moO`0300WZ2P1oOgl0Ogmo00l0Ogmo00<02NX:
07moO`09jPX00`09jPX707moO`@02NX:201oOgl00`000000Ogmo07moO`0507moO`0300WZ2P1oOgl0
Ogmo00P0Ogmo00<02NX:07moO`1oOgl0201oOgl200WZ2PX0Ogmo00<0000007moO`1oOgl00`1oOgl3
00WZ2PL0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0207moO`P02NX:0P1oOgl01`09jPX0Ogmo07mo
O`09jPX0Ogmo00WZ2P1oOgl00`09jPX00`1oOgl02NX:07moO`0607moO`D02NX:0P1oOgl500WZ2P<0
Ogmo00D0000007moO`1oOgl0Ogmo00WZ2P0707moO`050000001oOgl02NX:07moO`09jPX00P1oOgl0
0`000000Ogmo07moO`0?07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P09jPX707moO``02NX:5@3oool0
0`09jPX0oooo0?ooo`0e0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo
04/0oooo0P09jPX30?ooo`0300WZ2P1oOgl0Ogmo01T0Ogmo00<0000000WZ2P09jPX00P09jPX207mo
O`802NX:0P1oOgl00`000000Ogmo07moO`0300WZ2P0307moO`09jPX02NX:00X0Ogmo00@02NX:0000
000000002NX:0P1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<02NX:
07moO`1oOgl03P1oOgl400WZ2PL0Ogmo0`09jPX<07moO`030000001oOgl0Ogmo00H0Ogmo0P09jPX7
07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo0P09jPX:07moO`040000001oOgl0Ogmo07moO`802NX:2`1o
Ogl01009jPX0Ogmo07moO`09jPX507moO`T02NX:0P1oOgl01009jPX0Ogmo00WZ2P09jPX207moO`80
2NX:1@1oOgl200WZ2P0507moO`09jPX02NX:07moO`09jPX01P1oOgl500WZ2P80Ogmo00<02NX:07mo
O`1oOgl01P1oOgl010000000Ogmo00WZ2P09jPX407moO`8000003`1oOgl00`09jPX0Ogmo07moO`05
07moO`802NX:1@1oOgl200WZ2P0507moO`000000000007moO`0000006`3oool00`09jPX0oooo0?oo
o`0d0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo04/0oooo00<02NX:
0?ooo`09jPX00P3oool00`09jPX0000007moO`0I07moO`0400WZ2P000000Ogmo00WZ2P<0Ogmo00@0
2NX:07moO`09jPX000001P1oOgl200WZ2P0307moO`09jPX02NX:00P0Ogmo00@02NX:07moO`09jPX0
00000P09jPX607moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<02NX:07moO`1oOgl02P1oOgl500WZ2PD0
Ogmo1009jPX@07moO`030000001oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0
Ogmo07moO`0907moO`802NX:2@1oOgl00`000000Ogmo00WZ2P0200WZ2Ph0Ogmo00<02NX:07moO`09
jPX01@1oOgl200WZ2P<0Ogmo00<02NX:07moO`09jPX01`09jPX307moO`802NX:0P1oOgl200WZ2P80
Ogmo0P09jPX00`1oOgl02NX:00WZ2P0507moO`0400WZ2P1oOgl0000000000080Ogmo1009jPX807mo
O`0300000009jPX02NX:00H0Ogmo0P00000<07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo0P09jPX207mo
O`0300WZ2P1oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool06`3oool00`09jPX0oooo0?ooo`0W0?oo
o`8000002P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`1:0?ooo`08
00WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`00000M07moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P09
jPX00`000000Ogmo07moO`0607moO`802NX:00<0Ogmo00WZ2P09jPX01P1oOgl200WZ2P0307moO`09
jPX0000000P0Ogmo0P09jPX:07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo1009jPX307moO`0300WZ2P1o
Ogl0Ogmo00<02NX:501oOgl00`000000Ogmo07moO`0807moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0
2NX:07moO`1oOgl02P1oOgl00`09jPX0Ogmo00WZ2P0807moO`802NX:4@1oOgl00`09jPX0Ogmo00WZ
2P0507moO`802NX:0P1oOgl00`09jPX0Ogmo07moO`0507moO`0300000009jPX02NX:00L02NX:0P1o
Ogl200WZ2P0607moO`09jPX0Ogmo00WZ2P1oOgl02NX:101oOgl00`09jPX0000007moO`0407moO`03
00WZ2P1oOgl0Ogmo00D02NX:0`1oOgl00`0000002NX:07moO`0807moO`030000001oOgl0Ogmo00T0
Ogmo00<02NX:07moO`1oOgl02P1oOgl200WZ2PH0Ogmo00<000000?ooo`3oool0703oool00`09jPX0
oooo0?ooo`0T0?ooo`802NX:0P00000:0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000
003oool0oooo04X0oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`030000001oOgl0Ogmo01/0
Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo00WZ2P0:07moO`802NX:00<0Ogmo00WZ2P09
jPX00`1oOgl400WZ2P80Ogmo0P00000807moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<02NX:07moO`1o
Ogl00`1oOgl500WZ2P@0Ogmo1009jPXG07moO`030000001oOgl0Ogmo00T0Ogmo00D02NX:07moO`1o
Ogl0Ogmo00WZ2P0<07moO`0300WZ2P1oOgl02NX:00D0Ogmo0`09jPX00`000000Ogmo07moO`0A07mo
O`802NX:1@1oOgl200WZ2P0307moO`09jPX0Ogmo00L0Ogmo0P0000001009jPX0Ogmo07moO`1oOgl2
00WZ2P0307moO`09jPX02NX:00`02NX:00<0000000WZ2P1oOgl01@1oOgl00`09jPX0Ogmo07moO`05
07moO`D02NX:2P1oOgl2000000P0Ogmo00<02NX:07moO`1oOgl02P1oOgl200WZ2P0307moO`09jPX0
2NX:00@0Ogmo00<000000?ooo`3oool07@3oool00`09jPX0oooo0?ooo`0P0?ooo`<02NX:3P3oool0
0`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`1:0?ooo`0500WZ2P3oool0oooo
0?ooo`09jPX00`3oool00`000000Ogmo07moO`0K07moO`0700WZ2P1oOgl0Ogmo07moO`09jPX0Ogmo
00WZ2P0<07moO`802NX:00@0Ogmo00WZ2P1oOgl0Ogmo0P09jPX607moO`030000001oOgl0Ogmo00H0
Ogmo00<02NX:07moO`1oOgl01`1oOgl00`09jPX0Ogmo07moO`0500WZ2P@0Ogmo0`09jPX00`1oOgl0
2NX:07moO`0I07moO`030000001oOgl0Ogmo00T0Ogmo00<02NX:07moO`09jPX03@1oOgl00`09jPX0
Ogmo00WZ2P0207moO`<02NX:0P1oOgl00`000000Ogmo07moO`0C07moO`0300WZ2P1oOgl0Ogmo00<0
Ogmo0`09jPX907moO`0300WZ2P1oOgl0Ogmo00<02NX:0P1oOgl200WZ2PH0Ogmo00@02NX:07moO`09
jPX02NX:0P1oOgl00`0000002NX:00WZ2P0>00WZ2P80000000<0Ogmo00WZ2P09jPX0301oOgl20000
00H0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0307moO`802NX:00<0Ogmo0000
003oool0803oool00`09jPX0oooo0?ooo`0M0?ooo`802NX:4@3oool00`000000oooo0?ooo`0<0?oo
o`00P03oool00`000000oooo0?ooo`1:0?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:0P3oool0
0`000000Ogmo07moO`0K07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:00000009jPX03@1oOgl5
00WZ2PP0Ogmo0P00000707moO`0300WZ2P1oOgl0Ogmo00H0Ogmo1P09jPX207moO`@02NX:101oOgl0
0`09jPX0Ogmo07moO`0H07moO`030000001oOgl0Ogmo00X0Ogmo0P09jPX=07moO`0300WZ2P1oOgl0
Ogmo00802NX:1@1oOgl00`000000Ogmo07moO`0C07moO`802NX:101oOgl200WZ2PT0Ogmo00<02NX:
07moO`1oOgl00P09jPX207moO`@02NX:1P1oOgl00`09jPX0Ogmo07moO`0200WZ2P030000001oOgl0
2NX:00H0Ogmo00<02NX:07moO`1oOgl00`09jPX00`1oOgl02NX:00WZ2P0<00WZ2PL0Ogmo00<00000
07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0907moO`0300WZ2P1oOgl0Ogmo00H0Ogmo0P09jPXR
0?ooo`0300WZ2P3oool0oooo01X0oooo0P09jPXC0?ooo`030000003oool0oooo00`0oooo00200?oo
o`030000003oool0oooo04T0oooo00L02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:00<0oooo00<0
000007moO`1oOgl06P1oOgl00`09jPX0Ogmo07moO`0207moO`0400WZ2P1oOgl0Ogmo00WZ2Pd0Ogmo
1@09jPX907moO`030000001oOgl0Ogmo00D0Ogmo0P09jPX20000000507moO`09jPX02NX:00WZ2P1o
Ogl00P09jPX207moO`<02NX:201oOgl00`09jPX0Ogmo07moO`0H07moO`030000001oOgl0Ogmo00/0
Ogmo0P09jPX;07moO`D02NX:1P1oOgl00`000000Ogmo07moO`0C07moO`0300WZ2P1oOgl02NX:00<0
Ogmo0P09jPX807moO`0500WZ2P1oOgl02NX:00WZ2P1oOgl00`09jPX307moO`0300WZ2P1oOgl0Ogmo
00@0Ogmo00<02NX:07moO`1oOgl00P09jPX207moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P00000300WZ
2PP0Ogmo00D02NX:07moO`1oOgl02NX:07moO`0200WZ2P<0Ogmo3P09jPX807moO`802NX:2@1oOgl0
10000000oooo00WZ2P09jPXQ0?ooo`0300WZ2P3oool0oooo01L0oooo0P09jPXE0?ooo`030000003o
ool0oooo00`0oooo00200?ooo`030000003oool0oooo04T0oooo00@02NX:0?ooo`3oool02NX:0`3o
ool01009jPX0oooo0?ooo`00000L07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00@02NX:07moO`1oOgl0
2NX:0P00000:07moO`802NX:00<0Ogmo00WZ2P09jPX00`09jPX807moO`030000001oOgl0Ogmo00H0
Ogmo00@02NX:00000009jPX0Ogmo1`09jPX:07moO`0300WZ2P1oOgl0Ogmo01X0Ogmo00<0000007mo
O`1oOgl02@1oOgl01009jPX0Ogmo07moO`09jPX807moO`@02NX:0P1oOgl00`09jPX0Ogmo07moO`03
07moO`030000001oOgl0Ogmo01@0Ogmo00D02NX:07moO`1oOgl02NX:07moO`0300WZ2PL0Ogmo0`09
jPX207moO`<02NX:101oOgl200WZ2PD0Ogmo00@02NX:07moO`000000Ogmo0P09jPX00`1oOgl02NX:
07moO`0307moO`802NX:2@1oOgl200WZ2P040000001oOgl0Ogmo00WZ2P<0Ogmo0P09jPX;07moO`04
00000009jPX0Ogmo07moO`h02NX:1@1oOgl010000000oooo0?ooo`3oool200WZ2R00oooo00<02NX:
0?ooo`3oool0503oool200WZ2QL0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?oo
o`3oool0B@3oool01009jPX0oooo0?ooo`09jPX30?ooo`0400WZ2P3oool0oooo000001`0Ogmo00<0
2NX:07moO`1oOgl00P1oOgl01P0000002NX:07moO`1oOgl02NX:000000T0Ogmo00D02NX:07moO`1o
Ogl0Ogmo00WZ2P0307moO`<02NX:1`1oOgl2000000L0Ogmo1P09jPX00`1oOgl02NX:07moO`0;07mo
O`0300WZ2P1oOgl0Ogmo01X0Ogmo00<0000007moO`1oOgl02@1oOgl01@09jPX0Ogmo07moO`1oOgl0
2NX:00@0Ogmo0`09jPX0101oOgl0000000WZ2P1oOgl200WZ2P0307moO`09jPX0Ogmo00<0Ogmo00<0
000007moO`1oOgl05@1oOgl01@09jPX0Ogmo07moO`09jPX0Ogmo00802NX:1@1oOgl300WZ2P80Ogmo
0P09jPX207moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P09jPX407moO`0400WZ2P000000Ogmo07moO`<0
2NX:1@1oOgl200WZ2PH0Ogmo0`09jPX00`1oOgl000000000000207moO`0300WZ2P000000Ogmo00<0
Ogmo0P09jPX:07moO`0300WZ2P000000Ogmo00H0Ogmo00<02NX:07moO`1oOgl01@1oOgl?00WZ2Qd0
oooo00<02NX:0?ooo`3oool0403oool300WZ2QT0oooo00<000000?ooo`3oool0303oool00800oooo
00<000000?ooo`3oool0B@3oool00`09jPX0oooo00WZ2P040?ooo`0500WZ2P3oool0oooo0?ooo`00
0000701oOgl01P09jPX0Ogmo07moO`1oOgl0000000WZ2P80Ogmo00<02NX:07moO`1oOgl01P1oOgl2
00WZ2P@0Ogmo00<02NX:07moO`1oOgl00`1oOgl200WZ2PP0Ogmo00<0000007moO`1oOgl00P1oOgl5
00WZ2PD0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0J07moO`030000001oOgl0
Ogmo00P0Ogmo00<02NX:07moO`1oOgl00`1oOgl400WZ2PD0Ogmo00@02NX:07moO`1oOgl0Ogmo0P09
jPX407moO`030000001oOgl0Ogmo01D0Ogmo00@02NX:07moO`09jPX0Ogmo0`09jPX307moO`802NX:
00<0Ogmo00WZ2P1oOgl00P09jPX507moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P09jPX307moO`030000
0009jPX0Ogmo00<0Ogmo0P09jPX407moO`802NX:101oOgl300WZ2P<0Ogmo00<02NX:07moO`1oOgl0
0P1oOgl00`09jPX0000007moO`0507moO`802NX:1`1oOgl00`09jPX0Ogmo07moO`02000000<0Ogmo
0P09jPX<07moO`030000003oool0oooo00H0oooo4009jPX@0?ooo`0300WZ2P3oool0oooo00d0oooo
0P09jPXL0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo04P0oooo00<0
2NX:0?ooo`09jPX01P3oool01009jPX0oooo0?ooo`00000L07moO`0600WZ2P1oOgl0Ogmo07moO`00
00002NX:0`1oOgl00`09jPX0Ogmo07moO`0407moO`802NX:101oOgl00`09jPX0Ogmo07moO`0607mo
O`802NX:1`1oOgl00`000000Ogmo00WZ2P0200WZ2P@0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09
jPX0Ogmo07moO`0907moO`0300WZ2P1oOgl0Ogmo01/0Ogmo00<0000007moO`1oOgl01`1oOgl00`09
jPX0Ogmo07moO`0500WZ2PL0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2P80Ogmo00<0000007mo
O`1oOgl05P1oOgl200WZ2P<0Ogmo0P09jPX00`1oOgl02NX:00WZ2P0307moO`802NX:1`1oOgl00`09
jPX0Ogmo07moO`0307moO`802NX:00@0Ogmo0000001oOgl02NX:101oOgl200WZ2P<0Ogmo00@02NX:
07moO`09jPX0Ogmo0`09jPX507moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`0000001`1o
Ogl200WZ2PD0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000Ogmo00WZ2P0>07moO`030000003o
ool0oooo00P0oooo00<02NX:0?ooo`3oool02`3oool>00WZ2P<0oooo00<02NX:0?ooo`3oool02P3o
ool200WZ2Qh0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0B03oool0
0`09jPX0oooo00WZ2P060?ooo`0500WZ2P3oool0oooo0?ooo`0000006`1oOgl01009jPX0Ogmo07mo
O`00000207moO`0500WZ2P1oOgl0Ogmo07moO`09jPX00`1oOgl00`0000002NX:00WZ2P0507moO`03
00WZ2P1oOgl0Ogmo00P0Ogmo0P09jPX307moO`@02NX:00<0000007moO`1oOgl01@1oOgl01@09jPX0
Ogmo07moO`1oOgl02NX:00/0Ogmo00<02NX:07moO`1oOgl06`1oOgl00`000000Ogmo07moO`0607mo
O`@02NX:1@1oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo0080Ogmo00D02NX:07mo
O`09jPX02NX:0000000H07moO`0300WZ2P1oOgl0Ogmo0080Ogmo0`09jPX407moO`802NX:2@1oOgl0
0`09jPX0Ogmo07moO`0207moO`0300WZ2P0000002NX:0080Ogmo00<02NX:07moO`1oOgl00`1oOgl2
00WZ2P80Ogmo1009jPX707moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`0000002@1oOgl2
00WZ2P<0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0000007moO`0<07moO`030000003oool0
oooo00X0oooo0P09jPXI0?oooa002NX:803oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`00
0000oooo0?ooo`180?ooo`802NX:203oool01009jPX0oooo0?ooo`00000K07moO`0400WZ2P1oOgl0
Ogmo00000080Ogmo00<02NX:07moO`1oOgl00P1oOgl01@09jPX0Ogmo07moO`0000002NX:00H0Ogmo
00<02NX:07moO`1oOgl02P1oOgl400WZ2P@0Ogmo00<0000007moO`1oOgl01@1oOgl01@09jPX0Ogmo
07moO`1oOgl02NX:00X0Ogmo00<02NX:07moO`1oOgl06`1oOgl00`000000Ogmo07moO`0407moO`<0
2NX:2@1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1o
Ogl00P09jPXF07moO`802NX:0`1oOgl400WZ2P80Ogmo0P09jPX;07moO`0300WZ2P1oOgl0Ogmo0080
Ogmo00H0000000WZ2P1oOgl02NX:07moO`09jPX407moO`L02NX:2@1oOgl00`09jPX0Ogmo07moO`05
07moO`0300WZ2P1oOgl0000000X0Ogmo0`09jPX407moO`802NX:0P1oOgl00`000000Ogmo07moO`0:
07moO`030000003oool0oooo00`0oooo0P09jPXL0?ooo`0300WZ2P3oool0oooo00@0oooo4009jPXD
0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo04P0oooo0P09jPX80?oo
o`0400WZ2P3oool0oooo000001/0Ogmo00@02NX:07moO`1oOgl000000P1oOgl00`09jPX0Ogmo07mo
O`0307moO`<02NX:1P1oOgl00`09jPX0Ogmo07moO`0707moO`T02NX:101oOgl2000000H0Ogmo0P09
jPX00`1oOgl02NX:07moO`0907moO`0300WZ2P1oOgl0Ogmo01`0Ogmo00<0000007moO`1oOgl00`09
jPX00`1oOgl02NX:07moO`0:07moO`802NX:0P1oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1o
Ogl000000080Ogmo0P09jPXC07moO`0400WZ2P1oOgl02NX:07moO`802NX:00@0Ogmo00WZ2P09jPX0
Ogmo0P09jPX00`1oOgl02NX:07moO`0;07moO`0:00WZ2P1oOgl0Ogmo0000001oOgl02NX:07moO`09
jPX0Ogmo00WZ2P@0Ogmo1P09jPX00`000000Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00H0Ogmo
00<02NX:07moO`000000301oOgl200WZ2P80Ogmo00<02NX:07moO`1oOgl00`1oOgl2000000X0Ogmo
00<000000?ooo`3oool03P3oool200WZ2Q/0oooo00<02NX:0?ooo`3oool00`09jPX@0?ooo`h02NX:
1P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`170?ooo`802NX:2P3o
ool01009jPX0oooo0?ooo`00000K07moO`0300WZ2P1oOgl0000000<0Ogmo00<02NX:07moO`1oOgl0
0P1oOgl300WZ2PH0Ogmo00<02NX:07moO`1oOgl0101oOgl300WZ2P0307moO`09jPX02NX:00D0Ogmo
0`09jPX407moO`030000001oOgl0Ogmo00D0Ogmo00<02NX:07moO`09jPX02@1oOgl00`09jPX0Ogmo
07moO`0K07moO`@02NX:101oOgl00`09jPX0Ogmo07moO`0;07moO`0300WZ2P1oOgl02NX:00H0Ogmo
00<02NX:07moO`000000101oOgl00`09jPX0Ogmo07moO`0>07moO`802NX:0P1oOgl200WZ2P<0Ogmo
0`09jPX00`1oOgl02NX:00WZ2P0=07moO`0300WZ2P000000000000<0Ogmo00@02NX:07moO`09jPX0
2NX:0P1oOgl600WZ2P0407moO`0000000000000000H0Ogmo00<02NX:07moO`1oOgl01`1oOgl01009
jPX0Ogmo07moO`00000:07moO`0300WZ2P1oOgl0Ogmo00802NX:201oOgl2000000L0Ogmo00<00000
0?ooo`3oool04@3oool200WZ2QX0oooo0P09jPXQ0?ooo`D02NX:0P00000>0?ooo`00P03oool00`00
0000oooo0?ooo`170?ooo`802NX:2P3oool01009jPX0oooo0?ooo`00000K07moO`0300WZ2P1oOgl0
000000<0Ogmo00H02NX:07moO`1oOgl0Ogmo00WZ2P1oOgl200WZ2PH0Ogmo00<02NX:07moO`1oOgl0
1009jPX0101oOgl02NX:00WZ2P09jPX807moO`@02NX:0`1oOgl00`000000Ogmo07moO`0507moO`80
2NX:2@1oOgl00`09jPX0Ogmo07moO`0H07moO`<02NX:00<0Ogmo0000001oOgl0101oOgl00`09jPX0
Ogmo07moO`0=07moO`802NX:1`1oOgl00`09jPX0000007moO`0407moO`802NX:3@1oOgl00`09jPX0
Ogmo07moO`0300WZ2P<0Ogmo0`09jPX207moO`802NX:3@1oOgl00`0000002NX:07moO`0307moO`03
00WZ2P1oOgl0Ogmo00H02NX:00<0Ogmo00WZ2P09jPX00P1oOgl2000000H0Ogmo00<02NX:07moO`1o
Ogl01`1oOgl01009jPX0Ogmo07moO`00000:07moO`0300WZ2P1oOgl02NX:0080Ogmo0P09jPX807mo
O`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool04`3oool200WZ2QH0oooo0P09jPX00`3o
ool02NX:0?ooo`0U0?ooo`8000003P3oool00800oooo00<000000?ooo`3oool0A`3oool00`09jPX0
oooo0?ooo`0:0?ooo`0400WZ2P3oool0oooo000001X0Ogmo00<02NX:0000001oOgl00`1oOgl01009
jPX0Ogmo07moO`09jPX207moO`802NX:1@1oOgl400WZ2P<0Ogmo0P09jPX=07moO`@02NX:0P1oOgl2
000000H0Ogmo0P09jPX807moO`0300WZ2P1oOgl0Ogmo01D0Ogmo0`09jPX507moO`030000001oOgl0
Ogmo0080Ogmo00<02NX:07moO`1oOgl03P1oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0
Ogmo00H0Ogmo0P09jPX:07moO`0400WZ2P1oOgl02NX:00WZ2P80Ogmo00D02NX:07moO`09jPX02NX:
07moO`0200WZ2P80Ogmo00<02NX:07moO`09jPX02P1oOgl20000000307moO`09jPX0Ogmo00<0Ogmo
1P09jPX0101oOgl02NX:07moO`1oOgl300WZ2P0307moO`09jPX0Ogmo00D0Ogmo00<02NX:07moO`1o
Ogl0201oOgl01@09jPX0Ogmo07moO`1oOgl0000000P0Ogmo00<02NX:07moO`09jPX01@1oOgl200WZ
2PL0Ogmo0P00000307moO`030000003oool0oooo01H0oooo0P09jPXB0?ooo`802NX:103oool00`09
jPX0oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo04H0
oooo0P09jPX<0?ooo`0400WZ2P3oool0oooo000001X0Ogmo00<02NX:0000001oOgl00`1oOgl00`09
jPX0Ogmo00WZ2P0207moO`0500WZ2P1oOgl0Ogmo00WZ2P1oOgl01009jPX307moO`<02NX:4@1oOgl4
00WZ2P80Ogmo00<0000007moO`1oOgl0101oOgl200WZ2PL0Ogmo00<02NX:07moO`1oOgl04@1oOgl4
00WZ2PP0Ogmo00D0000007moO`1oOgl0Ogmo00WZ2P0A07moO`802NX:1P1oOgl00`09jPX0Ogmo07mo
O`0807moO`802NX:1`1oOgl300WZ2P@0Ogmo0P09jPX307moO`802NX:00<0Ogmo00WZ2P1oOgl00P1o
Ogl00`09jPX0Ogmo07moO`0607moO`030000001oOgl0Ogmo0080Ogmo2@09jPX207moO`0300WZ2P1o
Ogl02NX:0080Ogmo00<02NX:07moO`09jPX01@1oOgl00`09jPX0Ogmo07moO`0907moO`0500WZ2P1o
Ogl0Ogmo07moO`000000201oOgl200WZ2PP0Ogmo0P09jPX707moO`80000000<0Ogmo0000003oool0
6@3oool200WZ2Ph0oooo0P09jPX70?ooo`0300WZ2P3oool0oooo02<0oooo00<000000?ooo`3oool0
303oool00800oooo00<000000?ooo`3oool0AP3oool00`09jPX0oooo0?ooo`0;0?ooo`0500WZ2P3o
ool0oooo0?ooo`0000006@1oOgl00`09jPX0000007moO`0307moO`802NX:0P1oOgl20000000407mo
O`09jPX02NX:00WZ2P<0Ogmo00@02NX:07moO`09jPX02NX:5P1oOgl400WZ2P0307moO`0000000000
00D0Ogmo0P09jPX607moO`0300WZ2P1oOgl0Ogmo00h0Ogmo0`09jPX<07moO`050000001oOgl0Ogmo
07moO`09jPX04@1oOgl00`09jPX0Ogmo00WZ2P0507moO`0300000009jPX0Ogmo00X0Ogmo00<02NX:
07moO`1oOgl00P1oOgl200WZ2PH0Ogmo0P09jPX407moO`<02NX:1@1oOgl00`09jPX0Ogmo07moO`04
07moO`040000001oOgl0Ogmo07moO`H02NX:0P1oOgl200WZ2P0307moO`09jPX0Ogmo00802NX:0`1o
Ogl200WZ2P0307moO`09jPX0Ogmo0080Ogmo00<02NX:07moO`1oOgl02P1oOgl00`09jPX0Ogmo07mo
O`0207moO`030000001oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl02P1oOgl200WZ2PL0Ogmo00<0
00000?ooo`3oool06`3oool200WZ2PT0oooo0`09jPX:0?ooo`0300WZ2P3oool0oooo0280oooo00<0
00000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0A@3oool200WZ2Ph0oooo00@02NX:
00000000000000006P1oOgl01`09jPX0Ogmo07moO`1oOgl02NX:07moO`09jPX00P1oOgl00`000000
2NX:00WZ2P0307moO`0300WZ2P1oOgl02NX:00802NX:6P1oOgl00`09jPX0Ogmo00WZ2P0200WZ2P03
0000001oOgl0Ogmo0080Ogmo00<02NX:07moO`09jPX0101oOgl00`09jPX0Ogmo07moO`0<07moO`<0
2NX:401oOgl00`000000Ogmo00WZ2P0B07moO`0300WZ2P1oOgl0Ogmo00802NX:0P1oOgl00`000000
Ogmo00WZ2P0<07moO`D02NX:1@1oOgl200WZ2P0307moO`09jPX0Ogmo00<0Ogmo0`09jPX607moO`04
00WZ2P1oOgl0Ogmo07moO`8000000P1oOgl500WZ2PD0Ogmo0P09jPX207moO`0300WZ2P1oOgl02NX:
00@0Ogmo00<02NX:07moO`09jPX00`1oOgl00`09jPX0Ogmo07moO`0;07moO`0500WZ2P1oOgl0Ogmo
07moO`0000001@1oOgl200WZ2Ph0Ogmo0`09jPX507moO`8000007@3oool200WZ2PD0oooo0P09jPX>
0?ooo`0300WZ2P3oool0oooo0240oooo00<000000?ooo`3oool0303oool00800oooo00<000000?oo
o`3oool0A@3oool200WZ2Ph0oooo00@02NX:07moO`1oOgl000006P1oOgl01009jPX0Ogmo07moO`09
jPX207moO`0300WZ2P1oOgl0Ogmo00802NX:101oOgl300WZ2P030000001oOgl0Ogmo01X0Ogmo0P09
jPX207moO`802NX:101oOgl00`09jPX0Ogmo00WZ2P0307moO`0300WZ2P1oOgl0Ogmo00T0Ogmo0`09
jPXC07moO`030000001oOgl02NX:0140Ogmo00<02NX:07moO`1oOgl00`1oOgl01@09jPX0Ogmo0000
001oOgl02NX:00`0Ogmo1009jPX407moO`802NX:0`1oOgl00`09jPX0Ogmo07moO`0207moO`802NX:
201oOgl01009jPX0Ogmo0000001oOgl500WZ2P<0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2P80
Ogmo0P09jPX507moO`0300WZ2P1oOgl02NX:0080Ogmo00<02NX:07moO`1oOgl0301oOgl01@09jPX0
Ogmo07moO`1oOgl0000000<0Ogmo0`09jPXB07moO`802NX:1@1oOgl00`000000oooo0?ooo`0L0?oo
o`802NX:00<0oooo00WZ2P09jPX04@3oool00`09jPX0oooo0?ooo`0P0?ooo`030000003oool0oooo
00`0oooo00200?ooo`030000003oool0oooo04@0oooo00<02NX:0?ooo`09jPX0303oool200000005
07moO`09jPX0Ogmo07moO`000000601oOgl0100000002NX:07moO`09jPX407moO`<02NX:0`1oOgl2
00WZ2P0307moO`0000002NX:00T02NX:5P1oOgl200WZ2P80Ogmo0P09jPX00`000000Ogmo00WZ2P02
07moO`802NX:00<0Ogmo00WZ2P1oOgl01P1oOgl400WZ2QH0Ogmo00<0000000WZ2P1oOgl04@1oOgl0
0`09jPX0Ogmo07moO`0407moO`0500WZ2P000000Ogmo07moO`09jPX02@1oOgl200WZ2P80Ogmo00<0
2NX:07moO`09jPX00`09jPX507moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl0201o
Ogl500WZ2PH0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0200WZ2PH0Ogmo0P09
jPX00`1oOgl02NX:07moO`0>07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000007moO`09jPX00P1o
Ogl00`09jPX0Ogmo07moO`0B07moO`802NX:101oOgl2000001d0oooo0`09jPXC0?ooo`0300WZ2P3o
ool0oooo01l0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0A03oool2
00WZ2P/0oooo0P00000307moO`0400WZ2P1oOgl0Ogmo000001P0Ogmo00<0000000WZ2P09jPX01@1o
Ogl600WZ2P<0Ogmo0P00000907moOa402NX:1`1oOgl200WZ2P0307moO`0000002NX:00P02NX:101o
Ogl300WZ2Q/0Ogmo00<02NX:07moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0407moO`0500000009
jPX0Ogmo07moO`09jPX01`1oOgl200WZ2P<0Ogmo00<02NX:07moO`1oOgl00`09jPX607moO`0300WZ
2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl01@1oOgl500WZ2PX0Ogmo00<02NX:07moO`1oOgl0
0P1oOgl01P09jPX0Ogmo07moO`09jPX0Ogmo00WZ2PD0Ogmo0P09jPX00`1oOgl02NX:07moO`0>07mo
O`0300WZ2P1oOgl0Ogmo0080Ogmo00D0000000WZ2P1oOgl0Ogmo00WZ2P0G07moO`802NX:101oOgl2
000001T0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool07P3oool0
0`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`130?ooo`0300WZ2P3oool02NX:
00X0oooo00<0000007moO`1oOgl0101oOgl01009jPX0Ogmo07moO`00000G07moO`0300000009jPX0
Ogmo00D0Ogmo0`09jPX707moO`0300WZ2P1oOgl0Ogmo01P0Ogmo4P09jPX00`0000002NX:00WZ2P0=
00WZ2Q<0Ogmo00<02NX:0000001oOgl04@1oOgl00`09jPX0Ogmo07moO`0407moO`050000001oOgl0
2NX:07moO`09jPX01@1oOgl200WZ2P@0Ogmo00@02NX:07moO`09jPX02NX:0`1oOgl200WZ2P@0Ogmo
00@02NX:07moO`1oOgl0Ogmo0P09jPX407moO`D02NX:0`1oOgl00`09jPX0Ogmo07moO`0707moO`03
00WZ2P1oOgl0Ogmo0080Ogmo0`09jPX207moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<0000000WZ2P09
jPX0401oOgl01009jPX0Ogmo07moO`1oOgl200WZ2P040000001oOgl0Ogmo00WZ2QT0Ogmo0P09jPX4
07moO`030000003oool0oooo01<0oooo0`09jPX60?ooo`802NX:4P3oool00`09jPX0oooo0?ooo`0M
0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo0480oooo00@02NX:0?oo
o`3oool02NX:203oool2000000L0Ogmo00@02NX:07moO`1oOgl000005P1oOgl0100000002NX:07mo
O`09jPX307moO`@02NX:1`1oOgl00`09jPX0Ogmo07moO`0T07moO`0500WZ2P1oOgl0000000000009
jPX00P1oOglO00WZ2P@0Ogmo00<02NX:0000001oOgl04@1oOgl00`09jPX0Ogmo07moO`0407moO`06
0000001oOgl0Ogmo00WZ2P1oOgl02NX:0P1oOgl200WZ2PD0Ogmo0`09jPX707moO`802NX:0P1oOgl0
1`09jPX0Ogmo07moO`09jPX0Ogmo00WZ2P1oOgl01@09jPX00`000000Ogmo07moO`0407moO`0300WZ
2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2P<0Ogmo00<02NX:07moO`1oOgl0
0P1oOgl00`0000002NX:00WZ2P0@07moO`@02NX:0P1oOgl00`000000Ogmo00WZ2P0L07moO`802NX:
0`1oOgl200000140oooo0P09jPX;0?ooo`802NX:4@3oool00`09jPX0oooo0?ooo`0L0?ooo`030000
003oool0oooo00`0oooo00200?ooo`030000003oool0oooo0480oooo00@02NX:0?ooo`3oool02NX:
1`3oool00`000000Ogmo07moO`0707moO`0400WZ2P1oOgl0Ogmo000000<0Ogmo5009jPX010000000
Ogmo00WZ2P1oOgl200WZ2P80Ogmo0P09jPX707moO`0300WZ2P1oOgl0Ogmo02D0Ogmo0P09jPX00`1o
Ogl02NX:07moO`0407moO`802NX:301oOglM00WZ2PT0Ogmo00<02NX:07moO`1oOgl0101oOgl01000
0000Ogmo07moO`1oOgl400WZ2PH0Ogmo0P09jPX;07moO`<02NX:0P1oOgl00`09jPX0Ogmo00WZ2P03
00WZ2P0307moO`000000Ogmo00P0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`02
07moO`802NX:101oOgl01009jPX0Ogmo07moO`1oOgl300WZ2Pl0Ogmo0P09jPX607moO`0300000009
jPX0Ogmo01d0Ogmo0P09jPX307moO`030000003oool0oooo00`0oooo0P09jPX?0?ooo`802NX:403o
ool00`09jPX0oooo0?ooo`0K0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0
oooo03L0oooo9`09jPXC07moO`0300WZ2P1oOgl02NX:00802NX:0`1oOgl00`09jPX0Ogmo00WZ2P07
07moO`0300WZ2P1oOgl0Ogmo02L0Ogmo0`09jPX00`000000Ogmo07moO`0307moO`0300WZ2P1oOgl0
Ogmo01X0Ogmo6`09jPX00`000000Ogmo07moO`0207moO`<02NX:1P1oOgl00`09jPX0Ogmo07moO`0=
07moO`H02NX:0`1oOgl00`000000Ogmo07moO`0907moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:
07moO`1oOgl00`09jPX407moO`0700WZ2P1oOgl0Ogmo07moO`09jPX0Ogmo00WZ2P0=07moO`802NX:
00<0Ogmo00WZ2P1oOgl01@1oOgl00`09jPX0Ogmo07moO`0O07moO`802NX:0P1oOgl2000000X0oooo
0P09jPXC0?ooo`802NX:3`3oool00`09jPX0oooo0?ooo`0J0?ooo`030000003oool0oooo00`0oooo
00200?ooo`030000003oool0oooo0100oooo9`09jPX:0?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo
0P00000=07moO`0400WZ2P1oOgl0Ogmo000001@0Ogmo0`09jPX00`1oOgl02NX:07moO`0307moO`04
00WZ2P1oOgl0Ogmo00WZ2PH0Ogmo00<02NX:07moO`1oOgl0:@1oOgl200WZ2P030000001oOgl0Ogmo
00<0Ogmo00<02NX:07moO`1oOgl0601oOgl01@09jPX0Ogmo07moO`1oOgl0000000l0Ogmo5`09jPX>
07moO`@02NX:0P1oOgl01009jPX0Ogmo00000000000=07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00L0
2NX:07moO`09jPX0Ogmo00WZ2P1oOgl02NX:00@0Ogmo00<02NX:07moO`09jPX00P1oOgl00`09jPX0
Ogmo07moO`0807moO`<02NX:101oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P000000Ogmo0240
Ogmo0P09jPX207moO`8000001P3oool200WZ2QL0oooo00<02NX:0000000000003@3oool00`09jPX0
oooo0?ooo`0I0?ooo`030000003oool0oooo00`0oooo00200?ooo`8000004@09jPX`0?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX00`3oool00`000000Ogmo07moO`0>07moO`0400WZ2P1oOgl0Ogmo0000
0140Ogmo0`09jPX010000000Ogmo07moO`09jPX307moO`0500WZ2P1oOgl0Ogmo07moO`09jPX01P1o
Ogl00`09jPX0Ogmo07moO`0Z07moO`<02NX:1@1oOgl00`09jPX0Ogmo07moO`0G07moO`0500WZ2P1o
Ogl0Ogmo07moO`000000401oOgl00`09jPX0Ogmo07moO`0407moO`802NX:1@1oOgl00`09jPX0Ogmo
00WZ2P0F00WZ2P0507moO`09jPX02NX:00WZ2P000000401oOgl00`09jPX0Ogmo07moO`0507moO`80
2NX:00@0Ogmo00WZ2P1oOgl02NX:1@1oOgl01009jPX0Ogmo07moO`1oOgl200WZ2PL0Ogmo0P09jPX7
07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:0000001oOgl08`1oOgl200WZ2P80Ogmo00<00000
0?ooo`3oool00`09jPXJ0?ooo`8000003P3oool00`09jPX0oooo0?ooo`0H0?ooo`030000003oool0
oooo00`0oooo00200?ooo`800000@@3oool01009jPX0oooo0?ooo`09jPX20?ooo`8000004@1oOgl0
1009jPX0Ogmo07moO`00000?07moO`<02NX:0P1oOgl01@000000Ogmo07moO`1oOgl02NX:0080Ogmo
00D02NX:07moO`1oOgl0Ogmo00WZ2P0507moO`0300WZ2P1oOgl0Ogmo02/0Ogmo00D02NX:07moO`1o
Ogl02NX:0000000407moO`802NX:5P1oOgl00`09jPX0Ogmo07moO`0307moO`030000001oOgl0Ogmo
00d0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2PL0Ogmo1@09jPX:07moO`8000005009jPX:07mo
O`0300WZ2P1oOgl0Ogmo00@0Ogmo00@02NX:07moO`1oOgl02NX:0P1oOgl00`09jPX0Ogmo07moO`02
07moO`802NX:0`1oOgl00`09jPX0Ogmo07moO`0307moO`802NX:2@1oOgl00`09jPX0Ogmo07moO`02
07moO`0400WZ2P1oOgl0Ogmo000002D0Ogmo0P09jPX00`1oOgl02NX:00WZ2P0^0?ooo`0300WZ2P3o
ool0oooo01L0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0?`3oool0
1@09jPX0oooo0?ooo`3oool02NX:008000001`1oOgl2000000/0Ogmo00<02NX:07moO`0000002P1o
Ogl2000000<02NX:00<0Ogmo00WZ2P1oOgl00P1oOgl01`000000Ogmo07moO`1oOgl02NX:00000009
jPX01@1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo02`0Ogmo00<02NX:07moO`1o
Ogl00P09jPX507moO`0300WZ2P1oOgl0Ogmo01<0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0=07moO`0300WZ2P1oOgl0Ogmo00802NX:00<0Ogmo0000001oOgl01@1oOgl200WZ2P80
Ogmo0P09jPX707moO`8000000P09jPX00`000000Ogmo07moO`0307moO`802NX:0P1oOgl010000000
Ogmo00WZ2P1oOgl200WZ2PD0Ogmo5@09jPX207moO`0700WZ2P1oOgl0Ogmo07moO`09jPX0Ogmo00WZ
2P0307moO`0300WZ2P1oOgl0Ogmo00<02NX:2`1oOgl00`09jPX0Ogmo07moO`0207moO`0400WZ2P1o
Ogl0Ogmo000002H0Ogmo0`09jPX00`1oOgl000000000000]0?ooo`0300WZ2P3oool0oooo01H0oooo
00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0?P3oool00`09jPX0oooo0?oo
o`020?ooo`0300WZ2P1oOgl0Ogmo00L0Ogmo1009jPX907moO`0400WZ2P1oOgl0Ogmo000000T0Ogmo
0P09jPX407moO`0400WZ2P1oOgl0Ogmo000000@0Ogmo00<02NX:00000009jPX01@1oOgl00`09jPX0
Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo02`0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2P@0
Ogmo00<02NX:07moO`1oOgl04@1oOgl00`09jPX0Ogmo07moO`0407moO`030000001oOgl0Ogmo00d0
Ogmo0`09jPX307moO`030000001oOgl0Ogmo0080Ogmo0P09jPX207moO`802NX:0P1oOgl200WZ2PD0
Ogmo00@02NX:0000001oOgl02NX:1@1oOgl01@09jPX0Ogmo00WZ2P1oOgl000000080Ogmo00D02NX:
07moO`1oOgl0Ogmo00WZ2P0?07moO`0400WZ2P1oOgl0Ogmo07moOaD02NX:1P1oOgl2000000H0Ogmo
00D02NX:07moO`1oOgl0Ogmo00WZ2P0407moO`030000001oOgl0Ogmo0240Ogmo0P09jPX307moO`80
2NX:00<0Ogmo0000003oool0;03oool00`09jPX0oooo0?ooo`0E0?ooo`030000003oool0oooo00`0
oooo00200?ooo`030000003oool0oooo03h0oooo00<02NX:0?ooo`3oool00P0000000`09jPX0Ogmo
07moO`0707moO`0400WZ2P1oOgl0Ogmo07moO`D02NX:0P00000307moO`0300WZ2P1oOgl0000000H0
Ogmo0`09jPX507moO`0500WZ2P1oOgl0Ogmo07moO`000000101oOgl200WZ2PH0Ogmo00<02NX:07mo
O`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0]07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000000WZ
2P09jPX00`1oOgl200WZ2Q40Ogmo00<02NX:07moO`1oOgl01@1oOgl00`000000Ogmo07moO`0;07mo
O`802NX:101oOgl010000000Ogmo07moO`1oOgl200WZ2P<0Ogmo0P09jPX507moO`0300WZ2P1oOgl0
Ogmo0080Ogmo00@02NX:07moO`1oOgl02NX:1@1oOgl01009jPX0Ogmo00WZ2P00000307moO`0300WZ
2P1oOgl0Ogmo0080Ogmo00<02NX:0000000000003@1oOgl01009jPX0Ogmo07moO`09jPX307moO`80
2NX:0`1oOgl200WZ2P@0Ogmo5@09jPX307moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000007moO`1o
Ogl07`1oOgl200WZ2PL0Ogmo0P09jPX2000002`0oooo00<02NX:0?ooo`3oool0503oool00`000000
oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0m0?ooo`0600WZ2P3oool0oooo0000001o
Ogl02NX:2P1oOgl00`09jPX0Ogmo07moO`0607moO`0300000009jPX02NX:00<02NX:0P1oOgl00`00
0000Ogmo07moO`0300WZ2PL0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0207mo
O`802NX:1`1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:02l0Ogmo00<02NX:07moO`1oOgl0101oOgl0
0`0000002NX:00WZ2P0307moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00<02NX:07moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0907moO`802NX:00<0Ogmo00WZ2P1oOgl00`1oOgl010000000Ogmo00WZ2P09
jPX407moO`0300WZ2P1oOgl02NX:00H0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0307moO`0800WZ
2P1oOgl0Ogmo07moO`09jPX0Ogmo00000009jPX407moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P00000>
07moO`0300WZ2P1oOgl02NX:0080Ogmo0`09jPX407moO`0400WZ2P1oOgl0Ogmo07moO`<02NX:0P1o
Ogl00`09jPX0Ogmo07moO`0807moOa002NX:101oOgl2000001L0Ogmo0`09jPX;07moO`802NX:00<0
00000?ooo`3oool0:P3oool00`09jPX0oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo0020
0?ooo`800000?P3oool00`09jPX00000000000020000000300WZ2P000000Ogmo00P0Ogmo00<02NX:
07moO`1oOgl02`1oOgl800WZ2PD0Ogmo0P0000000`09jPX0000007moO`0307moO`8000000P1oOgl9
00WZ2P0300000009jPX02NX:00802NX:<01oOgl00`09jPX0Ogmo07moO`0507moO`8000000P09jPX2
07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`000000Ogmo07moO`07
07moO`802NX:0P1oOgl00`09jPX0Ogmo07moO`0307moO`0300000009jPX0Ogmo00@0Ogmo00D02NX:
07moO`1oOgl0Ogmo00WZ2P0607moO`0300WZ2P1oOgl02NX:00@0Ogmo00@02NX:07moO`1oOgl02NX:
0P0000000`1oOgl02NX:07moO`0307moO`0300WZ2P1oOgl0Ogmo01@0Ogmo00@02NX:07moO`1oOgl0
Ogmo0`09jPX00`1oOgl000000000000200WZ2P0307moO`09jPX02NX:00<0Ogmo00<02NX:07moO`09
jPX0301oOgl200000080Ogmo00<02NX:07moO`09jPX01P1oOgl<00WZ2Q00Ogmo0P09jPX@07moO`80
2NX:00<000000?ooo`3oool0:@3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00`0
oooo000>0?ooog802NX:0P00001400WZ2P0300000009jPX02NX:0>X02NX:00<0000000WZ2P09jPX0
6009jPX207moO`802NX:201oOgl00`000000Ogmo07moO`0807moO`X02NX:101oOgl200WZ2Q@0Ogmo
0P09jPX00`000000oooo0?ooo`0X0?ooo`0300WZ2P3oool0oooo0140oooo00<000000?ooo`3oool0
303oool00800oooo00<000000?ooo`3oool0>`3oool00`0000002NX:07moO`0207moO`0300WZ2P1o
Ogl02NX:00X0Ogmo00<02NX:07moO`1oOgl02@1oOgl400WZ2P80Ogmo00<0000007moO`1oOgl0201o
OglB00WZ2PD0Ogmo00<02NX:07moO`1oOgl00P1oOgl500WZ2RP0Ogmo00<02NX:07moO`1oOgl01`1o
Ogl01@000000Ogmo00WZ2P09jPX0Ogmo00802NX:2P1oOgl00`09jPX0Ogmo07moO`0807moO`030000
001oOgl0Ogmo0080Ogmo0P09jPX607moO`0300WZ2P1oOgl0Ogmo00802NX:00<0000007moO`1oOgl0
0`1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl0
0`1oOgl200WZ2P@0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0C07moO`0900WZ
2P1oOgl0Ogmo00WZ2P1oOgl02NX:07moO`09jPX0Ogmo00<02NX:00<0Ogmo00WZ2P1oOgl01P1oOgl2
00WZ2Pd0Ogmo1009jPX807moO`030000001oOgl0Ogmo0180Ogmo1@09jPX00`000000Ogmo07moO`0D
07moO`802NX::P3oool00`09jPX0oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00200?oo
o`030000003oool0oooo03T0oooo0P0000000`09jPX0Ogmo07moO`0207moO`802NX:2`1oOgl00`09
jPX0Ogmo07moO`0707moO`802NX:101oOgl00`09jPX0Ogmo0000000=07moO`802NX:00<0000007mo
O`1oOgl01`09jPX307moO`/02NX:101oOgl400WZ2RD0Ogmo00<02NX:07moO`1oOgl01`1oOgl20000
000507moO`09jPX02NX:07moO`09jPX02@1oOgl00`09jPX0Ogmo07moO`0807moO`030000001oOgl0
2NX:00802NX:1`1oOgl0100000002NX:00WZ2P09jPX207moO`030000001oOgl0Ogmo0080Ogmo00<0
2NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0407moO`0400WZ2P1oOgl02NX:00WZ2P80Ogmo
00<0000000WZ2P1oOgl01@1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:01@0Ogmo00<02NX:07moO`1o
Ogl00P1oOgl00`09jPX0Ogmo07moO`0200WZ2P@0Ogmo00<02NX:07moO`1oOgl01@1oOgl200WZ2Pl0
Ogmo0`09jPX807moO`030000001oOgl0Ogmo0140Ogmo0P09jPX207moO`800000601oOgl200WZ2RT0
oooo00<02NX:0?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo
0?ooo`0h0?ooo`030000001oOgl02NX:00D0Ogmo0P09jPX;07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo
0`09jPX607moO`0400WZ2P1oOgl0Ogmo000000h0Ogmo0P09jPX307moO`0300WZ2P1oOgl02NX:0080
Ogmo2@09jPX507moO`d02NX:801oOgl00`09jPX0Ogmo07moO`0907moO`030000001oOgl0Ogmo00<0
2NX:1`1oOgl00`09jPX0Ogmo07moO`0907moO`802NX:201oOgl200WZ2P8000000`1oOgl00`000000
Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl0101oOgl02009jPX0
Ogmo07moO`1oOgl02NX:0000001oOgl02NX:1P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:01<0Ogmo
00<02NX:07moO`1oOgl00`1oOgl500WZ2PD0Ogmo00<02NX:07moO`1oOgl0101oOgl200WZ2Pl0Ogmo
00<02NX:07moO`1oOgl00P09jPX607moO`030000001oOgl0Ogmo00h0Ogmo0`09jPX407moO`0300WZ
2P1oOgl0Ogmo01T0Ogmo0P09jPXX0?ooo`0300WZ2P3oool0oooo00h0oooo00<000000?ooo`3oool0
303oool00800oooo00<000000?ooo`3oool0=P3oool200000080Ogmo00<02NX:07moO`1oOgl00`1o
Ogl200WZ2P/0Ogmo00@02NX:07moO`1oOgl0Ogmo0`09jPX:07moO`0300WZ2P1oOgl0000000h0Ogmo
00<0000007moO`09jPX00P09jPX307moO`0300WZ2P1oOgl0Ogmo00H0Ogmo2009jPX:07moO`/02NX:
601oOgl00`09jPX0Ogmo07moO`0907moO`8000000P1oOgl200WZ2PH0Ogmo00<02NX:07moO`1oOgl0
1`1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo0`09jPX507moO`050000001oOgl0Ogmo07moO`09
jPX02@1oOgl00`09jPX0Ogmo07moO`0407moO`0500WZ2P1oOgl0Ogmo07moO`0000000P09jPX00`1o
Ogl02NX:07moO`0407moO`0500WZ2P1oOgl0Ogmo07moO`09jPX04`1oOgl01009jPX0Ogmo07moO`1o
Ogl300WZ2P0507moO`09jPX02NX:07moO`09jPX0101oOgl00`09jPX0Ogmo07moO`0507moO`802NX:
3@1oOgl200WZ2P@0Ogmo0`09jPX307moO`030000001oOgl0Ogmo00`0Ogmo0P09jPX707moO`0300WZ
2P1oOgl0Ogmo01X0Ogmo00<0000000WZ2P09jPX09`3oool00`09jPX0oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00200?ooo`030000003oool0oooo03@0oooo0P00000307moO`0300WZ2P1o
Ogl0Ogmo00@0Ogmo0P09jPX;07moO`0400WZ2P1oOgl02NX:00WZ2Pd0Ogmo00<02NX:07moO`000000
3P1oOgl010000000Ogmo07moO`1oOgl300WZ2P0307moO`09jPX0Ogmo00L0Ogmo00<02NX:07moO`1o
Ogl01@1oOgl700WZ2PX0Ogmo3`09jPX=07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00@0000007moO`1o
Ogl0Ogmo0P09jPX307moO`0300WZ2P1oOgl0Ogmo00H0Ogmo0P09jPX307moO`030000001oOgl0Ogmo
00<0Ogmo0`09jPX707moO`040000001oOgl0Ogmo00WZ2P/0Ogmo00<02NX:07moO`1oOgl00`1oOgl0
1@09jPX0Ogmo000000000000Ogmo00802NX:00<0Ogmo00WZ2P1oOgl0101oOgl01@09jPX0Ogmo07mo
O`1oOgl02NX:0180Ogmo00<02NX:07moO`1oOgl00P09jPX207moO`0600WZ2P1oOgl0Ogmo00WZ2P1o
Ogl02NX:1@1oOgl00`09jPX0Ogmo07moO`0407moO`802NX:3@1oOgl200WZ2PL0Ogmo0P09jPX207mo
O`030000001oOgl0Ogmo00T0Ogmo0P09jPX907moO`0300WZ2P1oOgl0Ogmo01`0Ogmo00<0000000WZ
2P09jPX09P3oool00`09jPX0oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00200?ooo`03
0000003oool0oooo03<0oooo00<0000007moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0407moO`03
00WZ2P1oOgl0Ogmo00T0Ogmo0`09jPX@07moO`0300WZ2P1oOgl0000000`0Ogmo00D0000007moO`1o
Ogl0Ogmo00WZ2P0307moO`802NX:201oOgl00`09jPX0Ogmo07moO`0<07moO`P02NX:1P1oOgl500WZ
2PH0Ogmo2`09jPX307moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00@0000007moO`1oOgl0Ogmo0P09jPX2
07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo0P09jPX607moO`030000001oOgl0Ogmo00<02NX:201oOgl0
10000000Ogmo07moO`09jPX<07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`0000000`1o
Ogl01009jPX0Ogmo00WZ2P09jPX507moO`0500WZ2P1oOgl0Ogmo07moO`09jPX04P1oOgl300WZ2P<0
Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPX00`1oOgl02NX:07moO`0307moO`0300WZ2P1oOgl0Ogmo
00@0Ogmo0`09jPX;07moO`0400WZ2P1oOgl0Ogmo00WZ2PL0Ogmo0P09jPX2000000T0Ogmo0P09jPX;
07moO`0300WZ2P1oOgl0Ogmo01h0Ogmo00<0000000WZ2P09jPX09@3oool00`09jPX0oooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo0340oooo0P00000507mo
O`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl01P1oOgl300WZ2P0307moO`09jPX0Ogmo
0100Ogmo00<02NX:07moO`000000301oOgl01@000000Ogmo07moO`1oOgl02NX:00@0Ogmo0`09jPX6
07moO`0300WZ2P1oOgl0Ogmo01@0Ogmo1`09jPX407moO`D02NX:301oOgl;00WZ2PL0Ogmo0P000003
07moO`802NX:1@1oOgl200WZ2PP0Ogmo00@0000007moO`09jPX02NX:2P1oOgl00`000000Ogmo00WZ
2P0=07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:0000001oOgl00P1oOgl01@09jPX0Ogmo07mo
O`1oOgl02NX:008000000`1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:0100Ogmo0`09jPX507moO`06
00WZ2P1oOgl0Ogmo07moO`09jPX0Ogmo0P09jPX507moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P09jPX0
0`1oOgl02NX:07moO`0907moO`0400WZ2P1oOgl0Ogmo00WZ2PH0Ogmo00H02NX:07moO`0000000000
07moO`00000607moO`802NX:3@1oOgl00`09jPX0Ogmo07moO`0O07moO`8000000P09jPXT0?ooo`03
00WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0
;`3oool2000000L0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0407moO`802NX:
101oOgl00`09jPX0Ogmo07moO`0?07moO`0400WZ2P1oOgl0Ogmo000000/0Ogmo00D0000007moO`1o
Ogl0Ogmo00WZ2P0407moO`0300WZ2P1oOgl0Ogmo00802NX:101oOgl00`09jPX0Ogmo07moO`0:07mo
O`8000003`1oOgl700WZ2P80Ogmo1009jPX<07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo3009jPX01@1o
Ogl02NX:00WZ2P09jPX0Ogmo00802NX:2P1oOgl300WZ2P/0Ogmo00<0000000WZ2P1oOgl03P1oOgl0
1@09jPX0Ogmo07moO`0000002NX:00<0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0000007mo
O`0207moO`0500WZ2P1oOgl0Ogmo07moO`09jPX03P1oOgl300WZ2PL0Ogmo00D02NX:07moO`1oOgl0
Ogmo00WZ2P0207moO`802NX:101oOgl00`09jPX0Ogmo07moO`0307moO`0500WZ2P1oOgl02NX:07mo
O`09jPX02@1oOgl01009jPX0Ogmo07moO`09jPX407moO`0300000009jPX0Ogmo00@0Ogmo00@00000
07moO`1oOgl0Ogmo0`09jPX?07moO`0300WZ2P1oOgl0Ogmo0240Ogmo0P00000200WZ2R<0oooo00<0
2NX:0?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0^
0?ooo`030000001oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl01P1oOgl01009jPX0Ogmo07moO`1o
Ogl300WZ2PH0Ogmo00<02NX:07moO`1oOgl0401oOgl00`09jPX0Ogmo0000000;07moO`040000001o
Ogl0Ogmo00WZ2PH0Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPX00`1oOgl02NX:07moO`0<07moO`80
00000P09jPXD07moO`/02NX:1`1oOgl00`09jPX0Ogmo07moO`0>07moO`030000001oOgl02NX:00X0
2NX:101oOgl300WZ2P030000001oOgl0Ogmo00T0Ogmo00<0000000WZ2P1oOgl03`1oOgl01009jPX0
Ogmo00000009jPX407moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl00P1oOgl01@09
jPX0Ogmo07moO`1oOgl02NX:00`0Ogmo0P09jPX207moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:
07moO`1oOgl00P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00D0Ogmo00<02NX:07moO`1oOgl00`1o
Ogl200WZ2P0307moO`09jPX0Ogmo00L0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0407moO`<02NX:
1@1oOgl00`0000002NX:00WZ2P0C07moO`0300WZ2P1oOgl0Ogmo0280Ogmo00@000000?ooo`09jPX0
2NX:8P3oool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00200?ooo`030000
003oool0oooo02`0oooo0P00000807moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:00000009jPX0
0P09jPX907moO`0300WZ2P1oOgl0Ogmo0100Ogmo00<02NX:07moO`0000002`1oOgl010000000Ogmo
07moO`09jPX607moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P09jPXA07moO`802NX:6P1oOgl800WZ2P<0
Ogmo00<02NX:07moO`1oOgl03P1oOgl0200000002NX:00WZ2P09jPX0Ogmo00WZ2P1oOgl02NX:101o
Ogl00`09jPX000000000000800WZ2PP0Ogmo00<02NX:07moO`1oOgl03`1oOgl01009jPX0000007mo
O`09jPX307moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl00P1oOgl01@09jPX0Ogmo
07moO`1oOgl02NX:00T0Ogmo0`09jPX307moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1o
Ogl00`1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00@0Ogmo00<02NX:07moO`1oOgl00`1oOgl200WZ
2P80Ogmo00<02NX:07moO`1oOgl01@1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:0080Ogmo0P09jPX0
0`1oOgl02NX:07moO`0300WZ2P0300000009jPX02NX:01D0Ogmo00<02NX:07moO`1oOgl08`1oOgl2
000000030?ooo`09jPX02NX:0240oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`0<
0?ooo`00P03oool00`000000oooo0?ooo`0[0?ooo`030000001oOgl0Ogmo00P0Ogmo00<02NX:07mo
O`1oOgl01P1oOgl200WZ2P`0Ogmo00<02NX:07moO`1oOgl04@1oOgl00`09jPX0Ogmo0000000907mo
O`040000001oOgl0Ogmo00WZ2PL0Ogmo00<02NX:07moO`1oOgl0101oOgl300WZ2Q40Ogmo0P09jPXO
07moO`P02NX:3@1oOgl200WZ2P060000001oOgl0Ogmo07moO`09jPX0Ogmo0P09jPX307moO`802NX:
101oOgl010000000Ogmo07moO`1oOgl;00WZ2Ph0Ogmo00D0000007moO`09jPX0Ogmo00WZ2P0207mo
O`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl00P1oOgl01@09jPX0Ogmo07moO`1oOgl0
2NX:00L0Ogmo0P09jPX507moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl00`1oOgl0
1009jPX0Ogmo07moO`1oOgl200WZ2P@0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo00WZ
2P0207moO`0300WZ2P000000Ogmo00<0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo00WZ
2P0207moO`0700WZ2P1oOgl0Ogmo07moO`09jPX0000000WZ2P0207moO`030000001oOgl0Ogmo0180
Ogmo00<02NX:07moO`1oOgl09@1oOgl00`000000oooo0?ooo`0200WZ2R00oooo00<02NX:0?ooo`3o
ool01P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0Y0?ooo`800000
2P1oOgl00`09jPX0Ogmo07moO`0407moO`D02NX:301oOgl00`09jPX0Ogmo07moO`0A07moO`0300WZ
2P1oOgl0000000T0Ogmo00@0000007moO`1oOgl02NX:1`1oOgl00`09jPX0Ogmo07moO`0407moO`03
00WZ2P1oOgl0Ogmo00802NX:4@1oOgl200WZ2R80Ogmo2P09jPX307moO`@02NX:0P1oOgl200000080
Ogmo00<02NX:07moO`1oOgl00`09jPX707moO`030000001oOgl0Ogmo00H0Ogmo00<02NX:0000001o
Ogl00P1oOgl;00WZ2P0307moO`00000000000080Ogmo00<02NX:07moO`09jPX00P1oOgl00`09jPX0
Ogmo07moO`0607moO`0500WZ2P1oOgl0Ogmo07moO`09jPX00`1oOgl00`09jPX0Ogmo07moO`0307mo
O`802NX:1`1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00L02NX:07mo
O`1oOgl0Ogmo00WZ2P1oOgl02NX:00<0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo00WZ
2P0207moO`0300WZ2P000000Ogmo00<0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2P80Ogmo1@09
jPX507moO`030000001oOgl0Ogmo0180Ogmo00<02NX:07moO`1oOgl09P1oOgl200000080oooo0P09
jPXO0?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?ooo`3oool0303oool00800oooo00<00000
0?ooo`3oool09`3oool2000000`0Ogmo00@02NX:07moO`1oOgl0Ogmo0`09jPX307moO`802NX:301o
Ogl00`09jPX0Ogmo07moO`0B07moO`0300WZ2P1oOgl0000000P0Ogmo00<0000007moO`09jPX0201o
Ogl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo0080Ogmo0`09jPX@07moO`802NX:801o
Ogl00`09jPX0Ogmo07moO`0207moO``02NX:101oOgl00`000000Ogmo07moO`0300WZ2P0307moO`09
jPX02NX:00H0Ogmo00<0000007moO`1oOgl01@1oOgl00`09jPX0Ogmo0000000>07moO`/02NX:201o
Ogl01@09jPX0Ogmo07moO`1oOgl02NX:00<0Ogmo00<02NX:07moO`1oOgl00`09jPX807moO`0300WZ
2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ
2P1oOgl02NX:00<0Ogmo00/02NX:07moO`1oOgl0Ogmo00WZ2P1oOgl02NX:07moO`09jPX0Ogmo00WZ
2P0307moO`0300WZ2P1oOgl0Ogmo0080Ogmo1P09jPX:07moO`030000001oOgl0Ogmo0140Ogmo00<0
2NX:07moO`1oOgl0:01oOgl200000080oooo0P09jPXN0?ooo`0300WZ2P3oool0oooo00@0oooo00<0
00000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool09P3oool00`000000Ogmo07moO`0;
07moO`0300WZ2P1oOgl0Ogmo00802NX:1P1oOgl200WZ2P`0Ogmo00<02NX:07moO`1oOgl04P1oOgl0
0`09jPX0Ogmo0000000807moO`030000001oOgl02NX:00T0Ogmo00<02NX:07moO`1oOgl00P1oOgl0
0`09jPX0Ogmo07moO`0607moO`802NX:401oOgl200WZ2Ql0Ogmo00<02NX:07moO`1oOgl01@1oOgl5
00WZ2P0307moO`09jPX0Ogmo00P02NX:00<0Ogmo00WZ2P1oOgl00P1oOgl200WZ2P@0Ogmo00<00000
07moO`1oOgl00`1oOgl200WZ2P80Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`03
07moO`802NX:00@0Ogmo00WZ2P1oOgl0Ogmo2`09jPX00`1oOgl02NX:07moO`0207moO`<02NX:2P1o
Ogl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl00P1o
Ogl01009jPX0Ogmo07moO`09jPX207moO`0300WZ2P1oOgl0Ogmo0080Ogmo00H02NX:000000000000
2NX:07moO`09jPX307moO`@02NX:00@0000000WZ2P1oOgl02NX:0P1oOgl00`09jPX0Ogmo07moO`08
07moO`030000001oOgl0Ogmo0140Ogmo00<02NX:07moO`1oOgl0:P1oOgl010000000oooo0?ooo`3o
ool200WZ2Qd0oooo00<02NX:0?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool0
0`000000oooo0?ooo`0T0?ooo`8000003P1oOgl300WZ2PP0Ogmo0P09jPX<07moO`0300WZ2P1oOgl0
Ogmo01<0Ogmo00<02NX:07moO`0000001`1oOgl00`0000002NX:07moO`0907moO`0300WZ2P1oOgl0
Ogmo0080Ogmo00<02NX:07moO`1oOgl0201oOgl200WZ2Q00Ogmo0P09jPXM07moO`0300WZ2P1oOgl0
Ogmo00<0Ogmo0P09jPX507moO`D02NX:0P1oOgl200WZ2P8000002009jPX407moO`050000001oOgl0
Ogmo07moO`09jPX00`1oOgl00`000000Ogmo07moO`0:07moO`8000001`1oOgl00`09jPX0Ogmo00WZ
2P0:07moO`0300WZ2P1oOgl0Ogmo00802NX:00<0000000WZ2P09jPX01P09jPX707moO`0300WZ2P1o
Ogl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0307moO`0400WZ2P1o
Ogl0Ogmo00WZ2P80Ogmo00L02NX:07moO`1oOgl0Ogmo00WZ2P0000002NX:0080Ogmo1009jPX407mo
O`0600000009jPX0Ogmo00WZ2P1oOgl02NX:301oOgl00`000000Ogmo07moO`0@07moO`0300WZ2P1o
Ogl0Ogmo02/0Ogmo0P0000030?ooo`802NX:703oool00`09jPX0oooo0?ooo`020?ooo`030000003o
ool0oooo00`0oooo00200?ooo`030000003oool0oooo02<0oooo00<0000007moO`1oOgl02`1oOgl3
00WZ2P/0Ogmo0P09jPX<07moO`0300WZ2P1oOgl0Ogmo01<0Ogmo00<02NX:07moO`0000001P1oOgl0
0`000000Ogmo00WZ2P0:07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl02P1oOgl2
00WZ2Q00Ogmo0P09jPXL07moO`0300WZ2P1oOgl0Ogmo00802NX:1`1oOgl00`09jPX0Ogmo07moO`02
07moO`D02NX:00D0Ogmo0000001oOgl0Ogmo00WZ2P0307moO`L02NX:00<0Ogmo00WZ2P1oOgl00`1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00H0Ogmo0`09jPX;07moO`0400WZ2P1o
Ogl0Ogmo07moO`<02NX:00<0Ogmo00WZ2P1oOgl0101oOgl;00WZ2P@0Ogmo00<0000000WZ2P1oOgl0
1P1oOgl00`09jPX0Ogmo07moO`0307moO`0700WZ2P1oOgl0Ogmo07moO`09jPX0Ogmo00WZ2P0307mo
O`D02NX:00@0Ogmo00WZ2P1oOgl02NX:101oOgl01P09jPX0Ogmo07moO`09jPX0Ogmo00WZ2P`0Ogmo
00<0000007moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0]07moO`030000003oool0oooo0080oooo
0`09jPXJ0?ooo`0500WZ2P3oool0oooo0?ooo`0000003P3oool00800oooo00<000000?ooo`3oool0
8@3oool2000000/0Ogmo0`09jPX00`1oOgl02NX:07moO`0;07moO`802NX:301oOgl00`09jPX0Ogmo
07moO`0C07moO`0300WZ2P1oOgl0000000H0Ogmo00<0000007moO`09jPX02P1oOgl00`09jPX0Ogmo
07moO`0207moO`0300WZ2P1oOgl0Ogmo00`0Ogmo0P09jPX@07moO`802NX:6P1oOgl300WZ2PP0Ogmo
00@02NX:07moO`1oOgl0Ogmo0P09jPX507moO`@02NX:00<0Ogmo00WZ2P09jPX0101oOgl200WZ2P03
0000001oOgl02NX:00L02NX:2@1oOgl00`000000Ogmo07moO`0707moO`802NX:301oOgl00`09jPX0
Ogmo00WZ2P0200WZ2P<0Ogmo00<02NX:07moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0307moO`@0
2NX:00<0000000WZ2P1oOgl01P1oOgl00`09jPX0Ogmo07moO`0407moO`0400WZ2P1oOgl0Ogmo07mo
O`L02NX:1@1oOgl00`09jPX0Ogmo07moO`0207moO`0400WZ2P1oOgl0Ogmo07moO`802NX:3P1oOgl0
0`000000Ogmo07moO`0?07moO`0300WZ2P1oOgl0Ogmo02h0Ogmo0P0000050?ooo`802NX:6@3oool0
1009jPX0oooo0?ooo`00000>0?ooo`00P03oool00`000000oooo0?ooo`0O0?ooo`8000002`1oOgl2
00WZ2P@0Ogmo00<02NX:07moO`1oOgl02P1oOgl200WZ2P`0Ogmo00<02NX:07moO`1oOgl0501oOgl0
0`09jPX0Ogmo0000000507moO`0300000009jPX0Ogmo00X0Ogmo00<02NX:07moO`1oOgl00P1oOgl0
0`09jPX0Ogmo07moO`0>07moO`802NX:401oOgl00`09jPX0Ogmo07moO`0F07moO`<02NX:2@1oOgl0
1009jPX0Ogmo00WZ2P09jPX:07moO`0300000009jPX02NX:00<02NX:101oOgl200WZ2PD0Ogmo00<0
000007moO`1oOgl01`09jPX2000000X0Ogmo0`09jPX;07moO`802NX:0P1oOgl01@09jPX0Ogmo07mo
O`1oOgl02NX:00X0Ogmo00<02NX:07moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0307moO`D02NX:
00<0Ogmo00WZ2P09jPX00P1oOgl200WZ2PD0Ogmo00<02NX:07moO`1oOgl00P1oOgl01009jPX0Ogmo
07moO`1oOgl200WZ2Ph0Ogmo00<0000007moO`1oOgl03`1oOgl00`09jPX0Ogmo07moO`0`07moO`80
00001@3oool200WZ2QP0oooo00<02NX:0?ooo`0000003P3oool00800oooo00<000000?ooo`3oool0
7P3oool00`000000Ogmo07moO`0807moO`<02NX:1@1oOgl00`09jPX0Ogmo07moO`0;07moO`802NX:
301oOgl00`09jPX0Ogmo07moO`0D07moO`0300WZ2P1oOgl0000000D0Ogmo00<0000000WZ2P1oOgl0
2`1oOgl01009jPX0Ogmo07moO`09jPXC07moO`802NX:3`1oOgl200WZ2Q@0Ogmo0P09jPX207moO`03
00WZ2P1oOgl0Ogmo00H0Ogmo0`09jPX>07moO`030000001oOgl0Ogmo00H02NX:00<0000000WZ2P09
jPX00`1oOgl00`000000Ogmo07moO`0607moO`0300000009jPX02NX:00D02NX:1@1oOgl00`09jPX0
Ogmo00WZ2P0807moO`<02NX:00D0Ogmo00WZ2P1oOgl0Ogmo00WZ2P0307moO`0300WZ2P1oOgl0Ogmo
00L0Ogmo00<02NX:07moO`1oOgl04@1oOgl00`09jPX0Ogmo00WZ2P0300WZ2P80Ogmo00<02NX:07mo
O`1oOgl00P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00@0Ogmo0P09jPX307moO`0300WZ2P1oOgl0
Ogmo0080Ogmo0P09jPX?07moO`030000001oOgl0Ogmo00h0Ogmo00<02NX:07moO`1oOgl0<P1oOgl0
0`000000oooo0?ooo`040?ooo`802NX:5`3oool00`09jPX000000?ooo`0=0?ooo`00P03oool20000
01d0oooo0P00000807moO`<02NX:201oOgl00`09jPX0Ogmo07moO`0;07moO`802NX:301oOgl00`09
jPX0Ogmo07moO`0E07moO`0300WZ2P1oOgl0000000@0Ogmo00<02NX:07moO`1oOgl02`1oOgl01009
jPX0Ogmo07moO`09jPXE07moO`802NX:3`1oOgl200WZ2Q00Ogmo0P09jPX507moO`0300WZ2P1oOgl0
Ogmo00@0Ogmo0P09jPXA07moO`80000000H0Ogmo00WZ2P09jPX0Ogmo00WZ2P1oOgl400WZ2P80Ogmo
00<0000007moO`1oOgl0101oOgl2000000P0Ogmo2009jPX607moO`802NX:101oOgl00`09jPX0Ogmo
00WZ2P0407moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl03P1oOgl400WZ2P030000
001oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl00`1oOgl01009jPX0Ogmo00WZ2P09jPX407moO`05
00WZ2P1oOgl02NX:07moO`09jPX01@1oOgl200WZ2Pl0Ogmo00<0000007moO`1oOgl03P1oOgl00`09
jPX0Ogmo07moO`0c07moO`8000001P3oool200WZ2QD0oooo0P00000>0?ooo`00P03oool2000001/0
oooo0P00000807moO`802NX:2P1oOgl00`09jPX0Ogmo07moO`0<07moO`802NX:301oOgl00`09jPX0
Ogmo07moO`0E07moO`0300WZ2P1oOgl0000000<0Ogmo00<0000000WZ2P1oOgl0301oOgl01009jPX0
Ogmo07moO`09jPXG07moO`<02NX:3P1oOgl200WZ2P`0Ogmo0P09jPX707moO`0300WZ2P1oOgl0Ogmo
00<0Ogmo0P09jPXD07moO`040000001oOgl0Ogmo00WZ2P<0Ogmo00<0000007moO`1oOgl01@09jPX3
07moO`030000001oOgl0Ogmo00`0Ogmo00@02NX:07moO`1oOgl0Ogmo1`09jPX507moO`0300WZ2P1o
Ogl02NX:00@0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0:07moO`H02NX:0P1o
Ogl2000000L0Ogmo00<02NX:07moO`1oOgl00P1oOgl400WZ2P040000001oOgl0Ogmo00WZ2P80Ogmo
00<02NX:07moO`09jPX01@1oOgl200WZ2Pl0Ogmo00<0000007moO`1oOgl03P1oOgl00`09jPX0Ogmo
07moO`0e07moO`8000001P3oool200WZ2Q<0oooo0P00000>0?ooo`00P03oool00`000000oooo00WZ
2P0200WZ2QL0oooo00<0000007moO`1oOgl01@1oOgl300WZ2P`0Ogmo00<02NX:07moO`1oOgl0301o
Ogl200WZ2P`0Ogmo00<02NX:07moO`1oOgl05P1oOgl00`09jPX0000007moO`0207moO`0300WZ2P1o
Ogl0Ogmo00`0Ogmo00@02NX:07moO`1oOgl02NX:6P1oOgl200WZ2Ph0Ogmo0P09jPX707moO`<02NX:
2@1oOgl01009jPX0Ogmo07moO`1oOgl200WZ2P0307moO`09jPX0Ogmo01@0Ogmo00@0000000WZ2P1o
Ogl02NX:0P1oOgl01@000000Ogmo07moO`1oOgl0000000802NX:00<0Ogmo00WZ2P09jPX00`09jPX<
07moO`802NX:0`1oOgl400WZ2P<0Ogmo2009jPX407moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:
07moO`1oOgl01P1oOgl600WZ2Q00Ogmo00<02NX:07moO`1oOgl00`1oOgl200WZ2P8000000P1oOgl0
1@09jPX0Ogmo07moO`1oOgl02NX:00D0Ogmo00<02NX:07moO`09jPX0401oOgl00`000000Ogmo07mo
O`0=07moO`0300WZ2P1oOgl0Ogmo03L0Ogmo00<000000?ooo`3oool01@3oool200WZ2Q80oooo00<0
00000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool00P3oool300WZ2Q80oooo0P000005
07moO`<02NX:3P1oOgl00`09jPX0Ogmo07moO`0=07moO`802NX:301oOgl00`09jPX0Ogmo07moO`0F
07moO`0300WZ2P1oOgl000000080Ogmo00<02NX:07moO`1oOgl0301oOgl01009jPX0Ogmo07moO`09
jPXL07moO`802NX:3P1oOgl200WZ2P<0Ogmo0P09jPX=07moO`<02NX:0P1oOgl00`09jPX0Ogmo07mo
O`0D07moO`0700WZ2P000000000007moO`09jPX0Ogmo0000000307moO`030000001oOgl0Ogmo0080
2NX:00@0000007moO`1oOgl0Ogmo1009jPX707moO`802NX:0`1oOgl200WZ2P/0Ogmo00<02NX:07mo
O`09jPX01`09jPX507moO`0400WZ2P1oOgl0Ogmo07moO`H02NX:5P1oOgl00`09jPX0Ogmo07moO`02
07moO`0300WZ2P1oOgl02NX:0080Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPX507moO`0300WZ2P00
00002NX:0100Ogmo00<0000007moO`1oOgl03P1oOgl00`09jPX0Ogmo07moO`0g07moO`8000001`3o
ool200WZ2Q00oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool01@3oool2
00WZ2Pl0oooo00<0000007moO`1oOgl00`1oOgl200WZ2Q00Ogmo00<02NX:07moO`1oOgl03P1oOgl0
0`09jPX0Ogmo07moO`0;07moO`0300WZ2P1oOgl0Ogmo01H0Ogmo00H02NX:07moO`000000Ogmo00WZ
2P00000?07moO`802NX:7`1oOgl200WZ2Ph0Ogmo0`09jPX>07moO`802NX:101oOgl00`09jPX0Ogmo
07moO`0C07moO`0600WZ2P1oOgl0Ogmo07moO`000000Ogmo0P09jPX00`000000Ogmo0000000307mo
O`<0000000<02NX:07moO`1oOgl0101oOgl500WZ2P80Ogmo0P09jPX00`0000002NX:00WZ2P0207mo
O`0300WZ2P1oOgl0Ogmo00P0Ogmo00<02NX:07moO`09jPX0101oOgl00`09jPX0Ogmo07moO`0:00WZ
2Q/0Ogmo00/02NX:07moO`1oOgl0Ogmo00WZ2P1oOgl02NX:07moO`09jPX0Ogmo00WZ2P0307moO`03
00WZ2P1oOgl02NX:00<0Ogmo00@02NX:07moO`0000002NX:4@1oOgl00`000000Ogmo07moO`0=07mo
O`0300WZ2P1oOgl0Ogmo03T0Ogmo00<000000?ooo`3oool01P3oool200WZ2Ph0oooo00<000000?oo
o`3oool0303oool00800oooo00<000000?ooo`3oool01`3oool300WZ2PX0oooo0P00000307moO`<0
2NX:4P1oOgl00`09jPX0Ogmo07moO`0>07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<02NX:07moO`1o
Ogl05P1oOgl01@09jPX0Ogmo00000009jPX0000000l0Ogmo0P09jPXQ07moO`802NX:2`1oOgl200WZ
2P0307moO`09jPX02NX:00/0Ogmo0P09jPX207moO`0500WZ2P1oOgl0Ogmo07moO`09jPX0501oOgl0
0`09jPX0Ogmo07moO`0307moO`80000000D0Ogmo00WZ2P1oOgl0000007moO`020000000307moO`00
00002NX:00802NX:2P1oOgl500WZ2P@0Ogmo00<02NX:07moO`1oOgl02@1oOgl200WZ2P@0Ogmo00<0
2NX:07moO`1oOgl01@09jPX207moO`P02NX:5P1oOgl02009jPX0Ogmo07moO`1oOgl02NX:07moO`09
jPX0Ogmo0`09jPX207moO`0400WZ2P1oOgl0Ogmo00WZ2P<0Ogmo00@02NX:07moO`1oOgl02NX:4@1o
Ogl00`000000Ogmo07moO`0=07moO`0300WZ2P1oOgl0Ogmo03X0Ogmo0P0000080?ooo`802NX:303o
ool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0:0?ooo`<02NX:1@3oool2
00000080Ogmo0`09jPXD07moO`0300WZ2P1oOgl0Ogmo00l0Ogmo00<02NX:07moO`1oOgl0301oOgl0
0`09jPX0Ogmo07moO`0F07moO`0400WZ2P1oOgl0000000WZ2Q00Ogmo0P09jPXS07moO`802NX:1`1o
Ogl200WZ2PD0Ogmo0P09jPX707moO`802NX:101oOgl01009jPX0Ogmo07moO`09jPXD07moO`0300WZ
2P1oOgl0Ogmo00H0Ogmo0P0000000`09jPX000000000000207moO`0400WZ2P1oOgl0Ogmo07moO`<0
2NX:1P1oOgl400WZ2P80Ogmo1P09jPX;07moO`802NX:0P1oOgl500WZ2P<0Ogmo00<02NX:07moO`1o
Ogl02@1oOgl700WZ2Q00Ogmo00<02NX:07moO`09jPX00`1oOgl300WZ2P040000001oOgl0Ogmo00WZ
2P<0Ogmo00<02NX:07moO`09jPX00`1oOgl200WZ2Q40Ogmo00<0000007moO`1oOgl0301oOgl00`09
jPX0Ogmo07moO`0l07moO`800000203oool200WZ2PX0oooo00<000000?ooo`3oool0303oool00800
oooo00<000000?ooo`3oool03@3oool200WZ2P80oooo00<0000007moO`1oOgl00P09jPXG07moO`03
00WZ2P1oOgl0Ogmo00l0Ogmo00<02NX:07moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0G07moO`80
2NX:00<0000007moO`1oOgl03P1oOgl200WZ2RD0Ogmo0P09jPX307moO`802NX:2@1oOgl200WZ2P<0
Ogmo0P09jPX707moO`0300WZ2P1oOgl02NX:01<0Ogmo00<02NX:07moO`1oOgl0201oOgl200000004
00WZ2P1oOgl0Ogmo00WZ2PL0Ogmo0P09jPX307moO`@02NX:201oOgl500WZ2PH0Ogmo1@09jPX207mo
O`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl04@1oOgl700WZ2PT0Ogmo00<02NX:07mo
O`09jPX00`1oOgl400WZ2P0307moO`09jPX0Ogmo00<0Ogmo00<02NX:07moO`09jPX00`1oOgl200WZ
2Q40Ogmo00<0000007moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0n07moO`030000003oool0oooo
00L0oooo0P09jPX80?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo00l0
oooo1@09jPXH0000000300WZ2P00000000000100000000<02NX:000000000000300000000`09jPX0
00000000000G000000802NX:4@00000200WZ2RL000000`09jPX=000000<02NX:2@00000200WZ2Q<0
000000<02NX:0000000000003000000200WZ2PX000001009jPX00`0000002NX:0000000900000004
00WZ2P0000000000000000H02NX:00<0000000WZ2P000000100000001@09jPX00000000000000000
2NX:01/000002009jPX20000000300WZ2P000000000000<0000000@02NX:0000000000002NX:1P00
00000`09jPX0000000000002000000802NX:4`00000=07moO`0300WZ2P1oOgl0Ogmo03h0Ogmo0P00
000:0?ooo`802NX:1P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0>
0?ooo`<02NX:00@0oooo00WZ2P09jPX02NX:5`1oOgl00`09jPX0Ogmo07moO`0@07moO`0300WZ2P1o
Ogl0Ogmo00`0Ogmo00<02NX:07moO`1oOgl05`1oOgl200WZ2P030000001oOgl0Ogmo00h0Ogmo0P09
jPXV07moO`802NX:00@0Ogmo00WZ2P09jPX02NX:2P1oOgl200WZ2P0307moO`09jPX02NX:00T0Ogmo
00<02NX:07moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0907moO`030000001oOgl0000000802NX:
00<0Ogmo00WZ2P1oOgl01`1oOgl200WZ2P0407moO`09jPX02NX:00WZ2P/0Ogmo1P09jPX207moO`D0
2NX:101oOgl01@09jPX0Ogmo07moO`1oOgl02NX:02<0Ogmo1`09jPX01@1oOgl02NX:00WZ2P1oOgl0
2NX:00H0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2Q80Ogmo00<0000007moO`1oOgl02`1oOgl0
0`09jPX0Ogmo07moO`0m07moO`030000003oool0oooo00`0oooo0P09jPX40?ooo`030000003oool0
oooo00`0oooo00200?ooo`030000003oool0oooo00`0oooo0P09jPX50?ooo`8000000P09jPXD07mo
O`0300WZ2P1oOgl0Ogmo0140Ogmo00<02NX:07moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0G07mo
O`802NX:00<0000007moO`1oOgl03P1oOgl200WZ2R@0Ogmo0P09jPX607moO`802NX:1P1oOgl200WZ
2PD0Ogmo0P09jPX607moO`802NX:4@1oOgl00`09jPX0Ogmo07moO`0907moO`040000001oOgl0Ogmo
00WZ2P80Ogmo00<0000007moO`09jPX01@1oOgl200WZ2PD0Ogmo0`09jPX407moO`L02NX:2@1oOgl0
0`09jPX0Ogmo00WZ2P0400WZ2P80Ogmo00<02NX:07moO`1oOgl0901oOgl200WZ2P<0Ogmo2009jPX2
07moO`0300WZ2P1oOgl02NX:00@0Ogmo00<02NX:07moO`1oOgl03`1oOgl00`000000Ogmo07moO`0<
07moO`0300WZ2P1oOgl0Ogmo03/0Ogmo0P00000A0?ooo`802NX:0P3oool00`000000oooo0?ooo`0<
0?ooo`00P03oool00`000000oooo0?ooo`090?ooo`<02NX:2@3oool2000000<02NX:401oOgl00`09
jPX0Ogmo07moO`0B07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<02NX:07moO`1oOgl05P1oOgl01009
jPX0Ogmo00000009jPX@07moO`802NX:8P1oOgl200WZ2PX0Ogmo0P09jPX207moO`802NX:2@1oOgl2
00WZ2P@0Ogmo00<02NX:07moO`09jPX03P1oOgl200WZ2PX0Ogmo0P00000207moO`0300WZ2P1oOgl0
00000080Ogmo1000000300WZ2PH0Ogmo00<02NX:07moO`09jPX01P09jPX507moO`0300WZ2P1oOgl0
Ogmo00L0Ogmo00<02NX:07moO`1oOgl00`1oOgl500WZ2R@0Ogmo00<02NX:07moO`09jPX00`1oOgl3
00WZ2P050000001oOgl0Ogmo00WZ2P1oOgl01`09jPX207moO`802NX:401oOgl00`000000Ogmo07mo
O`0<07moO`0300WZ2P1oOgl0Ogmo03T0Ogmo0P00000E0?ooo`0300WZ2P000000000000h0oooo0020
0?ooo`030000003oool0oooo00H0oooo0`09jPX>0?ooo`030000001oOgl0Ogmo00<02NX:3@1oOgl0
0`09jPX0Ogmo07moO`0B07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<02NX:07moO`1oOgl05P1oOgl0
1@09jPX0Ogmo00000009jPX0000000l0Ogmo0P09jPXO07moO`<02NX:3P1oOgl200WZ2Pd0Ogmo0P09
jPX01@1oOgl02NX:07moO`1oOgl02NX:00d0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0200WZ2P030000001oOgl0000000@0Ogmo00<0000000WZ2P09jPX01P1oOgl;00WZ2PD0Ogmo
00<02NX:07moO`1oOgl01`1oOgl200WZ2P@0Ogmo00<02NX:07moO`09jPX00P1oOgl500WZ2Ql0Ogmo
00L02NX:07moO`1oOgl02NX:07moO`09jPX0Ogmo00<02NX:0P1oOgl01009jPX0Ogmo07moO`09jPX2
07moO`0300WZ2P1oOgl0Ogmo00L02NX:0`1oOgl2000000L0Ogmo00<0000007moO`1oOgl03@1oOgl0
0`09jPX0Ogmo07moO`0h07moO`030000003oool0oooo01H0oooo0P00000>0?ooo`00P03oool00`00
0000oooo0?ooo`040?ooo`802NX:4P3oool2000000<0Ogmo0P09jPX:07moO`0300WZ2P1oOgl0Ogmo
01<0Ogmo00<02NX:07moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0F07moO`0500WZ2P000000Ogmo
00WZ2P0000003`1oOgl200WZ2Qd0Ogmo0P09jPX?07moO`802NX:0P1oOgl200WZ2Pd0Ogmo0P09jPX3
07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl0201oOgl200000080Ogmo00H02NX:
07moO`1oOgl0000007moO`00000407moO`802NX:00<0000007moO`09jPX01P09jPX607moO`0300WZ
2P000000Ogmo00802NX:0`1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl02NX:00@0Ogmo
0P09jPX807moO`D02NX:6@1oOgl01P09jPX0Ogmo07moO`1oOgl02NX:07moO`<02NX:00<0Ogmo00WZ
2P1oOgl00P1oOgl00`09jPX0Ogmo00WZ2P0307moO`0400WZ2P1oOgl0Ogmo07moO`802NX:0`1oOgl4
00WZ2P030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0f
07moO`8000006P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool010000000oooo0?ooo`3oool3
00WZ2QH0oooo00<0000007moO`1oOgl00P1oOgl300WZ2PL0Ogmo00<02NX:07moO`1oOgl04`1oOgl0
0`09jPX0Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo01D0Ogmo00<02NX:07moO`0000000P1oOgl0
0`09jPX0Ogmo07moO`0<07moO`0400WZ2P1oOgl0Ogmo00WZ2QX0Ogmo0P09jPX?07moO`802NX:1P1o
Ogl200WZ2P/0Ogmo00H02NX:07moO`09jPX02NX:07moO`09jPX:07moO`0300WZ2P1oOgl0Ogmo00P0
Ogmo00D0000007moO`1oOgl0Ogmo00WZ2P0207moO`060000001oOgl0Ogmo07moO`000000Ogmo2009
jPX307moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2P80Ogmo00<0
2NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo00WZ2P0407moO`802NX:3@1oOgl400WZ2QD0Ogmo00<0
2NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo00WZ2P0207moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0
2NX:07moO`1oOgl00P1oOgl01009jPX0Ogmo07moO`1oOgl600WZ2PX0Ogmo00<0000007moO`1oOgl0
3P1oOgl00`09jPX0Ogmo07moO`0e07moO`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
303oool00800oooo0P00000200WZ2QX0oooo0P00000507moO`<02NX:0`1oOgl00`09jPX0Ogmo07mo
O`0D07moO`802NX:3@1oOgl00`09jPX0Ogmo07moO`0E07moO`0300WZ2P000000Ogmo0080Ogmo00<0
2NX:07moO`1oOgl0301oOgl01009jPX0Ogmo07moO`09jPXH07moO`802NX:3`1oOgl200WZ2PX0Ogmo
0P09jPX907moO`0400WZ2P1oOgl0Ogmo07moO`<02NX:201oOgl00`09jPX0Ogmo07moO`0807moO`05
0000001oOgl0Ogmo07moO`09jPX00`1oOgl00`000000Ogmo00WZ2P0600WZ2P<0Ogmo00D0000007mo
O`1oOgl0Ogmo00WZ2P0807moO`0300WZ2P1oOgl0Ogmo00@0Ogmo0`09jPX707moO`0300WZ2P1oOgl0
2NX:00@0Ogmo00<02NX:07moO`1oOgl0401oOgl500WZ2Pl0Ogmo00<02NX:07moO`1oOgl00`1oOgl3
00WZ2P040000001oOgl0Ogmo00WZ2P<0Ogmo00<02NX:07moO`1oOgl00`1oOgl01P09jPX0Ogmo07mo
O`09jPX0000000WZ2Pd0Ogmo00<0000007moO`1oOgl03P1oOgl00`09jPX0Ogmo07moO`0c07moO`80
00007@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool2000001h0oooo0P00000607moO`802NX:
00<0Ogmo00WZ2P1oOgl05@1oOgl200WZ2Pd0Ogmo00<02NX:07moO`1oOgl0501oOgl00`09jPX0Ogmo
0000000307moO`0300000009jPX0Ogmo00`0Ogmo00@02NX:07moO`1oOgl02NX:5P1oOgl200WZ2Pl0
Ogmo0P09jPX>07moO`802NX:1P1oOgl00`09jPX0Ogmo07moO`0407moO`802NX:1P1oOgl00`09jPX0
Ogmo07moO`0707moO`8000000P1oOgl200WZ2P0307moO`09jPX02NX:00D02NX:00<0000007moO`1o
Ogl01P1oOgl20000000307moO`09jPX0Ogmo00P0Ogmo00<02NX:07moO`1oOgl01@1oOgl300WZ2PD0
Ogmo00<02NX:07moO`09jPX00`1oOgl200WZ2QL0Ogmo1@09jPX:07moO`0300WZ2P1oOgl0Ogmo0080
Ogmo1009jPX010000000Ogmo07moO`09jPX207moO`0300WZ2P1oOgl02NX:00@0Ogmo00<02NX:07mo
O`1oOgl00P0000000`09jPX0Ogmo07moO`0;07moO`030000001oOgl0Ogmo00h0Ogmo00<02NX:07mo
O`1oOgl0<@1oOgl2000001h0oooo0P00000>0?ooo`00P03oool00`000000oooo0?ooo`0O0?ooo`03
0000001oOgl0Ogmo00D0Ogmo0`09jPXE07moO`802NX:3@1oOgl00`09jPX0Ogmo07moO`0D07moO`03
00WZ2P1oOgl0000000@0Ogmo00<02NX:07moO`1oOgl02`1oOgl01009jPX0Ogmo07moO`09jPXD07mo
O`802NX:3`1oOgl200WZ2Q80Ogmo0P09jPX407moO`0300WZ2P1oOgl0Ogmo00D0Ogmo0P09jPX407mo
O`0300WZ2P1oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl02009jPX00`1oOgl02NX:07moO`0207mo
O`030000001oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0607mo
O`0400WZ2P1oOgl02NX:00WZ2P<0Ogmo00<02NX:07moO`09jPX00`1oOgl200WZ2Q`0Ogmo1009jPX5
07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00@02NX:07moO`09jPX02NX:101oOgl01@09jPX0Ogmo00WZ
2P1oOgl02NX:00D0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0<07moO`030000001oOgl0Ogmo0100
Ogmo00<02NX:07moO`1oOgl0;`1oOgl00`000000oooo0?ooo`0N0?ooo`8000003P3oool00800oooo
00<000000?ooo`3oool0803oool2000000@0Ogmo00@02NX:07moO`1oOgl0Ogmo0`09jPXB07moO`80
2NX:3@1oOgl00`09jPX0Ogmo07moO`0C07moO`0300WZ2P1oOgl0000000D0Ogmo00<0000000WZ2P1o
Ogl02`1oOgl01009jPX0Ogmo07moO`09jPXB07moO`802NX:3`1oOgl200WZ2QH0Ogmo1009jPX807mo
O`0600WZ2P1oOgl02NX:00WZ2P1oOgl02NX:1@1oOgl20000000307moO`09jPX02NX:00H02NX:101o
Ogl200WZ2P@0Ogmo00<0000007moO`1oOgl01P1oOgl00`09jPX0Ogmo0000000907moO`0300WZ2P1o
Ogl0Ogmo00H0Ogmo00@02NX:07moO`1oOgl0Ogmo1009jPX01`1oOgl02NX:07moO`1oOgl02NX:07mo
O`09jPX0801oOgl600WZ2P@0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0407moO`0300WZ2P1oOgl0
2NX:0080Ogmo00<02NX:07moO`1oOgl00P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00`0Ogmo00<0
000007moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0]07moO`800000803oool00`09jPX0oooo0000
000>0?ooo`00P03oool00`000000oooo0?ooo`0R0?ooo`050000001oOgl0Ogmo07moO`09jPX01P1o
Ogl200WZ2Q00Ogmo0P09jPX=07moO`0300WZ2P1oOgl0Ogmo01<0Ogmo00<02NX:07moO`0000001@1o
Ogl00`0000002NX:07moO`0:07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl03@1o
Ogl200WZ2Pl0Ogmo0P09jPXK07moO`802NX:201oOgl00`09jPX0Ogmo07moO`0200WZ2PD0Ogmo2009
jPX507moO`802NX:00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0607moO`0300WZ2P1o
Ogl0Ogmo00800000201oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00@0Ogmo0P09
jPX00`1oOgl02NX:00WZ2P0207moO`0300WZ2P1oOgl0Ogmo0180Ogmo0P00000>07moO`L02NX:0P1o
Ogl200WZ2PD0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0207moO`0500WZ2P1o
Ogl0Ogmo07moO`09jPX02P1oOgl00`000000Ogmo07moO`0A07moO`0300WZ2P1oOgl0Ogmo02`0Ogmo
00<000000?ooo`3oool07`3oool01009jPX0oooo0?ooo`00000>0?ooo`00P03oool00`000000oooo
0?ooo`0S0?ooo`80000000<02NX:07moO`1oOgl01`1oOgl300WZ2Pd0Ogmo0P09jPX=07moO`0300WZ
2P1oOgl0Ogmo0180Ogmo00<02NX:07moO`0000001P1oOgl00`000000Ogmo00WZ2P0:07moO`0300WZ
2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl02`1oOgl200WZ2Q00Ogmo00<02NX:07moO`1oOgl0
6P1oOgl00`09jPX0Ogmo07moO`0200WZ2PH0Ogmo00<02NX:07moO`09jPX00P1oOgl600WZ2P050000
001oOgl0Ogmo07moO`09jPX01@1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo00<0000007moO`1o
Ogl0101oOgl00`09jPX0Ogmo07moO`0307moO`030000001oOgl0Ogmo00D0Ogmo00<02NX:07moO`1o
Ogl01P1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00802NX:00@0000007moO`1o
Ogl02NX:3`1oOgl500WZ2P0300000009jPX0Ogmo00d0Ogmo00@02NX:07moO`1oOgl0Ogmo1`09jPX5
07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl00P1oOgl01@09jPX0Ogmo07moO`1o
Ogl02NX:00X0Ogmo00<0000007moO`1oOgl04@1oOgl00`09jPX0Ogmo07moO`0Z07moO`8000008@3o
ool01@09jPX0oooo0?ooo`3oool0000000h0oooo00200?ooo`030000003oool0oooo02D0oooo00<0
2NX:07moO`1oOgl02P1oOgl300WZ2PX0Ogmo0P09jPX=07moO`0300WZ2P1oOgl0Ogmo0180Ogmo00<0
2NX:07moO`0000001P1oOgl00`000000Ogmo00WZ2P0:07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0
2NX:07moO`1oOgl02@1oOgl200WZ2Q00Ogmo0P09jPXM07moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P09
jPX507moO`P02NX:00<0Ogmo00WZ2P1oOgl00P1oOgl00`09jPX0Ogmo07moO`0207moO`802NX:0`1o
Ogl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl01@1o
Ogl00`000000Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl00P1o
Ogl01009jPX0Ogmo07moO`1oOgl500WZ2P@0Ogmo2`09jPX607moO`0300WZ2P1oOgl0Ogmo00/0Ogmo
00L02NX:07moO`1oOgl0Ogmo00WZ2P1oOgl02NX:00<0Ogmo1`09jPX00`1oOgl02NX:07moO`0307mo
O`0300WZ2P1oOgl0Ogmo0080Ogmo00@02NX:07moO`1oOgl02NX:2@1oOgl00`000000Ogmo07moO`0B
07moO`0300WZ2P1oOgl0Ogmo02T0Ogmo00<000000?ooo`3oool0803oool00`09jPX0oooo0?ooo`02
0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo02@0oooo00@02NX:0?oo
o`00000000003@1oOgl300WZ2PL0Ogmo0P09jPX=07moO`0300WZ2P1oOgl0Ogmo0180Ogmo00<02NX:
07moO`0000001`1oOgl00`0000002NX:07moO`0907moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:
07moO`1oOgl01P1oOgl300WZ2Q00Ogmo0P09jPXN07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo1P09jPX6
07moO`0600000009jPX0000000WZ2P1oOgl02NX:101oOgl00`09jPX0Ogmo07moO`0307moO`030000
001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0607moO`800000
101oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`09jPX0
2P09jPXA07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00@02NX:07moO`1oOgl02NX:0P1oOgl01`09jPX0
Ogmo07moO`1oOgl02NX:07moO`09jPX00`1oOgl500WZ2P80Ogmo00<0000000WZ2P09jPX00P1oOgl0
1009jPX0Ogmo07moO`09jPX907moO`030000001oOgl0Ogmo0180Ogmo00<02NX:07moO`1oOgl09`1o
Ogl200000280oooo00<02NX:0?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool0
0`000000oooo0?ooo`0T0?ooo`0400WZ2P3oool0oooo0?ooo`8000003P1oOgl200WZ2PD0Ogmo0P09
jPX=07moO`0300WZ2P1oOgl0Ogmo0140Ogmo00<02NX:07moO`000000201oOgl00`000000Ogmo00WZ
2P0907moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl0101oOgl200WZ2Q40Ogmo0P09
jPXP07moO`0400WZ2P1oOgl0Ogmo07moO`D02NX:00<0Ogmo00WZ2P09jPX00P1oOgl00`09jPX0Ogmo
07moO`0207moO`0400000009jPX02NX:000000802NX:0`1oOgl200WZ2PD0Ogmo00<0000007moO`1o
Ogl01`1oOgl01@000000Ogmo07moO`1oOgl02NX:00/0Ogmo00<0000007moO`1oOgl00P1oOgl01009
jPX0Ogmo07moO`1oOgl;00WZ2P0307moO`09jPX02NX:00<0Ogmo00@02NX:07moO`09jPX02NX:4`1o
Ogl00`09jPX0Ogmo07moO`0:07moO`0300WZ2P1oOgl02NX:0080Ogmo00<02NX:07moO`1oOgl00P1o
Ogl01P09jPX0Ogmo07moO`09jPX0Ogmo00WZ2P<0Ogmo00@02NX:07moO`09jPX02NX:0P000000101o
Ogl02NX:07moO`09jPX207moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl04P1oOgl0
0`0000002NX:07moO`0V07moO`8000008`3oool00`09jPX0oooo0?ooo`040?ooo`030000003oool0
oooo00`0oooo00200?ooo`030000003oool0oooo02<0oooo00<02NX:0?ooo`3oool0103oool00`00
0000Ogmo07moO`0=07moO`<02NX:0P1oOgl200WZ2Pd0Ogmo00<02NX:07moO`1oOgl04@1oOgl00`09
jPX0Ogmo0000000807moO`030000001oOgl02NX:00P0Ogmo00<02NX:07moO`1oOgl0101oOgl01009
jPX0Ogmo07moO`1oOgl200WZ2Q40Ogmo0P09jPXQ07moO`D02NX:1P1oOgl00`09jPX0Ogmo00WZ2P07
00WZ2P80Ogmo00<02NX:07moO`1oOgl00`09jPX707moO`030000001oOgl0Ogmo00L0Ogmo00@00000
07moO`1oOgl02NX:2P1oOgl;00WZ2PD0Ogmo00T02NX:07moO`1oOgl0Ogmo00WZ2P1oOgl02NX:07mo
O`09jPX00`1oOgl01009jPX0Ogmo07moO`1oOgl300WZ2Q00Ogmo00<02NX:07moO`1oOgl02@1oOgl0
0`09jPX0Ogmo00WZ2P0307moO`0500WZ2P1oOgl0Ogmo07moO`09jPX00`1oOgl00`09jPX0Ogmo00WZ
2P0307moO`0300WZ2P1oOgl0Ogmo00<0Ogmo1@09jPX207moO`8000001P1oOgl00`000000Ogmo07mo
O`0B07moO`8000009P1oOgl00`000000oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo00D0oooo00<0
00000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool08P3oool00`09jPX0oooo0?ooo`06
0?ooo`800000401oOgl400WZ2Pd0Ogmo00<02NX:07moO`1oOgl0401oOgl00`09jPX0Ogmo00000009
07moO`040000001oOgl0Ogmo00WZ2PL0Ogmo00<02NX:07moO`1oOgl0101oOgl01009jPX0Ogmo00WZ
2P09jPXA07moO`802NX:7`1oOgl500WZ2PT0Ogmo1`09jPX00`000000Ogmo07moO`0207moO`0300WZ
2P1oOgl0Ogmo00802NX:00@0Ogmo00WZ2P09jPX000001@1oOgl00`000000Ogmo07moO`0707moO`03
0000001oOgl02NX:00/02NX:1@1oOgl00`000000Ogmo00WZ2P0807moO`0900WZ2P1oOgl0Ogmo07mo
O`09jPX0Ogmo00WZ2P1oOgl02NX:00<0Ogmo00<02NX:07moO`1oOgl0101oOgl200WZ2Ph0Ogmo00<0
2NX:07moO`1oOgl02@1oOgl200WZ2P<0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07mo
O`0207moO`0300WZ2P000000Ogmo00<0Ogmo00<02NX:07moO`1oOgl01@1oOgl500WZ2P0300000009
jPX0Ogmo00<0Ogmo00<0000007moO`1oOgl0501oOgl00`09jPX0Ogmo07moO`0R07moO`800000903o
ool00`09jPX0oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0
oooo0280oooo00<02NX:0?ooo`3oool0203oool00`000000Ogmo07moO`0?07moO`<02NX:301oOgl0
0`09jPX0Ogmo07moO`0@07moO`0300WZ2P1oOgl0000000T0Ogmo00@0000007moO`1oOgl02NX:1`1o
Ogl00`09jPX0Ogmo07moO`0407moO`802NX:4@1oOgl200WZ2Q`0Ogmo1@09jPX307moO`0300WZ2P1o
Ogl0Ogmo00@0Ogmo1@09jPX507moO`H02NX:00<0Ogmo00WZ2P09jPX0101oOgl00`0000002NX:00WZ
2P0307moO`030000001oOgl0Ogmo00/02NX:4@1oOgl00`000000Ogmo00WZ2P0807moO`0300WZ2P1o
Ogl0Ogmo00802NX:0P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00P0Ogmo0P09jPX=07moO`0300WZ
2P1oOgl0Ogmo00L0Ogmo0P09jPX407moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl0
0P1oOgl00`09jPX0000007moO`0307moO`0300WZ2P1oOgl0Ogmo00H0Ogmo0P09jPX407moO`<02NX:
00<0Ogmo0000001oOgl0501oOgl00`09jPX0Ogmo07moO`0R07moO`030000003oool0oooo02<0oooo
00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?oo
o`0Q0?ooo`0300WZ2P3oool0oooo00X0oooo0P00000?07moO`802NX:00@0Ogmo00WZ2P09jPX02NX:
2@1oOgl00`09jPX0Ogmo07moO`0?07moO`0400WZ2P1oOgl0Ogmo000000X0Ogmo00@0000007moO`1o
Ogl02NX:1P1oOgl00`09jPX0Ogmo07moO`0207moO`<02NX:401oOgl200WZ2QT0Ogmo1@09jPX807mo
O`0300WZ2P1oOgl02NX:00@02NX:0P1oOgl00`09jPX0Ogmo07moO`0307moO`80000000<02NX:07mo
O`1oOgl01009jPX407moO`/02NX:2@1oOgl00`09jPX0Ogmo07moO`0A07moO`0300000009jPX0Ogmo
00L0Ogmo00@02NX:07moO`09jPX02NX:0`1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00X0Ogmo0`09
jPX:07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07mo
O`0307moO`0500WZ2P1oOgl0Ogmo07moO`09jPX01`1oOgl00`09jPX0Ogmo07moO`0507moO`H02NX:
0P0000000`1oOgl02NX:00WZ2P0E07moO`0300WZ2P1oOgl0Ogmo0200Ogmo0P00000U0?ooo`0300WZ
2P3oool0oooo00P0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool08@3o
ool00`09jPX0oooo0?ooo`0<0?ooo`8000003@1oOgl200WZ2P@0Ogmo0`09jPX607moO`0300WZ2P1o
Ogl0Ogmo00l0Ogmo00<02NX:07moO`0000002`1oOgl010000000Ogmo07moO`09jPX607moO`0300WZ
2P1oOgl0Ogmo00802NX:0P1oOgl00`09jPX0Ogmo07moO`0;07moO`80000000<02NX:07moO`1oOgl0
501oOgl500WZ2PX0Ogmo1@09jPX507moO`802NX:1@1oOgl00`000000Ogmo00WZ2P0;00WZ2PL0Ogmo
0P09jPX:07moO`0300WZ2P000000Ogmo01<0Ogmo00<02NX:0000001oOgl01P1oOgl01009jPX0Ogmo
00WZ2P00000307moO`0500WZ2P1oOgl0Ogmo07moO`09jPX03@1oOgl200WZ2PP0Ogmo00<02NX:07mo
O`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00@02NX:07mo
O`1oOgl02NX:201oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0000000802NX:1@1oOgl0
0`000000Ogmo00WZ2P0200WZ2Q80Ogmo00<02NX:07moO`1oOgl07P1oOgl2000002H0oooo00<02NX:
0?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0P0?oo
o`0300WZ2P3oool0oooo00l0oooo00<0000007moO`1oOgl02`1oOgl00`09jPX0Ogmo07moO`0507mo
O`802NX:101oOgl00`09jPX0Ogmo07moO`0?07moO`0300WZ2P1oOgl0000000/0Ogmo00@0000007mo
O`1oOgl02NX:1@1oOgl01009jPX0Ogmo00WZ2P09jPX507moO`0300WZ2P1oOgl0Ogmo00X0Ogmo0P00
000C07moO`@02NX:2P1oOgl500WZ2P80Ogmo00<02NX:07moO`1oOgl00`1oOgl;00WZ2P80Ogmo0`09
jPX407moO`802NX:201oOgl010000000Ogmo00WZ2P09jPX807moO`0300WZ2P1oOgl0000001<0Ogmo
00<02NX:07moO`0000001`1oOgl200WZ2P050000001oOgl0Ogmo07moO`09jPX00`1oOgl00`09jPX0
Ogmo07moO`0=07moO`802NX:1P1oOgl00`09jPX0Ogmo07moO`0507moO`802NX:101oOgl00`09jPX0
Ogmo07moO`0307moO`0500WZ2P1oOgl0Ogmo07moO`09jPX02@1oOgl00`09jPX0Ogmo07moO`0207mo
O`0300WZ2P1oOgl0Ogmo00<0Ogmo00D02NX:07moO`1oOgl0Ogmo0000000507moO`802NX:401oOgl0
0`09jPX0Ogmo07moO`0M07moO`030000003oool0oooo02D0oooo00<02NX:0?ooo`3oool02P3oool0
0`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo
0100oooo0P00000;07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo0`09jPX00`1oOgl02NX:07moO`0?07mo
O`0300WZ2P1oOgl0000000`0Ogmo00D0000007moO`1oOgl0Ogmo00WZ2P0407moO`802NX:1`1oOgl0
0`09jPX0Ogmo07moO`0J07moO`D02NX:2@1oOgl500WZ2P80Ogmo3009jPX507moO`8000000`1oOgl4
00WZ2PL0Ogmo0P09jPX607moO`040000001oOgl0Ogmo07moO`802NX:1@1oOgl01009jPX0Ogmo07mo
O`00000D07moO`0400WZ2P1oOgl00000000000@0Ogmo0`09jPX407moO`0500WZ2P1oOgl0Ogmo07mo
O`09jPX04@1oOgl300WZ2P@0Ogmo00<02NX:07moO`1oOgl00`1oOgl200WZ2PD0Ogmo00<02NX:07mo
O`1oOgl00`1oOgl01009jPX0Ogmo07moO`09jPX:07moO`0500WZ2P1oOgl0Ogmo07moO`09jPX01P1o
Ogl200WZ2P030000001oOgl0000000L0Ogmo0P09jPX>07moO`0300WZ2P1oOgl0Ogmo01/0Ogmo0P00
000W0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool0303oool00800oooo00<00000
0?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0C0?ooo`030000001oOgl0Ogmo00P0Ogmo00<02NX:
07moO`1oOgl02P1oOgl300WZ2Pl0Ogmo00<02NX:07moO`000000301oOgl01@000000Ogmo07moO`1o
Ogl02NX:0080Ogmo0`09jPX807moO`0300WZ2P1oOgl0Ogmo01D0Ogmo1@09jPX807moO`d02NX:101o
Ogl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1o
Ogl200WZ2P80Ogmo00<02NX:07moO`1oOgl01`1oOgl200WZ2P@0Ogmo00<0000007moO`1oOgl00P1o
Ogl200WZ2P<0Ogmo00D02NX:07moO`1oOgl0Ogmo0000000D07moO`0500WZ2P1oOgl0Ogmo07moO`00
00000P1oOgl01009jPX0Ogmo00WZ2P09jPX407moO`0500WZ2P1oOgl0Ogmo07moO`09jPX0501oOgl2
00WZ2P80Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo00WZ2P0407moO`0300WZ2P1oOgl0
Ogmo00@0Ogmo00<02NX:07moO`09jPX02`1oOgl01009jPX0Ogmo00WZ2P09jPX507moO`802NX:00D0
Ogmo000000000000Ogmo0000000907moO`802NX:2`1oOgl00`09jPX0Ogmo07moO`0K07moO`030000
003oool0oooo02H0oooo00<02NX:0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`00P03o
ool00`000000oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo01D0oooo0P00000807moO`0300WZ2P1o
Ogl0Ogmo00T0Ogmo0`09jPX00`0000002NX:00WZ2P0<07moO`0400WZ2P1oOgl0Ogmo000000d0Ogmo
00<0000007moO`1oOgl00`09jPX207moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl0
401oOgl500WZ2P@0Ogmo2`09jPX?07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0
201oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo0P09jPX00`1oOgl02NX:07moO`0307moO`030000
001oOgl0Ogmo0140Ogmo00<02NX:07moO`1oOgl00P1oOgl00`0000002NX:07moO`0200WZ2PD0Ogmo
00D02NX:07moO`1oOgl0Ogmo00WZ2P0F07moO`<02NX:0`1oOgl00`09jPX0Ogmo00WZ2P0507moO`03
00WZ2P1oOgl0Ogmo00@0Ogmo0P09jPX=07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P09jPX507moO`03
0000001oOgl0Ogmo00X0Ogmo0`09jPX807moO`0300WZ2P1oOgl0Ogmo01T0Ogmo0P00000X0?ooo`03
00WZ2P3oool0oooo00d0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0
7P3oool00`09jPX0oooo0?ooo`0G0?ooo`8000001P1oOgl200WZ2PH0Ogmo1009jPX207moO`800000
0P1oOgl300WZ2PT0Ogmo00<02NX:07moO`0000003P1oOgl01@0000002NX:00WZ2P1oOgl02NX:00<0
Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0<07moOa402NX:5@1oOgl00`09jPX0
Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P00000307moO`802NX:1P1oOgl00`09jPX0
Ogmo07moO`0:07moO`802NX:2@1oOgl200WZ2P@0Ogmo00<0000007moO`1oOgl04P1oOgl02@09jPX0
Ogmo07moO`1oOgl02NX:00000009jPX0Ogmo00WZ2P0507moO`0500WZ2P1oOgl0Ogmo07moO`09jPX0
601oOgl400WZ2P80Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0507moO`802NX:
301oOgl200WZ2P<0Ogmo0P09jPX707moO`030000001oOgl0Ogmo00d0Ogmo0P09jPX607moO`0300WZ
2P1oOgl0Ogmo01L0Ogmo0P00000Y0?ooo`0300WZ2P3oool0oooo00h0oooo00<000000?ooo`3oool0
303oool00800oooo00<000000?ooo`3oool07@3oool00`09jPX0oooo0?ooo`0J0?ooo`030000001o
Ogl0Ogmo00<0Ogmo0P09jPX00`1oOgl02NX:00WZ2P0300WZ2PL0Ogmo00<02NX:07moO`1oOgl00`1o
Ogl300WZ2PD0Ogmo00@02NX:07moO`1oOgl000003@1oOgl200WZ2P@0Ogmo00<02NX:07moO`09jPX0
2P1oOgl00`09jPX0Ogmo07moO`0207moO`/02NX:1@1oOgl500WZ2QX0Ogmo00D02NX:07moO`1oOgl0
Ogmo00WZ2P0407moO`040000001oOgl0Ogmo07moO`<02NX:201oOgl00`09jPX0Ogmo07moO`0:07mo
O`0400000009jPX02NX:00WZ2PD0Ogmo00<02NX:07moO`0000000P09jPX207moO`030000001oOgl0
Ogmo0180Ogmo00T02NX:07moO`09jPX02NX:07moO`09jPX0Ogmo00000009jPX01@1oOgl01@09jPX0
Ogmo07moO`1oOgl02NX:01T0Ogmo1@09jPX507moO`0300WZ2P1oOgl0Ogmo00@0Ogmo0P09jPX<07mo
O`0300WZ2P1oOgl0Ogmo00<02NX:201oOgl00`000000Ogmo07moO`0@07moO`802NX:101oOgl00`09
jPX0Ogmo07moO`0F07moO`030000003oool0oooo02P0oooo00<02NX:0?ooo`3oool03`3oool00`00
0000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0M0?ooo`0300WZ2P3oool0oooo01/0
oooo0P00000207moO`@02NX:301oOgl00`09jPX0Ogmo07moO`0607moO`802NX:0`1oOgl00`09jPX0
Ogmo0000000<07moO`802NX:00<0Ogmo0000001oOgl00`1oOgl00`09jPX0Ogmo00WZ2P0407moO`l0
2NX:1`1oOgl500WZ2Qh0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0307moO`8000000P1oOgl300WZ
2PX0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0207moO`802NX:0`1oOgl01@09
jPX0Ogmo00000009jPX0Ogmo00802NX:00<0Ogmo0000001oOgl04P1oOgl200WZ2P80Ogmo00@02NX:
07moO`1oOgl02NX:0P00000407moO`0500WZ2P1oOgl0Ogmo07moO`09jPX06@1oOgl01009jPX0Ogmo
07moO`1oOgl200WZ2P<0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0:07moO`03
00WZ2P1oOgl0Ogmo00802NX:2P1oOgl00`000000Ogmo07moO`0B07moO`802NX:0P1oOgl00`09jPX0
Ogmo07moO`0D07moO`800000:P3oool00`09jPX0oooo0?ooo`0@0?ooo`030000003oool0oooo00`0
oooo00200?ooo`8000007@3oool00`09jPX0oooo0?ooo`0L0?ooo`@02NX:00<0Ogmo00WZ2P09jPX0
0P00000;07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo0`09jPX207moO`0300000009jPX02NX:00800000
101oOgl2000000802NX:0`1oOgl00`0000002NX:00WZ2P0900WZ2P@0Ogmo00<0000000WZ2P09jPX0
0`09jPX707moO`D02NX:8`1oOgl01009jPX0Ogmo07moO`09jPX307moO`030000001oOgl0Ogmo0080
2NX:00<0Ogmo00WZ2P1oOgl02`1oOgl00`09jPX0Ogmo07moO`0807moO`030000001oOgl0Ogmo00@0
Ogmo0`09jPX307moO`0400WZ2P1oOgl0Ogmo07moO`802NX:4`1oOgl01009jPX0Ogmo07moO`09jPX3
07moO`0400WZ2P1oOgl0Ogmo00000080Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07mo
O`0F07moO`802NX:0`1oOgl00`09jPX0000000WZ2P0300WZ2PL0Ogmo00<02NX:07moO`1oOgl02@1o
Ogl01009jPX0000000WZ2P09jPX207moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl0
5@1oOgl300WZ2QD0Ogmo00<000000?ooo`3oool0:@3oool00`09jPX0oooo0?ooo`0A0?ooo`030000
003oool0oooo00`0oooo000>0?ooog802NX:0P00001400WZ2P0300000009jPX02NX:01X02NX:0P00
003>00WZ2P0300000009jPX02NX:01L02NX:00D0000007moO`1oOgl0Ogmo00WZ2P0807moO`030000
001oOgl0Ogmo01H0Ogmo00@02NX:07moO`09jPX02NX:4@1oOgl2000002/0oooo00<02NX:0?ooo`3o
ool04P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0K0?ooo`0300WZ
2P3oool0oooo01@0oooo1@09jPX90?ooo`80000000<02NX:07moO`1oOgl02`1oOgl00`09jPX0Ogmo
07moO`0907moO`0400WZ2P1oOgl0000007moO`802NX:0P1oOgl00`09jPX0Ogmo07moO`0800WZ2P03
07moO`000000Ogmo00<0Ogmo0P09jPX607moO`0400000009jPX0Ogmo07moO`H02NX:;01oOgl00`09
jPX0Ogmo00WZ2P0207moO`80000000D0Ogmo00WZ2P09jPX0Ogmo00WZ2P0@07moO`0300WZ2P1oOgl0
Ogmo00L0Ogmo00<0000007moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0300WZ2PD0Ogmo00@00000
07moO`09jPX02NX:3@1oOgl02@09jPX0Ogmo00WZ2P09jPX0000007moO`09jPX0Ogmo00WZ2P0507mo
O`0300000009jPX0Ogmo00<0Ogmo00<02NX:07moO`1oOgl00`1oOgl2000000l0Ogmo00L02NX:07mo
O`1oOgl0Ogmo00WZ2P1oOgl02NX:0080Ogmo00<02NX:07moO`09jPX00P1oOgl200WZ2P80Ogmo00<0
2NX:07moO`09jPX0201oOgl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl05`1oOgl01009jPX0Ogmo07moO`1oOgl200WZ2Pd0Ogmo0P00000/0?ooo`0300WZ
2P3oool0oooo01<0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool06P3o
ool00`09jPX0oooo0?ooo`0A0?ooo`@02NX:403oool00`09jPX0Ogmo07moO`0;07moO`0300WZ2P1o
Ogl0Ogmo00P0Ogmo00@02NX:07moO`1oOgl000000`1oOgl500WZ2P<0Ogmo00<02NX:07moO`1oOgl0
0P1oOgl800WZ2PH0Ogmo1P09jPX_07moO`0300WZ2P1oOgl02NX:0080Ogmo00@0000007moO`09jPX0
2NX:0P1oOgl00`09jPX0Ogmo07moO`0?07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<0000007moO`1o
Ogl01@1oOgl00`09jPX0Ogmo07moO`0307moO`802NX:101oOgl010000000Ogmo07moO`1oOgl200WZ
2PX0Ogmo00D02NX:07moO`09jPX0Ogmo00WZ2P0307moO`802NX:1P1oOgl00`09jPX0000007moO`02
07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P00000>07moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P09jPX4
07moO`802NX:101oOgl300WZ2P0307moO`09jPX0Ogmo00H0Ogmo00<02NX:07moO`1oOgl0201oOgl0
0`09jPX0Ogmo07moO`0407moO`030000001oOgl0Ogmo01L0Ogmo00<02NX:07moO`1oOgl00`1oOgl2
00WZ2PX0Ogmo00<000000?ooo`3oool0:`3oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0
oooo00`0oooo00200?ooo`030000003oool0oooo01X0oooo00<02NX:0?ooo`3oool03@3oool400WZ
2Q@0oooo00<02NX:000000000000301oOgl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1oOgl00000
00L0Ogmo1009jPX207moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00P1oOgl900WZ
2P@0Ogmo00<02NX:07moO`1oOgl0;@1oOgl200WZ2P80Ogmo00<0000000WZ2P09jPX00`1oOgl00`09
jPX0Ogmo07moO`0A07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`09
jPX0Ogmo07moO`0507moO`<02NX:0P1oOgl00`000000Ogmo07moO`0307moO`802NX:1P1oOgl200WZ
2P0307moO`09jPX0Ogmo0080Ogmo00@02NX:0000001oOgl0Ogmo0P09jPX507moO`0300WZ2P1oOgl0
00000080Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPX?07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P09
jPX407moO`802NX:1@1oOgl01009jPX0Ogmo00WZ2P09jPX607moO`0300WZ2P1oOgl0Ogmo00X0Ogmo
00<02NX:07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0H07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo
0`09jPX507moO`800000;@3oool00`09jPX0oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo
00200?ooo`030000003oool0oooo01T0oooo00<02NX:0?ooo`3oool02@3oool500WZ2QT0oooo00<0
2NX:0?ooo`0000002`1oOgl00`09jPX0Ogmo07moO`0607moO`0400WZ2P1oOgl0Ogmo000000T0Ogmo
00H0000000WZ2P09jPX02NX:07moO`09jPX307moO`030000001oOgl0Ogmo0080Ogmo00<02NX:0000
0009jPX00P1oOgl20000000307moO`09jPX0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0;01oOgl200WZ
2P0407moO`0000002NX:00WZ2P<0Ogmo0P09jPXD07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00802NX:00<00000
07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0207moO`0400WZ2P1oOgl0Ogmo00WZ2P@0Ogmo00L0
2NX:0000001oOgl02NX:0000001oOgl02NX:00@0Ogmo00<02NX:07moO`1oOgl00P0000001009jPX0
Ogmo00WZ2P09jPX@07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo0P09jPX407moO`0300WZ2P1oOgl02NX:
00<0Ogmo00D02NX:07moO`1oOgl02NX:07moO`0200WZ2P<0Ogmo00<02NX:07moO`1oOgl02`1oOgl0
0`09jPX0Ogmo07moO`0207moO`030000001oOgl0Ogmo01L0Ogmo00<02NX:07moO`1oOgl02@1oOgl2
00WZ2P80Ogmo00<000000?ooo`3oool0;03oool00`09jPX0oooo0?ooo`0F0?ooo`030000003oool0
oooo00`0oooo00200?ooo`030000003oool0oooo01T0oooo00<02NX:0?ooo`3oool01@3oool400WZ
2Qh0oooo00<02NX:0?ooo`3oool00P00000907moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07mo
O`0000003@1oOgl400WZ2P<0Ogmo00L0000007moO`1oOgl0Ogmo00WZ2P0000002NX:00D0Ogmo00<0
2NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0/07moO`0400WZ2P1oOgl02NX:00WZ2P@0Ogmo
00<02NX:07moO`1oOgl05@1oOgl00`09jPX0Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<02NX:07moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0207moO`802NX:1`1oOgl200WZ2P0307mo
O`09jPX0Ogmo00802NX:1`1oOgl200WZ2P0300000009jPX0Ogmo00802NX:0P1oOgl00`09jPX0Ogmo
07moO`0207moO`802NX:4P1oOgl00`09jPX0Ogmo07moO`0407moO`802NX:0`1oOgl01009jPX0Ogmo
07moO`09jPX307moO`0400WZ2P1oOgl0Ogmo00WZ2P<0Ogmo0`09jPX?07moO`0400WZ2P1oOgl0Ogmo
000001X0Ogmo00<02NX:07moO`1oOgl02`1oOgl200WZ2Rh0oooo00<02NX:0?ooo`3oool05`3oool0
0`000000oooo0?ooo`0<0?ooo`00P03oool2000000h02NX:2`3oool00`09jPX0oooo0?ooo`020?oo
o`@02NX:8P3oool00`09jPX0oooo0?ooo`020?ooo`800000201oOgl00`09jPX0Ogmo07moO`0407mo
O`0400WZ2P1oOgl0Ogmo000000l0Ogmo0`09jPX207moO`050000001oOgl0Ogmo07moO`09jPX00P1o
Ogl01@09jPX0Ogmo07moO`1oOgl02NX:00D0Ogmo00<02NX:07moO`1oOgl0:`1oOgl00`09jPX0Ogmo
00WZ2P0507moO`0300WZ2P1oOgl0Ogmo01H0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl00`1oOgl0100000002NX:
00WZ2P09jPX607moO`<02NX:301oOgl500WZ2P0307moO`09jPX0Ogmo0080Ogmo0P09jPX200000100
Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo00WZ2P0307moO`0700WZ2P1oOgl0Ogmo07mo
O`09jPX0Ogmo00WZ2P0307moO`0400WZ2P1oOgl0Ogmo07moO`802NX:00<0Ogmo00WZ2P09jPX03@1o
Ogl01009jPX0Ogmo07moO`00000J07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo0P0000020?ooo`802NX:
:`3oool00`09jPX0oooo0?ooo`0H0?ooo`030000003oool0oooo00`0oooo00200?ooo`8000003P3o
oolM00WZ2QT0oooo00<02NX:0?ooo`3oool0103oool00`000000Ogmo07moO`0507moO`0300WZ2P1o
Ogl0Ogmo00@0Ogmo00@02NX:07moO`1oOgl000004@1oOgl400WZ2P80Ogmo00D02NX:07moO`1oOgl0
Ogmo00WZ2P0307moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl0:@1oOgl300WZ2P@0
Ogmo0P09jPXJ07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`09jPX0
Ogmo07moO`0707moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00@0000007moO`1oOgl0Ogmo0P09jPX307mo
O`0300WZ2P1oOgl02NX:00802NX:3P1oOgl400WZ2P0507moO`09jPX02NX:07moO`09jPX00P1oOgl0
0`000000Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00H02NX:07moO`1oOgl02NX:07mo
O`09jPX507moO`0300WZ2P1oOgl0Ogmo0080Ogmo00@02NX:07moO`1oOgl02NX:1@1oOgl200WZ2P`0
Ogmo00<02NX:0000001oOgl06P1oOgl00`09jPX0Ogmo07moO`0807moO`030000003oool0oooo00@0
oooo0`09jPXH0?ooo`8000003@3oool00`09jPX0oooo0?ooo`0I0?ooo`030000003oool0oooo00`0
oooo00200?ooo`030000003oool0oooo01@0oooo1@09jPXA0?oooad02NX:103oool2000000D0Ogmo
00<02NX:07moO`1oOgl00`1oOgl01009jPX0Ogmo07moO`00000C07moO`H02NX:101oOgl01009jPX0
Ogmo07moO`09jPX607moO`0300WZ2P1oOgl0Ogmo02P0Ogmo0P09jPX507moO`0300WZ2P1oOgl0Ogmo
01X0Ogmo00D02NX:07moO`1oOgl0Ogmo0000000507moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<02NX:
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0207moO`<02NX:00<0Ogmo00WZ2P1oOgl00P1oOgl2
00WZ2Pl0Ogmo1009jPX00`1oOgl02NX:07moO`0207moO`030000001oOgl0Ogmo00X0Ogmo00<02NX:
07moO`1oOgl01@1oOgl01`09jPX0Ogmo07moO`1oOgl02NX:07moO`09jPX0101oOgl00`09jPX0Ogmo
00WZ2P0207moO`0400WZ2P1oOgl0Ogmo00WZ2PP0Ogmo0`09jPX907moO`0300WZ2P000000Ogmo01X0
Ogmo00<02NX:07moO`1oOgl01P1oOgl2000000X0oooo0P09jPXD0?ooo`802NX:0P00000<0?ooo`03
00WZ2P3oool0oooo01X0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0
403oool400WZ2P80oooo00<02NX:0?ooo`3oool0:`3oool00`09jPX0oooo0?ooo`0M00WZ2P`0Ogmo
00@02NX:00000009jPX0Ogmo0`09jPX207moO`0300WZ2P1oOgl02NX:00L0Ogmo00<02NX:07moO`1o
Ogl09P1oOgl200WZ2P0300000009jPX0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0701oOgl01009jPX0
Ogmo07moO`00000407moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0207moO`0400WZ2P1oOgl02NX:00WZ2PH0Ogmo0P09jPX;07moO`<02NX:00<0Ogmo
00WZ2P09jPX00`09jPX307moO`8000002@1oOgl00`09jPX0Ogmo07moO`0607moO`0400WZ2P1oOgl0
Ogmo07moO`802NX:1@1oOgl00`09jPX0Ogmo00WZ2P0207moO`0300WZ2P1oOgl02NX:00`0Ogmo0P09
jPX707moO`0300WZ2P000000Ogmo01T0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`000000oooo0?oo
o`0<0?ooo`802NX:403oool200WZ2Pl0oooo00<02NX:0?ooo`3oool06`3oool00`000000oooo0?oo
o`0<0?ooo`00P03oool00`000000oooo0?ooo`0<0?ooo`@02NX:1P3oool00`09jPX0oooo0?ooo`0[
0?ooo`0300WZ2P3oool0oooo00L0oooo0P00000307moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:
07moO`0000002@1oOglA00WZ2P80Ogmo1@09jPX707moO`0300WZ2P1oOgl0Ogmo02@0Ogmo0P09jPX0
0`000000Ogmo00WZ2P0207moO`80000000<02NX:07moO`1oOgl07@1oOgl01009jPX0Ogmo07moO`00
000407moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<02NX:07moO`1oOgl00`1oOgl01P000000Ogmo07mo
O`1oOgl02NX:07moO`802NX:00<0Ogmo00WZ2P09jPX01P1oOgl200WZ2PL0Ogmo0P09jPX207moO`05
00WZ2P1oOgl0Ogmo00WZ2P1oOgl01@09jPX207moO`030000001oOgl0Ogmo00D0Ogmo00<02NX:07mo
O`1oOgl01`1oOgl01009jPX0Ogmo07moO`1oOgl200WZ2P@0Ogmo00H02NX:07moO`1oOgl0Ogmo00WZ
2P1oOgl200WZ2Pl0Ogmo0P09jPX507moO`0300000009jPX0Ogmo01T0Ogmo00<02NX:07moO`1oOgl0
101oOgl200000140oooo0P09jPX<0?ooo`802NX:403oool00`09jPX0oooo0?ooo`0L0?ooo`030000
003oool0oooo00`0oooo00200?ooo`030000003oool0oooo00P0oooo1009jPX90?ooo`0300WZ2P3o
ool0oooo02d0oooo00<02NX:0?ooo`3oool0203oool010000000Ogmo07moO`09jPX307moO`0400WZ
2P1oOgl0Ogmo000001L0Ogmo00<0000000WZ2P09jPX00P09jPX207moO`<02NX:1`1oOgl00`09jPX0
Ogmo07moO`0S07moO`802NX:00@0000007moO`1oOgl02NX:0P1oOgl400WZ2Ql0Ogmo00<02NX:0000
001oOgl00`1oOgl00`09jPX0Ogmo07moO`0;07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00D0000007mo
O`09jPX0Ogmo00WZ2P0507moO`802NX:1P1oOgl200WZ2P@0Ogmo00<02NX:07moO`1oOgl00P1oOgl0
1009jPX0Ogmo07moO`1oOgl200WZ2P<0Ogmo1009jPX00`000000Ogmo07moO`0307moO`0300WZ2P1o
Ogl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2P<0Ogmo00<02NX:07moO`1oOgl00`1o
Ogl200WZ2Q80Ogmo0`09jPX207moO`0300000009jPX0Ogmo01T0Ogmo00<02NX:07moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0C0?ooo`<02NX:1`3oool200WZ2Q40oooo00<02NX:0?ooo`3oool07@3o
ool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`030?ooo`D02NX:3@3oool0
0`09jPX0oooo0?ooo`0]0?ooo`0300WZ2P3oool0oooo00T0oooo0P0000001@1oOgl02NX:07moO`1o
Ogl02NX:0080Ogmo00<0000007moO`1oOgl05@1oOgl00`0000002NX:00WZ2P0207moO`802NX:00<0
Ogmo00WZ2P09jPX00P09jPX607moO`0300WZ2P1oOgl0Ogmo0200Ogmo0`09jPX010000000Ogmo07mo
O`09jPX207moO`0300WZ2P1oOgl02NX:0080Ogmo0`09jPXL07moO`0300WZ2P000000Ogmo0080Ogmo
00<02NX:07moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0407moO`0400000009jPX0Ogmo00WZ2PP0
Ogmo0P09jPX607moO`@02NX:1@1oOgl00`09jPX0Ogmo07moO`0207moO`802NX:1@1oOgl400WZ2P80
Ogmo00<02NX:07moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0207moO`802NX:0`1oOgl00`09jPX0
Ogmo07moO`0207moO`0300WZ2P1oOgl02NX:01D0Ogmo0P09jPX207moO`0300WZ2P1oOgl0Ogmo01L0
Ogmo00@02NX:07moO`1oOgl0Ogmo0P00000I0?ooo`802NX:0`3oool200WZ2Q80oooo00<02NX:0?oo
o`3oool07P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool2000000D02NX:403oool00`09jPX0
oooo0?ooo`0^0?ooo`0300WZ2P3oool0oooo00/0oooo00@0000000WZ2P1oOgl02NX:0P1oOgl00`00
0000Ogmo07moO`0F07moO`0400000009jPX0Ogmo00WZ2P<0Ogmo0`09jPX207moO`<02NX:0`1oOgl0
0`09jPX0Ogmo07moO`0N07moO`802NX:00<0Ogmo00WZ2P1oOgl00`1oOgl00`09jPX0Ogmo00WZ2P02
07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo1009jPXH07moO`0300WZ2P000000Ogmo0080Ogmo00<02NX:
07moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl02NX:00/0Ogmo0P09jPX4
07moO`@02NX:1@1oOgl00`09jPX0Ogmo07moO`0207moO`0400WZ2P1oOgl02NX:00WZ2PH0Ogmo1009
jPX907moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`09jPX00P1oOgl00`09jPX0Ogmo07mo
O`0207moO`0400WZ2P1oOgl02NX:00WZ2QD0Ogmo0P0000000`09jPX0Ogmo00WZ2P0H07moO`0300WZ
2P1oOgl0Ogmo008000007@3oool300WZ2Q<0oooo00<02NX:0?ooo`3oool07`3oool00`000000oooo
0?ooo`0<0?ooo`00P03oool2000000D0oooo3@09jPX30?ooo`0300WZ2P3oool0oooo02h0oooo00<0
2NX:0?ooo`3oool0303oool00`09jPX0000000WZ2P0207moO`030000001oOgl0Ogmo01H0Ogmo00D0
000000WZ2P1oOgl0Ogmo00WZ2P0307moO`<02NX:101oOgl200WZ2P0307moO`09jPX0000001d0Ogmo
0P09jPX207moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`09jPX00`1oOgl00`09jPX0Ogmo
07moO`0707moO`<02NX:5@1oOgl01@0000002NX:07moO`1oOgl02NX:00l0Ogmo00<02NX:07moO`1o
Ogl00P1oOgl200WZ2P0307moO`09jPX0Ogmo00d0Ogmo1009jPX407moO`802NX:0`1oOgl00`09jPX0
Ogmo07moO`0207moO`0500WZ2P1oOgl0Ogmo07moO`09jPX01P1oOgl00`09jPX0000000WZ2P0300WZ
2PH0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0200WZ2P@0Ogmo00H02NX:07mo
O`1oOgl02NX:07moO`09jPXD07moO`060000001oOgl0Ogmo00WZ2P1oOgl02NX:5`1oOgl00`09jPX0
Ogmo0000000N0?ooo`802NX:00<0oooo00WZ2P09jPX04@3oool00`09jPX0oooo0?ooo`0P0?ooo`03
0000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo0140oooo3@09jPXX0?ooo`0300WZ
2P3oool0oooo00`0oooo00@02NX:00000000000000006@1oOgl00`0000002NX:07moO`0207moO`03
00WZ2P1oOgl02NX:0080Ogmo0P09jPX507moO`0300WZ2P000000000001/0Ogmo0P09jPX207moO`03
00000009jPX0Ogmo00@0Ogmo0P09jPX407moO`0300WZ2P1oOgl0Ogmo00X0Ogmo1009jPXA07moO`04
00000009jPX0Ogmo00WZ2Q00Ogmo00H02NX:07moO`1oOgl0Ogmo00WZ2P1oOgl200WZ2P030000001o
Ogl0Ogmo00`0Ogmo0P09jPX00`1oOgl02NX:00WZ2P0507moO`0400WZ2P1oOgl0Ogmo00WZ2P@0Ogmo
0P09jPX307moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl00P0000000`1oOgl02NX:
00WZ2P0200WZ2P80Ogmo00<02NX:07moO`1oOgl00P1oOgl01009jPX0Ogmo07moO`1oOgl200WZ2P<0
Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0207moO`0300WZ2P1oOgl0Ogmo0140Ogmo00@0000007mo
O`1oOgl0Ogmo0P09jPXG07moO`0300WZ2P000000oooo01`0oooo0P09jPX50?ooo`<02NX:3@3oool0
0`09jPX0oooo0?ooo`0Q0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo
0180oooo00<02NX:0?ooo`3oool02@3oool<00WZ2Q`0oooo00<02NX:0?ooo`3oool0303oool01009
jPX0oooo0?ooo`00000J07moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P09jPX207moO`0400000009jPX0
2NX:00WZ2P@0Ogmo1009jPXH07moO`0600WZ2P1oOgl0Ogmo07moO`0000002NX:1@1oOgl00`09jPX0
Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00h0Ogmo0`09jPX>07moO`040000001oOgl02NX:00WZ
2Q40Ogmo00D02NX:07moO`09jPX0Ogmo00WZ2P0207moO`030000001oOgl0Ogmo00X0Ogmo0P09jPX5
07moO`802NX:101oOgl300WZ2P@0Ogmo0P09jPX407moO`802NX:00<0Ogmo00WZ2P1oOgl0101oOgl0
10000000Ogmo07moO`1oOgl400WZ2P@0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0307moO`0300WZ
2P1oOgl0Ogmo0080Ogmo00@02NX:07moO`1oOgl02NX:4P1oOgl00`000000Ogmo07moO`0407moO`03
00WZ2P1oOgl0Ogmo01<0Ogmo00<0000000WZ2P3oool0703oool00`09jPX0oooo0?ooo`080?ooo`80
2NX:2P3oool00`09jPX0oooo0?ooo`0R0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000
003oool0oooo0180oooo00<02NX:0?ooo`3oool05@3oool=00WZ2Pl0oooo00<02NX:0?ooo`3oool0
303oool01009jPX0oooo0?ooo`00000I07moO`0300WZ2P000000Ogmo00@0Ogmo0P09jPX207moO`03
00WZ2P1oOgl0Ogmo00<02NX:0P1oOgl00`09jPX0Ogmo07moO`0200WZ2Q@0Ogmo0P09jPX307moO`03
00000009jPX0Ogmo00@0Ogmo0P09jPX607moO`0300WZ2P1oOgl0Ogmo0140Ogmo1009jPX907moO`04
0000001oOgl0Ogmo00WZ2Q80Ogmo0P09jPX00`1oOgl02NX:07moO`0307moO`030000001oOgl0Ogmo
00L0Ogmo0P09jPX907moO`802NX:101oOgl200WZ2P<0Ogmo0P09jPX607moO`0300WZ2P1oOgl0Ogmo
00D0Ogmo0P00000307moO`D02NX:00@0Ogmo00WZ2P1oOgl0Ogmo0P09jPX00`1oOgl02NX:00WZ2P05
07moO`0500WZ2P1oOgl0Ogmo07moO`09jPX04@1oOgl00`000000Ogmo07moO`0407moO`802NX:4P1o
Ogl30000000300WZ2P3oool0oooo01T0oooo0P09jPX=0?ooo`802NX:1`3oool00`09jPX0oooo0?oo
o`0S0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo0140oooo00<02NX:
0?ooo`3oool08`3oool<00WZ2P<0oooo00<02NX:0?ooo`3oool02`3oool01009jPX0oooo00WZ2P00
000J07moO`0300WZ2P000000Ogmo00@0Ogmo00D02NX:07moO`09jPX0Ogmo00WZ2P0307moO`H02NX:
0`1oOgl300WZ2Pl0Ogmo0P09jPX307moO`80000000<02NX:07moO`1oOgl00P1oOgl300WZ2PP0Ogmo
00<02NX:07moO`1oOgl0501oOgl300WZ2PH0Ogmo00D0000007moO`09jPX0Ogmo00WZ2P0A07moO`03
00WZ2P1oOgl02NX:00D0Ogmo00<0000007moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0;07moO`80
2NX:0P1oOgl01@09jPX0Ogmo00WZ2P09jPX0Ogmo00802NX:1@1oOgl00`09jPX0Ogmo00WZ2P0807mo
O`040000001oOgl0Ogmo00WZ2P<0Ogmo1009jPX0101oOgl02NX:07moO`09jPX607moO`0300WZ2P1o
Ogl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl03@1oOgl00`000000Ogmo07moO`0607moO`<02NX:3P1o
Ogl200000080Ogmo00<02NX:0000003oool0603oool200WZ2Q40oooo0P09jPX40?ooo`0300WZ2P3o
ool0oooo02@0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool04@3oool0
0`09jPX0oooo0?ooo`0_0?ooo`d02NX:103oool01009jPX0oooo00WZ2P00000J07moO`0300WZ2P00
0000Ogmo00<0Ogmo00L02NX:07moO`1oOgl0Ogmo00WZ2P1oOgl02NX:00@0Ogmo0`09jPX00`1oOgl0
2NX:00WZ2P0200WZ2P80Ogmo0P09jPX;07moO`802NX:101oOgl00`000000Ogmo00WZ2P0407moO`04
00WZ2P1oOgl0Ogmo00WZ2PP0Ogmo00<02NX:07moO`1oOgl05`1oOgl400WZ2P80Ogmo00D0000007mo
O`09jPX0Ogmo00WZ2P0?07moO`@02NX:1P1oOgl00`000000Ogmo07moO`0407moO`802NX:401oOgl3
00WZ2P<0Ogmo0`09jPX407moO`0400WZ2P1oOgl0Ogmo07moO`802NX:1`1oOgl00`0000002NX:07mo
O`0407moO`0300WZ2P1oOgl02NX:00@02NX:1P1oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl01P1oOgl01009jPX0Ogmo07moO`09jPX<07moO`030000
001oOgl0Ogmo0080Ogmo00<02NX:0000003oool05P3oool200WZ2QD0oooo1009jPXW0?ooo`030000
003oool0oooo00`0oooo00200?ooo`030000003oool0oooo0100oooo00<02NX:0?ooo`3oool0=03o
ool00`09jPX0oooo0?ooo`060?ooo`d02NX:5@1oOgl00`09jPX0000007moO`0307moO`0300WZ2P1o
Ogl0Ogmo0080Ogmo0P09jPX607moO`802NX:101oOgl300WZ2P0407moO`09jPX02NX:00WZ2PH0Ogmo
0P09jPX407moO`80000000<0Ogmo00WZ2P1oOgl00`1oOgl01009jPX0Ogmo07moO`09jPX907moO`03
00WZ2P1oOgl0Ogmo01/0Ogmo1009jPX307moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00@02NX:07moO`09
jPX02NX:201oOgl010000000Ogmo07moO`1oOgl200WZ2Q@0Ogmo0P09jPX307moO`<02NX:0P1oOgl0
0`09jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:0000001oOgl00P1oOgl0
1@09jPX0Ogmo07moO`09jPX0Ogmo00D02NX:101oOgl00`09jPX0000007moO`0407moO`0300WZ2P1o
Ogl0Ogmo00/0Ogmo00<0000007moO`1oOgl0201oOgl01009jPX0Ogmo07moO`09jPX907moO`800000
1@1oOgl00`09jPX0Ogmo0000000D0?ooo`802NX:6@3oool300WZ2RH0oooo00<000000?ooo`3oool0
303oool00800oooo00<000000?ooo`3oool0403oool00`09jPX0oooo0?ooo`0d0?ooo`0300WZ2P3o
ool0oooo00T0oooo00D02NX:0?ooo`3oool0000000WZ2P0507moO``02NX:2@1oOgl00`09jPX0Ogmo
0000000307moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl01@1oOgl200WZ2PH0Ogmo
1P09jPX307moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00@0000007moO`1oOgl02NX:101oOgl01@09jPX0
Ogmo07moO`1oOgl02NX:00T0Ogmo00<02NX:07moO`1oOgl0701oOgl00`0000002NX:00WZ2P0400WZ
2P`0Ogmo00D02NX:07moO`09jPX0Ogmo00WZ2P0807moO`040000001oOgl02NX:00WZ2QH0Ogmo00D0
2NX:07moO`09jPX02NX:07moO`0200WZ2P0307moO`09jPX02NX:00P0Ogmo0P09jPX407moO`0400WZ
2P1oOgl0Ogmo00000080Ogmo00D02NX:07moO`09jPX0Ogmo00WZ2P0307moO`D02NX:0`00000607mo
O`0300WZ2P1oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0201oOgl01009jPX0Ogmo07moO`1oOgl2
00WZ2PH0Ogmo00<0000007moO`1oOgl01@1oOgl00`09jPX0Ogmo0000000B0?ooo`802NX:6P3oool0
1009jPX0oooo0?ooo`3oool200WZ2R@0oooo00<000000?ooo`3oool0303oool00800oooo00<00000
0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0e0?ooo`0300WZ2P3oool0oooo00P0oooo00H02NX:
0?ooo`3oool0oooo00000009jPXA07moO`d02NX:00<0Ogmo00WZ2P1oOgl00P1oOgl200000080Ogmo
0P09jPX507moO`0400WZ2P1oOgl02NX:00WZ2PP0Ogmo1@09jPX507moO`040000001oOgl0Ogmo00WZ
2P<0Ogmo0P09jPX407moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl0701oOgl00`00
00002NX:07moO`0307moO`<02NX:2@1oOgl00`09jPX0Ogmo00WZ2P0207moO`0300WZ2P1oOgl0Ogmo
00H0Ogmo0P09jPXH07moO`0400WZ2P1oOgl0Ogmo07moO`<02NX:00<0Ogmo00WZ2P1oOgl00P09jPX8
07moO`0500WZ2P1oOgl0Ogmo07moO`09jPX00`1oOgl0100000002NX:07moO`1oOgl200WZ2P@0Ogmo
00@02NX:07moO`1oOgl0Ogmo0P09jPX00`000000Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0207moO`0400WZ2P1oOgl0Ogmo07mo
O`800000201oOgl00`09jPX0Ogmo0000000@0?ooo`802NX:6`3oool00`09jPX0oooo0?ooo`040?oo
o`802NX:8P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0>0?ooo`03
00WZ2P3oool0oooo03L0oooo00<02NX:0?ooo`3oool01`3oool01P09jPX0oooo0?ooo`000000Ogmo
00WZ2QT0Ogmo00D02NX:07moO`1oOgl0000007moO`0600WZ2P0300000009jPX02NX:00T02NX:0P1o
Ogl200WZ2PL0Ogmo1P09jPX00`1oOgl000000000000207moO`0500WZ2P1oOgl0Ogmo07moO`09jPX0
1@1oOgl00`09jPX0Ogmo07moO`0807moO`0300WZ2P1oOgl0Ogmo01/0Ogmo00<0000000WZ2P1oOgl0
1@1oOgl00`09jPX0Ogmo00WZ2P0300WZ2P@0Ogmo00<02NX:07moO`09jPX0101oOgl00`09jPX0Ogmo
07moO`0307moO`802NX:00<0Ogmo0000001oOgl05`1oOgl00`09jPX0Ogmo07moO`0207moO`@02NX:
0`1oOgl200WZ2PL0Ogmo0P0000000`1oOgl02NX:07moO`0307moO`0400WZ2P0000002NX:00WZ2PD0
Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo00WZ2P0200WZ2PH0Ogmo00<02NX:07moO`1o
Ogl01`1oOgl00`000000Ogmo07moO`0:07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P09jPX00`000000
Ogmo07moO`0707moO`0500WZ2P1oOgl0Ogmo07moO`0000003@3oool200WZ2Q`0oooo00<02NX:0?oo
o`3oool01`3oool300WZ2Ql0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3o
ool03P3oool00`09jPX0oooo0?ooo`0g0?ooo`0300WZ2P3oool0oooo00H0oooo00D02NX:0?ooo`3o
ool0oooo0000000207moO`0300WZ2P1oOgl0Ogmo01H0Ogmo00@02NX:07moO`1oOgl000000P1oOgl0
0`09jPX0Ogmo07moO`0507moO`0400000009jPX02NX:00WZ2P@0Ogmo5@09jPX00`1oOgl02NX:07mo
O`0207moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl0201oOgl00`09jPX0Ogmo07mo
O`0K07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl00P1oOgl600WZ2PD0Ogmo00<0
2NX:07moO`1oOgl00P1oOgl01@09jPX0Ogmo07moO`1oOgl0000001P0Ogmo00<02NX:07moO`1oOgl0
0P1oOgl200WZ2P80Ogmo0P09jPX307moO`802NX:1@1oOgl20000000300WZ2P1oOgl0Ogmo0080Ogmo
00@02NX:07moO`09jPX000001P1oOgl00`09jPX0Ogmo07moO`0307moO`0400WZ2P1oOgl0Ogmo07mo
O`<02NX:0`1oOgl00`09jPX0Ogmo07moO`0707moO`030000001oOgl0Ogmo00/0Ogmo00<02NX:07mo
O`1oOgl00P1oOgl00`000000Ogmo00WZ2P0907moO`0500WZ2P1oOgl0Ogmo07moO`0000002`3oool2
00WZ2Qd0oooo00<02NX:0?ooo`3oool02`3oool200WZ2Qd0oooo00<000000?ooo`3oool0303oool0
0800oooo00<000000?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0h0?ooo`0300WZ2P3oool0oooo
00H0oooo00@02NX:0?ooo`3oool000000`1oOgl00`09jPX0Ogmo07moO`0F07moO`0600WZ2P1oOgl0
Ogmo0000001oOgl02NX:2`1oOgl200WZ2P<0Ogmo00<02NX:07moO`1oOgl0101oOgl300WZ2PL0Ogmo
00@0000007moO`1oOgl0Ogmo5P09jPX00`1oOgl02NX:07moO`0L07moO`0300WZ2P1oOgl0Ogmo00H0
Ogmo00<02NX:07moO`1oOgl00`1oOgl600WZ2P@0Ogmo00<02NX:07moO`1oOgl00P09jPX407moO`03
0000001oOgl0Ogmo01H0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2P@0Ogmo0P09jPX307moO`03
00WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl00P1oOgl300WZ2P0307moO`000000Ogmo00D0
Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0407moO`<02NX:00<0Ogmo00WZ2P1o
Ogl01P1oOgl00`000000Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo008000000`1oOgl00`09jPX0
Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<000000?ooo`3oool01P3oool200WZ2Qh0
oooo00<02NX:0?ooo`3oool03P3oool200WZ2Q/0oooo00<000000?ooo`3oool0303oool00800oooo
00<000000?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0h0?ooo`0300WZ2P3oool0oooo00H0oooo
00@02NX:0?ooo`3oool00000101oOgl00`09jPX0Ogmo07moO`0E07moO`0600WZ2P1oOgl0Ogmo07mo
O`0000002NX:301oOgl200WZ2P80Ogmo00<02NX:07moO`1oOgl0101oOgl300WZ2PD0Ogmo0P000002
07moO`802NX:0P1oOgl600WZ2P<0Ogmo00<02NX:07moO`1oOgl0201oOglF00WZ2PP0Ogmo00<02NX:
07moO`1oOgl0201oOgl01`09jPX0Ogmo07moO`1oOgl02NX:07moO`09jPX0101oOgl300WZ2P0407mo
O`09jPX02NX:00WZ2PL0Ogmo00<0000007moO`1oOgl05@1oOgl01009jPX0Ogmo07moO`1oOgl300WZ
2PH0Ogmo0P09jPX207moO`802NX:0`1oOgl00`09jPX0Ogmo07moO`0207moO`<02NX:0`1oOgl20000
00@0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0607moO`<02NX:1P1oOgl00`00
0000Ogmo07moO`0<07moO`0300WZ2P1oOgl0000000H0Ogmo0P09jPX607moO`0300WZ2P1oOgl0Ogmo
0080Ogmo00<000000?ooo`3oool0103oool200WZ2Ql0oooo00<02NX:0?ooo`3oool04@3oool200WZ
2QT0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0303oool00`09jPX0
oooo0?ooo`0j0?ooo`0300WZ2P3oool0oooo00@0oooo00D02NX:0?ooo`3oool0oooo0000000407mo
O`0300WZ2P1oOgl0Ogmo01@0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`0000002NX:07moO`0=07mo
O`0400WZ2P1oOgl0Ogmo00WZ2P<0Ogmo0P09jPX307moO`802NX:0P1oOgl01@000000Ogmo07moO`1o
Ogl02NX:00<0Ogmo00@02NX:000000000000Ogmo0P09jPX0101oOgl02NX:00WZ2P09jPX<07moO`03
00WZ2P1oOgl0Ogmo0180Ogmo5@09jPX0101oOgl02NX:07moO`09jPX807moO`<02NX:201oOgl00`00
0000Ogmo07moO`0E07moO`0500WZ2P1oOgl0Ogmo00WZ2P1oOgl00P09jPX807moO`802NX:0P1oOgl2
00WZ2P0307moO`09jPX0Ogmo00<0Ogmo0P09jPX607moO`050000001oOgl0Ogmo07moO`09jPX01@1o
Ogl00`09jPX0Ogmo07moO`0907moO`0300WZ2P000000Ogmo0080Ogmo00<0000007moO`1oOgl03@1o
Ogl00`0000002NX:07moO`0807moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl00P1o
Ogl00`000000oooo0?ooo`020?ooo`802NX:803oool00`09jPX0oooo0?ooo`0D0?ooo`<02NX:5P3o
ool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0<0?ooo`0300WZ2P3oool0
oooo03X0oooo00<02NX:0?ooo`3oool0103oool01009jPX0oooo0?ooo`00000507moO`0300WZ2P1o
Ogl0Ogmo01@0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0>07moO`<02NX:00<0
Ogmo00WZ2P09jPX01`1oOgl200WZ2P<0Ogmo00H02NX:07moO`1oOgl0Ogmo00WZ2P1oOgl200000080
2NX:00<0Ogmo00WZ2P09jPX01P09jPX807moO`0300WZ2P1oOgl0Ogmo01T0Ogmo00<02NX:0000001o
Ogl02P1oOglG00WZ2P0307moO`000000Ogmo01D0Ogmo00@02NX:07moO`1oOgl02NX:0P1oOgl200WZ
2PX0Ogmo0P09jPX207moO`802NX:0`1oOgl00`09jPX0Ogmo00WZ2P0707moO`80000000<0Ogmo00WZ
2P1oOgl01@1oOgl00`09jPX0Ogmo07moO`0807moO`0300WZ2P000000Ogmo0080Ogmo00<0000007mo
O`1oOgl02`1oOgl20000000307moO`09jPX0Ogmo00T0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P06
07moO`040000003oool02NX:00WZ2R40oooo00<02NX:0?ooo`3oool0603oool200WZ2Q@0oooo00<0
00000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0k
0?ooo`0300WZ2P3oool0oooo00<0oooo00D02NX:0?ooo`3oool0oooo0000000607moO`0300WZ2P1o
Ogl0Ogmo01<0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0@07moO`802NX:201o
Ogl20000000407moO`09jPX0Ogmo00WZ2P80Ogmo0P09jPX607moO`H02NX:0`1oOgl300WZ2PD0Ogmo
00<02NX:07moO`1oOgl0601oOgl00`09jPX0000007moO`0;07moO`<02NX:2`1oOgl00`09jPX0Ogmo
07moO`0207moO`802NX:0P1oOglF00WZ2P80Ogmo00<02NX:07moO`09jPX00`1oOgl200WZ2P`0Ogmo
0`09jPX00`1oOgl02NX:00WZ2P0300WZ2PX0Ogmo00<0000007moO`09jPX01@1oOgl00`09jPX0Ogmo
07moO`0907moO`0400WZ2P1oOgl0Ogmo000000d0Ogmo00<0000007moO`1oOgl00P1oOgl00`09jPX0
Ogmo07moO`0807moO`802NX:00<0Ogmo00WZ2P1oOgl01@1oOgl200WZ2R80oooo00<02NX:0?ooo`3o
ool06`3oool200WZ2Q80oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0
2P3oool00`09jPX0oooo0?ooo`0l0?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`3oool0
00001`1oOgl00`09jPX0Ogmo07moO`0C07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1o
Ogl03P1oOgl200WZ2P0307moO`09jPX02NX:00H0Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P03
07moO`09jPX0Ogmo00X0Ogmo1P09jPX307moO`@02NX:0P1oOgl00`09jPX0Ogmo07moO`0F07moO`03
00WZ2P1oOgl0000000X0Ogmo1009jPX=07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0`09jPX00`1oOgl0
000007moO`0B07moOaD02NX:0P1oOgl400WZ2P0307moO`09jPX02NX:00`0Ogmo00<0000000WZ2P1o
Ogl01@1oOgl00`09jPX0Ogmo07moO`0807moO`0400WZ2P1oOgl0Ogmo000000/0Ogmo0P00000507mo
O`0300WZ2P1oOgl0Ogmo00X0Ogmo0P09jPX407moO`802NX:00<0Ogmo0000003oool0803oool00`09
jPX0oooo0?ooo`0N0?ooo`802NX:403oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000
oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo03d0oooo00D02NX:0?ooo`3oool0oooo00WZ2P030?oo
o`030000001oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl04`1oOgl00`09jPX0Ogmo07moO`0207mo
O`0300WZ2P000000Ogmo00d0Ogmo00@02NX:07moO`1oOgl0Ogmo0`09jPX307moO`800000101oOgl0
0`09jPX0Ogmo07moO`0200WZ2PX0Ogmo00@02NX:07moO`1oOgl0Ogmo1@09jPX507moO`<02NX:601o
Ogl00`09jPX0Ogmo0000000907moO`0500WZ2P1oOgl02NX:07moO`09jPX03@1oOgl00`09jPX0Ogmo
07moO`0607moO`802NX:5@1oOgl00`09jPX0Ogmo07moO`0307moO`802NX:2`1oOglG00WZ2P030000
001oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX0000007moO`0:07moO`030000
001oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`09jPX0Ogmo07moO`0200WZ2P<0Ogmo
00<000000?ooo`3oool07P3oool00`09jPX0oooo0?ooo`0Q0?ooo`<02NX:3@3oool00`000000oooo
0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`090?ooo`0300WZ2P3oool0oooo03h0oooo00D0
2NX:0?ooo`3oool0oooo00WZ2P030?ooo`030000001oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl0
4@1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0000000`0Ogmo0P09jPX407moO`0300WZ
2P1oOgl02NX:00802NX:00<0000007moO`1oOgl00`1oOgl01009jPX0Ogmo00WZ2P09jPX207moO`80
2NX:201oOgl00`09jPX0Ogmo07moO`0407moO`D02NX:101oOgl500WZ2Q<0Ogmo00@02NX:07moO`1o
Ogl00000201oOgl00`09jPX0Ogmo00WZ2P0307moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<02NX:07mo
O`1oOgl0201oOgl200WZ2Q80Ogmo0P09jPX507moO`802NX:2P1oOgl20000000300WZ2P1oOgl02NX:
0080Ogmo1009jPX00`1oOgl02NX:00WZ2P0907moOaH02NX:201oOgl2000000T0Ogmo00<02NX:07mo
O`1oOgl02P1oOgl300WZ2PD0Ogmo00<000000?ooo`3oool07@3oool00`09jPX0oooo0?ooo`0U0?oo
o`802NX:2`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`090?ooo`03
00WZ2P3oool0oooo03h0oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`030000001oOgl0Ogmo
00L0Ogmo00<02NX:07moO`1oOgl03P1oOgl20000000307moO`09jPX0Ogmo00<0Ogmo00<02NX:07mo
O`0000002P1oOgl200WZ2PL0Ogmo00D02NX:07moO`09jPX0000000WZ2P0407moO`0300WZ2P1oOgl0
2NX:00H0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0807moO`@02NX:0P1oOgl0
0`09jPX0Ogmo07moO`0207moO`@02NX:3P1oOgl01009jPX0Ogmo07moO`00000807moO`0300WZ2P1o
Ogl02NX:00@0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`09jPX0Ogmo07moO`0807moO`030000001o
Ogl02NX:00802NX:3P1oOgl00`09jPX0Ogmo00WZ2P0507moO`802NX:2@1oOgl00`09jPX0000000WZ
2P0200WZ2P<0Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPX00`1oOgl02NX:00WZ2P0807moO`0300WZ
2P1oOgl0000000@0Ogmo00<02NX:07moO`1oOgl0201oOgl00`0000002NX:07moO`0E00WZ2PT0Ogmo
00<0000000WZ2P09jPX00P1oOgl00`09jPX0Ogmo07moO`0307moO`030000003oool0oooo01/0oooo
00<02NX:0?ooo`3oool09`3oool2000000X0oooo00<000000?ooo`3oool0303oool00800oooo00<0
00000?ooo`3oool0203oool00`09jPX0oooo0?ooo`0o0?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo
00<0000007moO`1oOgl01`1oOgl00`09jPX0Ogmo07moO`0>07moO`0400WZ2P0000002NX:00WZ2P@0
Ogmo00<02NX:07moO`000000201oOgl200WZ2PT0Ogmo00D02NX:0000000000002NX:07moO`0200WZ
2P0407moO`09jPX0Ogmo00WZ2PP0Ogmo0P09jPX407moO`0300WZ2P1oOgl0Ogmo00/0Ogmo1009jPX8
07moO`<02NX:2`1oOgl01009jPX0Ogmo07moO`00000707moO`0400WZ2P1oOgl02NX:000000D0Ogmo
00<02NX:07moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0807moO`030000001oOgl0Ogmo0080Ogmo
0P09jPX<07moO`0300WZ2P1oOgl02NX:00D0Ogmo0P09jPX607moO`<02NX:0P1oOgl200WZ2P<0Ogmo
0P09jPX507moO`802NX:00<0Ogmo00WZ2P09jPX01P1oOgl00`09jPX0Ogmo07moO`0200000080Ogmo
00<02NX:07moO`1oOgl0201oOgl00`0000002NX:07moO`0507moO`8000003@1oOgl<00WZ2P@0Ogmo
00<02NX:07moO`1oOgl00P1oOgl00`000000oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo02P0oooo
0P00000:0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo00P0oooo00<0
2NX:0?ooo`3oool0@03oool00`09jPX0oooo00WZ2P020?ooo`030000001oOgl0Ogmo00T0Ogmo00<0
2NX:07moO`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0300WZ2P0507moO`09jPX0Ogmo07moO`000000
1P1oOgl200WZ2P/0Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPX0101oOgl02NX:07moO`09jPX;07mo
O`802NX:00<0Ogmo00WZ2P1oOgl0401oOgl400WZ2PP0Ogmo1009jPX607moO`0500WZ2P1oOgl0Ogmo
07moO`0000001P1oOgl01@09jPX0Ogmo07moO`09jPX0000000D0Ogmo00<02NX:07moO`1oOgl02@1o
Ogl00`09jPX0Ogmo07moO`0807moO`030000001oOgl0Ogmo00@0Ogmo0`09jPX807moO`0400WZ2P1o
Ogl0Ogmo00WZ2PD0Ogmo0P09jPX207moO`@02NX:101oOgl300WZ2P<0Ogmo00<02NX:07moO`1oOgl0
1P1oOgl200WZ2P0307moO`09jPX0Ogmo00@0Ogmo00<02NX:07moO`1oOgl00P1oOgl010000000Ogmo
07moO`09jPX807moO`040000001oOgl0Ogmo00WZ2P<0Ogmo0P00000@07moO`0300WZ2P1oOgl0Ogmo
00@0Ogmo0P09jPX00`1oOgl02NX:07moO`0407moO`802NX:0`1oOgl00`000000oooo0?ooo`0H0?oo
o`0300WZ2P3oool0oooo03D0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3o
ool01`3oool00`09jPX0oooo0?ooo`110?ooo`802NX:0`3oool00`000000Ogmo07moO`0907moO`03
00WZ2P1oOgl0Ogmo00h0Ogmo00<02NX:07moO`09jPX00P1oOgl400WZ2P0307moO`000000Ogmo00<0
Ogmo00<02NX:07moO`1oOgl02P1oOgl00`0000002NX:07moO`0407moO`0400WZ2P0000002NX:00WZ
2Pd0Ogmo0P09jPXA07moO`0300WZ2P1oOgl0Ogmo00@02NX:2@1oOgl300WZ2P80Ogmo00D02NX:07mo
O`1oOgl0Ogmo0000000507moO`802NX:101oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0
Ogmo00T0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0607moO`802NX:1@1oOgl0
1@09jPX0Ogmo07moO`1oOgl02NX:00D0Ogmo1009jPX707moO`0400WZ2P1oOgl02NX:00WZ2P800000
0P09jPX:07moO`@02NX:101oOgl00`09jPX0Ogmo07moO`0207moO`030000001oOgl02NX:00P0Ogmo
00L0000007moO`1oOgl0Ogmo00WZ2P1oOgl000000180Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ
2P80Ogmo00<02NX:07moO`1oOgl01P1oOgl01009jPX0Ogmo07moO`00000I0?ooo`0300WZ2P3oool0
oooo03H0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool01P3oool00`09
jPX0oooo0?ooo`120?ooo`802NX:0`3oool00`000000Ogmo07moO`0907moO`0300WZ2P1oOgl0Ogmo
00l0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0300WZ2P0307moO`09jPX02NX:
00/0Ogmo0P00000207moO`0400WZ2P1oOgl0Ogmo07moO`802NX:0P0000000`1oOgl02NX:07moO`0;
07moO`0300WZ2P1oOgl02NX:0100Ogmo00<02NX:07moO`1oOgl00P1oOgl500WZ2PT0Ogmo1009jPX2
07moO`030000001oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`04
07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl0201oOgl00`000000Ogmo07moO`08
07moO`<02NX:00<0Ogmo00WZ2P1oOgl00`1oOgl01009jPX0Ogmo07moO`1oOgl400WZ2PP0Ogmo00H0
2NX:07moO`09jPX0Ogmo00WZ2P00000200WZ2Pd0Ogmo1009jPX207moO`0300WZ2P1oOgl0Ogmo00<0
Ogmo0P0000000`09jPX0Ogmo07moO`0507moO`060000001oOgl0Ogmo07moO`09jPX00000501oOgl0
1009jPX0Ogmo00WZ2P09jPX307moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<02NX:07moO`000000603o
ool00`09jPX0oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0
oooo00H0oooo00<02NX:0?ooo`3oool0@P3oool01@09jPX0oooo0?ooo`3oool0000000d0Ogmo00<0
2NX:07moO`1oOgl03P1oOgl200WZ2P80Ogmo00<02NX:07moO`1oOgl00P1oOgl2000000@02NX:2@1o
Ogl00`000000Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00802NX:0P1oOgl00`09jPX0Ogmo07mo
O`0200WZ2PX0Ogmo00<02NX:07moO`1oOgl00P09jPX>07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo1@09
jPX707moO`0300WZ2P1oOgl0Ogmo00<02NX:0`1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1o
Ogl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0807moO`030000001o
Ogl0Ogmo00/0Ogmo0P09jPX407moO`@02NX:0P1oOgl200WZ2PL0Ogmo00@02NX:07moO`1oOgl02NX:
0P1oOgl300WZ2Pl0Ogmo1@09jPX707moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00L0000007moO`1oOgl0
Ogmo0000001oOgl02NX:01@0Ogmo0P09jPX507moO`0300WZ2P1oOgl0Ogmo00T0Ogmo0P09jPX00`00
0000oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo03P0oooo00<000000?ooo`3oool0303oool00800
oooo00<000000?ooo`3oool01@3oool00`09jPX0oooo0?ooo`130?ooo`802NX:0P3oool00`000000
Ogmo07moO`0;07moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00D02NX:07moO`09jPX0Ogmo00WZ2P0307mo
O`802NX:00<0000007moO`1oOgl00P1oOgl300WZ2PD0Ogmo00<0000007moO`1oOgl00`1oOgl01009
jPX0Ogmo00WZ2P09jPX407moO`0500WZ2P1oOgl0Ogmo07moO`09jPX0201oOgl00`09jPX0Ogmo07mo
O`0307moO`802NX:301oOgl00`09jPX0Ogmo07moO`0707moO`H02NX:0`1oOgl00`09jPX0Ogmo07mo
O`0207moO`030000001oOgl02NX:00<02NX:201oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1o
Ogl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`0300WZ2P1o
Ogl0Ogmo00D02NX:1@1oOgl200WZ2PH0Ogmo00@02NX:07moO`1oOgl02NX:0`1oOgl200WZ2Q80Ogmo
1009jPX00`000000Ogmo07moO`0407moO`0300WZ2P000000Ogmo00<0Ogmo00@0000007moO`000000
00000P1oOgl00`09jPX0Ogmo07moO`0@07moO`802NX:00<0Ogmo00WZ2P1oOgl00`1oOgl00`09jPX0
Ogmo07moO`0<07moO`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0>@3oool00`000000
oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo0480oooo
00D02NX:0?ooo`09jPX0oooo0000000>07moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00<02NX:07moO`1o
Ogl00P09jPX01@1oOgl02NX:00WZ2P1oOgl0000000P0Ogmo1009jPX00`000000Ogmo07moO`0507mo
O`802NX:1P1oOgl01009jPX0Ogmo07moO`1oOgl200WZ2PH0Ogmo00<02NX:07moO`1oOgl01@1oOgl2
00WZ2PX0Ogmo00<02NX:07moO`1oOgl02P1oOgl200WZ2P0407moO`09jPX02NX:00WZ2PD0Ogmo00@0
000007moO`1oOgl02NX:0P1oOgl400WZ2PD0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo
07moO`0807moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0201oOgl500WZ2P0407mo
O`09jPX02NX:00WZ2PD0Ogmo0P09jPX507moO`0500WZ2P1oOgl0Ogmo07moO`09jPX00P1oOgl00`09
jPX0Ogmo00WZ2P0?07moO`T02NX:1@1oOgl00`09jPX0Ogmo0000000207moO`<000001@1oOgl00`09
jPX0Ogmo07moO`0=07moO`802NX:0`1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:0100Ogmo0P09jPXB
0?ooo`0300WZ2P3oool0oooo03X0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?oo
o`3oool0103oool00`09jPX0oooo0?ooo`130?ooo`0500WZ2P3oool02NX:0?ooo`0000003`1oOgl0
0`09jPX0Ogmo07moO`0=07moO`0300WZ2P1oOgl0Ogmo00<02NX:101oOgl00`000000Ogmo07moO`07
07moO`030000001oOgl02NX:00802NX:101oOgl200WZ2PP0Ogmo0P09jPX307moO`0300WZ2P1oOgl0
Ogmo0080Ogmo00<02NX:07moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1oOgl0
Ogmo00`0Ogmo1`09jPX207moO`0300000009jPX02NX:00L0Ogmo0`09jPX207moO`0300WZ2P1oOgl0
Ogmo00@0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`09jPX0Ogmo07moO`0907moO`030000001oOgl0
Ogmo00H0Ogmo0`09jPX707moO`<02NX:0`1oOgl200WZ2P<0Ogmo0P09jPX307moO`0500WZ2P1oOgl0
Ogmo00WZ2P1oOgl00P09jPX207moO`d02NX:1P1oOgl00`09jPX0Ogmo00WZ2P0200WZ2P@0Ogmo00D0
2NX:07moO`000000Ogmo0000000707moO`0300WZ2P1oOgl0Ogmo00/0Ogmo0P09jPX607moO`0400WZ
2P1oOgl0Ogmo00WZ2Q00Ogmo00<000000?ooo`09jPX0403oool00`09jPX0oooo0?ooo`0k0?ooo`03
0000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo00@0oooo00<02NX:0?ooo`3oool0
@`3oool01@09jPX0oooo00WZ2P3oool0000000l0Ogmo00<02NX:07moO`1oOgl0301oOgl00`09jPX0
Ogmo07moO`0200WZ2P0307moO`09jPX0Ogmo00<0Ogmo00<0000007moO`1oOgl01@1oOgl2000000D0
Ogmo1009jPX00`1oOgl02NX:07moO`0907moO`0400WZ2P1oOgl0Ogmo07moO`802NX:0P1oOgl00`09
jPX0Ogmo07moO`0907moO`802NX:1`1oOgl00`09jPX0Ogmo07moO`0>07moO`<02NX:0P1oOgl300WZ
2P`0Ogmo1009jPX507moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0207moO`@02NX:2@1oOgl00`09jPX0Ogmo07moO`0500WZ2P80Ogmo00<02NX:07mo
O`09jPX03009jPXC07moO`0400WZ2P1oOgl0Ogmo07moO`<02NX:0P1oOgl00`09jPX0Ogmo00000002
000000P0Ogmo00<02NX:07moO`1oOgl0201oOgl200WZ2PP0Ogmo00<02NX:07moO`09jPX04@1oOgl0
10000000oooo0?ooo`09jPX>0?ooo`0300WZ2P3oool0oooo03`0oooo00<000000?ooo`3oool0303o
ool00800oooo00<000000?ooo`3oool00`3oool00`09jPX0oooo0?ooo`130?ooo`0500WZ2P3oool0
oooo0?ooo`09jPX0401oOgl00`09jPX0Ogmo07moO`0<07moO`<02NX:00D0Ogmo00WZ2P1oOgl0Ogmo
00WZ2P0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01`1oOgl00`09jPX00000
00WZ2P0200WZ2PX0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2Ph0Ogmo0P09jPX607moO`0300WZ
2P1oOgl0Ogmo00`0Ogmo00@02NX:07moO`1oOgl0Ogmo1009jPX00`1oOgl02NX:00WZ2P0200WZ2P/0
Ogmo1009jPX307moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`000000
2NX:00WZ2P0200WZ2P80Ogmo00<02NX:07moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0207moO`03
00000009jPX02NX:00@02NX:0`1oOgl00`09jPX0Ogmo00WZ2P0207moO`0400WZ2P1oOgl0Ogmo00WZ
2Q<0Ogmo00<02NX:07moO`1oOgl0101oOgl300WZ2P0607moO`09jPX0Ogmo0000001oOgl000001`1o
Ogl00`09jPX0Ogmo07moO`0607moO`802NX:2P1oOgl200WZ2Q<0Ogmo00<000000?ooo`3oool00P09
jPX;0?ooo`0300WZ2P3oool0oooo03d0oooo00<000000?ooo`3oool0303oool00800oooo00<00000
0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`140?ooo`0500WZ2P3oool0oooo0?ooo`09jPX04@1o
Ogl00`09jPX0Ogmo07moO`0:07moO`8000000P1oOgl00`09jPX0Ogmo07moO`0207moO`0400WZ2P1o
Ogl0Ogmo000000D0Ogmo00<0000007moO`1oOgl01P1oOgl300WZ2P80Ogmo00<0000000WZ2P09jPX0
0`09jPX707moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P09jPX?07moO`802NX:101oOgl00`09jPX0Ogmo
07moO`0<07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0`09jPX407moO`<02NX:2@1oOgl00`09jPX0Ogmo
07moO`0400WZ2PP0Ogmo00<02NX:07moO`1oOgl0201oOgl300WZ2PD0Ogmo00<02NX:07moO`1oOgl0
2@1oOgl00`09jPX0Ogmo07moO`0407moO`802NX:1P1oOgl200WZ2P<0Ogmo00@02NX:07moO`1oOgl0
2NX:4`1oOgl00`09jPX0Ogmo07moO`0607moO`<02NX:00D0Ogmo0000001oOgl0Ogmo0000000707mo
O`0300WZ2P1oOgl0Ogmo00<0Ogmo0P09jPX=07moO`0300WZ2P1oOgl0Ogmo0140Ogmo00<000000?oo
o`3oool00P3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo03h0oooo00<000000?oo
o`3oool0303oool00800oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`130?ooo`06
00WZ2P3oool0oooo0?ooo`0000002NX:4@1oOgl00`09jPX0Ogmo07moO`0907moO`0300WZ2P000000
00000080Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo0000000307moO`800000201oOgl0
0`09jPX0Ogmo00WZ2P0307moO`8000000P1oOgl600WZ2P@0Ogmo00@02NX:07moO`1oOgl02NX:0P1o
Ogl00`09jPX0Ogmo07moO`0>07moO`0500WZ2P1oOgl0Ogmo07moO`09jPX03@1oOgl00`09jPX0Ogmo
07moO`0307moO`0400WZ2P000000Ogmo07moO`<02NX:101oOgl300WZ2PH0Ogmo00<02NX:07moO`1o
Ogl0101oOgl300WZ2PH0Ogmo00<02NX:07moO`1oOgl00`1oOgl400WZ2P<0Ogmo00D0000007moO`1o
Ogl0Ogmo00WZ2P0<07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl0101oOgl200WZ
2P<0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0@07moO`0300WZ2P1oOgl0Ogmo
00H0Ogmo00<0000007moO`09jPX00P09jPX307moO`8000001@1oOgl01009jPX0Ogmo07moO`1oOgl2
00WZ2Ph0Ogmo0P09jPXD07moO`030000003oool0oooo0080oooo00<02NX:0?ooo`3oool01@3oool0
0`09jPX0oooo0?ooo`0o0?ooo`030000003oool0oooo00`0oooo00200?ooo`050000003oool0oooo
0?ooo`09jPX0AP3oool01P09jPX0oooo0?ooo`3oool0000000WZ2Q40Ogmo00<02NX:07moO`1oOgl0
1`1oOgl200WZ2PD0Ogmo00<02NX:07moO`1oOgl0101oOgl01@09jPX0Ogmo0000001oOgl0000000T0
Ogmo00<02NX:07moO`09jPX02`1oOgl600WZ2P80Ogmo00<02NX:07moO`09jPX00`1oOgl200WZ2Pl0
Ogmo0P09jPX00`1oOgl02NX:07moO`0;07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`00
00001@1oOgl200WZ2PD0Ogmo0`09jPX407moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1o
Ogl01009jPX207moO`0300WZ2P1oOgl0Ogmo00<02NX:1`1oOgl010000000Ogmo07moO`09jPX=07mo
O`0300WZ2P1oOgl0Ogmo00<0Ogmo0P09jPX607moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07mo
O`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0@07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00@0000007mo
O`1oOgl0Ogmo0`09jPX407moO`030000001oOgl0Ogmo00<0Ogmo0`09jPX?07moO`0400WZ2P1oOgl0
Ogmo00WZ2Q<0Ogmo00<000000?ooo`3oool00`3oool200WZ2P@0oooo00<02NX:0?ooo`3oool0@03o
ool00`000000oooo0?ooo`0<0?ooo`00P03oool01@000000oooo0?ooo`3oool02NX:04D0oooo00<0
2NX:0?ooo`3oool00P3oool00`000000Ogmo00WZ2P0A07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo0P09
jPX707moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:0000000000002@1oOgl00`09jPX0Ogmo00WZ
2P0?07moO`P02NX:1@1oOgl00`09jPX0Ogmo07moO`0>07moO`802NX:301oOgl01009jPX0Ogmo07mo
O`1oOgl200WZ2P80Ogmo00<0000007moO`1oOgl01@1oOgl300WZ2PD0Ogmo0`09jPX00`1oOgl02NX:
07moO`0507moO`0300WZ2P1oOgl0Ogmo00<0Ogmo1@09jPX:07moO`030000001oOgl02NX:00h0Ogmo
00@02NX:07moO`1oOgl0Ogmo0P09jPX00`1oOgl02NX:07moO`0407moO`802NX:0`1oOgl00`09jPX0
Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`000000
Ogmo07moO`0207moO`0300000009jPX0Ogmo00802NX:0`1oOgl200000080Ogmo0P09jPXA07moO`04
00WZ2P1oOgl0Ogmo00WZ2Q<0Ogmo00<000000?ooo`3oool01@3oool01009jPX0oooo0?ooo`09jPY3
0?ooo`030000003oool0oooo00`0oooo00200?ooo`040000003oool0oooo00WZ2TH0oooo00D02NX:
0?ooo`3oool0oooo0000000207moO`0300WZ2P1oOgl0Ogmo00l0Ogmo00<02NX:07moO`1oOgl00P1o
Ogl200WZ2PP0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`09jPX0000007moO`0607moO`802NX:00<0
Ogmo00WZ2P1oOgl04P1oOgl700WZ2P@0Ogmo0P09jPX?07moO`<02NX:2@1oOgl01@09jPX0Ogmo07mo
O`1oOgl02NX:00<0Ogmo00<0000007moO`1oOgl02@1oOgl200WZ2PH0Ogmo0`09jPX507moO`0400WZ
2P1oOgl0Ogmo07moO`D02NX:00@0Ogmo00WZ2P09jPX02NX:2@1oOgl00`09jPX0Ogmo07moO`0=07mo
O`0400WZ2P1oOgl0Ogmo00WZ2P<0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2P@0Ogmo00<02NX:
07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0>07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`0000002NX:07moO`0207moO`<02NX:0P1oOgl200WZ2P80Ogmo00<02NX:
07moO`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo0140Ogmo00<00000
0?ooo`3oool01@3oool200WZ2T@0oooo00<000000?ooo`3oool0303oool00800oooo00@000000?oo
o`3oool02NX:A@3oool00`09jPX0oooo0?ooo`020?ooo`040000001oOgl0Ogmo00WZ2Q40Ogmo00<0
2NX:07moO`1oOgl00P09jPX:07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<02NX:000000000000101o
Ogl01009jPX0Ogmo07moO`09jPXG07moO`P02NX:0P1oOgl00`09jPX0Ogmo07moO`0<07moO`0400WZ
2P1oOgl0Ogmo00WZ2PL0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0407moO`030000001oOgl0Ogmo
00/0Ogmo0`09jPX507moO`@02NX:0`1oOgl300WZ2P@0Ogmo00<02NX:07moO`1oOgl00P1oOgl400WZ
2P@0Ogmo00<02NX:0000001oOgl03P1oOgl00`09jPX0Ogmo00WZ2P0407moO`0700WZ2P1oOgl0Ogmo
07moO`09jPX0Ogmo00WZ2P0407moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl03P1o
Ogl00`09jPX0Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00@0000007moO`1oOgl02NX:
101oOgl300WZ2P0307moO`000000Ogmo0080Ogmo00<02NX:07moO`1oOgl02`1oOgl00`09jPX0Ogmo
07moO`0307moO`0300WZ2P1oOgl0Ogmo0140Ogmo00<000000?ooo`3oool01@3oool300WZ2T<0oooo
00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`09jPX0AP3oool01@09jPX0oooo0?oo
o`3oool0000000@0Ogmo00<02NX:07moO`1oOgl03`1oOgl200WZ2P`0Ogmo00<02NX:07moO`1oOgl0
2@1oOgl00`09jPX0Ogmo0000000207moO`0400WZ2P1oOgl0Ogmo00WZ2QL0Ogmo00<02NX:07moO`1o
Ogl00P1oOgl300WZ2P0307moO`09jPX02NX:00<02NX:301oOgl01009jPX0Ogmo07moO`1oOgl200WZ
2PD0Ogmo00@02NX:07moO`1oOgl02NX:1@1oOgl00`000000Ogmo07moO`0>07moO`802NX:101oOgl0
0`09jPX0Ogmo07moO`0600WZ2P@0Ogmo00<02NX:07moO`1oOgl01P1oOgl400WZ2P0307moO`000000
Ogmo00h0Ogmo0P09jPX507moO`0600WZ2P1oOgl0Ogmo00WZ2P1oOgl02NX:101oOgl00`09jPX0Ogmo
07moO`0607moO`0300WZ2P1oOgl0Ogmo00d0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000Ogmo
07moO`0407moO`040000001oOgl0Ogmo00WZ2P<0Ogmo0P09jPX0101oOgl02NX:00WZ2P09jPX20000
000307moO`09jPX0Ogmo00`0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0A07mo
O`030000003oool0oooo00<0oooo00D02NX:0?ooo`3oool0oooo00WZ2P120?ooo`030000003oool0
oooo00`0oooo00200?ooo`0300000009jPX0oooo04H0oooo00D02NX:0?ooo`3oool0oooo00000004
07moO`0300WZ2P1oOgl0Ogmo00d0Ogmo0`09jPX<07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00@02NX:
07moO`0000002NX:0P1oOgl00`09jPX0Ogmo07moO`0F07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<0
2NX:07moO`09jPX00P09jPX00`1oOgl02NX:00WZ2P0200WZ2PX0Ogmo00<02NX:07moO`1oOgl00`1o
Ogl200WZ2P80Ogmo00@02NX:07moO`1oOgl02NX:1@1oOgl00`000000Ogmo07moO`0A07moO`<02NX:
00@0Ogmo00WZ2P1oOgl0Ogmo0P00000207moO`0300WZ2P1oOgl02NX:00P02NX:1P1oOgl500WZ2Ph0
Ogmo00<02NX:07moO`1oOgl0101oOgl01009jPX0Ogmo00WZ2P1oOgl2000000@0Ogmo00<02NX:07mo
O`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000007mo
O`1oOgl01@1oOgl010000000Ogmo07moO`1oOgl300WZ2PD0Ogmo0`09jPX00`000000Ogmo00WZ2P0;
07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl04@1oOgl00`000000oooo0?ooo`02
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0?`3oool00`000000oooo0?ooo`0<
0?ooo`00P03oool2000004H0oooo00<02NX:0?ooo`3oool00P3oool00`000000Ogmo07moO`0207mo
O`0300WZ2P1oOgl0Ogmo00/0Ogmo0P09jPX207moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<02NX:07mo
O`1oOgl0301oOgl200WZ2P0307moO`0000002NX:01P0Ogmo00<02NX:07moO`1oOgl01@1oOgl01009
jPX0Ogmo07moO`1oOgl300WZ2P0307moO`09jPX02NX:00802NX:1`1oOgl00`09jPX0Ogmo07moO`05
07moO`802NX:00<0Ogmo00WZ2P09jPX01P1oOgl00`000000Ogmo07moO`0D07moO`<02NX:1@1oOgl0
0`09jPX0Ogmo07moO`0407moO`0400WZ2P1oOgl0Ogmo07moO`T02NX:00<0Ogmo00000009jPX00P09
jPX907moO`<02NX:1P1oOgl200WZ2P80Ogmo0P09jPX307moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<0
2NX:07moO`1oOgl02`1oOgl01@09jPX0Ogmo07moO`1oOgl0000000P0Ogmo00D0000007moO`1oOgl0
Ogmo00WZ2P0907moO`@02NX:2P1oOgl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1oOgl0Ogmo0100
Ogmo00D000000?ooo`3oool0oooo00WZ2P070?ooo`802NX:?`3oool00`000000oooo0?ooo`0<0?oo
o`00P03oool2000004H0oooo00D02NX:0?ooo`3oool0oooo0000000507moO`0300WZ2P1oOgl0Ogmo
00T0Ogmo0P09jPX407moO`0300000009jPX0Ogmo00X0Ogmo00<02NX:07moO`1oOgl02`1oOgl01P09
jPX0Ogmo00WZ2P1oOgl02NX:07moO`8000005P1oOgl00`09jPX0Ogmo07moO`0607moO`802NX:101o
Ogl400WZ2P0307moO`09jPX02NX:00802NX:0`1oOgl00`09jPX0Ogmo07moO`0607moO`802NX:201o
Ogl00`000000Ogmo07moO`0F07moO`<02NX:101oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1o
Ogl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl00P1oOgl900WZ2P@0Ogmo00@02NX:07moO`1oOgl02NX:
1P1oOgl00`09jPX0Ogmo07moO`0307moO`0400WZ2P1oOgl0Ogmo00WZ2PX0Ogmo00<02NX:07moO`1o
Ogl02`1oOgl01009jPX0Ogmo07moO`00000807moO`030000001oOgl0Ogmo00<02NX:2P1oOgl01000
00002NX:00WZ2P09jPX807moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl04@1oOgl0
0`000000oooo00WZ2P0:0?ooo`0300WZ2P3oool0oooo03`0oooo00<000000?ooo`3oool0303oool0
0800oooo00<000000?ooo`3oool0A03oool00`09jPX0oooo0?ooo`020?ooo`030000001oOgl0Ogmo
00@0Ogmo00<02NX:07moO`1oOgl01P1oOgl200WZ2PH0Ogmo0P00000:07moO`0300WZ2P1oOgl0Ogmo
00/0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0407moO`8000004`1oOgl00`09jPX0Ogmo07moO`09
07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo0`09jPX207moO`@02NX:1`1oOgl200WZ2P0307moO`09jPX0
2NX:00D0Ogmo00<0000007moO`1oOgl0601oOgl01009jPX0Ogmo00WZ2P09jPX207moO`0300WZ2P1o
Ogl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0507moO`030000001o
Ogl0Ogmo00@0Ogmo2@09jPX407moO`802NX:1P1oOgl200WZ2P/0Ogmo00<02NX:07moO`1oOgl02P1o
Ogl01009jPX0Ogmo07moO`00000907moO`0300000009jPX02NX:00<0Ogmo00<02NX:07moO`1oOgl0
2P1oOgl400WZ2PD0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0@07moO`030000
0009jPX0oooo00/0oooo00<02NX:0?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`00P03o
ool00`000000oooo0?ooo`140?ooo`0500WZ2P3oool0oooo0?ooo`0000001`1oOgl00`09jPX0Ogmo
07moO`0507moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`09jPX0Ogmo
07moO`0:07moO`0700WZ2P1oOgl0Ogmo07moO`09jPX0Ogmo00WZ2P0507moO`030000001oOgl0Ogmo
0100Ogmo00<02NX:07moO`1oOgl02P1oOgl00`09jPX0Ogmo07moO`0607moO`@02NX:0P1oOgl400WZ
2P<0Ogmo0P09jPX407moO`802NX:0`1oOgl00`000000Ogmo07moO`0H07moO`0400WZ2P1oOgl0Ogmo
07moO`@02NX:101oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<00000
07moO`1oOgl01P1oOgl00`09jPX0Ogmo00WZ2P0300WZ2P0307moO`09jPX02NX:00L02NX:101oOgl2
00WZ2P/0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX000000000000907moO`802NX:1@1oOgl0
0`09jPX0Ogmo07moO`0;07moO`D02NX:0P1oOgl00`09jPX0Ogmo07moO`0:07moO`0300WZ2P1oOgl0
Ogmo0100Ogmo00<02NX:0000003oool0303oool200WZ2S/0oooo00<000000?ooo`3oool0303oool0
0800oooo00<000000?ooo`3oool0@`3oool00`09jPX0oooo0?ooo`020?ooo`030000001oOgl0Ogmo
00D0Ogmo00<02NX:07moO`1oOgl00`1oOgl200WZ2P`0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09
jPX0Ogmo07moO`0907moO`0500WZ2P1oOgl0Ogmo07moO`09jPX00P1oOgl00`0000002NX:00WZ2P04
07moO`8000003`1oOgl00`09jPX0Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo0P09jPX0
0`1oOgl02NX:00WZ2P0200WZ2P80Ogmo1009jPX707moO`802NX:00<0Ogmo0000001oOgl06P1oOgl0
0`09jPX0Ogmo07moO`0307moO`802NX:0`1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0
Ogmo00L0Ogmo00<0000007moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0307moO`D02NX:0P1oOgl0
1009jPX0Ogmo07moO`1oOgl400WZ2P80Ogmo00<02NX:07moO`1oOgl0201oOgl00`09jPX0Ogmo07mo
O`0907moO`0300WZ2P1oOgl0Ogmo00L0Ogmo0P09jPX00`1oOgl0000007moO`0507moO`0300WZ2P1o
Ogl0Ogmo00X0Ogmo00D02NX:07moO`1oOgl02NX:07moO`0200WZ2Ph0Ogmo00<02NX:07moO`1oOgl0
3P1oOgl00`09jPX0Ogmo0000000?0?ooo`0300WZ2P3oool0oooo03P0oooo00<000000?ooo`3oool0
303oool00800oooo00<000000?ooo`3oool0@`3oool00`09jPX0oooo0?ooo`020?ooo`030000001o
Ogl0Ogmo00D0Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPX>07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo
00<02NX:07moO`1oOgl0201oOgl200WZ2P<0Ogmo00@02NX:07moO`1oOgl0Ogmo0P0000000`1oOgl0
2NX:07moO`0407moO`8000003@1oOgl00`09jPX0Ogmo07moO`0=07moO`0300WZ2P1oOgl0Ogmo00L0
Ogmo00@02NX:07moO`1oOgl0Ogmo0`09jPX207moO`D02NX:1P1oOgl00`09jPX0Ogmo07moO`0J07mo
O`0300WZ2P1oOgl0Ogmo00@0Ogmo0`09jPX00`1oOgl02NX:07moO`0207moO`0300WZ2P1oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0307moO`0400WZ2P1oOgl0Ogmo
07moO`D02NX:1@1oOgl2000000<0Ogmo0P09jPX907moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<00000
00WZ2P1oOgl01P1oOgl200WZ2P80Ogmo00<0000007moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0;
07moO`0300WZ2P1oOgl0Ogmo00H02NX:2`1oOgl00`09jPX0Ogmo07moO`0=07moO`0400WZ2P1oOgl0
Ogmo00000100oooo0P09jPXh0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0
oooo04<0oooo00D02NX:0?ooo`3oool0oooo0000000907moO`<02NX:4@1oOgl00`09jPX0Ogmo07mo
O`0407moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07mo
O`0607moO`0300WZ2P1oOgl0Ogmo00@0Ogmo0P00000:07moO`0300WZ2P1oOgl0Ogmo00l0Ogmo00<0
2NX:07moO`1oOgl01`1oOgl200WZ2P0407moO`09jPX0Ogmo07moO`802NX:00<0000007moO`1oOgl0
0P1oOgl300WZ2P<0Ogmo00<0000000WZ2P09jPX06`1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ
2P1oOgl0Ogmo00<02NX:00<0Ogmo00WZ2P1oOgl02`1oOgl010000000Ogmo07moO`1oOgl200WZ2PH0
Ogmo00@02NX:07moO`1oOgl02NX:101oOgl400WZ2PT0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09
jPX0Ogmo07moO`0607moO`0300000009jPX0Ogmo00D0Ogmo0P09jPX407moO`030000001oOgl0Ogmo
00H0Ogmo00<02NX:07moO`1oOgl02P1oOgl01009jPX0Ogmo07moO`1oOgl300WZ2P80Ogmo0P09jPX9
07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000oooo0?ooo`0?
0?ooo`0300WZ2P3oool0oooo03D0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?oo
o`3oool0@P3oool00`09jPX0oooo0?ooo`020?ooo`030000001oOgl0Ogmo00H0Ogmo0P09jPXD07mo
O`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0207mo
O`0300WZ2P1oOgl0Ogmo00P0Ogmo0P09jPX607moO`800000201oOgl00`09jPX0Ogmo07moO`0@07mo
O`802NX:2@1oOgl00`09jPX000000000000207moO`8000001`1oOgl400WZ2P80Ogmo0P09jPXI07mo
O`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl00P1oOgl300WZ2P`0Ogmo00@0000007mo
O`1oOgl02NX:201oOgl00`09jPX0Ogmo00WZ2P0507moO`0400WZ2P1oOgl0Ogmo07moO`<02NX:1`1o
Ogl200WZ2PL0Ogmo00<02NX:07moO`1oOgl0101oOgl00`000000Ogmo00WZ2P0407moO`802NX:1P1o
Ogl00`000000Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<02NX:07moO`09jPX00P1o
Ogl00`0000002NX:00WZ2P0207moO`802NX:201oOgl00`09jPX0Ogmo07moO`0:07moO`0300WZ2P1o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0403oool00`09jPX0oooo0?ooo`0d0?ooo`030000003o
ool0oooo00`0oooo00200?ooo`030000003oool0oooo0480oooo00D02NX:0?ooo`3oool0oooo0000
000707moO`802NX:00<0Ogmo00WZ2P1oOgl04`1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1o
Ogl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0;07moO`0300WZ2P1o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl00`1oOgl200WZ2QD0Ogmo00<02NX:07moO`1oOgl01`1o
Ogl01009jPX0000007moO`09jPX<07moO`0500000009jPX02NX:00WZ2P1oOgl00P09jPXH07moO`03
00WZ2P1oOgl0Ogmo00<0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0207moO`<02NX:2P1oOgl00`00
00002NX:07moO`0807moO`802NX:1P1oOgl00`09jPX0Ogmo07moO`0407moO`@02NX:1@1oOgl00`09
jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00@0000007moO`1oOgl02NX:0P1oOgl2
00WZ2PP0Ogmo00<0000007moO`1oOgl01`1oOgl00`09jPX0Ogmo07moO`0:07moO`0300WZ2P1oOgl0
2NX:00<0Ogmo00@0000007moO`09jPX02NX:0P1oOgl200WZ2PH0Ogmo00<02NX:07moO`1oOgl02@1o
Ogl00`09jPX0Ogmo07moO`0507moO`030000003oool0oooo0100oooo0P09jPXd0?ooo`030000003o
ool0oooo00`0oooo00200?ooo`030000003oool0oooo0440oooo00<02NX:0?ooo`3oool00P3oool0
0`000000Ogmo07moO`0307moO`802NX:0`1oOgl00`09jPX0Ogmo07moO`0C07moO`0500WZ2P1oOgl0
Ogmo07moO`09jPX01P1oOgl200WZ2P@0Ogmo00<02NX:07moO`1oOgl03@1oOgl00`09jPX0Ogmo07mo
O`0507moO`8000000P1oOgl00`09jPX000000000000F07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo0P09
jPX<07moO`030000001oOgl0Ogmo0080Ogmo1009jPXG07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<0
2NX:07moO`1oOgl00P09jPX507moO`802NX:201oOgl00`09jPX0Ogmo07moO`0807moO`0300WZ2P1o
Ogl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl0201oOgl400WZ2P80Ogmo0P09jPX407moO`0300WZ2P1o
Ogl0Ogmo0080Ogmo00@0000007moO`1oOgl0Ogmo0`09jPX907moO`030000001oOgl0Ogmo00P0Ogmo
00<02NX:07moO`1oOgl02`1oOgl00`09jPX0Ogmo07moO`0307moO`80000000<0Ogmo00WZ2P000000
0P1oOgl300WZ2P@0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`09jPX0Ogmo07moO`0607moO`030000
003oool0oooo0180oooo00<02NX:0?ooo`3oool0<@3oool00`000000oooo0?ooo`0<0?ooo`00P03o
ool00`000000oooo0?ooo`110?ooo`0300WZ2P3oool0oooo0080oooo00@0000007moO`1oOgl0Ogmo
0P09jPX607moO`0300WZ2P1oOgl0Ogmo01<0Ogmo00@02NX:07moO`1oOgl02NX:1@1oOgl00`09jPX0
Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00l0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`000000
2NX:07moO`0I07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:000000000000301oOgl00`000000
Ogmo07moO`0607moO`<02NX:5@1oOgl00`09jPX0Ogmo07moO`0307moO`802NX:00<0Ogmo00WZ2P1o
Ogl01P1oOgl300WZ2P@0Ogmo00<02NX:0000001oOgl0201oOgl200WZ2PL0Ogmo00<02NX:07moO`1o
Ogl0301oOgl300WZ2P0307moO`09jPX0Ogmo00<0Ogmo00@02NX:0000001oOgl000000`1oOgl200WZ
2P/0Ogmo00<0000007moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0907moO`0300WZ2P1oOgl02NX:
00H0Ogmo0`00000507moO`802NX:0P1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo
00L0Ogmo00<000000?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0`0?ooo`030000003oool0oooo
00`0oooo00200?ooo`030000003oool0oooo0400oooo00<02NX:0?ooo`3oool00P3oool00`000000
Ogmo07moO`0200WZ2PP0Ogmo00<02NX:07moO`1oOgl04`1oOgl01009jPX0Ogmo07moO`09jPX407mo
O`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl04@1oOgl200WZ2PH0Ogmo00@02NX:07mo
O`00000000006@1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00d0Ogmo00<00000
07moO`1oOgl0201oOgl500WZ2Q40Ogmo00<02NX:07moO`1oOgl00P1oOgl01@0000002NX:07moO`1o
Ogl02NX:00X0Ogmo0P09jPX01@1oOgl02NX:07moO`1oOgl0000000L0Ogmo00<02NX:07moO`09jPX0
1`1oOgl00`09jPX0Ogmo07moO`0?07moO`@02NX:0P1oOgl00`09jPX000000000000207moO`<02NX:
301oOgl00`000000Ogmo07moO`0907moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<02NX:07moO`09jPX0
1P1oOgl00`09jPX000000000000707moO`802NX:00<0Ogmo00WZ2P1oOgl01@1oOgl00`09jPX0Ogmo
07moO`0907moO`030000003oool0oooo01<0oooo0P09jPX`0?ooo`030000003oool0oooo00`0oooo
00200?ooo`030000003oool0oooo0400oooo00<02NX:0?ooo`3oool00P3oool00`0000002NX:00WZ
2P0:07moO`0300WZ2P1oOgl0Ogmo01@0Ogmo0P09jPX407moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<0
2NX:07moO`1oOgl0501oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P00
000H07moO`0500WZ2P1oOgl0Ogmo07moO`09jPX03`1oOgl00`000000Ogmo07moO`0;07moO`802NX:
00@0Ogmo00WZ2P09jPX02NX:3`1oOgl01009jPX0Ogmo07moO`1oOgl20000000300WZ2P1oOgl02NX:
00/0Ogmo1009jPX00`1oOgl0000007moO`0507moO`0400WZ2P1oOgl0Ogmo00WZ2PL0Ogmo00<02NX:
07moO`1oOgl04`1oOgl300WZ2P040000001oOgl02NX:00WZ2P80Ogmo00<02NX:07moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00D02NX:07moO`1oOgl0Ogmo
00WZ2P0507moO`0400WZ2P000000Ogmo000000P0Ogmo0P09jPX507moO`0300WZ2P1oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool05@3oool00`09jPX0oooo0?ooo`0]0?ooo`030000003oool0oooo00`0
oooo00200?ooo`030000003oool0oooo03l0oooo00<02NX:0?ooo`3oool00P3oool200WZ2P`0Ogmo
00<02NX:07moO`1oOgl05@1oOgl00`09jPX0Ogmo07moO`0200WZ2PD0Ogmo00<02NX:07moO`1oOgl0
5P1oOgl01009jPX0Ogmo07moO`09jPX707moO`030000001oOgl0Ogmo01H0Ogmo0`09jPX@07moO`03
0000001oOgl0Ogmo00d0Ogmo00@02NX:07moO`1oOgl0Ogmo1009jPX;07moO`0300WZ2P1oOgl0Ogmo
00<0Ogmo00<02NX:07moO`09jPX02P1oOgl00`09jPX0Ogmo07moO`0207moO`802NX:1@1oOgl01@09
jPX0Ogmo07moO`1oOgl02NX:00L0Ogmo00<02NX:07moO`1oOgl0501oOgl600WZ2P80Ogmo00<02NX:
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0;07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:
07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl02NX:0080Ogmo00<00000
07moO`1oOgl01P1oOgl01P0000002NX:00WZ2P09jPX0Ogmo00WZ2Ph0Ogmo00<000000?ooo`3oool0
5@3oool00`09jPX0oooo0?ooo`0/0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003o
ool0oooo03l0oooo00H02NX:0?ooo`3oool0oooo00WZ2P00000>07moO`0300WZ2P1oOgl0Ogmo01@0
Ogmo00<02NX:07moO`09jPX01P1oOgl00`09jPX0Ogmo07moO`0H07moO`802NX:2@1oOgl2000001L0
Ogmo0P09jPX@07moO`030000001oOgl0Ogmo00h0Ogmo0P09jPX507moO`<02NX:2@1oOgl00`09jPX0
Ogmo07moO`0307moO`0300WZ2P1oOgl02NX:00P0Ogmo00<02NX:07moO`1oOgl0101oOgl01P000000
2NX:00WZ2P09jPX0000000WZ2P@0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0D
07moO`<02NX:0`1oOgl300WZ2P/0Ogmo00<0000007moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`05
07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00@02NX:07moO`1oOgl02NX:0`1oOgl00`09jPX0Ogmo07mo
O`02000000H0Ogmo0P00000207moO`802NX:3P1oOgl00`000000oooo0?ooo`0F0?ooo`802NX:;03o
ool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0o0?ooo`0500WZ2P3oool0
2NX:00WZ2P0000003`1oOgl00`09jPX0000007moO`0C07moO`0300WZ2P1oOgl02NX:00H0Ogmo00<0
2NX:07moO`1oOgl06@1oOgl00`09jPX0Ogmo00WZ2P0:07moO`800000501oOgl01009jPX0Ogmo07mo
O`09jPX>07moO`030000001oOgl0Ogmo0140Ogmo0P09jPX607moO`@02NX:1@1oOgl00`09jPX0Ogmo
07moO`0307moO`0300WZ2P1oOgl02NX:00L0Ogmo00<02NX:07moO`1oOgl01P1oOgl010000000Ogmo
00000009jPX507moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl04P1oOgl200WZ2P80
Ogmo0P09jPX307moO`0300WZ2P1oOgl02NX:00<02NX:1`1oOgl00`000000Ogmo07moO`0<07moO`03
00WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo00WZ2P0407moO`03
00WZ2P1oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0101oOgl00`09jPX0Ogmo00WZ2P0207moO`80
2NX:3@1oOgl00`000000oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo02T0oooo00<000000?ooo`3o
ool0303oool00800oooo00<000000?ooo`3oool0?P3oool300WZ2P80oooo00<0000007moO`1oOgl0
3@1oOgl00`09jPX0000007moO`0C07moO`802NX:00<0Ogmo00WZ2P1oOgl00`1oOgl00`09jPX0Ogmo
07moO`0I07moO`0500WZ2P1oOgl0Ogmo07moO`09jPX02`1oOgl200000140Ogmo00<02NX:07moO`1o
Ogl00P1oOgl00`09jPX0Ogmo07moO`0;07moO`030000001oOgl0Ogmo01<0Ogmo0P09jPX807moO`@0
2NX:0P1oOgl00`09jPX0Ogmo07moO`0307moO`802NX:1P1oOgl00`09jPX0Ogmo07moO`0707moO`03
0000001oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0@07moO`80
2NX:00H0000007moO`1oOgl0Ogmo00WZ2P1oOgl20000000307moO`09jPX0Ogmo00@0Ogmo1009jPX3
07moO`030000001oOgl0Ogmo00d0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`06
07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl00P1oOgl2000000@0Ogmo00<00000
00WZ2P1oOgl0101oOgl300WZ2PX0Ogmo00<000000?ooo`3oool0603oool00`09jPX0oooo0?ooo`0X
0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo03d0oooo0P09jPX40?oo
o`030000001oOgl0Ogmo00h0Ogmo00<02NX:07moO`1oOgl04@1oOgl200WZ2P030000001oOgl02NX:
00<0Ogmo00<02NX:07moO`1oOgl06@1oOgl00`09jPX0Ogmo07moO`0307moO`802NX:2`1oOgl00`00
0000Ogmo07moO`0=07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0E07moO`0300WZ2P1oOgl0Ogmo00T0Ogmo0`09jPX507moO`802NX:1@1oOgl00`09
jPX0Ogmo07moO`0807moO`030000001oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09
jPX0Ogmo07moO`0>07moO`802NX:00<0000007moO`1oOgl00`1oOgl01P09jPX0Ogmo000000000000
Ogmo00WZ2PT0Ogmo0`09jPX@07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl01@1o
Ogl200WZ2PL0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0200WZ2P030000001o
Ogl0Ogmo00H0Ogmo0P09jPX807moO`030000003oool0oooo01T0oooo0P09jPXX0?ooo`030000003o
ool0oooo00`0oooo00200?ooo`030000003oool0oooo03/0oooo0`09jPX40?ooo`030000001oOgl0
Ogmo0100Ogmo00<02NX:07moO`1oOgl03`1oOgl200WZ2P8000000P1oOgl00`09jPX000000000000K
07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl02@1oOgl2000000`0Ogmo00<02NX:
07moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0807moO`030000001oOgl0Ogmo01L0Ogmo0P09jPX<
07moO`@02NX:00<0Ogmo00000009jPX00`1oOgl200WZ2P`0Ogmo00<0000007moO`1oOgl0101oOgl0
0`0000002NX:07moO`0607moO`0300WZ2P1oOgl0Ogmo00d0Ogmo00<02NX:07moO`0000001P1oOgl0
1@09jPX0Ogmo07moO`1oOgl02NX:00`0Ogmo00<0000000WZ2P09jPX00P09jPX=07moO`0400WZ2P1o
Ogl0Ogmo00WZ2PP0Ogmo00<02NX:07moO`09jPX01P1oOgl00`09jPX0Ogmo07moO`0407moO`050000
0009jPX0Ogmo07moO`09jPX02P1oOgl00`09jPX0000007moO`0607moO`030000003oool0oooo01X0
oooo00<02NX:0?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo
0?ooo`0i0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`030000001oOgl0Ogmo0100Ogmo
00<02NX:07moO`1oOgl03P1oOgl00`09jPX0Ogmo00WZ2P0507moO`0300WZ2P000000Ogmo01T0Ogmo
00<02NX:07moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0:07moO`8000002@1oOgl00`09jPX0Ogmo
07moO`0807moO`802NX:201oOgl00`000000Ogmo07moO`0I07moO`802NX:2`1oOgl00`09jPX0Ogmo
07moO`0300WZ2P80Ogmo00<02NX:07moO`1oOgl0301oOgl00`000000Ogmo07moO`0407moO`030000
0009jPX0Ogmo00H0Ogmo00<02NX:07moO`1oOgl02`1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo
00D02NX:07moO`1oOgl0Ogmo00WZ2P0<07moO`030000001oOgl0Ogmo0080Ogmo0`09jPX:07moO`04
00WZ2P1oOgl02NX:000000L0Ogmo00@02NX:07moO`1oOgl02NX:1`1oOgl00`09jPX0Ogmo07moO`02
07moO`802NX:0P00000207moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<02NX:0000001oOgl01P1oOgl0
0`000000oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo02@0oooo00<000000?ooo`3oool0303oool0
0800oooo00<000000?ooo`3oool0=`3oool200WZ2P<0oooo00<02NX:0?ooo`3oool00P3oool00`00
0000Ogmo07moO`0B07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00@02NX:07moO`1oOgl02NX:801oOgl0
0`09jPX0Ogmo07moO`0:07moO`802NX:301oOgl2000000H0Ogmo00<02NX:07moO`1oOgl02`1oOgl0
0`09jPX0Ogmo07moO`0507moO`030000001oOgl0Ogmo01/0Ogmo0P09jPX907moO`0300WZ2P1oOgl0
Ogmo0080Ogmo1@09jPX=07moO`030000001oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl0101oOgl0
0`09jPX0Ogmo07moO`0907moO`802NX:0P1oOgl00`000000Ogmo07moO`0707moO`0400WZ2P1oOgl0
Ogmo00WZ2P`0Ogmo00<0000007moO`1oOgl01@1oOgl00`0000002NX:00WZ2P0300WZ2PD0Ogmo00<0
2NX:0000000000001P1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00@0
2NX:07moO`1oOgl02NX:101oOgl00`000000Ogmo00WZ2P0807moO`0300WZ2P1oOgl0Ogmo00P0Ogmo
00<000000?ooo`3oool06`3oool200WZ2R@0oooo00<000000?ooo`3oool0303oool00800oooo00<0
00000?ooo`3oool0=@3oool200WZ2PD0oooo00<02NX:0?ooo`3oool00P3oool00`000000Ogmo07mo
O`0C07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<02NX:07moO`1oOgl00P00000O07moO`0300WZ2P1o
Ogl0Ogmo00d0Ogmo00<02NX:07moO`1oOgl02`1oOgl2000000<0Ogmo00<02NX:07moO`1oOgl03@1o
Ogl00`09jPX0Ogmo07moO`0307moO`030000001oOgl0Ogmo01h0Ogmo00<02NX:07moO`1oOgl01`1o
Ogl00`09jPX0Ogmo07moO`0207moO`0400WZ2P1oOgl0Ogmo07moO`<02NX:2`1oOgl00`000000Ogmo
07moO`0507moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl01`1oOgl200WZ2P<0Ogmo
00<0000007moO`1oOgl0201oOgl00`09jPX0Ogmo00WZ2P0<07moO`030000001oOgl0Ogmo00H0Ogmo
0P00000407moO`L02NX:1P1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00D0Ogmo
00<02NX:07moO`09jPX01P1oOgl00`0000002NX:07moO`0707moO`0300WZ2P1oOgl0Ogmo00P0Ogmo
00<000000?ooo`3oool07@3oool00`09jPX0oooo0?ooo`0Q0?ooo`030000003oool0oooo00`0oooo
00200?ooo`030000003oool0oooo03<0oooo0P09jPX70?ooo`0300WZ2P3oool0oooo0080oooo00<0
000007moO`1oOgl0501oOgl00`09jPX0Ogmo07moO`0707moO`802NX:0`1oOgl00`09jPX0000007mo
O`0M07moO`0300WZ2P1oOgl0Ogmo00l0Ogmo00<02NX:07moO`1oOgl0301oOgl00`000000Ogmo00WZ
2P0A07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl07`1oOgl200WZ2PL0Ogmo00@0
2NX:07moO`1oOgl0Ogmo0`09jPX507moO`@02NX:1`1oOgl00`000000Ogmo07moO`0507moO`0300WZ
2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl01@1oOgl200WZ2P@0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`09jPX0Ogmo00WZ2P0<07moO`030000001oOgl0Ogmo0100Ogmo0P09jPX00`1oOgl02NX:
00WZ2P0600WZ2PD0Ogmo00<02NX:07moO`1oOgl0101oOgl200WZ2PP0Ogmo00<0000000WZ2P1oOgl0
1P1oOgl00`09jPX0Ogmo07moO`0807moO`030000003oool0oooo01h0oooo0P09jPXQ0?ooo`030000
003oool0oooo00`0oooo00200?ooo`030000003oool0oooo0340oooo0P09jPX80?ooo`0300WZ2P3o
ool0oooo0080oooo00<0000007moO`1oOgl05@1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1o
Ogl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0701oOgl00`09jPX0Ogmo07moO`0A07moO`0300WZ2P1o
Ogl0Ogmo00`0Ogmo00<02NX:0000001oOgl04@1oOgl01@09jPX0Ogmo07moO`1oOgl0000002<0Ogmo
0P09jPX607moO`0300WZ2P1oOgl02NX:0080000000<02NX:07moO`1oOgl01`1oOgl300WZ2P@0Ogmo
00<0000007moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00<0Ogmo
0P09jPX507moO`030000001oOgl0Ogmo00X0Ogmo00<02NX:07moO`09jPX0301oOgl00`000000Ogmo
07moO`0?07moO`0400WZ2P1oOgl0Ogmo00WZ2P@0Ogmo00@02NX:07moO`1oOgl0Ogmo1`09jPX407mo
O`0400WZ2P1oOgl0Ogmo00WZ2PP0Ogmo00<02NX:0000001oOgl0101oOgl00`09jPX0Ogmo07moO`0:
07moO`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool07P3oool00`000000oooo0?ooo`0<
0?ooo`00P03oool00`000000oooo0?ooo`0`0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?oo
o`3oool00P3oool00`000000Ogmo07moO`0F07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07mo
O`1oOgl0101oOgl00`09jPX0Ogmo07moO`0K07moO`0300WZ2P1oOgl0Ogmo01<0Ogmo0P09jPX;07mo
O`0300WZ2P1oOgl0Ogmo008000004@1oOgl00`09jPX0Ogmo0000000V07moO`802NX:101oOgl200WZ
2P0507moO`0000002NX:07moO`09jPX02`1oOgl400WZ2P0307moO`000000Ogmo00H0Ogmo00<02NX:
07moO`1oOgl00`1oOgl01009jPX0Ogmo07moO`1oOgl200WZ2PH0Ogmo00<0000007moO`1oOgl02`1o
Ogl00`09jPX0Ogmo00WZ2P0<07moO`030000001oOgl0Ogmo00h0Ogmo00D02NX:07moO`1oOgl0Ogmo
00WZ2P0407moO`0300WZ2P1oOgl0Ogmo00L0Ogmo1@09jPX010000000Ogmo07moO`09jPX807moO`04
00WZ2P1oOgl00000000000<0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`000000oooo0?ooo`0P0?oo
o`0300WZ2P3oool0oooo01d0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3o
ool0;P3oool200WZ2PX0oooo00<02NX:0?ooo`3oool00P3oool00`000000Ogmo07moO`0H07moO`03
00WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl0101oOgl200WZ2Q`0Ogmo00<02NX:07moO`1o
Ogl05P1oOgl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P00000@07moO`03
00WZ2P000000Ogmo02L0Ogmo00H02NX:07moO`1oOgl02NX:07moO`09jPX207moO`0300WZ2P1oOgl0
2NX:00l0Ogmo0`09jPX707moO`0300WZ2P1oOgl0Ogmo0080Ogmo00@02NX:07moO`09jPX02NX:1`1o
Ogl00`000000Ogmo07moO`0=07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl03P1o
Ogl00`09jPX0Ogmo07moO`0307moO`0400WZ2P1oOgl0Ogmo00WZ2P/0Ogmo00<02NX:07moO`1oOgl0
0P00000307moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00L02NX:07moO`1oOgl0Ogmo0000001oOgl02NX:
00h0Ogmo00<000000?ooo`3oool0803oool200WZ2Qd0oooo00<000000?ooo`3oool0303oool00800
oooo00<000000?ooo`3oool0;03oool200WZ2P`0oooo00<02NX:0?ooo`3oool00P3oool00`000000
Ogmo07moO`0H07moO`0500WZ2P1oOgl0Ogmo07moO`09jPX01`1oOgl00`09jPX0Ogmo07moO`0J07mo
O`0300WZ2P1oOgl0Ogmo01P0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0607mo
O`8000003`1oOgl200WZ2RP0Ogmo0P09jPX207moO`0400WZ2P1oOgl0Ogmo00WZ2P80Ogmo00<02NX:
07moO`1oOgl03@1oOgl00`000000Ogmo00WZ2P0300WZ2P<0Ogmo00<02NX:07moO`1oOgl00P1oOgl2
00WZ2PP0Ogmo00<0000007moO`1oOgl03P1oOgl00`09jPX0Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00d0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo00WZ2P0<07moO`0300WZ2P1oOgl0
Ogmo00H0Ogmo00<02NX:07moO`1oOgl01@1oOgl01P09jPX0Ogmo07moO`1oOgl0000000WZ2Ph0Ogmo
00<000000?ooo`3oool08P3oool00`09jPX0oooo0?ooo`0J0?ooo`030000003oool0oooo00`0oooo
00200?ooo`030000003oool0oooo02X0oooo0P09jPX=0?ooo`0300WZ2P3oool0oooo00<0oooo00<0
000007moO`1oOgl06@1oOgl00`09jPX0Ogmo00WZ2P0807moO`0300WZ2P1oOgl0Ogmo01T0Ogmo00<0
2NX:07moO`1oOgl06P1oOgl200WZ2P@0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0;07moO`040000001oOgl0Ogmo00WZ2RL0Ogmo00P02NX:07moO`09jPX02NX:07moO`09jPX0Ogmo
00WZ2P80Ogmo00<02NX:07moO`1oOgl03P1oOgl00`000000Ogmo07moO`0207moO`<02NX:0P000000
101oOgl0000000WZ2P09jPX807moO`030000001oOgl0Ogmo00l0Ogmo00<02NX:07moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl0301o
Ogl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl00P1o
Ogl00`09jPX0000007moO`0<07moO`030000003oool0oooo02<0oooo00<02NX:0?ooo`3oool06@3o
ool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0X0?ooo`802NX:3`3oool0
0`09jPX0oooo0?ooo`020?ooo`030000001oOgl0Ogmo01/0Ogmo00<02NX:0000001oOgl01P1oOgl2
00WZ2QX0Ogmo00<02NX:07moO`1oOgl07@1oOgl01009jPX0Ogmo07moO`09jPX=07moO`8000002`1o
Ogl01@000000Ogmo07moO`1oOgl02NX:02D0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2P0307mo
O`09jPX0Ogmo0080Ogmo00<02NX:07moO`1oOgl03@1oOgl00`000000Ogmo07moO`0507moO`<02NX:
0P0000000`09jPX0Ogmo07moO`0507moO`030000001oOgl0Ogmo0100Ogmo00<02NX:07moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0;07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo0P09jPX>07moO`0300WZ
2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl0101oOgl01@09jPX0Ogmo07moO`1oOgl02NX:0080
Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`0S0?ooo`802NX:6@3oool00`000000
oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0V0?ooo`802NX:403oool00`09jPX0oooo
0?ooo`030?ooo`030000001oOgl0Ogmo01/0Ogmo0P00000707moO`802NX:6@1oOgl00`09jPX0Ogmo
07moO`0O07moO`802NX:401oOgl2000000T0Ogmo00<0000007moO`1oOgl00P1oOgl00`09jPX0Ogmo
07moO`0Q07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo0P09jPX307moO`0300WZ2P1oOgl0Ogmo00d0Ogmo
00<0000007moO`1oOgl0101oOgl200WZ2P@0Ogmo00<02NX:07moO`1oOgl0101oOgl00`000000Ogmo
07moO`0@07moO`802NX:2`1oOgl00`000000Ogmo07moO`0;07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo
00@02NX:07moO`1oOgl02NX:3P1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00@0
Ogmo00@02NX:07moO`1oOgl02NX:0`1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo
02D0oooo00<02NX:0?ooo`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000
oooo0?ooo`0T0?ooo`802NX:4P3oool00`09jPX0oooo0?ooo`020?ooo`030000001oOgl0Ogmo02D0
Ogmo0P09jPXH07moO`0300WZ2P1oOgl0Ogmo0200Ogmo0`09jPXA07moO`8000001P1oOgl00`000000
Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo01h0Ogmo0P09jPX807moO`<02NX:0`1oOgl00`09jPX0
Ogmo07moO`0=07moO`040000001oOgl0Ogmo07moO`802NX:00<0000007moO`1oOgl00`1oOgl00`09
jPX0Ogmo07moO`0207moO`8000004`1oOgl200WZ2P/0Ogmo00<0000007moO`1oOgl02P1oOgl00`09
jPX0Ogmo07moO`0707moO`0400WZ2P1oOgl0Ogmo00WZ2Ph0Ogmo00<02NX:07moO`1oOgl01`1oOgl0
0`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl02NX:00D0Ogmo0P00000;07moO`030000003oool0
oooo02D0oooo00<02NX:0?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`00
0000oooo0?ooo`0R0?ooo`802NX:503oool00`09jPX0oooo0?ooo`020?ooo`030000001oOgl0Ogmo
02@0Ogmo0P09jPXG07moO`802NX:8P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:0180Ogmo0P000004
07moO`030000001oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl0701oOgl00`09jPX0Ogmo07moO`09
07moO`0600WZ2P1oOgl02NX:00WZ2P1oOgl02NX:3`1oOgl01@000000Ogmo00WZ2P09jPX0Ogmo0080
00001@1oOgl01@09jPX0Ogmo07moO`1oOgl0000001D0Ogmo00<02NX:07moO`09jPX02P1oOgl00`00
0000Ogmo07moO`0907moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09
jPX0Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09
jPX0Ogmo00WZ2P0707moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool09P3oool200WZ
2QD0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0803oool200WZ2QD0
oooo00<02NX:0?ooo`3oool00`3oool00`000000Ogmo07moO`0T07moO`802NX:5P1oOgl00`09jPX0
Ogmo07moO`0Q07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl04@1oOgl01@000000
Ogmo07moO`1oOgl0000000P0Ogmo0P09jPXK07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00@02NX:07mo
O`1oOgl0Ogmo0`09jPX>07moO`0300000009jPX0Ogmo00T0Ogmo00@02NX:07moO`1oOgl000005P1o
Ogl00`09jPX0Ogmo00WZ2P0:07moO`030000001oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl01`1o
Ogl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<02NX:07moO`1oOgl01`1o
Ogl00`09jPX0Ogmo07moO`0307moO`802NX:201oOgl2000000P0Ogmo00<000000?ooo`3oool0:03o
ool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0
oooo01h0oooo0P09jPXG0?ooo`0300WZ2P3oool0oooo0080oooo00<0000007moO`1oOgl09@1oOgl2
00WZ2P030000001oOgl0Ogmo0180Ogmo00<02NX:07moO`1oOgl08@1oOgl00`09jPX0Ogmo07moO`05
07moO`802NX:4P1oOgl3000000/0Ogmo00<02NX:07moO`1oOgl05`1oOgl00`09jPX0Ogmo07moO`0;
07moO`802NX:101oOgl00`09jPX0Ogmo07moO`0;07moO`802NX:00<0000007moO`1oOgl0201oOgl0
0`09jPX0Ogmo0000000F07moO`0400WZ2P1oOgl0Ogmo00WZ2PT0Ogmo00<0000007moO`1oOgl01`1o
Ogl00`0000002NX:07moO`0807moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl0301o
Ogl00`09jPX0Ogmo07moO`0707moO`0600WZ2P1oOgl0Ogmo07moO`0000002NX:2`1oOgl00`000000
Ogmo07moO`0607moO`030000003oool0oooo02P0oooo00<02NX:0?ooo`3oool04@3oool00`000000
oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0L0?ooo`802NX:603oool00`09jPX0oooo
0?ooo`030?ooo`030000001oOgl0Ogmo02<0Ogmo0P09jPX00`1oOgl000000000000C07moO`0300WZ
2P1oOgl0Ogmo0240Ogmo00<02NX:07moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0:07moO``00000
201oOgl00`09jPX0Ogmo07moO`0E07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo0P09jPX507moO`802NX:
2@1oOgl200WZ2P80Ogmo00<0000007moO`1oOgl0201oOgl00`09jPX0000007moO`0F07moO`0400WZ
2P1oOgl0Ogmo00WZ2PT0Ogmo00<0000007moO`1oOgl0101oOgl300WZ2P80000000<02NX:07moO`1o
Ogl01@1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<02NX:07moO`1o
Ogl01`1oOgl01P09jPX0Ogmo07moO`1oOgl0000000WZ2P`0Ogmo00<0000007moO`1oOgl01@1oOgl0
0`000000oooo0?ooo`0Y0?ooo`802NX:4@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`00
0000oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool00P3oool00`00
0000Ogmo07moO`0R07moO`802NX:00<0Ogmo00WZ2P1oOgl0501oOgl00`09jPX0Ogmo07moO`0Q07mo
O`0300WZ2P1oOgl0Ogmo00L0Ogmo0`0000000`09jPX0000000000009000000L0Ogmo00<0000007mo
O`0000000P1oOgl90000000300WZ2P1oOgl0Ogmo01<0Ogmo00<02NX:07moO`1oOgl0301oOgl20000
000307moO`09jPX0Ogmo00@0Ogmo0`09jPX507moO`802NX:101oOgl00`000000Ogmo07moO`0807mo
O`0300WZ2P1oOgl0Ogmo01H0Ogmo00@02NX:07moO`1oOgl02NX:2@1oOgl00`000000Ogmo07moO`02
07moO`802NX:1P1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<02NX:
07moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0707moO`0400WZ2P1oOgl0Ogmo00WZ2Ph0Ogmo0P00
000607moO`030000003oool0oooo02X0oooo00<02NX:0?ooo`3oool03P3oool00`000000oooo0?oo
o`0<0?ooo`00P03oool00`000000oooo0?ooo`0I0?ooo`802NX:6P3oool00`09jPX0oooo0?ooo`03
0?ooo`030000001oOgl0Ogmo0200Ogmo0P09jPX307moO`0300WZ2P1oOgl0Ogmo0180Ogmo00<02NX:
07moO`1oOgl07@1oOgl40000000300WZ2P000000000000P00000101oOgl00`09jPX0Ogmo07moO`0?
07moO`040000001oOgl0Ogmo000000X0Ogmo00<0000000WZ2P0000001@00000<07moO`802NX:3`1o
Ogl00`0000002NX:00WZ2P0700WZ2P80Ogmo0P09jPX00`1oOgl02NX:00WZ2P0707moO`030000001o
Ogl0Ogmo00H0Ogmo00<0000000WZ2P1oOgl05`1oOgl01009jPX0Ogmo07moO`09jPX907moO`030000
001oOgl02NX:00802NX:2@1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00P0Ogmo
00<02NX:07moO`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0707moO`802NX:4@1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo02/0oooo00<02NX:0?ooo`3oool03@3oool00`000000oooo
0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0G0?ooo`802NX:703oool00`09jPX0oooo0?oo
o`030?ooo`030000001oOgl0Ogmo01l0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07mo
O`0B07moO`0300WZ2P1oOgl0Ogmo00l0Ogmo3`00000307moO`0300WZ2P1oOgl0Ogmo00h0Ogmo0P09
jPX>07moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl02@1oOgl00`09jPX0Ogmo07mo
O`0307moO`T000000P1oOgl00`09jPX0Ogmo07moO`0C07moO`0300WZ2P1oOgl0Ogmo0080Ogmo1009
jPX00`0000002NX:00WZ2P0807moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`09jPX05`1o
Ogl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<0000000WZ2P09jPX00P00
000;07moO`0400WZ2P1oOgl0Ogmo00WZ2P`0Ogmo00<02NX:07moO`1oOgl0301oOgl00`09jPX0Ogmo
07moO`0707moO`802NX:4P1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo02`0oooo
0P09jPX=0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo01D0oooo0P09
jPXN0?ooo`0300WZ2P3oool0oooo0080oooo00<0000007moO`1oOgl07P1oOgl200WZ2PD0Ogmo00<0
2NX:07moO`1oOgl04@1oOgl01009jPX0Ogmo07moO`1oOgl?000000@0oooo00<0000007moO`1oOgl0
2P1oOgl00`09jPX0Ogmo07moO`0A07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0907moO`802NX:301oOgl00`0000002NX:00000006000000l0Ogmo
00<02NX:07moO`1oOgl00`1oOgl01@09jPX0Ogmo00WZ2P09jPX0000000802NX:1`1oOgl00`000000
Ogmo07moO`0407moO`040000001oOgl0Ogmo00WZ2QL0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09
jPX0Ogmo07moO`0307moO`<02NX:103oool<000000802NX:00<0000007moO`1oOgl02P1oOgl00`09
jPX0Ogmo07moO`0=07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo0P09jPXC07moO`8000000`1oOgl00`00
0000oooo0?ooo`0]0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool0303oool00800
oooo00<000000?ooo`3oool04`3oool200WZ2Ql0oooo00<02NX:0?ooo`3oool00`3oool00`000000
Ogmo07moO`0L07moO`802NX:1`1oOgl00`09jPX0Ogmo07moO`0707moO`T0000000<02NX:00000000
00000P00000C0?ooo`030000001oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl04`1oOgl00`09jPX0
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00@0Ogmo0P00000;07moO`0300WZ2P1oOgl0Ogmo00T0
Ogmo00<02NX:07moO`1oOgl01P1oOgl8000000P0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0
Ogmo07moO`0307moO`802NX:1P1oOgl00`000000Ogmo07moO`0207moO`050000001oOgl0Ogmo07mo
O`09jPX05`1oOgl00`09jPX0Ogmo07moO`0207moO`0400WZ2P1oOgl0Ogmo07moO`802NX:0P1oOgl0
0`000000oooo0?ooo`0>0?ooo`802NX:00<0oooo0000000000002`0000000`09jPX0Ogmo07moO`0<
07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00@02NX:07moO`1oOgl02NX:501oOgl010000000Ogmo07mo
O`00000`0?ooo`802NX:2P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?oo
o`0A0?ooo`802NX:8@3oool00`09jPX0oooo0?ooo`020?ooo`030000001oOgl0Ogmo01/0Ogmo0P09
jPX407moO`@0000000<02NX:000000000000200000080?ooo`0300WZ2P3oool0oooo01H0oooo00<0
000007moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0E07moO`802NX:2@1oOgl00`000000Ogmo07mo
O`0707moO`030000001oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`09jPX0Ogmo07mo
O`0?07moO`P0000000@02NX:07moO`1oOgl0Ogmo0`09jPX707moO`802NX:101oOgl01@000000Ogmo
07moO`1oOgl0000000@0Ogmo00<02NX:07moO`1oOgl0501oOgl00`09jPX0Ogmo07moO`0307moO`@0
2NX:101oOgl00`000000oooo0?ooo`0=0?ooo`0400WZ2P3oool0oooo00WZ2Pd0oooo00<02NX:0000
000000003@0000000`09jPX0Ogmo07moO`0307moO`0500WZ2P1oOgl0Ogmo07moO`09jPX05@1oOgl2
0000000307moO`000000oooo0300oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`0<
0?ooo`00P03oool00`000000oooo0?ooo`0?0?ooo`802NX:8P3oool00`09jPX0oooo0?ooo`030?oo
o`030000001oOgl0Ogmo0180Ogmo1`00000200WZ2PH00000103oool00`09jPX0oooo0?ooo`0?0?oo
o`0300WZ2P3oool0oooo01P0oooo00<0000007moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0H07mo
O`0300WZ2P1oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0907mo
O`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl06@1oOgl300WZ2P<0000000<02NX:0000
001oOgl01P1oOgl01@09jPX0Ogmo07moO`1oOgl000000080Ogmo00<0000007moO`1oOgl00`1oOgl0
0`09jPX0Ogmo07moO`0D07moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P09jPX607moO`030000003oool0
oooo00d0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00`0oooo00<02NX:0000000000000`0000000`09jPX00000000000020000000400WZ2P000000
0000000001<0Ogmo0P00000b0?ooo`0300WZ2P3oool0oooo00H0oooo00<000000?ooo`3oool0303o
ool00800oooo00<000000?ooo`3oool03@3oool200WZ2R@0oooo00<02NX:0?ooo`3oool00`3oool0
0`000000Ogmo07moO`0307moO`l000001@3oool200WZ2P`0oooo00<02NX:0?ooo`3oool03P3oool0
0`09jPX0oooo0?ooo`0I0?ooo`030000001oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl06P1oOgl0
0`09jPX0Ogmo07moO`0507moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`09jPX0Ogmo07moO`0207moO`802NX:6`1oOgl200WZ2PD0Ogmo00<02NX:07moO`0000001`000002
00WZ2P80Ogmo0P00000607moO`0300WZ2P1oOgl0Ogmo01@0Ogmo00<02NX:07moO`09jPX00P09jPX2
07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool03@3oool00`09jPX0oooo0?ooo`03
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool03@3oool01@09jPX0oooo0?ooo`3o
ool02NX:00H0oooo00<02NX:0?ooo`3oool03`00000507moO`030000003oool0oooo0340oooo0P09
jPX60?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo00/0oooo0P09jPXU
0?ooo`0300WZ2P3oool0oooo00<0oooo1`00000B0?ooo`802NX:3@3oool00`09jPX0oooo0?ooo`0>
0?ooo`0300WZ2P3oool0oooo01X0oooo00<0000007moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0L
07moO`802NX:101oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00T0Ogmo00@02NX:
07moO`1oOgl02NX:701oOgl01009jPX0Ogmo07moO`09jPX507moO`0300WZ2P1oOgl0Ogmo00L0Ogmo
00@0000000WZ2P09jPX000001`1oOgl00`09jPX0Ogmo07moO`0D07moO`802NX:1@1oOgl00`09jPX0
Ogmo07moO`0307moO`030000003oool0oooo00`0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0
oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00d0oooo00@02NX:0?ooo`3oool02NX:1`3oool00`09
jPX0oooo0?ooo`0?0?ooo`L00000=03oool00`09jPX0oooo0?ooo`030?ooo`030000003oool0oooo
00`0oooo00200?ooo`030000003oool0oooo00T0oooo0P09jPXW0?ooo`0300WZ2P3oool0oooo01X0
oooo0P09jPX?0?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool06`3oool00`000000
Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo01l0Ogmo00D02NX:07moO`1oOgl0Ogmo0000000>07mo
O`8000002P1oOgl200WZ2Q/0Ogmo0P09jPX307moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07mo
O`1oOgl02P1oOgl200WZ2PH0Ogmo00<02NX:07moO`1oOgl04@1oOgl300WZ2PL0Ogmo00<02NX:07mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?oo
o`3oool02@3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool02NX:00P0oooo00<02NX:0?oo
o`3oool0BP3oool00`09jPX0oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00200?ooo`03
0000003oool0oooo00L0oooo0P09jPXX0?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3o
ool03`3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo01d0oooo00D0000007moO`1o
Ogl0Ogmo00WZ2P0S07moO`0400WZ2P1oOgl0Ogmo00000100Ogmo00<0000007moO`1oOgl01`1oOgl0
0`09jPX0000000WZ2P0H07moO`802NX:1P1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0
Ogmo00/0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0?07moO`802NX:0P1oOgl0
0`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<000000?ooo`3oool02`3oool0
0`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool03@3oool2
00WZ2PX0oooo00<02NX:0?ooo`3oool0BP3oool200WZ2P80oooo00<000000?ooo`3oool0303oool0
0800oooo00<000000?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0X0?ooo`0300WZ2P3oool0oooo
01P0oooo0P09jPXB0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool07P3oool01000
0000Ogmo07moO`09jPXU07moO`802NX:4P1oOgl00`000000Ogmo07moO`0507moO`0400WZ2P1oOgl0
Ogmo07moO`802NX:501oOgl200WZ2PP0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07mo
O`0<07moO`802NX:0`1oOgl00`09jPX0Ogmo07moO`0<07moO`<02NX:101oOgl00`09jPX0Ogmo07mo
O`0507moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<000000?ooo`3oool02P3oool00`09jPX0oooo0?oo
o`0;0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0303oool200WZ2PX0oooo00<0
2NX:0?ooo`3oool0C03oool00`09jPX0oooo0000000>0?ooo`00P03oool00`000000oooo0?ooo`04
0?ooo`802NX::`3oool00`09jPX0oooo0?ooo`0F0?ooo`802NX:4`3oool00`09jPX0oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo01l0oooo00<0000007moO`09jPX09`1oOgl00`0000002NX:07moO`0A
07moO`030000001oOgl0Ogmo0080Ogmo0P09jPX607moO`0300WZ2P1oOgl0Ogmo0100Ogmo00<02NX:
07moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00d0Ogmo0P09jPX0
0`1oOgl02NX:07moO`0;07moO`802NX:1`1oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0
Ogmo0080Ogmo00<000000?ooo`3oool02@3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0
oooo00L0oooo00<02NX:0?ooo`3oool0303oool200WZ2P/0oooo00<02NX:0?ooo`3oool0C03oool2
000000h0oooo00200?ooo`030000003oool0oooo0080oooo0P09jPX/0?ooo`0300WZ2P3oool0oooo
01D0oooo0P09jPXE0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0803oool00`00
00002NX:07moO`0W07moO`030000001oOgl02NX:0180Ogmo00@0000007moO`1oOgl02NX:2@1oOgl0
0`09jPX0Ogmo07moO`0=07moO`802NX:301oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0
Ogmo00l0Ogmo0P09jPX907moO`<02NX:201oOgl00`09jPX0Ogmo07moO`0707moO`0500WZ2P1oOgl0
Ogmo07moO`0000002P3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo00L0oooo00<0
2NX:0?ooo`3oool02P3oool01009jPX0oooo0?ooo`09jPX;0?ooo`0300WZ2P3oool0oooo04/0oooo
0P00000>0?ooo`00P03oool00`000000oooo0?ooo`0200WZ2Rh0oooo00<02NX:0?ooo`3oool04`3o
ool200WZ2QL0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P00
0000Ogmo02H0Ogmo00D0000007moO`1oOgl0Ogmo00WZ2P0B07moO`0300000009jPX0Ogmo00X0Ogmo
0P09jPX;07moO`802NX:3`1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00l0Ogmo
0P09jPX607moO`802NX:2`1oOgl00`09jPX0Ogmo07moO`0707moO`80000000<0Ogmo0000003oool0
2P3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0
2@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0
C03oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`0000002NX:00WZ2P0_0?ooo`0300WZ2P3o
ool0oooo0180oooo0P09jPXH0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool08@3o
ool00`09jPX0oooo0000000W07moO`030000001oOgl0Ogmo0080Ogmo0P09jPX@07moO`0300WZ2P1o
Ogl0000000`0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`09jPX0Ogmo07moO`0?07moO`0300WZ2P1o
Ogl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl03`1oOgl01@09jPX0Ogmo00WZ2P09jPX0000000<02NX:
3@1oOgl00`09jPX0Ogmo07moO`0707moO`80000000<0Ogmo0000003oool02@3oool00`09jPX0oooo
0?ooo`0B0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo
0?ooo`020?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool0B`3oool00`000000oooo
0?ooo`0<0?ooo`00P03oool200000300oooo00<02NX:0?ooo`3oool0403oool200WZ2QX0oooo00<0
2NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0Q0?ooo`0400WZ2P3oool0oooo000002L0Ogmo
00<0000007moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0<07moO`0500WZ2P1oOgl0Ogmo07moO`00
0000301oOgl200WZ2PD0Ogmo0P09jPXC07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1o
Ogl03P1oOgl500WZ2P030000001oOgl0Ogmo00d0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`000000
oooo0?ooo`070?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0
oooo0?ooo`070?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0
oooo0?ooo`1:0?ooo`030000003oool0oooo00`0oooo00200?ooo`800000;`3oool00`09jPX0oooo
0?ooo`0?0?ooo`802NX:703oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo0240oooo
00D02NX:0?ooo`3oool0oooo0000000V07moO`030000001oOgl0Ogmo00H0Ogmo00<02NX:07moO`1o
Ogl02P1oOgl00`09jPX0Ogmo07moO`0307moO`030000001oOgl0Ogmo00/0Ogmo00<02NX:07moO`1o
Ogl00P09jPX00`000000Ogmo07moO`0B07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1o
Ogl02@1oOgl600WZ2Q<0Ogmo00<02NX:07moO`1oOgl02`1oOgl00`000000oooo0?ooo`060?ooo`03
00WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`050?ooo`03
00WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`1:0?ooo`03
0000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo02h0oooo00<02NX:0?ooo`3oool0
3@3oool200WZ2Qd0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ
2P3oool0oooo00<0oooo00<0000007moO`1oOgl08`1oOgl00`000000Ogmo07moO`0707moO`802NX:
201oOgl200WZ2PL0Ogmo00<0000007moO`1oOgl02P1oOgl300WZ2P0307moO`000000000001D0Ogmo
00<02NX:07moO`1oOgl00`1oOgl01009jPX0Ogmo07moO`1oOgl700WZ2PD0Ogmo00<02NX:07moO`1o
Ogl04@1oOgl00`09jPX0Ogmo07moO`0:07moO`030000003oool0oooo00H0oooo00<02NX:0?ooo`3o
ool0603oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool01`3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo04T0oooo00<000000?ooo`3o
ool0303oool00800oooo00<000000?ooo`3oool0;@3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ
2P3oool0oooo01d0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ
2P3oool0oooo00@0oooo00<0000007moO`1oOgl08`1oOgl00`000000Ogmo07moO`0907moO`0300WZ
2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl0201oOgl2000000L0Ogmo0`09jPX307moO`0300WZ
2P1oOgl0Ogmo01D0Ogmo00@02NX:07moO`1oOgl0Ogmo1P09jPX<07moO`0300WZ2P1oOgl0Ogmo0140
Ogmo00<02NX:07moO`1oOgl02P1oOgl00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo01X0
oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00L0
oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`180?ooo`030000003oool0oooo00`0
oooo00200?ooo`030000003oool0oooo02d0oooo00<02NX:0?ooo`3oool02`3oool200WZ2R00oooo
00<02NX:0?ooo`3oool0103oool200WZ2R<0oooo00<02NX:0?ooo`3oool01@3oool00`000000Ogmo
07moO`0R07moO`030000001oOgl0Ogmo00/0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo
07moO`0;07moO`040000001oOgl0Ogmo07moO`<02NX:1`1oOgl00`09jPX0Ogmo07moO`0D07moO`04
00000009jPX02NX:00WZ2P<0Ogmo00<02NX:07moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0A07mo
O`0300WZ2P1oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0K0?oo
o`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`090?oo
o`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0A`3oool00`000000oooo0?ooo`0<0?oo
o`00P03oool00`000000oooo0?ooo`0]0?ooo`0300WZ2P3oool0oooo00T0oooo0P09jPXQ0?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool08P3oool00`09jPX0oooo0?ooo`060?ooo`03
0000001oOgl0Ogmo0280Ogmo00<0000007moO`1oOgl0301oOgl200WZ2P0307moO`09jPX0Ogmo00h0
Ogmo00<0000000WZ2P09jPX02`1oOgl200WZ2Q@0Ogmo0P00000507moO`0300WZ2P1oOgl0Ogmo00`0
Ogmo00<02NX:07moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0;07moO`030000003oool0oooo00@0
oooo00<02NX:0?ooo`3oool07@3oool00`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool0oooo00WZ
2P`0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`170?ooo`030000003oool0oooo
00`0oooo00200?ooo`030000003oool0oooo02`0oooo00<02NX:0?ooo`3oool0203oool200WZ2R<0
oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo00L0
oooo00<0000007moO`1oOgl08P1oOgl00`000000Ogmo07moO`0>07moO`0300WZ2P1oOgl0Ogmo00`0
Ogmo0`09jPX00`000000Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo01T0Ogmo00<02NX:07moO`1o
Ogl02`1oOgl00`09jPX0Ogmo07moO`0@07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<000000?ooo`3o
ool00`3oool00`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo0080oooo00@02NX:0?ooo`3o
ool02NX:3@3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo04H0oooo00<000000?oo
o`3oool0303oool00800oooo00<000000?ooo`3oool0;03oool00`09jPX0oooo0?ooo`060?ooo`80
2NX:9@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo0280oooo00<02NX:0?ooo`3o
ool02@3oool00`000000Ogmo07moO`0P07moO`030000001oOgl0Ogmo00h0Ogmo00<02NX:07moO`09
jPX02P1oOgl300WZ2P@0Ogmo00<0000007moO`1oOgl0301oOgl200WZ2QT0Ogmo00<02NX:07moO`1o
Ogl02`1oOgl00`09jPX0Ogmo07moO`0@07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<000000?ooo`3o
ool00`3oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX>0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0A@3oool00`000000oooo0?ooo`0<0?ooo`00
P03oool00`000000oooo0?ooo`0[0?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPXV0?ooo`0300WZ
2P3oool0oooo0080oooo00<02NX:0?ooo`3oool08P3oool00`09jPX0oooo0?ooo`0:0?ooo`030000
001oOgl0Ogmo0200Ogmo00<0000007moO`1oOgl0301oOgl200WZ2P<0Ogmo0P09jPX607moO`802NX:
201oOgl2000000h0Ogmo00<02NX:07moO`1oOgl05`1oOgl00`09jPX0Ogmo07moO`0:07moO`0300WZ
2P1oOgl0Ogmo00l0Ogmo00<02NX:07moO`1oOgl02`1oOgl00`000000oooo0?ooo`020?ooo`0300WZ
2P3oool0oooo02<0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0@0?ooo`0300WZ2P3oool0oooo00X0
oooo00<02NX:0?ooo`3oool0A@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo
0?ooo`0[0?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPXX0?ooo`0500WZ2P3oool0oooo0?ooo`09
jPX0903oool00`09jPX0oooo0?ooo`0;0?ooo`030000001oOgl0Ogmo0200Ogmo00<0000007moO`1o
Ogl02`1oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00<02NX:301oOgl00`000000
Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo01H0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`09jPX0
Ogmo07moO`0?07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00D000000?ooo`3oool0oooo00WZ2P0W0?oo
o`0300WZ2P3oool0oooo00802NX:3`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo
04@0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0:P3oool00`09jPX0
oooo0?ooo`020?ooo`802NX::P3oool01009jPX0oooo0?ooo`09jPXT0?ooo`0300WZ2P3oool0oooo
00`0oooo00<0000007moO`1oOgl07`1oOgl00`000000Ogmo07moO`0;07moO`0300WZ2P1oOgl0Ogmo
00H0Ogmo0`09jPX@07moO`030000001oOgl0Ogmo00`0Ogmo0P09jPXG07moO`0300WZ2P1oOgl0Ogmo
00T0Ogmo00<02NX:07moO`1oOgl03`1oOgl00`09jPX0Ogmo07moO`0;07moO`050000003oool0oooo
0?ooo`09jPX0:03oool200WZ2P030?ooo`09jPX0oooo00l0oooo00<02NX:0?ooo`3oool02`3oool0
0`09jPX0oooo0?ooo`130?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo
02X0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0[0?ooo`0400WZ2P3oool0oooo00WZ2R@0oooo00<0
2NX:0?ooo`3oool03P3oool00`000000Ogmo07moO`0N07moO`030000001oOgl0Ogmo00X0Ogmo00<0
2NX:07moO`1oOgl0101oOgl300WZ2P80Ogmo00<02NX:07moO`1oOgl03`1oOgl00`000000Ogmo07mo
O`0=07moO`0300WZ2P1oOgl0Ogmo01@0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX0Ogmo07mo
O`0?07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00D000000?ooo`3oool0oooo00WZ2P0Y0?ooo`802NX:
00<0oooo00WZ2P3oool0403oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo04<0oooo
00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0:P3oool01009jPX0oooo00WZ
2P09jPX/0?ooo`0300WZ2P3oool02NX:02@0oooo00<02NX:0?ooo`3oool03`3oool00`000000Ogmo
07moO`0N07moO`030000001oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl00`1oOgl200WZ2PH0Ogmo
0P09jPX@07moO`030000001oOgl0Ogmo00d0Ogmo0P09jPXE07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo
00<02NX:07moO`1oOgl03P1oOgl00`09jPX0Ogmo07moO`0;07moO`040000003oool0oooo00WZ2RT0
oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX@0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0Y0?oo
o`<02NX:;P3oool200WZ2R@0oooo00<02NX:0?ooo`3oool0403oool00`000000Ogmo07moO`0M07mo
O`030000001oOgl0Ogmo00T0Ogmo00@02NX:07moO`1oOgl0Ogmo0`09jPX:07moO`0300WZ2P1oOgl0
Ogmo00h0Ogmo0P00000?07moO`0300WZ2P1oOgl0Ogmo0180Ogmo00<02NX:07moO`1oOgl0201oOgl0
0`09jPX0Ogmo07moO`0>07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<000000?ooo`09jPX0:P3oool0
1009jPX0oooo0?ooo`3oool200WZ2Q40oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`110?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo02L0oooo0P000000
0`09jPX0oooo0?ooo`0^0?ooo`0300WZ2P3oool0oooo0280oooo00<02NX:0?ooo`3oool04@3oool0
0`000000Ogmo07moO`0M07moO`030000001oOgl0Ogmo00P0Ogmo0P00000300WZ2Ph0Ogmo00<02NX:
07moO`1oOgl03@1oOgl00`000000oooo0000000?07moO`802NX:4`1oOgl00`09jPX0Ogmo07moO`07
07moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00<02NX:07moO`1oOgl02`1oOgl00`0000002NX:0?ooo`0Y
0?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPX@0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0W0?oo
o`0300000009jPX0oooo02l0oooo00<02NX:0?ooo`3oool08P3oool00`09jPX0oooo0?ooo`0C0?oo
o`030000001oOgl0Ogmo01`0Ogmo00<0000007moO`1oOgl01`1oOgl300WZ2Q80Ogmo0P09jPX<07mo
O`050000003oool0oooo0?ooo`000000401oOgl00`09jPX0Ogmo07moO`0A07moO`0300WZ2P1oOgl0
Ogmo00H0Ogmo00<02NX:07moO`1oOgl03P1oOgl00`09jPX0Ogmo07moO`0:07moO`0300000009jPX0
oooo02T0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool0@03oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`00
0000oooo0?ooo`0X0?ooo`0300WZ2P3oool0oooo02d0oooo0P09jPXS0?ooo`0300WZ2P3oool0oooo
01@0oooo00<0000007moO`1oOgl06`1oOgl00`000000Ogmo07moO`0607moO`802NX:5`1oOgl00`09
jPX0Ogmo07moO`0807moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl03P1oOgl00`09
jPX0Ogmo07moO`0@07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl03@1oOgl00`09
jPX0Ogmo07moO`0;07moO`0300000009jPX0oooo02T0oooo00<02NX:0?ooo`3oool01P3oool00`09
jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo02d0
oooo00<02NX:0?ooo`09jPX08P3oool00`09jPX0oooo0?ooo`0E0?ooo`030000001oOgl0Ogmo01/0
Ogmo00<0000007moO`1oOgl00`1oOgl300WZ2QX0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`000000
oooo0?ooo`050?ooo`030000001oOgl0Ogmo00h0Ogmo0P09jPXA07moO`0300WZ2P1oOgl0Ogmo00D0
Ogmo00<02NX:07moO`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0;07moO`0300WZ2P3oool0oooo02P0
oooo00<02NX:0?ooo`3oool01`3oool200WZ2Q00oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`0o0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo02L0oooo
00<02NX:0?ooo`3oool0;03oool00`09jPX0oooo00WZ2P0R0?ooo`0300WZ2P3oool0oooo01H0oooo
00<0000007moO`1oOgl06`1oOgl00`000000Ogmo07moO`0300WZ2Qh0Ogmo0P09jPX407moO`800000
2@3oool200000100Ogmo00<02NX:0000000000003P1oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ
2P1oOgl0Ogmo00d0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`09jPX000000?ooo`0X0?ooo`0300WZ
2P3oool0oooo00T0oooo0P09jPX?0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool0
?P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0V0?ooo`0300WZ2P3o
ool0oooo02`0oooo00@02NX:0?ooo`3oool02NX:8@3oool00`09jPX0oooo0?ooo`0H0?ooo`030000
001oOgl0Ogmo01T0Ogmo00@0000000WZ2P09jPX02NX:8`1oOgl01009jPX0Ogmo07moO`00000=0?oo
o`030000001oOgl0Ogmo00h0Ogmo0`09jPX>07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07mo
O`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0907moO`0300WZ2P000000oooo02T0oooo00<02NX:0?oo
o`3oool02@3oool00`09jPX0oooo00WZ2P0?0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?oo
o`3oool0?@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0V0?ooo`03
00WZ2P3oool0oooo02/0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0P0?ooo`0300WZ2P3oool0oooo
01T0oooo00<0000007moO`1oOgl0601oOgl200WZ2RL0Ogmo00<02NX:0000003oool03P3oool00`00
0000Ogmo07moO`0@07moO`<02NX:2`1oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo
00`0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX0Ogmo0000000Y0?ooo`0300WZ2P3oool0oooo
00X0oooo0P0000000`3oool02NX:0?ooo`0=0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?oo
o`3oool0?@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0V0?ooo`03
00WZ2P3oool0oooo02X0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0P0?ooo`0300WZ2P3oool0oooo
01X0oooo00<0000007moO`1oOgl05@1oOgl300WZ2P0307moO`000000Ogmo02H0Ogmo00<0000000WZ
2P09jPX03`3oool00`000000Ogmo07moO`0B07moO`<02NX:2@1oOgl00`09jPX0Ogmo07moO`0307mo
O`0300WZ2P1oOgl0Ogmo00`0Ogmo00<02NX:07moO`1oOgl0201oOgl01009jPX0Ogmo07moO`00000X
0?ooo`0300WZ2P3oool0oooo00/0oooo0P0000020?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:
0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0l0?ooo`030000003oool0oooo00`0oooo00200?oo
o`030000003oool0oooo02D0oooo00<02NX:0?ooo`3oool0:P3oool00`09jPX0oooo0?ooo`020?oo
o`0300WZ2P3oool0oooo01d0oooo00<02NX:0?ooo`3oool06`3oool00`000000Ogmo07moO`0B07mo
O`<02NX:0`1oOgl00`000000Ogmo07moO`0U07moO`050000003oool0oooo0?ooo`09jPX03`3oool0
0`000000Ogmo07moO`0D07moO`<02NX:1P1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0
Ogmo00`0Ogmo00<02NX:07moO`1oOgl0201oOgl01009jPX0Ogmo07moO`00000X0?ooo`0300WZ2P3o
ool0oooo0100oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool09@3oool0
0`09jPX0oooo0?ooo`0Y0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0703oool0
0`09jPX0oooo0?ooo`0M0?ooo`030000001oOgl0Ogmo00l0Ogmo0P09jPX607moO`030000001oOgl0
Ogmo02<0Ogmo0P0000050?ooo`0300WZ2P3oool0oooo00d0oooo0P00000G07moO`<02NX:101oOgl0
0`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<02NX:07moO`1oOgl01`1oOgl0
1009jPX0Ogmo07moO`00000X0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool02`3o
ool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo03/0oooo00<000000?ooo`3oool0303o
ool00800oooo00<000000?ooo`3oool0903oool00`09jPX0oooo0?ooo`0Y0?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool0703oool00`09jPX0oooo0?ooo`0N0?ooo`030000001oOgl0
Ogmo00`0Ogmo0`09jPX807moO`030000001oOgl0Ogmo0280Ogmo00<000000?ooo`3oool01P3oool0
0`09jPX0oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo01L0Ogmo0`09jPX00`1oOgl02NX:07moO`03
07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<02NX:07moO`1oOgl01`1oOgl01@09jPX0Ogmo07moO`1o
Ogl0000002L0oooo00<02NX:0?ooo`3oool0503oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3o
ool0oooo00d0oooo00<02NX:0?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool0
0`000000oooo0?ooo`0T0?ooo`0300WZ2P3oool0oooo02P0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo01l0oooo00<0000007moO`1oOgl02@1oOgl3
00WZ2PX0Ogmo00<0000007moO`1oOgl08P1oOgl00`000000oooo0?ooo`080?ooo`802NX:3`3oool0
0`000000Ogmo07moO`0I07moO`<02NX:0`1oOgl00`09jPX0Ogmo07moO`0;07moO`0300WZ2P1oOgl0
Ogmo00H0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000oooo0?ooo`0T0?ooo`0300WZ2P3oool0
oooo01H0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0
oooo03T0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool08`3oool00`09
jPX0oooo0?ooo`0X0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool06P3oool00`09
jPX0oooo0?ooo`0P0?ooo`030000001oOgl0Ogmo00H0Ogmo0`09jPX=07moO`030000001oOgl0Ogmo
0240Ogmo00<000000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0=0?ooo`030000001oOgl0Ogmo
01X0Ogmo1@09jPX=07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0T0?ooo`0300WZ2P3oool0oooo01L0oooo00<02NX:0?ooo`3oool02P3oool00`09
jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo03T0oooo00<000000?ooo`3oool0303oool00800
oooo00<000000?ooo`3oool08`3oool00`09jPX0oooo0?ooo`0V0?ooo`802NX:1`3oool00`09jPX0
oooo0?ooo`0I0?ooo`802NX:903oool00`000000Ogmo07moO`0307moO`802NX:401oOgl00`000000
Ogmo07moO`0P07moO`030000003oool0oooo00d0oooo00<02NX:0?ooo`3oool03@3oool00`000000
Ogmo07moO`0J07moO`0300WZ2P1oOgl0000000<02NX:2`1oOgl00`09jPX0Ogmo07moO`0407moO`03
00WZ2P1oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0903oool00`09jPX0oooo0?ooo`0I0?ooo`03
00WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0h0?ooo`03
0000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo02<0oooo00<02NX:0?ooo`3oool0
9@3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool0
903oool00`000000Ogmo07moO`0300WZ2Q40Ogmo00<0000007moO`1oOgl07`1oOgl200000140oooo
0P09jPX>0?ooo`8000006P1oOgl01009jPX0000007moO`09jPX207moO`<02NX:1`1oOgl00`09jPX0
Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08`3oool00`09jPX0
oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0
oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo0280oooo
00<02NX:0?ooo`3oool09@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01L0oooo
00<02NX:0?ooo`3oool09@3oool300WZ2Q@0Ogmo00<0000007moO`1oOgl07P1oOgl00`000000oooo
0?ooo`0C0?ooo`0300WZ2P3oool0oooo00d0oooo00<0000007moO`1oOgl05`1oOgl00`0000002NX:
00WZ2P0900WZ2P@0Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0407moO`030000
003oool0oooo02<0oooo00<02NX:0?ooo`3oool0703oool00`09jPX0oooo0?ooo`080?ooo`0300WZ
2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`00P03o
ool00`000000oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo02@0oooo00<02NX:0?ooo`3oool0203o
ool00`09jPX0oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo02<0oooo0`09jPX00`000000Ogmo07mo
O`0D07moO`030000001oOgl0Ogmo01d0Ogmo00<000000?ooo`3oool05@3oool00`09jPX0oooo0?oo
o`0=0?ooo`030000001oOgl0Ogmo01T0Ogmo00<02NX:07moO`1oOgl0101oOgl2000000802NX:0P1o
Ogl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool08P3o
ool00`09jPX0oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool03@3o
ool00`09jPX0oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0
oooo0240oooo00<02NX:0?ooo`3oool0903oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0
oooo01H0oooo00<02NX:0?ooo`3oool08P3oool200WZ2P@0oooo00<0000007moO`1oOgl04P1oOgl0
0`000000Ogmo07moO`0M07moO`030000003oool0oooo01L0oooo0P09jPX>0?ooo`030000001oOgl0
Ogmo01L0Ogmo00<02NX:07moO`1oOgl02@1oOgl300WZ2P@0Ogmo00<02NX:07moO`1oOgl01@1oOgl0
0`000000oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo0200oooo00<02NX:0?ooo`3oool01`3oool0
0`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo03D0oooo00<000000?ooo`3oool0303oool0
0800oooo00<000000?ooo`3oool08@3oool00`09jPX0oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo
00X0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`0P0?ooo`<02NX:1P3oool00`00
0000Ogmo07moO`0B07moO`030000001oOgl0Ogmo01`0Ogmo00<000000?ooo`3oool06P3oool00`09
jPX0oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo01H0Ogmo00<02NX:07moO`1oOgl02P1oOgl01P09
jPX0Ogmo00WZ2P09jPX0Ogmo00WZ2PP0Ogmo00<000000?ooo`3oool08P3oool00`09jPX0oooo0?oo
o`0Q0?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?oo
o`0d0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo0200oooo00<02NX:
0?ooo`3oool08`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:
0?ooo`3oool07P3oool300WZ2PT0oooo00<0000007moO`1oOgl04P1oOgl00`000000Ogmo07moO`0J
07moO`8000007P3oool00`09jPX0oooo0?ooo`0<0?ooo`8000005P1oOgl00`09jPX0Ogmo07moO`0:
07moO`0400WZ2P1oOgl0Ogmo000000802NX:201oOgl00`000000oooo0?ooo`0Q0?ooo`0300WZ2P3o
ool0oooo02<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3o
ool0oooo03@0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0803oool0
0`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0503oool0
0`09jPX0oooo0?ooo`0M0?ooo`802NX:303oool00`000000Ogmo07moO`0A07moO`030000001oOgl0
Ogmo01X0Ogmo00<000000?ooo`3oool07`3oool200WZ2Ph0oooo00<0000007moO`1oOgl04`1oOgl0
0`09jPX0Ogmo07moO`0:07moO`<02NX:0P000000101oOgl02NX:00WZ2P09jPX507moO`030000003o
ool0oooo0200oooo00<02NX:0?ooo`3oool09@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3o
ool0oooo00h0oooo00<02NX:0?ooo`3oool0<`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool0
0`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo0280oooo00<02NX:0?ooo`3oool0303oool0
0`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01/0oooo0`09jPX?0?ooo`030000001oOgl0
Ogmo0100Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`0R0?ooo`0300WZ2P3oool0
oooo00`0oooo00<0000007moO`1oOgl04P1oOgl00`09jPX0Ogmo07moO`0907moO`802NX:201oOgl2
00WZ2P80Ogmo00<000000?ooo`3oool0803oool00`09jPX0oooo0?ooo`0W0?ooo`0300WZ2P3oool0
oooo00D0oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0b0?ooo`030000003oool0
oooo00`0oooo00200?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool08@3oool00`09
jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool06@3oool300WZ
2Q80oooo00<0000007moO`1oOgl0401oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo
02@0oooo00<02NX:0?ooo`3oool0303oool00`000000Ogmo07moO`0A07moO`0300WZ2P1oOgl0Ogmo
00L0Ogmo0`09jPX;07moO`802NX:00<000000?ooo`3oool0803oool00`09jPX0oooo0?ooo`0X0?oo
o`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0b0?oo
o`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3o
ool0803oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3o
ool05@3oool2000000<02NX:5@3oool00`000000Ogmo07moO`0?07moO`030000001oOgl0Ogmo01P0
Ogmo00<000000?ooo`3oool09P3oool00`09jPX0oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo0100
Ogmo00<02NX:07moO`1oOgl01@1oOgl200WZ2P80Ogmo00<02NX:07moO`1oOgl02`1oOgl200WZ2R00
oooo00<02NX:0?ooo`3oool0:P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00l0
oooo00<02NX:0?ooo`3oool0<@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo
0?ooo`0N0?ooo`0300WZ2P3oool0oooo0200oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo
0?ooo`0A0?ooo`0300WZ2P3oool0oooo01H0oooo0P00000H0?ooo`030000001oOgl0Ogmo00l0Ogmo
00<0000007moO`1oOgl05P1oOgl2000002X0oooo0P09jPX=0?ooo`800000401oOgl00`09jPX0Ogmo
07moO`0307moO`802NX:101oOgl00`09jPX0Ogmo07moO`0;07moO`030000003oool02NX:00802NX:
703oool00`09jPX0oooo0?ooo`0/0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
3`3oool00`09jPX0oooo0?ooo`0`0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003o
ool0oooo01h0oooo00<02NX:0?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3o
ool0oooo0100oooo00<02NX:0?ooo`3oool0<P3oool00`000000Ogmo07moO`0>07moO`030000001o
Ogl0Ogmo01D0Ogmo00<000000?ooo`3oool0;03oool00`09jPX0oooo0?ooo`0<0?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2PD0Ogmo00<02NX:07moO`1oOgl02`1o
Ogl00`000000oooo0?ooo`030?ooo`802NX:6P3oool00`09jPX0oooo0?ooo`0]0?ooo`0300WZ2P3o
ool0oooo00@0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0`0?ooo`030000003o
ool0oooo00`0oooo00200?ooo`030000003oool0oooo01d0oooo00<02NX:0?ooo`3oool07`3oool0
0`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0<`3oool0
0`000000Ogmo07moO`0=07moO`030000001oOgl0Ogmo01D0Ogmo00<000000?ooo`3oool0;P3oool0
0`09jPX0oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00/0Ogmo00<02NX:07moO`1oOgl00P09jPX7
07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool01@3oool200WZ2QL0oooo00<02NX:
0?ooo`3oool0;`3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00l0oooo00<02NX:
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0M0?oo
o`0300WZ2P3oool0oooo01h0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`0?0?oo
o`0300WZ2P3oool0oooo03@0oooo00<0000007moO`1oOgl03@1oOgl00`000000Ogmo07moO`0D07mo
O`030000003oool0oooo0300oooo0P09jPX=0?ooo`030000001oOgl0Ogmo00T0Ogmo0P00000200WZ
2PT0Ogmo00<02NX:07moO`1oOgl02`1oOgl00`000000oooo0?ooo`070?ooo`802NX:503oool00`09
jPX0oooo0?ooo`0a0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool03`3oool00`09
jPX0oooo0?ooo`0^0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo01`0
oooo00<02NX:0?ooo`3oool07P3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo00h0
oooo00<02NX:0?ooo`3oool0=@3oool00`000000Ogmo07moO`0=07moO`030000001oOgl0Ogmo01<0
Ogmo00<000000?ooo`3oool0<`3oool00`09jPX0oooo0?ooo`0;0?ooo`030000001oOgl0Ogmo00P0
Ogmo00<0000000WZ2P1oOgl02P1oOgl00`09jPX0Ogmo07moO`0;07moO`030000003oool0oooo00T0
oooo0`09jPXA0?ooo`0300WZ2P3oool0oooo0380oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0
oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo02h0oooo00<000000?ooo`3oool0303oool00800oooo
00<000000?ooo`3oool0703oool00`09jPX0oooo0?ooo`0M0?ooo`0300WZ2P3oool0oooo0140oooo
00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0g0?ooo`030000001oOgl0Ogmo00/0Ogmo
00<0000007moO`1oOgl04P1oOgl2000003L0oooo00<02NX:0?ooo`3oool02`3oool2000001@0Ogmo
00<02NX:07moO`1oOgl02`1oOgl00`000000oooo0?ooo`0=0?ooo`802NX:3P3oool00`09jPX0oooo
0?ooo`0d0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo
0?ooo`0]0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo01/0oooo00<0
2NX:0?ooo`3oool07@3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo00d0oooo00<0
2NX:0?ooo`3oool0>03oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo0140Ogmo00<0
00000?ooo`3oool0>03oool200WZ2Pd0oooo00<0000007moO`1oOgl04@1oOgl00`09jPX0Ogmo07mo
O`0;07moO`030000003oool0oooo00l0oooo0P09jPX;0?ooo`0300WZ2P3oool0oooo03H0oooo00D0
2NX:0?ooo`3oool0oooo00WZ2P0B0?ooo`0300WZ2P3oool0oooo02`0oooo00<000000?ooo`3oool0
303oool00800oooo00<000000?ooo`3oool06`3oool00`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3o
ool0oooo01<0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0i0?ooo`030000001o
Ogl0Ogmo00/0Ogmo00<0000007moO`1oOgl0401oOgl00`000000oooo0?ooo`0k0?ooo`0300WZ2P3o
ool0oooo00/0oooo00<0000007moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0;07moO`030000003o
ool0oooo0140oooo0`09jPX80?ooo`0300WZ2P3oool0oooo03L0oooo00D02NX:0?ooo`3oool0oooo
00WZ2P0A0?ooo`0300WZ2P3oool0oooo02`0oooo00<000000?ooo`3oool0303oool00800oooo00<0
00000?ooo`3oool06`3oool00`09jPX0oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo01<0oooo00<0
2NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl0401oOgl00`000000oooo0?ooo`0m0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
000007moO`1oOgl03`1oOgl00`09jPX0Ogmo07moO`0;07moO`030000003oool0oooo01@0oooo0P09
jPX50?ooo`0300WZ2P3oool0oooo03T0oooo00@02NX:0?ooo`3oool02NX:4P3oool00`09jPX0oooo
0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo01X0oooo00<0
2NX:0?ooo`3oool06`3oool00`09jPX0oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool0?03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00l0Ogmo00<0
00000?ooo`3oool0?`3oool200WZ2P`0oooo00<0000007moO`1oOgl03@1oOgl00`09jPX0Ogmo07mo
O`0;07moO`030000003oool0oooo01L0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo03/0oooo00@0
2NX:0?ooo`3oool02NX:4P3oool00`09jPX0oooo0?ooo`0Z0?ooo`030000003oool0oooo00`0oooo
00200?ooo`030000003oool0oooo01X0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?oo
o`0E0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0?@3oool00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00d0Ogmo0P0000140?ooo`0300WZ2P3oool0oooo00X0oooo0P00
000=07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool06@3oool200WZ2Sl0oooo00<0
2NX:0?ooo`09jPX04P3oool00`09jPX0oooo0?ooo`0Z0?ooo`030000003oool0oooo00`0oooo0020
0?ooo`030000003oool0oooo01T0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`0E
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0?P3oool00`000000Ogmo07moO`08
07moO`030000001oOgl0Ogmo00d0Ogmo00<000000?ooo`3oool0A@3oool00`09jPX0oooo0?ooo`0;
0?ooo`030000001oOgl0Ogmo00X0Ogmo00<02NX:07moO`1oOgl02`1oOgl00`000000oooo0?ooo`0J
0?ooo`@02NX:?@3oool00`09jPX0oooo00WZ2P0B0?ooo`0300WZ2P3oool0oooo02T0oooo00<00000
0?ooo`3oool0303oool00800oooo00<000000?ooo`3oool06@3oool00`09jPX0oooo0?ooo`0H0?oo
o`802NX:603oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo03l0oooo00<0000007mo
O`1oOgl0201oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo04L0oooo00<02NX:0?oo
o`3oool02`3oool00`000000Ogmo07moO`0807moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<000000?oo
o`3oool06@3oool00`09jPX0oooo0?ooo`020?ooo`802NX:?03oool200WZ2Q<0oooo00<02NX:0?oo
o`3oool0:03oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0H0?ooo`03
00WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool0603oool00`09jPX0oooo0?ooo`080?ooo`03
00WZ2P3oool0oooo0440oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0;07moO`03
0000003oool0oooo04T0oooo0P09jPX<0?ooo`030000001oOgl0Ogmo00L0Ogmo00<02NX:07moO`1o
Ogl02`1oOgl00`000000oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPXk0?ooo`80
2NX:4P3oool00`09jPX0oooo0?ooo`0X0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000
003oool0oooo01P0oooo00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ
2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0@P3oool00`000000Ogmo07moO`0607moO`030000
001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0C03oool00`09jPX0oooo0?ooo`0:0?ooo`030000
001oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl02`1oOgl00`000000oooo0?ooo`0I0?ooo`0300WZ
2P3oool0oooo00L0oooo0`09jPXi0?ooo`802NX:4P3oool00`09jPX0oooo0?ooo`0W0?ooo`030000
003oool0oooo00`0oooo00200?ooo`030000003oool0oooo01P0oooo00<02NX:0?ooo`3oool05P3o
ool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool0@`3o
ool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo00T0Ogmo0P00001@0?ooo`0300WZ2P3o
ool0oooo00X0oooo0P00000607moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0603o
ool00`09jPX0oooo0?ooo`0;0?ooo`802NX:>03oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3o
ool0oooo02H0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool05`3oool0
0`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3oool01P3oool0
0`09jPX0oooo0?ooo`140?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl0201oOgl0
0`000000oooo0?ooo`1A0?ooo`800000303oool00`000000Ogmo07moO`0207moO`0300WZ2P1oOgl0
Ogmo00`0Ogmo00<000000?ooo`3oool05`3oool00`09jPX0oooo0?ooo`0>0?ooo`802NX:=`3oool0
0`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo02H0oooo00<000000?ooo`3oool0303oool0
0800oooo00<000000?ooo`3oool05`3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo
01X0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`160?ooo`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`1B0?ooo`8000003@3oool01@00
0000Ogmo07moO`1oOgl02NX:00d0Ogmo00<000000?ooo`3oool0603oool00`09jPX0oooo0?ooo`0@
0?ooo`802NX:=@3oool200WZ2Q80oooo00<02NX:0?ooo`3oool09@3oool00`000000oooo0?ooo`0<
0?ooo`00P03oool00`000000oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?oo
o`3oool06`3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo04L0oooo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0707moO`030000003oool0oooo06<0oooo00@0000007mo
O`1oOgl02NX:3@1oOgl00`000000oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo01<0oooo0`09jPXc
0?ooo`802NX:4P3oool00`09jPX0oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo00200?oo
o`030000003oool0oooo01H0oooo00<02NX:0?ooo`3oool0503oool00`09jPX0oooo0?ooo`0L0?oo
o`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0B03oool00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00H0Ogmo00<000000?ooo`3oool0I@3oool00`000000Ogmo00WZ2P0=07mo
O`030000003oool0oooo01H0oooo00<02NX:0?ooo`3oool05`3oool200WZ2S40oooo00<02NX:0?oo
o`09jPX04P3oool00`09jPX0oooo0?ooo`0S0?ooo`030000003oool0oooo00`0oooo00200?ooo`03
0000003oool0oooo01D0oooo00<02NX:0?ooo`3oool0503oool00`09jPX0oooo0?ooo`0M0?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0B@3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00D0Ogmo0P00001Y0?ooo`0300WZ2P000000Ogmo00`0Ogmo00<000000?ooo`3o
ool05@3oool00`09jPX0oooo0?ooo`0J0?ooo`802NX:<03oool00`09jPX0oooo00WZ2P0A0?ooo`03
00WZ2P3oool0oooo02<0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0
5@3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01d0oooo00<02NX:0?ooo`3oool0
0`3oool00`09jPX0oooo0?ooo`1;0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0
101oOgl00`000000oooo0?ooo`1Y0?ooo`0300WZ2P3oool0000000/0Ogmo00<000000?ooo`3oool0
5P3oool00`09jPX0oooo0?ooo`0L0?ooo`<02NX:;@3oool01009jPX0oooo0?ooo`09jPXA0?ooo`03
00WZ2P3oool0oooo0280oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0
503oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01h0oooo00<02NX:0?ooo`3oool0
0P3oool00`09jPX0oooo0?ooo`1<0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`1Z0?ooo`0400WZ2P3oool0oooo000000X0Ogmo00<000000?ooo`3o
ool05@3oool00`09jPX0oooo0?ooo`0P0?ooo`802NX:;03oool01009jPX0oooo0?ooo`09jPXA0?oo
o`0300WZ2P3oool0oooo0240oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3o
ool0503oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo01l0oooo00D02NX:0?ooo`3o
ool0oooo00WZ2P1?0?ooo`050000001oOgl0Ogmo07moO`0000001@1oOgl00`000000oooo0?ooo`1[
0?ooo`0500WZ2P3oool0oooo0?ooo`0000002@1oOgl00`000000oooo0?ooo`0D0?ooo`0300WZ2P3o
ool0oooo02<0oooo0P09jPXZ0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0403oool00`09jPX0oooo
0?ooo`0Q0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo01@0oooo00<0
2NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0O0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0
D03oool01@000000Ogmo07moO`1oOgl0000000@0Ogmo00<000000?ooo`3oool0J`3oool00`09jPX0
oooo0?ooo`030?ooo`030000001oOgl0Ogmo00H0Ogmo00<000000?ooo`3oool0503oool00`09jPX0
oooo0?ooo`0U0?ooo`802NX::@3oool01@09jPX0oooo0?ooo`3oool02NX:0100oooo00<02NX:0?oo
o`3oool0803oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0C0?ooo`03
00WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool0803oool01009jPX0oooo0?ooo`09jPYB0?oo
o`040000001oOgl0Ogmo00000080Ogmo0P00001^0?ooo`0300WZ2P3oool0oooo00@0oooo0P000005
07moO`030000003oool0oooo01@0oooo00<02NX:0?ooo`3oool0:03oool300WZ2RH0oooo00<02NX:
0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo01l0oooo00<00000
0?ooo`3oool0303oool00800oooo00<000000?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0@0?oo
o`0300WZ2P3oool0oooo0240oooo00<02NX:0?ooo`09jPX0D`3oool00`000000Ogmo0000000207mo
O`030000003oool0oooo06h0oooo00<02NX:0?ooo`3oool01P3oool00`000000Ogmo07moO`0207mo
O`030000003oool0oooo01<0oooo00<02NX:0?ooo`3oool0;03oool200WZ2RD0oooo00<02NX:0?oo
o`3oool00P3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo01l0oooo00<000000?oo
o`3oool0303oool00800oooo00<000000?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0@0?ooo`03
00WZ2P3oool0oooo0240oooo00<02NX:0?ooo`09jPX0E03oool01@000000Ogmo0000001oOgl00000
0740oooo00<02NX:0?ooo`3oool01`3oool01@000000Ogmo07moO`1oOgl0000001D0oooo00<02NX:
0?ooo`3oool0;P3oool200WZ2R@0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0=
0?ooo`0300WZ2P3oool0oooo01h0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?oo
o`3oool04P3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo0280oooo0P09jPYE0?oo
o`040000001oOgl0000000000740oooo00<02NX:0?ooo`3oool02@3oool010000000Ogmo07moO`00
000D0?ooo`0300WZ2P3oool0oooo0340oooo0P09jPXR0?ooo`0300WZ2P3oool0oooo00<0oooo00<0
2NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo0020
0?ooo`030000003oool0oooo0140oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0S
0?ooo`0300WZ2P3oool0oooo05D0oooo0P00001b0?ooo`0300WZ2P3oool0oooo00X0oooo0P00000D
0?ooo`0300WZ2P3oool0oooo03@0oooo0`09jPXP0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:
0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo00200?oo
o`030000003oool0oooo0140oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0S0?oo
o`0300WZ2P3oool0oooo05H0oooo00<000000?ooo`3oool0L@3oool00`09jPX0oooo0?ooo`0;0?oo
o`030000003oool0oooo0180oooo00<02NX:0?ooo`3oool0=`3oool200WZ2Qh0oooo00<02NX:0?oo
o`3oool0103oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo01`0oooo00<000000?oo
o`3oool0303oool00800oooo00<000000?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0=0?ooo`03
00WZ2P3oool0oooo02<0oooo0P09jP[;0?ooo`0300WZ2P3oool0oooo0200oooo00<02NX:0?ooo`3o
ool0>P3oool200WZ2Qd0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0<0?ooo`03
00WZ2P3oool0oooo01/0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool0
403oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo02<0oooo00<02NX:0?ooo`09jPX0
b`3oool00`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo03d0oooo0`09jPXJ0?ooo`0300WZ
2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0K0?ooo`030000
003oool0oooo00`0oooo00200?ooo`030000003oool0oooo0100oooo00<02NX:0?ooo`3oool0303o
ool00`09jPX0oooo0?ooo`0S0?ooo`0300WZ2P3oool02NX:0<`0oooo00<02NX:0?ooo`3oool07P3o
ool00`09jPX0oooo0?ooo`110?ooo`802NX:6@3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3o
ool0oooo00/0oooo00<02NX:0?ooo`3oool06P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool0
0`000000oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool08`3oool0
1009jPX0oooo0?ooo`09jP[<0?ooo`0300WZ2P3oool0oooo01h0oooo00<02NX:0?ooo`3oool0@`3o
ool200WZ2QL0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3o
ool0oooo01T0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool03`3oool0
0`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo02<0oooo00D02NX:0?ooo`3oool0oooo00WZ
2P3;0?ooo`0300WZ2P3oool0oooo01h0oooo00<02NX:0?ooo`3oool0AP3oool200WZ2QH0oooo00<0
2NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo01T0oooo00<0
00000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0:
0?ooo`802NX:9@3oool01@09jPX0oooo0?ooo`3oool02NX:0<`0oooo00<02NX:0?ooo`3oool07@3o
ool00`09jPX0oooo0?ooo`190?ooo`<02NX:4`3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3o
ool0oooo00X0oooo00<02NX:0?ooo`3oool0603oool00`000000oooo0?ooo`0<0?ooo`00P03oool0
0`000000oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool0903oool0
0`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo0<X0oooo00<02NX:0?ooo`3oool07@3oool0
0`09jPX0oooo0?ooo`1<0?ooo`802NX:4P3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`00
0000oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool0903oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0<X0oooo00<02NX:0?ooo`3oool0703oool00`09
jPX0oooo0?ooo`1?0?ooo`802NX:403oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo
00T0oooo00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000
oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0903oool00`09jPX0
oooo0?ooo`040?ooo`0300WZ2P3oool0oooo0<T0oooo00<02NX:0?ooo`3oool0703oool00`09jPX0
oooo0?ooo`1B0?ooo`<02NX:3P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo00T0
oooo00<02NX:0?ooo`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo
0?ooo`0=0?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool0903oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo0<X0oooo00<02NX:0?ooo`3oool0703oool00`09jPX0oooo
0?ooo`1E0?ooo`802NX:3@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo00T0oooo
00<02NX:0?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?oo
o`0<0?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool0903oool00`09jPX0oooo0?oo
o`050?ooo`0300WZ2P3oool0oooo0<X0oooo00<02NX:0?ooo`3oool06`3oool00`09jPX0oooo0?oo
o`1H0?ooo`802NX:2`3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00P0oooo00<0
2NX:0?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0<
0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0903oool00`09jPX0oooo0?ooo`06
0?ooo`0300WZ2P3oool0oooo0<X0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`1K
0?ooo`802NX:2P3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:
0?ooo`3oool0503oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0903oool00`09jPX0oooo0?ooo`060?oo
o`0300WZ2P3oool0oooo0<X0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`1N0?oo
o`<02NX:1`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?oo
o`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0;0?ooo`03
00WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0903oool00`09jPX0oooo0?ooo`070?ooo`03
00WZ2P3oool0oooo0<X0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`1Q0?ooo`80
2NX:1P3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3o
ool04`3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0903oool00`09jPX0oooo0?ooo`080?ooo`0300WZ
2P3oool0oooo0<X0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`1T0?ooo`802NX:
103oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool0
4P3oool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`0:0?ooo`0300WZ2P3o
ool0oooo00@0oooo00<02NX:0?ooo`3oool0903oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3o
ool0oooo0</0oooo00<02NX:0?ooo`3oool0603oool00`09jPX0oooo0?ooo`1W0?ooo`<02NX:0P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool04@3o
ool00`000000oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`090?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool0903oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0
oooo0<X0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`1Z0?ooo`<02NX:3P3oool0
0`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo0100oooo00<000000?ooo`3oool0303oool0
0800oooo00<000000?ooo`3oool02@3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo
02@0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`3:0?ooo`0300WZ2P3oool0oooo
01P0oooo00<02NX:0?ooo`3oool0K@3oool200WZ2Ph0oooo00<02NX:0?ooo`3oool01P3oool00`09
jPX0oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00200?ooo`030000003oool0oooo00T0
oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0T0?ooo`0300WZ2P3oool0oooo00X0
oooo00<02NX:0?ooo`3oool0b`3oool00`09jPX0oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo06l0
oooo0`09jPX=0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool03`3oool00`000000
oooo0?ooo`0<0?ooo`00P03oool00`000000oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo
00<02NX:0?ooo`3oool0903oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo0<X0oooo
00<02NX:0?ooo`3oool0603oool00`09jPX0oooo0?ooo`1`0?ooo`0300WZ2P3oool02NX:00802NX:
2`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00h0oooo00<000000?ooo`3oool0
303oool00800oooo00<000000?ooo`3oool0203oool01@09jPX0oooo0?ooo`3oool02NX:02H0oooo
00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`3:0?ooo`0300WZ2P3oool0oooo01L0oooo
00<02NX:0?ooo`3oool0L@3oool00`09jPX0oooo0?ooo`020?ooo`802NX:2P3oool00`09jPX0oooo
0?ooo`050?ooo`0300WZ2P3oool0oooo00h0oooo00<000000?ooo`3oool0303oool00800oooo00<0
00000?ooo`3oool01`3oool01@09jPX0oooo0?ooo`3oool02NX:02H0oooo00<02NX:0?ooo`3oool0
303oool00`09jPX0oooo0?ooo`3;0?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool0
L`3oool00`09jPX0oooo0?ooo`030?ooo`802NX:2@3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ
2P3oool0oooo00d0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool01`3o
ool01009jPX0oooo0?ooo`09jPXV0?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool0
b`3oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo07@0oooo00<02NX:0?ooo`3oool0
103oool200WZ2PP0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00200?ooo`030000003oool0oooo00H0oooo00@02NX:0?ooo`3oool02NX:
9P3oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo0<X0oooo00<02NX:0?ooo`3oool0
5P3oool00`09jPX0oooo0?ooo`1e0?ooo`0300WZ2P3oool0oooo00H0oooo0`09jPX60?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`00P03o
ool00`000000oooo0?ooo`060?ooo`0300WZ2P3oool02NX:02H0oooo00<02NX:0?ooo`3oool03P3o
ool00`09jPX0oooo0?ooo`3;0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0M`3o
ool00`09jPX0oooo0?ooo`080?ooo`802NX:1@3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3o
ool0oooo00/0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool01P3oool2
00WZ2RH0oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`3;0?ooo`0300WZ2P3oool0
oooo01@0oooo00<02NX:0?ooo`3oool0N03oool00`09jPX0oooo0?ooo`0:0?ooo`802NX:103oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool0303oool0
0800oooo00<000000?ooo`3oool01@3oool200WZ2RH0oooo00<02NX:0?ooo`3oool0403oool00`09
jPX0oooo0?ooo`3;0?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool0N@3oool00`09
jPX0oooo0?ooo`0;0?ooo`<02NX:0P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo
00X0oooo00<000000?ooo`3oool0303oool00800oooo00<000000?ooo`3oool01@3oool00`09jPX0
oooo0?ooo`0T0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0b`3oool00`09jPX0
oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo07X0oooo00<02NX:0?ooo`3oool03P3oool200WZ2P03
0?ooo`09jPX0oooo00@0oooo00<02NX:0?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`00
P03ooooo00000<`000003P3oool008H0oooo0`00000U0?ooo`8000004@3oool200000<`0oooo0P00
000E0?ooo`800000O@3oool2000000l0oooo100000040?ooo`8000006@3oool00?l0ooooo`3ooomK
0?ooo`00o`3ooooo0?oooe/0oooo003o0?ooool0ooooF`3oool00?l0ooooo`3ooomK0?ooo`00o`3o
oooo0?oooe/0oooo003o0?ooool0ooooF`3oool00?l0ooooo`3ooomK0?ooo`00o`3ooooo0?oooe/0
oooo003o0?ooool0ooooF`3oool00?l0ooooo`3ooomK0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 600.75}, {480.438, 0}} -> {-3.12592, -2.10002, \
0.00874213, 0.00874213}},
  CellTags->"CustomPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboPlot[stelsys,CreateStereoView->Crossed];", "Input",
  CellTags->"CustomPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .57143 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0136054 0.47619 [
[ 0 0 0 0 ]
[ 1 .57143 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .57143 L
0 .57143 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0136054 0.568027 0.557823 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 0 r
2 Mabswid
.4705 .70013 Mdot
.46471 .56223 m .46471 .56223 L .57235 .5066 L .692 .724 .874 r
F
.46471 .56223 m .49653 .59965 L .49653 .59965 L 0 0 .52 r
F
.58819 .63654 m .57235 .5066 L .57235 .5066 L .264 .262 .67 r
F
.70026 .53787 m .57235 .5066 L .57235 .5066 L .629 .684 .882 r
F
.70026 .53787 m .70026 .53787 L .57237 .50661 L .711 .325 .316 r
F
.58819 .63654 m .57235 .5066 L .57235 .5066 L .873 .707 .674 r
F
.49879 .42139 m .57235 .5066 L .57235 .5066 L .33 .369 .751 r
F
.46471 .56223 m .57235 .5066 L .57235 .5066 L .692 .724 .874 r
F
.46471 .56223 m .57235 .5066 L .57235 .5066 L F
.5149 .60704 m .49653 .59965 L .49653 .59965 L .873 .707 .674 r
F
.5149 .60704 m .49653 .59965 L .54094 .56152 L F
.58819 .63654 m .57235 .5066 L .58819 .63654 L .264 .262 .67 r
F
.58819 .63654 m .58819 .63654 L .57235 .5066 L .873 .707 .674 r
F
.70026 .53787 m .59719 .51268 L .67158 .44492 L .629 .684 .882 r
F
.57237 .50661 m .65133 .57584 L .57235 .5066 L .711 .325 .316 r
F
.70026 .53787 m .57235 .5066 L .70026 .53787 L .629 .684 .882 r
F
.70026 .53787 m .70026 .53787 L .67865 .55465 L .966 .84 .668 r
F
.70026 .53787 m .65133 .57584 L .65133 .57584 L .711 .325 .316 r
F
.70026 .53787 m .65133 .57584 L .57237 .50661 L F
.70026 .53787 m .65133 .57584 L .70026 .53787 L F
.58819 .63654 m .60941 .56055 L .63895 .58545 L .264 .262 .67 r
F
.70026 .53787 m .67158 .44492 L .67158 .44492 L .966 .84 .668 r
F
.70026 .53787 m .67158 .44492 L .67865 .55465 L F
.65133 .57584 m .63895 .58545 L .63895 .58545 L .711 .325 .316 r
F
.65133 .57584 m .63895 .58545 L .61532 .54427 L F
.67865 .55465 m .67158 .44492 L .63895 .58545 L .966 .84 .668 r
F
.70026 .53787 m .70026 .53787 L .67158 .44492 L .629 .684 .882 r
F
.67158 .44492 m .57235 .5066 L .63089 .47021 L F
.6425 .40472 m .6425 .40472 L .58615 .48656 L .245 0 .285 r
F
.6425 .40472 m .60526 .4588 L .57235 .5066 L .857 .739 .731 r
F
.60526 .4588 m .57235 .5066 L .57235 .5066 L F
.60526 .4588 m .57235 .5066 L .57235 .5066 L F
.60941 .56055 m .61152 .55298 L .63895 .58545 L .264 .262 .67 r
F
.63895 .58545 m .61152 .55298 L .63895 .58545 L F
.58819 .63654 m .58819 .63654 L .55872 .62468 L .593 .805 .981 r
F
.58819 .63654 m .63895 .58545 L .58819 .63654 L F
.58819 .63654 m .5149 .60704 L .5149 .60704 L .873 .707 .674 r
F
.58819 .63654 m .5149 .60704 L .57235 .5066 L F
.58819 .63654 m .5149 .60704 L .58819 .63654 L F
.46471 .56223 m .49653 .59965 L .46471 .56223 L 0 0 .52 r
F
.46471 .56223 m .57235 .5066 L .57235 .5066 L .319 0 .229 r
F
.46471 .56223 m .57235 .5066 L .52752 .56162 L F
.46471 .56223 m .57235 .5066 L .46471 .56223 L F
.46471 .56223 m .57235 .5066 L .57235 .5066 L .692 .724 .874 r
F
.46471 .56223 m .52752 .56162 L .46471 .56223 L .319 0 .229 r
F
.46471 .56223 m .52752 .56162 L .49653 .59965 L F
.6425 .40472 m .57235 .5066 L .6425 .40472 L .857 .739 .731 r
F
.6425 .40472 m .67158 .44492 L .58615 .48656 L .245 0 .285 r
F
.6425 .40472 m .58615 .48656 L .58615 .48656 L F
.58615 .48656 m .67158 .44492 L .57235 .5066 L F
.6425 .40472 m .57235 .5066 L .56866 .38179 L .857 .739 .731 r
F
.6425 .40472 m .55016 .37604 L .6425 .40472 L .645 .09 0 r
F
.49879 .42139 m .57235 .5066 L .49879 .42139 L .781 .427 .387 r
F
.49879 .42139 m .49879 .42139 L .444 .47042 L F
.49879 .42139 m .45507 .46051 L .45507 .46051 L 0 0 0 r
F
.49879 .42139 m .45507 .46051 L .49879 .42139 L F
.49879 .42139 m .444 .47042 L .444 .47042 L .781 .427 .387 r
F
.42166 .33803 m .52511 .36863 L .5251 .36863 L .688 .557 .701 r
F
.49879 .42139 m .57235 .5066 L .57235 .5066 L .781 .427 .387 r
F
.49879 .42139 m .49879 .42139 L .57235 .5066 L .33 .369 .751 r
F
.49879 .42139 m .57235 .5066 L .444 .47042 L .781 .427 .387 r
F
.46471 .56223 m .46471 .56223 L .444 .47042 L 0 0 .52 r
F
.46471 .56223 m .444 .47042 L .52164 .49231 L .692 .724 .874 r
F
.46471 .56223 m .52164 .49231 L .57235 .5066 L F
.58819 .63654 m .57235 .5066 L .61152 .55298 L .264 .262 .67 r
F
.44816 .48886 m .49653 .59965 L .444 .47042 L 0 0 .52 r
F
.46471 .56223 m .49653 .59965 L .44816 .48886 L F
.46471 .56223 m .444 .47042 L .444 .47042 L F
.46471 .56223 m .444 .47042 L .444 .47042 L F
.36243 .57751 m .444 .47042 L .47379 .54371 L .697 .529 .656 r
F
.46471 .56223 m .49653 .59965 L .49653 .59965 L .319 0 .229 r
F
.46471 .56223 m .46471 .56223 L .49653 .59965 L F
.36243 .57751 m .49653 .59965 L .49653 .59965 L .549 .721 .954 r
F
.57289 .70658 m .49653 .59965 L .49653 .59965 L .654 .473 .627 r
F
.57289 .70658 m .57289 .70658 L .5266 .64176 L .054 .24 .736 r
F
.58819 .63654 m .63895 .58545 L .63895 .58545 L .593 .805 .981 r
F
.58819 .63654 m .58819 .63654 L .63895 .58545 L .264 .262 .67 r
F
.58819 .63654 m .63895 .58545 L .63895 .58545 L F
.36243 .57751 m .36243 .57751 L .42965 .48925 L 0 0 0 r
F
.36243 .57751 m .49653 .59965 L .36243 .57751 L .549 .721 .954 r
F
.36243 .57751 m .40834 .53633 L .42965 .48925 L 0 0 0 r
F
.46471 .56223 m .49653 .59965 L .49653 .59965 L 0 0 .52 r
F
.36243 .57751 m .47379 .54371 L .49653 .59965 L .697 .529 .656 r
F
.444 .47042 m .49653 .59965 L .444 .47042 L 0 0 .52 r
F
.49653 .59965 m .49653 .59965 L .57235 .5066 L .873 .707 .674 r
F
.49653 .59965 m .41999 .52588 L .49653 .59965 L .928 .747 .636 r
F
.40834 .53633 m .41999 .52588 L .43647 .48782 L 0 0 0 r
F
.40834 .53633 m .43647 .48782 L .444 .47042 L F
.42965 .48925 m .40834 .53633 L .444 .47042 L F
.40834 .53633 m .40834 .53633 L .444 .47042 L F
.57235 .5066 m .49653 .59965 L .57235 .5066 L .873 .707 .674 r
F
.42166 .33803 m .5251 .36863 L .5251 .36863 L .688 .557 .701 r
F
.42166 .33803 m .5251 .36863 L .444 .47042 L F
.444 .47042 m .57235 .5066 L .444 .47042 L .781 .427 .387 r
F
.42909 .38208 m .444 .47042 L .45076 .41785 L 0 0 .502 r
F
.4312 .39122 m .4312 .39122 L .444 .47042 L .702 .791 .919 r
F
.36243 .57751 m .40834 .53633 L .41999 .52588 L .549 .721 .954 r
F
.36243 .57751 m .444 .47042 L .444 .47042 L .697 .529 .656 r
F
.36243 .57751 m .444 .47042 L .36243 .57751 L F
.42166 .33803 m .42166 .33803 L .55014 .37603 L .603 .072 0 r
F
.49879 .42139 m .55014 .37603 L .55014 .37603 L .33 .369 .751 r
F
.6425 .40472 m .55014 .37603 L .55014 .37603 L .645 .09 0 r
F
.52511 .36863 m .55014 .37603 L .55014 .37603 L .688 .557 .701 r
F
.49879 .42139 m .55014 .37603 L .55014 .37603 L 0 0 0 r
F
.49879 .42139 m .55012 .37604 L .55012 .37604 L .33 .369 .751 r
F
.49879 .42139 m .55016 .37615 L .57235 .5066 L F
.49879 .42139 m .57235 .5066 L .57235 .5066 L .781 .427 .387 r
F
.49879 .42139 m .45507 .46051 L .55014 .37603 L 0 0 0 r
F
.45507 .46051 m .444 .47042 L .55014 .37603 L F
.49879 .42139 m .49879 .42139 L .55014 .37603 L F
.49879 .42139 m .55014 .37603 L .49879 .42139 L .33 .369 .751 r
F
.5251 .36863 m .55014 .37603 L .444 .47042 L .688 .557 .701 r
F
.52511 .36863 m .55014 .37603 L .5251 .36863 L F
.42168 .33804 m .55014 .37603 L .55014 .37603 L .603 .072 0 r
F
.52406 .26216 m .55014 .37603 L .55014 .37603 L .898 .807 .75 r
F
.52406 .26216 m .52406 .26216 L .55013 .37602 L .162 .304 .762 r
F
.42909 .38208 m .444 .47042 L .444 .47042 L 0 0 .502 r
F
.42166 .33803 m .444 .47042 L .444 .47042 L .688 .557 .701 r
F
.33199 .43374 m .444 .47042 L .444 .47042 L .702 .791 .919 r
F
.42166 .33803 m .45552 .3808 L .5251 .36863 L .603 .072 0 r
F
.42166 .33803 m .44715 .37023 L .42166 .33803 L F
.55014 .37603 m .444 .47042 L .50761 .41385 L 0 0 0 r
F
.42166 .33803 m .42909 .38208 L .45076 .41785 L 0 0 .502 r
F
.42166 .33803 m .5251 .36863 L .42166 .33803 L .688 .557 .701 r
F
.5251 .36863 m .45552 .3808 L .55014 .37603 L .603 .072 0 r
F
.444 .47042 m .57235 .5066 L .444 .47042 L .781 .427 .387 r
F
.57235 .5066 m .57235 .5066 L .444 .47042 L F
.55014 .37603 m .57235 .5066 L .55014 .37603 L .857 .739 .731 r
F
.56967 .43599 m .55014 .37603 L .55014 .37603 L F
.57032 .43798 m .55014 .37603 L .56967 .43599 L F
.56866 .38179 m .5688 .38662 L .55014 .37603 L F
.5688 .38662 m .57032 .43798 L .55014 .37603 L F
.55014 .37603 m .57032 .43798 L .55014 .37603 L F
.57235 .5066 m .57235 .5066 L .56866 .38179 L F
.6425 .40472 m .6425 .40472 L .65953 .42827 L .645 .09 0 r
F
.6425 .40472 m .67158 .44492 L .6425 .40472 L .245 0 .285 r
F
.6425 .40472 m .56866 .38179 L .56866 .38179 L .857 .739 .731 r
F
.65953 .42827 m .56866 .38179 L .67158 .44492 L .645 .09 0 r
F
.6425 .40472 m .56866 .38179 L .65953 .42827 L F
.55014 .37603 m .55014 .37603 L .444 .47042 L .688 .557 .701 r
F
.55014 .37603 m .50761 .41385 L .55014 .37603 L 0 0 0 r
F
.50619 .36603 m .55014 .37603 L .45552 .3808 L .898 .807 .75 r
F
.67158 .44492 m .55014 .37603 L .58981 .39854 L .645 .09 0 r
F
.67158 .44492 m .58981 .39854 L .67158 .44492 L F
.67158 .44492 m .58981 .39854 L .67158 .44492 L F
.57032 .43798 m .57235 .5066 L .55014 .37603 L .857 .739 .731 r
F
.57235 .5066 m .57235 .5066 L .55014 .37603 L F
.444 .47042 m .55014 .37603 L .444 .47042 L .688 .557 .701 r
F
.56866 .38179 m .55014 .37603 L .55014 .37603 L .645 .09 0 r
F
.61394 .40956 m .55014 .37603 L .67158 .44492 L F
.56866 .38179 m .55014 .37603 L .61394 .40956 L F
.6425 .40472 m .67158 .44492 L .67158 .44492 L .245 0 .285 r
F
.6425 .40472 m .6425 .40472 L .56866 .38179 L .857 .739 .731 r
F
.56901 .36491 m .67158 .44492 L .60172 .4053 L .642 .522 .703 r
F
.56901 .36491 m .60172 .4053 L .55014 .37603 L F
.66634 .30758 m .66634 .30758 L .66933 .38595 L .946 .76 .619 r
F
.66634 .30758 m .55014 .37603 L .55014 .37603 L 0 0 0 r
F
.66634 .30758 m .67158 .44492 L .56901 .36491 L .642 .522 .703 r
F
.55014 .37603 m .55014 .37603 L .61605 .35185 L 0 0 0 r
F
.52406 .26216 m .55014 .37603 L .52406 .26216 L .898 .807 .75 r
F
.45552 .3808 m .55014 .37603 L .45552 .3808 L F
.444 .47042 m .45552 .3808 L .444 .47042 L .702 .791 .919 r
F
.42166 .33803 m .44812 .41061 L .45552 .3808 L 0 0 .502 r
F
.44812 .41061 m .45076 .41785 L .45552 .3808 L F
.43708 .42759 m .45552 .3808 L .444 .47042 L .702 .791 .919 r
F
.4312 .39122 m .45552 .3808 L .43708 .42759 L F
.45552 .3808 m .52134 .4594 L .45552 .3808 L .698 .282 .253 r
F
.33199 .43374 m .33199 .43374 L .444 .47042 L .702 .791 .919 r
F
.43435 .46726 m .444 .47042 L .42627 .50024 L .811 .393 .253 r
F
.42627 .50024 m .444 .47042 L .42996 .50284 L F
.444 .47042 m .41999 .52588 L .444 .47042 L 0 0 0 r
F
.41999 .52588 m .41999 .52588 L .49653 .59965 L .928 .747 .636 r
F
.49653 .59965 m .49653 .59965 L .63895 .58545 L .654 .473 .627 r
F
.41999 .52588 m .49653 .59965 L .41999 .52588 L .549 .721 .954 r
F
.58819 .63654 m .63895 .58545 L .55872 .62468 L .593 .805 .981 r
F
.49653 .59965 m .63895 .58545 L .49653 .59965 L F
.55872 .62468 m .63895 .58545 L .49653 .59965 L F
.57289 .70658 m .49653 .59965 L .61006 .58833 L .654 .473 .627 r
F
.49653 .59965 m .54672 .60197 L .49653 .59965 L .054 .24 .736 r
F
.40834 .53633 m .44853 .56518 L .41999 .52588 L .549 .721 .954 r
F
.44853 .56518 m .49653 .59965 L .41999 .52588 L F
.36243 .57751 m .49653 .59965 L .40834 .53633 L F
.41999 .52588 m .41999 .52588 L .49653 .59965 L .928 .747 .636 r
F
.49653 .59965 m .49653 .59965 L .41999 .52588 L .549 .721 .954 r
F
.41999 .52588 m .46236 .49809 L .41999 .52588 L .151 0 .197 r
F
.41999 .52588 m .41999 .52588 L .49302 .45246 L .617 .692 .897 r
F
.33199 .43374 m .444 .47042 L .444 .47042 L .811 .393 .253 r
F
.33199 .43374 m .444 .47042 L .33199 .43374 L F
.36231 .46549 m .42996 .50284 L .41999 .52588 L F
.33199 .43374 m .41999 .52588 L .33199 .43374 L .61 .459 .652 r
F
.33199 .43374 m .33199 .43374 L .36231 .46549 L .811 .393 .253 r
F
.33199 .43374 m .42996 .50284 L .36231 .46549 L F
.33199 .43374 m .41999 .52588 L .41999 .52588 L .61 .459 .652 r
F
.42166 .33803 m .42166 .33803 L .444 .47042 L .688 .557 .701 r
F
.33199 .43374 m .4312 .39122 L .444 .47042 L .702 .791 .919 r
F
.33199 .43374 m .43435 .46726 L .42627 .50024 L .811 .393 .253 r
F
.33199 .43374 m .41999 .52588 L .45552 .3808 L .61 .459 .652 r
F
.33199 .43374 m .39411 .40712 L .40632 .40189 L F
.39412 .40712 m .4312 .39122 L .40632 .40189 L F
.33199 .43374 m .4312 .39122 L .4312 .39122 L .702 .791 .919 r
F
.45552 .3808 m .45076 .41785 L .45552 .3808 L 0 0 .502 r
F
.39412 .40712 m .45552 .3808 L .4312 .39122 L .61 .459 .652 r
F
.45552 .3808 m .41999 .52588 L .45552 .3808 L F
.45552 .3808 m .45552 .3808 L .44634 .41831 L .948 .819 .684 r
F
.45552 .3808 m .44634 .41831 L .41999 .52588 L F
.41999 .52588 m .45552 .3808 L .41999 .52588 L F
.41999 .52588 m .41999 .52588 L .45552 .3808 L .61 .459 .652 r
F
.33199 .43374 m .45552 .3808 L .45552 .3808 L F
.41289 .50972 m .45552 .3808 L .41999 .52588 L .948 .819 .684 r
F
.39412 .40712 m .33199 .43374 L .45552 .3808 L .61 .459 .652 r
F
.45568 .38052 m .45552 .3808 L .52406 .26216 L .649 .464 .62 r
F
.52406 .26216 m .58763 .34306 L .55013 .37602 L .162 .304 .762 r
F
.66634 .30758 m .55014 .37603 L .66634 .30758 L 0 0 0 r
F
.66634 .30758 m .66634 .30758 L .56901 .36491 L .642 .522 .703 r
F
.66634 .30758 m .61605 .35185 L .66933 .38595 L .946 .76 .619 r
F
.66634 .30758 m .66634 .30758 L .61605 .35185 L 0 0 0 r
F
.66634 .30758 m .55014 .37603 L .61605 .35185 L F
.66634 .30758 m .61611 .3518 L .66634 .30758 L .946 .76 .619 r
F
.61611 .3518 m .61605 .35185 L .66634 .30758 L F
.66634 .30758 m .61605 .35185 L .61605 .35185 L 0 0 0 r
F
.66634 .30758 m .61605 .35185 L .61605 .35185 L .946 .76 .619 r
F
.66933 .38595 m .61605 .35185 L .67158 .44492 L F
.67158 .44492 m .57243 .50655 L .57235 .5066 L .245 0 .285 r
F
.67158 .44492 m .63089 .47021 L .67158 .44492 L .629 .684 .882 r
F
.67158 .44492 m .67158 .44492 L .57245 .50654 L .245 0 .285 r
F
.59719 .51268 m .57235 .5066 L .67158 .44492 L .629 .684 .882 r
F
.67158 .44492 m .60334 .36304 L .67158 .44492 L .946 .76 .619 r
F
.74693 .38536 m .67158 .44492 L .67158 .44492 L .576 .713 .936 r
F
.74693 .38536 m .74693 .38536 L .72111 .40577 L 0 0 .006 r
F
.61605 .35185 m .60334 .36304 L .67158 .44492 L .946 .76 .619 r
F
.74693 .38536 m .67158 .44492 L .74693 .38536 L .576 .713 .936 r
F
.60334 .36304 m .67158 .44492 L .60334 .36304 L F
.69445 .3772 m .67762 .42702 L .60334 .36304 L F
.67762 .42702 m .67158 .44492 L .60334 .36304 L F
.70026 .53787 m .67158 .44492 L .67158 .44492 L .966 .84 .668 r
F
.70026 .53787 m .67162 .44505 L .70026 .53787 L F
.67162 .44505 m .67158 .44492 L .70026 .53787 L F
.70026 .53787 m .68083 .4749 L .68083 .4749 L .629 .684 .882 r
F
.68083 .4749 m .67158 .44492 L .68083 .4749 L F
.68083 .4749 m .67158 .44492 L .67158 .44492 L F
.76721 .53583 m .67158 .44492 L .67158 .44492 L .801 .348 .165 r
F
.76721 .53583 m .76721 .53583 L .68968 .56583 L .694 .809 .936 r
F
.76721 .53583 m .63895 .58545 L .67089 .44786 L .618 .469 .657 r
F
.55014 .37603 m .60334 .36304 L .55014 .37603 L .162 .304 .762 r
F
.60334 .36304 m .60334 .36304 L .55014 .37603 L F
.63895 .58545 m .63895 .58545 L .67158 .44492 L .618 .469 .657 r
F
.67158 .44492 m .63895 .58545 L .67158 .44492 L F
.63895 .58545 m .67158 .44492 L .63895 .58545 L .966 .84 .668 r
F
.67158 .44492 m .67158 .44492 L .63895 .58545 L F
.57235 .5066 m .67158 .44492 L .57235 .5066 L .245 0 .285 r
F
.60334 .36304 m .66236 .49991 L .60334 .36304 L 0 .058 .611 r
F
.76721 .53583 m .67158 .44492 L .76721 .53583 L .801 .348 .165 r
F
.76721 .53583 m .76721 .53583 L .67158 .44492 L .618 .469 .657 r
F
.76721 .53583 m .67089 .44786 L .67158 .44492 L F
.76721 .53583 m .67158 .44492 L .67158 .44492 L F
.76721 .53583 m .67158 .44492 L .66619 .47705 L .801 .348 .165 r
F
.76721 .53583 m .66236 .49991 L .68968 .56583 L .694 .809 .936 r
F
.76721 .53583 m .63895 .58545 L .76721 .53583 L .618 .469 .657 r
F
.66236 .49991 m .66619 .47705 L .66236 .49991 L .801 .348 .165 r
F
.76721 .53583 m .67516 .48226 L .66236 .49991 L F
.67516 .48226 m .66619 .47705 L .66236 .49991 L F
.54094 .56152 m .49653 .59965 L .57235 .5066 L .873 .707 .674 r
F
.57235 .5066 m .63895 .58545 L .57235 .5066 L .711 .325 .316 r
F
.49653 .59965 m .52752 .56162 L .49653 .59965 L .319 0 .229 r
F
.63895 .58545 m .49653 .59965 L .63895 .58545 L .654 .473 .627 r
F
.57235 .5066 m .63895 .58545 L .57235 .5066 L .711 .325 .316 r
F
.63895 .58545 m .63895 .58545 L .57235 .5066 L F
.55196 .62293 m .63895 .58545 L .55196 .62293 L .914 .828 .748 r
F
.57289 .70658 m .63895 .58545 L .55196 .62293 L F
.55196 .62293 m .63895 .58545 L .54672 .60197 L F
.63895 .58545 m .54672 .60197 L .63895 .58545 L .651 .162 .076 r
F
.54672 .60197 m .54672 .60197 L .63895 .58545 L F
.49653 .59965 m .47379 .54371 L .49653 .59965 L .697 .529 .656 r
F
.54672 .60197 m .41999 .52588 L .54672 .60197 L .706 .19 0 r
F
.54672 .60197 m .49653 .59965 L .54672 .60197 L .074 0 0 r
F
.42515 .66973 m .42515 .66973 L .49653 .59965 L .928 .747 .636 r
F
.5266 .64176 m .54672 .60197 L .49653 .59965 L .054 .24 .736 r
F
.63895 .58545 m .63895 .58545 L .54672 .60197 L .914 .828 .748 r
F
.65214 .53725 m .66236 .49991 L .65214 .53725 L .694 .809 .936 r
F
.65214 .53725 m .65214 .53725 L .63895 .58545 L F
.63895 .58545 m .65214 .53725 L .63895 .58545 L F
.54672 .60197 m .63895 .58545 L .54672 .60197 L .914 .828 .748 r
F
.57289 .70658 m .63895 .58545 L .57289 .70658 L F
.57289 .70658 m .63895 .58545 L .63895 .58545 L F
.57289 .70658 m .63895 .58545 L .63895 .58545 L F
.57289 .70658 m .54672 .60197 L .54672 .60197 L .054 .24 .736 r
F
.68751 .6451 m .68751 .6451 L .54673 .60197 L .687 .555 .7 r
F
.65907 .61016 m .54672 .60197 L .63895 .58545 L .651 .162 .076 r
F
.68751 .6451 m .68751 .6451 L .65907 .61016 L F
.68751 .6451 m .54672 .60197 L .65907 .61016 L F
.66236 .49991 m .66619 .47705 L .66236 .49991 L .801 .348 .165 r
F
.68968 .56583 m .66236 .49991 L .66236 .49991 L .694 .809 .936 r
F
.72111 .40577 m .66236 .49991 L .66586 .47904 L 0 0 .006 r
F
.74693 .38536 m .66236 .49991 L .66236 .49991 L .696 .525 .652 r
F
.68968 .56583 m .66236 .49991 L .66345 .57598 L .694 .809 .936 r
F
.66345 .57598 m .66236 .49991 L .63895 .58545 L F
.76721 .53583 m .63895 .58545 L .63895 .58545 L .618 .469 .657 r
F
.68751 .6451 m .64807 .59665 L .65832 .51468 L 0 .057 .572 r
F
.64807 .59665 m .63895 .58545 L .65832 .51468 L F
.57289 .70658 m .49653 .59965 L .57289 .70658 L .654 .473 .627 r
F
.42515 .66973 m .51852 .61768 L .42515 .66973 L .636 .518 .702 r
F
.42515 .66973 m .49653 .59965 L .49653 .59965 L .928 .747 .636 r
F
.42515 .66973 m .49653 .59965 L .52281 .61529 L .074 0 0 r
F
.49653 .59965 m .49653 .59965 L .54672 .60197 L F
.56481 .67428 m .54672 .60197 L .54672 .60197 L .054 .24 .736 r
F
.57015 .6956 m .54672 .60197 L .56481 .67428 L F
.57015 .6956 m .54672 .60197 L .54672 .60197 L F
.57289 .70658 m .54672 .60197 L .5266 .64176 L F
.57289 .70658 m .57289 .70658 L .54672 .60197 L .914 .828 .748 r
F
.42515 .66973 m .54672 .60197 L .54672 .60197 L .636 .518 .702 r
F
.57289 .70658 m .54672 .60197 L .54672 .60197 L .914 .828 .748 r
F
.52281 .61529 m .52281 .61529 L .54672 .60197 L .074 0 0 r
F
.54672 .60197 m .54672 .60197 L .49653 .59965 L .054 .24 .736 r
F
.52281 .61529 m .49653 .59965 L .54672 .60197 L .074 0 0 r
F
.54631 .60219 m .54656 .60205 L .52964 .61148 L .636 .518 .702 r
F
.52281 .61529 m .54672 .60197 L .54672 .60197 L .074 0 0 r
F
.54656 .60205 m .54672 .60197 L .51852 .61768 L .636 .518 .702 r
F
.42515 .66973 m .49653 .59965 L .42515 .66973 L .074 0 0 r
F
.54672 .60197 m .51655 .61878 L .48955 .63383 L .636 .518 .702 r
F
.33199 .43374 m .41999 .52588 L .41999 .52588 L .61 .459 .652 r
F
.40834 .53633 m .41999 .52588 L .41999 .52588 L .549 .721 .954 r
F
.42514 .66967 m .41999 .52588 L .41999 .52588 L .636 .518 .702 r
F
.41999 .52588 m .41999 .52588 L .49653 .59965 L .928 .747 .636 r
F
.42515 .66973 m .49653 .59965 L .49653 .59965 L .074 0 0 r
F
.42515 .66973 m .41999 .52588 L .42514 .66967 L .636 .518 .702 r
F
.42515 .66973 m .41999 .52588 L .41999 .52588 L .928 .747 .636 r
F
.42515 .66973 m .41999 .52588 L .49653 .59965 L F
.42253 .59676 m .41999 .52588 L .41999 .52588 L F
.42515 .66973 m .42515 .66973 L .41999 .52588 L .636 .518 .702 r
F
.42515 .66973 m .41999 .52588 L .42253 .59676 L .928 .747 .636 r
F
.42515 .66973 m .41999 .52588 L .42515 .66973 L F
.54672 .60197 m .54672 .60197 L .49653 .59965 L .054 .24 .736 r
F
.49653 .59965 m .49653 .59965 L .52281 .61529 L .074 0 0 r
F
.42515 .66973 m .54672 .60197 L .42125 .52664 L .636 .518 .702 r
F
.43728 .57895 m .43728 .57895 L .41999 .52588 L .151 0 .197 r
F
.43728 .57895 m .54672 .60197 L .54672 .60197 L .87 .753 .731 r
F
.54672 .60197 m .54672 .60197 L .41999 .52588 L .636 .518 .702 r
F
.76721 .53583 m .66236 .49991 L .66236 .49991 L .694 .809 .936 r
F
.74693 .38536 m .74693 .38536 L .66236 .49991 L .696 .525 .652 r
F
.76721 .53583 m .66236 .49991 L .76721 .53583 L .694 .809 .936 r
F
.66236 .49991 m .65832 .51468 L .66236 .49991 L 0 .057 .572 r
F
.57235 .5066 m .55016 .37615 L .57235 .5066 L .33 .369 .751 r
F
.66236 .49991 m .52134 .4594 L .66236 .49991 L .687 .736 .888 r
F
.52134 .4594 m .52561 .4834 L .52134 .4594 L .87 .753 .731 r
F
.52134 .4594 m .58265 .47701 L .52134 .4594 L .78 .401 .338 r
F
.66236 .49991 m .66236 .49991 L .60334 .36304 L 0 .058 .611 r
F
.74693 .38536 m .67158 .44492 L .69445 .3772 L .576 .713 .936 r
F
.74693 .38536 m .60334 .36304 L .60336 .3631 L .696 .525 .652 r
F
.67158 .44492 m .66586 .47904 L .67158 .44492 L 0 0 .006 r
F
.72111 .40577 m .66586 .47904 L .67158 .44492 L F
.74693 .38536 m .66236 .49991 L .72111 .40577 L F
.67158 .44492 m .67089 .44786 L .67158 .44492 L .618 .469 .657 r
F
.74693 .38536 m .60336 .3631 L .66236 .49991 L .696 .525 .652 r
F
.61041 .36747 m .66236 .49991 L .60334 .36304 L 0 .058 .611 r
F
.64879 .39152 m .60334 .36304 L .63471 .3827 L .237 0 .135 r
F
.64879 .39152 m .64879 .39152 L .65389 .43226 L .687 .736 .888 r
F
.64879 .39152 m .64879 .39152 L .61041 .36747 L 0 .058 .611 r
F
.64879 .39152 m .66236 .49991 L .61041 .36747 L F
.74693 .38536 m .60334 .36304 L .60334 .36304 L .696 .525 .652 r
F
.74693 .38536 m .60334 .36304 L .60334 .36304 L F
.74693 .38536 m .60334 .36304 L .74693 .38536 L F
.74693 .38536 m .60334 .36304 L .60334 .36304 L F
.64879 .39152 m .60334 .36304 L .60334 .36304 L .237 0 .135 r
F
.60334 .36304 m .55014 .37603 L .60334 .36304 L 0 0 0 r
F
.61605 .35185 m .58571 .36298 L .60334 .36304 L F
.58571 .36298 m .55014 .37603 L .60334 .36304 L F
.55014 .37603 m .60334 .36304 L .55014 .37603 L .162 .304 .762 r
F
.55014 .37603 m .60172 .4053 L .55014 .37603 L .642 .522 .703 r
F
.60334 .36304 m .56895 .40345 L .60334 .36304 L .886 .717 .667 r
F
.54552 .44652 m .60334 .36304 L .57422 .39726 L .237 0 .135 r
F
.52134 .4594 m .57422 .39726 L .52134 .4594 L F
.54552 .44652 m .57422 .39726 L .52134 .4594 L F
.60334 .36304 m .55014 .37603 L .60334 .36304 L 0 0 0 r
F
.55883 .36839 m .60334 .36304 L .55014 .37603 L .162 .304 .762 r
F
.58763 .34306 m .60334 .36304 L .55883 .36839 L F
.58763 .34306 m .60334 .36304 L .60334 .36304 L F
.55014 .37603 m .55014 .37603 L .46895 .35755 L .898 .807 .75 r
F
.4625 .36872 m .50619 .36603 L .45552 .3808 L F
.52406 .26216 m .45552 .3808 L .45552 .3808 L .649 .464 .62 r
F
.46895 .35755 m .46895 .35755 L .4625 .36872 L .898 .807 .75 r
F
.46895 .35755 m .50619 .36603 L .4625 .36872 L F
.52406 .26216 m .45552 .3808 L .45552 .3808 L .649 .464 .62 r
F
.52406 .26216 m .45568 .38052 L .52406 .26216 L F
.52406 .26216 m .55014 .37603 L .46895 .35755 L .898 .807 .75 r
F
.52406 .26216 m .45552 .3808 L .45552 .3808 L .649 .464 .62 r
F
.52406 .26216 m .45552 .3808 L .45554 .38079 L F
.42166 .33803 m .45552 .3808 L .42166 .33803 L .603 .072 0 r
F
.42166 .33803 m .45552 .3808 L .45552 .3808 L F
.40632 .40189 m .4312 .39122 L .45552 .3808 L .61 .459 .652 r
F
.4312 .39122 m .45552 .3808 L .45552 .3808 L F
.4312 .39122 m .45552 .3808 L .45552 .3808 L F
.4312 .39122 m .45552 .3808 L .45552 .3808 L .702 .791 .919 r
F
.45554 .38079 m .45552 .3808 L .45554 .3808 L .649 .464 .62 r
F
.52406 .26216 m .60334 .36304 L .60334 .36304 L F
.61605 .35185 m .60334 .36304 L .60334 .36304 L .946 .76 .619 r
F
.55013 .37602 m .58763 .34306 L .55014 .37603 L .162 .304 .762 r
F
.52406 .26216 m .45554 .3808 L .60334 .36304 L .649 .464 .62 r
F
.60334 .36304 m .55014 .37603 L .60334 .36304 L 0 0 0 r
F
.60334 .36304 m .56895 .40345 L .60334 .36304 L .886 .717 .667 r
F
.55014 .37603 m .55014 .37603 L .60334 .36304 L 0 0 0 r
F
.60334 .36304 m .45554 .3808 L .60334 .36304 L .649 .464 .62 r
F
.5028 .30955 m .5028 .30955 L .56132 .34068 L .886 .717 .667 r
F
.5028 .30955 m .45552 .3808 L .45552 .3808 L .189 .207 .648 r
F
.52134 .4594 m .52134 .4594 L .45552 .3808 L .698 .282 .253 r
F
.66236 .49991 m .60336 .3631 L .66236 .49991 L .696 .525 .652 r
F
.61532 .54427 m .63895 .58545 L .57235 .5066 L .711 .325 .316 r
F
.54672 .60197 m .66236 .49991 L .54672 .60197 L .687 .555 .7 r
F
.5028 .30955 m .60334 .36304 L .51846 .37324 L .62 .79 .963 r
F
.45552 .3808 m .51845 .37324 L .45552 .3808 L F
.5028 .30955 m .45557 .38073 L .5028 .30955 L .189 .207 .648 r
F
.45557 .38073 m .45552 .3808 L .5028 .30955 L F
.48493 .33649 m .51845 .37324 L .45552 .3808 L .62 .79 .963 r
F
.5028 .30955 m .5028 .30955 L .48493 .33649 L F
.5028 .30955 m .51845 .37324 L .48493 .33649 L F
.55014 .37603 m .45552 .3808 L .55014 .37603 L .603 .072 0 r
F
.5028 .30955 m .51001 .44587 L .52134 .4594 L .189 .207 .648 r
F
.52134 .4594 m .51001 .44587 L .52134 .4594 L F
.52134 .4594 m .52561 .4834 L .52134 .4594 L .87 .753 .731 r
F
.41999 .52588 m .54672 .60197 L .41999 .52588 L .636 .518 .702 r
F
.47834 .58758 m .41999 .52588 L .54672 .60197 L .706 .19 0 r
F
.43728 .57895 m .54668 .60196 L .43728 .57895 L .87 .753 .731 r
F
.43728 .57895 m .43728 .57895 L .47834 .58758 L .706 .19 0 r
F
.43728 .57895 m .41999 .52588 L .47834 .58758 L F
.54668 .60196 m .54672 .60197 L .43728 .57895 L .87 .753 .731 r
F
.4683 .53483 m .52233 .48695 L .52134 .4594 L F
.46236 .49809 m .48053 .48617 L .52134 .4594 L .617 .692 .897 r
F
.41999 .52588 m .48053 .48617 L .46236 .49809 L F
.41999 .52588 m .41999 .52588 L .48053 .48617 L F
.52134 .4594 m .41999 .52588 L .52134 .4594 L F
.43728 .57895 m .52134 .4594 L .46236 .49809 L .151 0 .197 r
F
.43728 .57895 m .41999 .52588 L .43728 .57895 L .706 .19 0 r
F
.43728 .57895 m .54672 .60197 L .54672 .60197 L .87 .753 .731 r
F
.43728 .57895 m .46236 .49809 L .41999 .52588 L .151 0 .197 r
F
.57235 .5066 m .52164 .49231 L .57235 .5066 L .692 .724 .874 r
F
.43728 .57895 m .54672 .60197 L .52561 .4834 L .87 .753 .731 r
F
.43728 .57895 m .52233 .48695 L .4683 .53483 L F
.43728 .57895 m .47769 .52147 L .43729 .57893 L .151 0 .197 r
F
.47769 .52147 m .52134 .4594 L .43729 .57893 L F
.43728 .57895 m .43728 .57895 L .4683 .53483 L .87 .753 .731 r
F
.52134 .4594 m .52134 .4594 L .66236 .49991 L .687 .736 .888 r
F
.5028 .30955 m .52134 .4594 L .56895 .40345 L .886 .717 .667 r
F
.5028 .30955 m .60334 .36304 L .5028 .30955 L .62 .79 .963 r
F
.5028 .30955 m .56292 .39489 L .56132 .34068 L .886 .717 .667 r
F
.5028 .30955 m .5028 .30955 L .52134 .4594 L .189 .207 .648 r
F
.43728 .57895 m .52134 .4594 L .52134 .4594 L .151 0 .197 r
F
.52233 .48695 m .52561 .4834 L .52134 .4594 L .87 .753 .731 r
F
.49302 .45246 m .52134 .4594 L .52134 .4594 L .617 .692 .897 r
F
.60156 .41667 m .60334 .36304 L .54552 .44652 L .237 0 .135 r
F
.64879 .39152 m .52134 .4594 L .65389 .43226 L .687 .736 .888 r
F
.64879 .39152 m .66236 .49991 L .66236 .49991 L 0 .058 .611 r
F
.64879 .39152 m .66236 .49991 L .64879 .39152 L F
.64879 .39152 m .60334 .36304 L .60156 .41667 L .237 0 .135 r
F
.64879 .39152 m .63472 .3827 L .64879 .39152 L F
.63472 .3827 m .60334 .36304 L .64879 .39152 L F
.64879 .39152 m .64879 .39152 L .60156 .41667 L F
.64879 .39152 m .52134 .4594 L .52134 .4594 L .687 .736 .888 r
F
.64879 .39152 m .52134 .4594 L .64879 .39152 L F
.5028 .30955 m .45552 .3808 L .5028 .30956 L .189 .207 .648 r
F
.5028 .30956 m .45552 .3808 L .51001 .44587 L F
.5028 .30955 m .52134 .4594 L .52134 .4594 L .886 .717 .667 r
F
.65389 .43226 m .52134 .4594 L .52134 .4594 L .687 .736 .888 r
F
.65983 .47973 m .52134 .4594 L .66236 .49991 L F
.65389 .43226 m .52134 .4594 L .65983 .47973 L F
.5028 .30955 m .52134 .4594 L .5028 .30955 L .886 .717 .667 r
F
.5028 .30955 m .60334 .36304 L .60334 .36304 L .62 .79 .963 r
F
.56132 .34068 m .56292 .39489 L .60334 .36304 L .886 .717 .667 r
F
.56292 .39489 m .56895 .40345 L .60334 .36304 L F
.63471 .3827 m .60334 .36304 L .60334 .36304 L .237 0 .135 r
F
.67833 .59211 m .65832 .51468 L .66236 .49991 L 0 .057 .572 r
F
.68751 .6451 m .65832 .51468 L .67833 .59211 L F
.66236 .49991 m .66236 .49991 L .63895 .58545 L .694 .809 .936 r
F
.66723 .52799 m .66236 .49991 L .54672 .60197 L .687 .555 .7 r
F
.5433 .60387 m .48955 .63383 L .50181 .627 L .636 .518 .702 r
F
.42515 .66973 m .52281 .61529 L .52281 .61529 L .074 0 0 r
F
.42515 .66973 m .54631 .60219 L .42515 .66973 L .636 .518 .702 r
F
.54631 .60219 m .52964 .61148 L .42515 .66973 L F
.42703 .66868 m .52281 .61529 L .52281 .61529 L .074 0 0 r
F
.50181 .627 m .48955 .63383 L .42515 .66973 L .636 .518 .702 r
F
.42515 .66973 m .52281 .61529 L .42703 .66868 L .074 0 0 r
F
.54673 .60197 m .66723 .52799 L .54672 .60197 L .687 .555 .7 r
F
.5582 .59449 m .54672 .60197 L .66236 .49991 L 0 0 0 r
F
.654 .50954 m .5582 .59449 L .66236 .49991 L F
.60902 .56141 m .66236 .49991 L .6176 .55151 L .78 .401 .338 r
F
.60902 .56141 m .5582 .59449 L .654 .50954 L 0 0 0 r
F
.66236 .49991 m .54672 .60197 L .66236 .49991 L F
.60902 .56141 m .66236 .49991 L .5857 .48679 L .78 .401 .338 r
F
.60902 .56141 m .60902 .56141 L .58532 .57683 L .27 .332 .743 r
F
.57933 .52686 m .58265 .47701 L .52134 .4594 L .78 .401 .338 r
F
.60902 .56141 m .52134 .4594 L .58532 .57683 L .27 .332 .743 r
F
.60902 .56141 m .60902 .56141 L .57933 .52686 L .78 .401 .338 r
F
.60902 .56141 m .58265 .47701 L .57933 .52686 L F
.60902 .56141 m .60902 .56141 L .654 .50954 L 0 0 0 r
F
.60902 .56141 m .52134 .4594 L .52134 .4594 L .27 .332 .743 r
F
.60902 .56141 m .52134 .4594 L .60902 .56141 L F
.60902 .56141 m .66236 .49991 L .66236 .49991 L .78 .401 .338 r
F
.6176 .55151 m .66236 .49991 L .66236 .49991 L F
.5857 .48679 m .66236 .49991 L .58265 .47701 L F
.58532 .57683 m .52134 .4594 L .53074 .51221 L .27 .332 .743 r
F
.54672 .60197 m .53074 .51221 L .54672 .60197 L F
.58532 .57683 m .53074 .51221 L .54672 .60197 L F
.66723 .52799 m .66236 .49991 L .66236 .49991 L .687 .555 .7 r
F
.66723 .52799 m .66236 .49991 L .66723 .52799 L F
.68751 .6451 m .54672 .60197 L .54672 .60197 L .651 .162 .076 r
F
.68751 .6451 m .54672 .60197 L .68751 .6451 L F
.64807 .59665 m .63895 .58545 L .63895 .58545 L 0 .057 .572 r
F
.68751 .6451 m .66723 .52799 L .54673 .60197 L .687 .555 .7 r
F
.68751 .6451 m .68751 .6451 L .67833 .59211 L 0 .057 .572 r
F
.43728 .57895 m .41999 .52588 L .41999 .52588 L .706 .19 0 r
F
.42515 .66973 m .41999 .52588 L .41999 .52588 L .928 .747 .636 r
F
.51852 .61768 m .54672 .60197 L .42515 .66973 L .636 .518 .702 r
F
.42515 .66973 m .42515 .66973 L .52281 .61529 L .074 0 0 r
F
.74693 .38536 m .74693 .38536 L .69445 .3772 L .576 .713 .936 r
F
.52406 .26216 m .52406 .26216 L .60334 .36304 L .649 .464 .62 r
F
.74693 .38536 m .66236 .49991 L .66236 .49991 L 0 0 .006 r
F
.74693 .38536 m .66236 .49991 L .74693 .38536 L F
.61605 .35185 m .60334 .36304 L .61605 .35185 L .946 .76 .619 r
F
.61605 .35185 m .61605 .35185 L .60334 .36304 L 0 0 0 r
F
.37505 .42357 m .45552 .3808 L .45552 .3808 L .948 .819 .684 r
F
.37505 .42357 m .45552 .3808 L .41288 .50969 L F
.444 .47042 m .43647 .48782 L .444 .47042 L 0 0 0 r
F
.41999 .52588 m .42996 .50284 L .41999 .52588 L .811 .393 .253 r
F
.37506 .42357 m .41999 .52588 L .49248 .45301 L .617 .692 .897 r
F
.52134 .4594 m .41999 .52588 L .52134 .4594 L F
.37505 .42357 m .37505 .42357 L .41288 .50969 L .948 .819 .684 r
F
.37505 .42357 m .52134 .4594 L .49302 .45246 L .698 .282 .253 r
F
.37505 .42357 m .49302 .45246 L .37505 .42357 L F
.37505 .42357 m .49302 .45246 L .37505 .42357 L F
.37505 .42357 m .52134 .4594 L .52134 .4594 L F
.37505 .42357 m .45552 .3808 L .45552 .3808 L .948 .819 .684 r
F
.37505 .42357 m .37505 .42357 L .4054 .40744 L .698 .282 .253 r
F
.37505 .42357 m .45552 .3808 L .37505 .42357 L .948 .819 .684 r
F
.4054 .40744 m .49302 .45246 L .45552 .3808 L .698 .282 .253 r
F
.37505 .42357 m .49302 .45246 L .4054 .40744 L F
.49302 .45246 m .49302 .45246 L .52134 .4594 L .617 .692 .897 r
F
.41999 .52588 m .46236 .49809 L .41999 .52588 L .151 0 .197 r
F
.33199 .43374 m .33199 .43374 L .39412 .40712 L .61 .459 .652 r
F
.33199 .43374 m .4312 .39122 L .33199 .43374 L .702 .791 .919 r
F
.52134 .4594 m .51001 .44587 L .52134 .4594 L .189 .207 .648 r
F
.52406 .26216 m .58763 .34306 L .58763 .34306 L .162 .304 .762 r
F
.57959 .33283 m .58763 .34306 L .58763 .34306 L F
.52406 .26216 m .58763 .34306 L .57959 .33283 L F
.52406 .26216 m .58763 .34306 L .52406 .26216 L F
.58763 .34306 m .60334 .36304 L .60334 .36304 L F
.58763 .34306 m .60334 .36304 L .58763 .34306 L F
.4312 .39122 m .45552 .3808 L .4312 .39122 L .702 .791 .919 r
F
.40834 .53633 m .41999 .52588 L .41999 .52588 L .549 .721 .954 r
F
.36243 .57751 m .36243 .57751 L .41999 .52588 L F
.36243 .57751 m .40834 .53633 L .40834 .53633 L 0 0 0 r
F
.36243 .57751 m .40834 .53633 L .36243 .57751 L F
.57289 .70658 m .54672 .60197 L .57015 .6956 L .054 .24 .736 r
F
.57289 .70658 m .57015 .6956 L .57289 .70658 L F
.57015 .6956 m .54672 .60197 L .57289 .70658 L F
0 g
.5 Mabswid
[ ] 0 setdash
.48586 .48222 m
.48586 .48222 L
s
.73668 .39925 m
.84795 .36244 L
s
.23704 .24365 m
.32999 .3387 L
s
.32999 .3387 m
.39608 .40628 L
s
.039 .916 .04 r
.27745 .54795 m
.40172 .50675 L
s
0 g
.4592 .84869 m
.46755 .64609 L
s
.46755 .64609 m
.46755 .64609 L
s
.46755 .64609 m
.46755 .64609 L
s
.64898 .0747 m
.76573 .24354 L
s
.76573 .24354 m
.84795 .36244 L
s
.84795 .36244 m
.88379 .74384 L
s
.039 .916 .04 r
.4705 .70013 m
.49557 .637 L
s
.49557 .637 m
.4989 .62862 L
s
.4989 .62862 m
.4989 .62862 L
s
0 g
.53333 .52677 m
.53333 .52677 L
s
.039 .916 .04 r
.27256 .59329 m
.36655 .56313 L
s
.36655 .56313 m
.36655 .56313 L
s
.36655 .56313 m
.36655 .56313 L
s
.36655 .56313 m
.36655 .56313 L
s
.36655 .56313 m
.37559 .56023 L
s
.24539 .51996 m
.37282 .47649 L
s
.61725 .43977 m
.61725 .43977 L
s
.47707 .47974 m
.47707 .47974 L
s
.47707 .47974 m
.47707 .47974 L
s
.49077 .42882 m
.49077 .42882 L
s
.49077 .42882 m
.50948 .45649 L
s
.50948 .45649 m
.50948 .45649 L
s
.50948 .45649 m
.51197 .46017 L
s
.51197 .46017 m
.51197 .46017 L
s
0 0 0 r
2 Mabswid
.51197 .46017 Mdot
.039 .916 .04 r
.5 Mabswid
.51197 .46017 m
.51822 .46145 L
s
.51969 .46175 m
.51969 .46175 L
s
.51969 .46175 m
.51969 .46175 L
s
.52414 .46265 m
.52414 .46265 L
s
.51197 .46017 m
.51197 .46017 L
s
.45227 .80526 m
.48192 .63808 L
s
.48192 .63808 m
.48192 .63808 L
s
.41597 .29976 m
.4331 .32933 L
s
.4331 .32933 m
.44156 .34392 L
s
0 0 0 r
2 Mabswid
.8442 .43333 Mdot
.039 .916 .04 r
.5 Mabswid
.71118 .48083 m
.74589 .46843 L
s
.71118 .48083 m
.71118 .48083 L
s
.70985 .4813 m
.71118 .48083 L
s
.74589 .46843 m
.74589 .46843 L
s
.74589 .46843 m
.74589 .46843 L
s
.74589 .46843 m
.8442 .43333 L
s
0 0 0 r
2 Mabswid
.63021 .31471 Mdot
.039 .916 .04 r
.5 Mabswid
.62104 .33427 m
.62365 .3287 L
s
.62889 .31752 m
.63021 .31471 L
s
.62889 .31752 m
.62889 .31752 L
s
.62889 .31752 m
.62889 .31752 L
s
.62889 .31752 m
.62889 .31752 L
s
.62365 .3287 m
.62889 .31752 L
s
.70127 .31508 m
.73275 .26567 L
s
.70127 .31508 m
.70127 .31508 L
s
.66858 .36639 m
.70127 .31508 L
s
.48193 .44974 m
.48304 .45065 L
s
.48959 .45592 m
.48959 .45592 L
s
.48959 .45592 m
.49063 .45675 L
s
.49063 .45675 m
.49063 .45675 L
s
0 0 0 r
2 Mabswid
.49063 .45675 Mdot
.039 .916 .04 r
.5 Mabswid
.49063 .45675 m
.5174 .46198 L
s
.51927 .46235 m
.51927 .46235 L
s
.51927 .46235 m
.51927 .46235 L
s
.5248 .46343 m
.5248 .46343 L
s
.49063 .45675 m
.49063 .45675 L
s
.49063 .45675 m
.49063 .45675 L
s
0 0 0 r
2 Mabswid
.5002 .781 Mdot
.039 .916 .04 r
.5 Mabswid
.53062 .6799 m
.5375 .65703 L
s
.53062 .6799 m
.53062 .6799 L
s
.53062 .6799 m
.53062 .6799 L
s
.5002 .781 m
.53037 .68072 L
s
.53037 .68072 m
.53037 .68072 L
s
.53037 .68072 m
.53062 .6799 L
s
.53671 .54576 m
.53671 .54576 L
s
.54921 .49183 m
.54921 .49183 L
s
0 0 0 r
2 Mabswid
.41597 .29976 Mdot
.039 .916 .04 r
.5 Mabswid
.47738 .44863 m
.47782 .44934 L
s
.23671 .28718 m
.28499 .31896 L
s
.28499 .31896 m
.28499 .31896 L
s
.28499 .31896 m
.38162 .38257 L
s
.38162 .38257 m
.38162 .38257 L
s
.38162 .38257 m
.38162 .38257 L
s
.38162 .38257 m
.40913 .40068 L
s
.54613 .48824 m
.54613 .48824 L
s
.65192 .53739 m
.65192 .53739 L
s
.48547 .46006 m
.48547 .46006 L
s
.48547 .46006 m
.50588 .46954 L
s
.51216 .47246 m
.51216 .47246 L
s
.51216 .47246 m
.51216 .47246 L
s
.5247 .47828 m
.5247 .47828 L
s
0 0 0 r
2 Mabswid
.3729 .56332 Mdot
.039 .916 .04 r
.5 Mabswid
.3729 .56332 m
.37327 .56327 L
s
.40914 .59619 m
.42236 .59209 L
s
.26751 .64006 m
.40914 .59619 L
s
0 g
.61664 .55904 m
.61664 .55904 L
s
.61664 .55904 m
.61664 .55904 L
s
.60816 .48434 m
.60816 .48434 L
s
.53738 .54951 m
.53738 .54951 L
s
.60816 .48434 m
.60816 .48434 L
s
.53738 .54951 m
.53738 .54951 L
s
.55716 .41731 m
.55716 .41731 L
s
.56287 .4509 m
.56287 .4509 L
s
.56653 .47238 m
.56653 .47238 L
s
.46834 .47728 m
.46834 .47728 L
s
.46834 .47728 m
.48635 .48236 L
s
.50208 .48679 m
.50208 .48679 L
s
.50208 .48679 m
.50208 .48679 L
s
.52749 .49396 m
.52749 .49396 L
s
.55716 .41731 m
.55716 .41731 L
s
.56287 .4509 m
.56287 .4509 L
s
.56653 .47238 m
.56653 .47238 L
s
.46834 .47728 m
.46834 .47728 L
s
.46834 .47728 m
.48635 .48236 L
s
.50208 .48679 m
.50208 .48679 L
s
.50208 .48679 m
.50208 .48679 L
s
.52749 .49396 m
.52749 .49396 L
s
.039 .916 .04 r
.58634 .57764 m
.58634 .57764 L
s
.60806 .44165 m
.60806 .44165 L
s
.51642 .46639 m
.51642 .46639 L
s
.51642 .46639 m
.51642 .46639 L
s
.51855 .46123 m
.51949 .45894 L
s
.51949 .45894 m
.51949 .45894 L
s
.51949 .45894 m
.51997 .45776 L
s
.52087 .45558 m
.52087 .45558 L
s
.52087 .45558 m
.52087 .45558 L
s
.53228 .52083 m
.53228 .52083 L
s
.33491 .53431 m
.40571 .51092 L
s
.33491 .53431 m
.33491 .53431 L
s
.2399 .56568 m
.33491 .53431 L
s
0 0 0 r
2 Mabswid
.46613 .29344 Mdot
.039 .916 .04 r
.5 Mabswid
.48133 .30877 m
.49131 .31885 L
s
.46613 .29344 m
.48133 .30877 L
s
.5386 .55638 m
.5386 .55638 L
s
.63012 .55077 m
.63012 .55077 L
s
.52894 .5021 m
.52894 .5021 L
s
.2619 .47345 m
.34278 .44505 L
s
.2619 .47345 m
.2619 .47345 L
s
.24071 .48089 m
.2619 .47345 L
s
.21215 .49092 m
.24071 .48089 L
s
0 g
.4592 .84869 m
.88379 .74384 L
s
.18411 .63308 m
.31917 .73894 L
s
.31917 .73894 m
.4592 .84869 L
s
.039 .916 .04 r
.57041 .58742 m
.57041 .58742 L
s
.60734 .4841 m
.60734 .4841 L
s
.48863 .45205 m
.48908 .4515 L
s
.49117 .44893 m
.50173 .43597 L
s
.50902 .42702 m
.50902 .42702 L
s
.51624 .41815 m
.51624 .41815 L
s
.51624 .41815 m
.51624 .41815 L
s
.63515 .54768 m
.63515 .54768 L
s
.57982 .44743 m
.57982 .44743 L
s
.59869 .48162 m
.59869 .48162 L
s
0 0 0 r
2 Mabswid
.35419 .54258 Mdot
.039 .916 .04 r
.5 Mabswid
.3877 .51093 m
.39717 .50199 L
s
.35419 .54258 m
.3877 .51093 L
s
.6469 .54046 m
.6469 .54046 L
s
.53176 .51795 m
.53176 .51795 L
s
.45424 .49561 m
.46251 .49799 L
s
.48886 .50559 m
.48886 .50559 L
s
.48886 .50559 m
.48886 .50559 L
s
.63509 .54772 m
.63509 .54772 L
s
.47443 .479 m
.47443 .479 L
s
.47443 .479 m
.47443 .479 L
s
.61341 .56102 m
.61341 .56102 L
s
.5326 .52266 m
.5326 .52266 L
s
.49081 .50282 m
.49081 .50282 L
s
.49081 .50282 m
.49081 .50282 L
s
.45905 .48774 m
.47013 .493 L
s
0 0 0 r
2 Mabswid
.45905 .48774 Mdot
.039 .916 .04 r
.5 Mabswid
.47648 .47783 m
.50314 .45494 L
s
.50314 .45494 m
.50314 .45494 L
s
.50314 .45494 m
.51084 .44833 L
s
.47648 .47783 m
.47648 .47783 L
s
.47648 .47783 m
.47648 .47783 L
s
.51084 .44833 m
.51084 .44833 L
s
.61848 .35592 m
.61848 .35592 L
s
.5191 .44124 m
.5191 .44124 L
s
.5191 .44124 m
.5191 .44124 L
s
.51084 .44833 m
.51156 .44771 L
s
0 0 0 r
2 Mabswid
.47648 .47783 Mdot
.34613 .5352 Mdot
.039 .916 .04 r
.5 Mabswid
.34613 .5352 m
.40075 .52338 L
s
.40075 .52338 m
.40075 .52338 L
s
.40075 .52338 m
.40423 .52263 L
s
.47461 .47098 m
.47461 .47098 L
s
.47461 .47098 m
.49989 .47347 L
s
.5107 .47453 m
.5107 .47453 L
s
.5107 .47453 m
.5107 .47453 L
s
.53654 .47708 m
.53654 .47708 L
s
.60712 .48404 m
.60712 .48404 L
s
.60978 .4848 m
.60978 .4848 L
s
.57134 .44916 m
.57134 .44916 L
s
.58538 .47779 m
.58538 .47779 L
s
.55625 .41838 m
.55625 .41838 L
s
.54555 .48757 m
.54555 .48757 L
s
.52723 .49247 m
.52723 .49247 L
s
.58379 .47734 m
.58379 .47734 L
s
.49133 .50208 m
.49133 .50208 L
s
.49133 .50208 m
.49133 .50208 L
s
.6329 .43656 m
.6329 .43656 L
s
0 0 0 r
2 Mabswid
.36579 .60263 Mdot
.039 .916 .04 r
.5 Mabswid
.36579 .60263 m
.37569 .59595 L
s
.37569 .59595 m
.37569 .59595 L
s
.37569 .59595 m
.39504 .58289 L
s
0 0 0 r
2 Mabswid
.36243 .59663 Mdot
.039 .916 .04 r
.5 Mabswid
.41634 .58666 m
.42056 .58588 L
s
.42056 .58588 m
.42056 .58588 L
s
.36243 .59663 m
.41634 .58666 L
s
0 g
.42166 .33803 m
.42166 .33803 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.42166 .33803 m
.45552 .3808 L
s
.42166 .33803 m
.42166 .33803 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.42166 .33803 m
.45552 .3808 L
s
.42166 .33803 m
.42166 .33803 L
s
.42166 .33803 m
.42166 .33803 L
s
.42166 .33803 m
.43067 .39145 L
s
.42166 .33803 m
.42166 .33803 L
s
.42166 .33803 m
.47168 .35283 L
s
.039 .916 .04 r
.28769 .59583 m
.37744 .5672 L
s
.37744 .5672 m
.37744 .5672 L
s
.37744 .5672 m
.37744 .5672 L
s
.37744 .5672 m
.42098 .55331 L
s
.23424 .61289 m
.28769 .59583 L
s
0 0 0 r
2 Mabswid
.28548 .36692 Mdot
.039 .916 .04 r
.5 Mabswid
.30415 .37626 m
.37888 .41365 L
s
.28548 .36692 m
.30415 .37626 L
s
.73931 .58587 m
.85542 .6476 L
s
.73931 .58587 m
.73931 .58587 L
s
.69659 .56315 m
.73931 .58587 L
s
.45678 .38321 m
.45754 .3832 L
s
.45754 .3832 m
.45754 .3832 L
s
.50669 .38304 m
.50669 .38304 L
s
.51189 .38302 m
.51189 .38302 L
s
.51189 .38302 m
.51189 .38302 L
s
.58816 .57652 m
.58816 .57652 L
s
.54075 .56845 m
.54075 .56845 L
s
.51704 .45426 m
.51737 .45842 L
s
.51737 .45842 m
.51737 .45842 L
s
.51737 .45842 m
.51763 .46183 L
s
.51783 .46439 m
.51783 .46439 L
s
0 0 0 r
2 Mabswid
.71673 .64564 Mdot
.039 .916 .04 r
.5 Mabswid
.71673 .64564 m
.72976 .57361 L
s
.72976 .57361 m
.72976 .57361 L
s
.72976 .57361 m
.73429 .54857 L
s
0 0 0 r
2 Mabswid
.77222 .27135 Mdot
.039 .916 .04 r
.5 Mabswid
.66505 .3512 m
.67293 .34532 L
s
.66505 .3512 m
.66505 .3512 L
s
.66505 .3512 m
.66505 .3512 L
s
.67293 .34532 m
.77222 .27135 L
s
0 g
.41999 .52588 m
.41999 .52588 L
s
.33199 .43374 m
.33199 .43374 L
s
.33199 .43374 m
.33199 .43374 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.44768 .44178 m
.44773 .44137 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.44768 .44178 m
.44773 .44137 L
s
.45304 .49266 m
.45304 .49266 L
s
.45304 .49266 m
.45674 .50177 L
s
.36243 .57751 m
.36243 .57751 L
s
.36243 .57751 m
.40984 .51526 L
s
.46993 .44736 m
.47041 .44692 L
s
.48387 .43496 m
.49362 .42629 L
s
.49362 .42629 m
.49362 .42629 L
s
.50829 .41325 m
.50829 .41325 L
s
.5149 .40736 m
.5149 .40736 L
s
.5149 .40736 m
.5149 .40736 L
s
.45304 .49266 m
.45304 .49266 L
s
.45304 .49266 m
.45674 .50177 L
s
.46993 .44736 m
.47041 .44692 L
s
.48387 .43496 m
.49362 .42629 L
s
.49362 .42629 m
.49362 .42629 L
s
.50829 .41325 m
.50829 .41325 L
s
.5149 .40736 m
.5149 .40736 L
s
.5149 .40736 m
.5149 .40736 L
s
.039 .916 .04 r
.62404 .4889 m
.62404 .4889 L
s
.60074 .56881 m
.60074 .56881 L
s
.21465 .5341 m
.37556 .47936 L
s
.21465 .5341 m
.21465 .5341 L
s
.20602 .53704 m
.21465 .5341 L
s
.24245 .3398 m
.32828 .35896 L
s
.32828 .35896 m
.32828 .35896 L
s
.32828 .35896 m
.4309 .38187 L
s
0 0 0 r
2 Mabswid
.4309 .38187 Mdot
.73275 .26567 Mdot
0 g
.5 Mabswid
.52406 .26216 m
.52406 .26216 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.50644 .37823 m
.50644 .37823 L
s
.51127 .37799 m
.51127 .37799 L
s
.51127 .37799 m
.51127 .37799 L
s
.52406 .26216 m
.52406 .26216 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.66634 .30758 m
.66634 .30758 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.50644 .37823 m
.50644 .37823 L
s
.51127 .37799 m
.51127 .37799 L
s
.51127 .37799 m
.51127 .37799 L
s
.66634 .30758 m
.66634 .30758 L
s
.66634 .30758 m
.66634 .30758 L
s
.59348 .3505 m
.66634 .30758 L
s
.039 .916 .04 r
.46657 .40191 m
.47204 .40052 L
s
.47204 .40052 m
.47204 .40052 L
s
.50714 .39155 m
.50714 .39155 L
s
.51277 .39012 m
.51277 .39012 L
s
.51277 .39012 m
.51277 .39012 L
s
.64736 .4956 m
.64736 .4956 L
s
0 0 0 r
2 Mabswid
.6974 .68181 Mdot
.039 .916 .04 r
.5 Mabswid
.68407 .64405 m
.6974 .68181 L
s
0 g
.23704 .24365 m
.64898 .0747 L
s
.18411 .63308 m
.23704 .24365 L
s
.039 .916 .04 r
.63427 .43628 m
.63427 .43628 L
s
.5277 .49511 m
.5277 .49511 L
s
.54425 .48605 m
.54425 .48605 L
s
.56829 .47288 m
.56829 .47288 L
s
.54465 .43201 m
.54465 .43201 L
s
.47529 .41858 m
.48946 .42132 L
s
.48946 .42132 m
.48946 .42132 L
s
.50892 .42509 m
.50892 .42509 L
s
.5173 .42671 m
.5173 .42671 L
s
.5173 .42671 m
.5173 .42671 L
s
0 0 0 r
2 Mabswid
.51443 .24711 Mdot
.039 .916 .04 r
.5 Mabswid
.56885 .28337 m
.63444 .32708 L
s
.63444 .32708 m
.63444 .32708 L
s
.63444 .32708 m
.63444 .32708 L
s
.56885 .28337 m
.56885 .28337 L
s
.51443 .24711 m
.56885 .28337 L
s
.45562 .38098 m
.45565 .38095 L
s
.45565 .38095 m
.45565 .38095 L
s
.46358 .44576 m
.46437 .44544 L
s
.48501 .43715 m
.48984 .43521 L
s
.48984 .43521 m
.49826 .43183 L
s
.50904 .4275 m
.50904 .4275 L
s
.517 .4243 m
.517 .4243 L
s
.517 .4243 m
.517 .4243 L
s
0 g
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.40834 .53633 m
.41999 .52588 L
s
.36243 .57751 m
.40834 .53633 L
s
.36243 .57751 m
.36243 .57751 L
s
.36243 .57751 m
.36243 .57751 L
s
.36243 .57751 m
.36243 .57751 L
s
.38793 .58172 m
.4222 .58738 L
s
.36243 .57751 m
.40834 .53633 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.40834 .53633 m
.41999 .52588 L
s
.36243 .57751 m
.4222 .58738 L
s
.039 .916 .04 r
.46935 .47856 m
.48199 .48521 L
s
.49746 .49335 m
.49746 .49335 L
s
.49746 .49335 m
.49746 .49335 L
s
.53048 .51072 m
.53048 .51072 L
s
.46935 .47856 m
.46935 .47856 L
s
.46785 .47777 m
.46785 .47777 L
s
.46785 .47777 m
.46935 .47856 L
s
0 0 0 r
2 Mabswid
.38026 .23613 Mdot
.039 .916 .04 r
.5 Mabswid
.38026 .23613 m
.44092 .31023 L
s
.46247 .33654 m
.47485 .35167 L
s
.47485 .35167 m
.47485 .35167 L
s
.47485 .35167 m
.47485 .35167 L
s
.44092 .31023 m
.46247 .33654 L
s
.45353 .44325 m
.4542 .44295 L
s
.48177 .43096 m
.49332 .42593 L
s
.49332 .42593 m
.49332 .42593 L
s
.51598 .41607 m
.51598 .41607 L
s
.51598 .41607 m
.51598 .41607 L
s
.50861 .41928 m
.50861 .41928 L
s
0 0 0 r
2 Mabswid
.42056 .58588 Mdot
.039 .916 .04 r
.5 Mabswid
.42056 .58588 m
.42214 .58574 L
s
.42056 .58588 m
.42056 .58588 L
s
0 0 0 r
2 Mabswid
.38383 .72908 Mdot
.039 .916 .04 r
.5 Mabswid
.38328 .55282 m
.38331 .56043 L
s
.38331 .56043 m
.38331 .56043 L
s
.38331 .56043 m
.38331 .56043 L
s
.38331 .56043 m
.38366 .6739 L
s
.38366 .6739 m
.38383 .72908 L
s
.38328 .55282 m
.38328 .55282 L
s
.38328 .55282 m
.38328 .55282 L
s
.38328 .55282 m
.38328 .55282 L
s
.38308 .48723 m
.38308 .48723 L
s
.38308 .48723 m
.38328 .55282 L
s
0 g
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.42515 .66973 m
.42515 .66973 L
s
.42515 .66973 m
.42515 .66973 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.54544 .59477 m
.54544 .59477 L
s
.56095 .59323 m
.56095 .59323 L
s
.54544 .59477 m
.54544 .59477 L
s
.56095 .59323 m
.56095 .59323 L
s
.039 .916 .04 r
.65005 .49637 m
.65005 .49637 L
s
0 0 0 r
2 Mabswid
.33035 .56812 Mdot
.039 .916 .04 r
.5 Mabswid
.33035 .56812 m
.38481 .55751 L
s
.38481 .55751 m
.38481 .55751 L
s
.38481 .55751 m
.38907 .55668 L
s
.38907 .55668 m
.38907 .55668 L
s
.5777 .47559 m
.5777 .47559 L
s
.59495 .44433 m
.59495 .44433 L
s
.3191 .54541 m
.39659 .51992 L
s
.3191 .54541 m
.3191 .54541 L
s
.19969 .58467 m
.3191 .54541 L
s
.39659 .51992 m
.40515 .51711 L
s
.40515 .51711 m
.41475 .51395 L
s
0 0 0 r
2 Mabswid
.43757 .38096 Mdot
.63444 .32708 Mdot
.27089 .39371 Mdot
.039 .916 .04 r
.5 Mabswid
.35917 .46717 m
.41438 .5131 L
s
.35917 .46717 m
.35917 .46717 L
s
.32201 .43624 m
.35917 .46717 L
s
.32201 .43624 m
.32201 .43624 L
s
.27089 .39371 m
.32201 .43624 L
s
.52961 .50585 m
.52961 .50585 L
s
.54609 .48819 m
.54609 .48819 L
s
.56205 .47109 m
.56205 .47109 L
s
.58515 .44634 m
.58515 .44634 L
s
.50677 .38462 m
.50677 .38462 L
s
.51145 .37943 m
.51145 .37943 L
s
.51145 .37943 m
.51145 .37943 L
s
.47564 .41923 m
.48189 .41228 L
s
.48189 .41228 m
.48189 .41228 L
s
.45394 .44335 m
.45428 .44297 L
s
0 0 0 r
2 Mabswid
.32636 .56767 Mdot
.039 .916 .04 r
.5 Mabswid
.32636 .56767 m
.33608 .56046 L
s
.33608 .56046 m
.33608 .56046 L
s
.33608 .56046 m
.40452 .50968 L
s
0 0 0 r
2 Mabswid
.85115 .57699 Mdot
.039 .916 .04 r
.5 Mabswid
.76049 .56284 m
.85115 .57699 L
s
.76049 .56284 m
.76049 .56284 L
s
.71554 .55582 m
.76049 .56284 L
s
0 g
.66634 .30758 m
.66634 .30758 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.66634 .30758 L
s
.66634 .30758 m
.66634 .30758 L
s
.61605 .35185 m
.66634 .30758 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.61605 .35185 L
s
.66634 .30758 m
.66634 .30758 L
s
.66634 .30758 m
.66634 .30758 L
s
.66634 .30758 m
.66884 .37322 L
s
.66884 .37322 m
.66884 .37322 L
s
.039 .916 .04 r
.61128 .44099 m
.61128 .44099 L
s
.62452 .36605 m
.62452 .36605 L
s
0 0 0 r
2 Mabswid
.63086 .33021 Mdot
.45227 .80526 Mdot
.039 .916 .04 r
.5 Mabswid
.50232 .20531 m
.54281 .23795 L
s
.54281 .23795 m
.58852 .2748 L
s
.58852 .2748 m
.58852 .2748 L
s
.58852 .2748 m
.64575 .32094 L
s
.64575 .32094 m
.64575 .32094 L
s
0 0 0 r
2 Mabswid
.64575 .32094 Mdot
0 g
.5 Mabswid
.74693 .38536 m
.74693 .38536 L
s
.66236 .49991 m
.66236 .49991 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.76721 .53583 m
.76721 .53583 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.76721 .53583 m
.76721 .53583 L
s
.69002 .46245 m
.76721 .53583 L
s
.64981 .53868 m
.64981 .53868 L
s
.65903 .49895 m
.65903 .49895 L
s
.64981 .53868 m
.64981 .53868 L
s
.65903 .49895 m
.65903 .49895 L
s
.039 .916 .04 r
.73243 .405 m
.81901 .42601 L
s
.37302 .4767 m
.39366 .54224 L
s
.39366 .54224 m
.39366 .54224 L
s
.39366 .54224 m
.39366 .54224 L
s
0 0 0 r
2 Mabswid
.39366 .54224 Mdot
.039 .916 .04 r
.5 Mabswid
.55528 .59671 m
.55528 .59671 L
s
.57348 .44872 m
.57348 .44872 L
s
.57044 .4735 m
.57044 .4735 L
s
0 0 0 r
2 Mabswid
.66603 .35717 Mdot
.66505 .3512 Mdot
.83471 .60635 Mdot
.039 .916 .04 r
.5 Mabswid
.67728 .58601 m
.75431 .59596 L
s
.75431 .59596 m
.83471 .60635 L
s
0 0 0 r
2 Mabswid
.81901 .42601 Mdot
.23671 .28718 Mdot
.36244 .69982 Mdot
.039 .916 .04 r
.5 Mabswid
.36244 .69982 m
.42449 .65152 L
s
0 0 0 r
2 Mabswid
.66143 .36065 Mdot
.039 .916 .04 r
.5 Mabswid
.54253 .57846 m
.54253 .57846 L
s
.68952 .50921 m
.68952 .50921 L
s
0 0 0 r
2 Mabswid
.6595 .34095 Mdot
.039 .916 .04 r
.5 Mabswid
.50498 .47013 m
.51862 .45873 L
s
.51862 .45873 m
.51862 .45873 L
s
.51862 .45873 m
.51989 .45767 L
s
.52101 .45673 m
.52101 .45673 L
s
.52101 .45673 m
.52101 .45673 L
s
.53003 .44919 m
.53003 .44919 L
s
0 0 0 r
2 Mabswid
.70115 .22165 Mdot
.039 .916 .04 r
.5 Mabswid
.5405 .28308 m
.70115 .22165 L
s
.48389 .51266 m
.48389 .51266 L
s
.48389 .51266 m
.48389 .51266 L
s
.53201 .51934 m
.53201 .51934 L
s
.4393 .50647 m
.4393 .50647 L
s
.4393 .50647 m
.44779 .50765 L
s
.5693 .5881 m
.5693 .5881 L
s
.53864 .5566 m
.53864 .5566 L
s
.46487 .48077 m
.46487 .48077 L
s
.46487 .48077 m
.47418 .49034 L
s
.48893 .5055 m
.48893 .5055 L
s
.48893 .5055 m
.48893 .5055 L
s
0 0 0 r
2 Mabswid
.63919 .32705 Mdot
.039 .916 .04 r
.5 Mabswid
.63532 .54757 m
.63532 .54757 L
s
.6337 .49167 m
.6337 .49167 L
s
.63211 .43672 m
.63211 .43672 L
s
.58674 .34192 m
.62912 .33371 L
s
.62912 .33371 m
.62912 .33371 L
s
0 0 0 r
2 Mabswid
.62912 .33371 Mdot
0 g
.5 Mabswid
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.68751 .6451 m
.68751 .6451 L
s
.68751 .6451 m
.68751 .6451 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.65214 .53725 m
.65214 .53725 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.57289 .70658 m
.57289 .70658 L
s
.57289 .70658 m
.61803 .62381 L
s
.76721 .53583 m
.76721 .53583 L
s
.67478 .57159 m
.76721 .53583 L
s
.57289 .70658 m
.57289 .70658 L
s
.57289 .70658 m
.61803 .62381 L
s
0 0 0 r
2 Mabswid
.75895 .25191 Mdot
.039 .916 .04 r
.5 Mabswid
.75551 .25454 m
.75895 .25191 L
s
.61171 .36434 m
.75551 .25454 L
s
.57688 .58345 m
.57688 .58345 L
s
.54328 .58268 m
.54328 .58268 L
s
.44591 .44133 m
.44605 .44096 L
s
.46271 .39452 m
.464 .39092 L
s
.464 .39092 m
.464 .39092 L
s
0 0 0 r
2 Mabswid
.38736 .55416 Mdot
.643 .32617 Mdot
.039 .916 .04 r
.5 Mabswid
.59589 .57178 m
.59589 .57178 L
s
.67813 .50531 m
.67813 .50531 L
s
0 0 0 r
2 Mabswid
.70834 .48089 Mdot
.38907 .55668 Mdot
.039 .916 .04 r
.5 Mabswid
.38907 .55668 m
.42098 .55347 L
s
.38907 .55668 m
.38907 .55668 L
s
.38907 .55668 m
.38907 .55668 L
s
0 0 0 r
2 Mabswid
.39707 .54264 Mdot
.039 .916 .04 r
.5 Mabswid
.65341 .32045 m
.71813 .19392 L
s
.65341 .32045 m
.65341 .32045 L
s
.64842 .33021 m
.65341 .32045 L
s
.64842 .33021 m
.64842 .33021 L
s
0 0 0 r
2 Mabswid
.64842 .33021 Mdot
.039 .916 .04 r
.5 Mabswid
.43455 .36433 m
.44108 .34166 L
s
.45462 .29477 m
.48815 .17856 L
s
.45462 .29477 m
.45462 .29477 L
s
.45462 .29477 m
.45462 .29477 L
s
.44108 .34166 m
.45462 .29477 L
s
.43455 .36433 m
.43455 .36433 L
s
.42616 .39338 m
.43455 .36433 L
s
.47097 .44706 m
.47102 .44763 L
s
.47306 .47253 m
.47306 .47253 L
s
.47306 .47253 m
.4745 .49013 L
s
.46663 .39406 m
.46663 .39406 L
s
.46663 .39406 m
.4674 .40349 L
s
0 0 0 r
2 Mabswid
.64537 .33116 Mdot
.039 .916 .04 r
.5 Mabswid
.4975 .43093 m
.4975 .43093 L
s
.4975 .43093 m
.51013 .45665 L
s
.51013 .45665 m
.51013 .45665 L
s
.51013 .45665 m
.51388 .46429 L
s
.51553 .46766 m
.51553 .46766 L
s
.51553 .46766 m
.51553 .46766 L
s
.52695 .49091 m
.52695 .49091 L
s
.27343 .37408 m
.36953 .41684 L
s
.36953 .41684 m
.37046 .41726 L
s
0 g
.33199 .43374 m
.40632 .40189 L
s
.33199 .43374 m
.33199 .43374 L
s
.40632 .40189 m
.42213 .39511 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.42213 .39511 m
.45552 .3808 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.33199 .43374 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.33199 .43374 m
.41999 .52588 L
s
.33199 .43374 m
.33199 .43374 L
s
.33199 .43374 m
.4312 .39122 L
s
.33199 .43374 m
.33199 .43374 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.4312 .39122 m
.45552 .3808 L
s
0 0 0 r
2 Mabswid
.62913 .33669 Mdot
.039 .916 .04 r
.5 Mabswid
.50332 .47122 m
.51567 .45801 L
s
.51567 .45801 m
.51567 .45801 L
s
.51567 .45801 m
.51805 .45547 L
s
.52053 .45282 m
.52053 .45282 L
s
.52053 .45282 m
.52053 .45282 L
s
.61438 .35246 m
.61438 .35246 L
s
.48597 .43897 m
.48795 .43997 L
s
.48795 .43997 m
.51755 .45487 L
s
.521 .4566 m
.521 .4566 L
s
.521 .4566 m
.521 .4566 L
s
.5229 .45756 m
.5229 .45756 L
s
.52504 .45864 m
.52504 .45864 L
s
.72478 .49802 m
.74283 .42451 L
s
.75989 .35509 m
.76575 .33125 L
s
.74283 .42451 m
.74283 .42451 L
s
.74283 .42451 m
.74283 .42451 L
s
.75989 .35509 m
.75989 .35509 L
s
.75989 .35509 m
.75989 .35509 L
s
.74283 .42451 m
.75989 .35509 L
s
0 0 0 r
2 Mabswid
.72478 .49802 Mdot
.40574 .5531 Mdot
.039 .916 .04 r
.5 Mabswid
.32772 .35311 m
.38953 .37731 L
s
.38953 .37731 m
.42595 .39157 L
s
.42595 .39157 m
.42595 .39157 L
s
.42595 .39157 m
.42826 .39248 L
s
.50641 .37781 m
.50641 .37781 L
s
.511 .37581 m
.511 .37581 L
s
.511 .37581 m
.511 .37581 L
s
.46372 .39647 m
.46733 .39489 L
s
.46733 .39489 m
.46733 .39489 L
s
.52769 .46679 m
.52769 .46679 L
s
.46582 .47982 m
.46582 .47982 L
s
.46582 .47982 m
.4799 .47685 L
s
.4799 .47685 m
.4799 .47685 L
s
.4799 .47685 m
.4799 .47685 L
s
.4799 .47685 m
.50175 .47225 L
s
.51414 .46964 m
.51414 .46964 L
s
.51414 .46964 m
.51414 .46964 L
s
0 g
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.55196 .62293 L
s
.55196 .62293 m
.57289 .70658 L
s
.57289 .70658 m
.57289 .70658 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.57289 .70658 L
s
.57289 .70658 m
.57289 .70658 L
s
0 0 0 r
2 Mabswid
.71813 .19392 Mdot
.85542 .6476 Mdot
0 g
.5 Mabswid
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.52406 .26216 m
.60334 .36304 L
s
.52406 .26216 m
.52406 .26216 L
s
.45552 .3808 m
.45552 .3808 L
s
.52406 .26216 m
.52406 .26216 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.52406 .26216 m
.52406 .26216 L
s
.52406 .26216 m
.60334 .36304 L
s
.52406 .26216 m
.52406 .26216 L
s
.52406 .26216 m
.52406 .26216 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.46895 .35755 L
s
.46895 .35755 m
.52406 .26216 L
s
.52406 .26216 m
.52406 .26216 L
s
.45552 .3808 m
.45552 .3808 L
s
.039 .916 .04 r
.68097 .68178 m
.69014 .73457 L
s
.68097 .68178 m
.68097 .68178 L
s
.67388 .64092 m
.68097 .68178 L
s
0 0 0 r
2 Mabswid
.68996 .55506 Mdot
.039 .916 .04 r
.5 Mabswid
.27934 .6656 m
.34684 .50309 L
s
.35661 .47956 m
.37621 .43237 L
s
.37621 .43237 m
.37621 .43237 L
s
.34684 .50309 m
.35661 .47956 L
s
0 0 0 r
2 Mabswid
.37621 .43237 Mdot
.039 .916 .04 r
.5 Mabswid
.56848 .44975 m
.56848 .44975 L
s
.70391 .51414 m
.70391 .51414 L
s
0 0 0 r
2 Mabswid
.70025 .54992 Mdot
.48815 .17856 Mdot
.039 .916 .04 r
.5 Mabswid
.50714 .39163 m
.50714 .39163 L
s
.51252 .38813 m
.51252 .38813 L
s
.51252 .38813 m
.51252 .38813 L
s
.62253 .32931 m
.71006 .29507 L
s
.62253 .32931 m
.62253 .32931 L
s
.71006 .29507 m
.73929 .28364 L
s
.62253 .32931 m
.62253 .32931 L
s
.58757 .34298 m
.62253 .32931 L
s
0 0 0 r
2 Mabswid
.37009 .44878 Mdot
0 g
.5 Mabswid
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.76721 .53583 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.76721 .53583 L
s
0 0 0 r
2 Mabswid
.51519 .29366 Mdot
.73799 .5157 Mdot
.039 .916 .04 r
.5 Mabswid
.63308 .33858 m
.70338 .26875 L
s
.63308 .33858 m
.63308 .33858 L
s
.62995 .34169 m
.63308 .33858 L
s
0 0 0 r
2 Mabswid
.62995 .34169 Mdot
.24245 .3398 Mdot
.039 .916 .04 r
.5 Mabswid
.53791 .55249 m
.53791 .55249 L
s
.62653 .43787 m
.62653 .43787 L
s
.70255 .51367 m
.70255 .51367 L
s
0 0 0 r
2 Mabswid
.72457 .53564 Mdot
.6915 .54149 Mdot
0 g
.5 Mabswid
.45552 .3808 m
.45552 .3808 L
s
.52134 .4594 m
.52134 .4594 L
s
.45552 .3808 m
.52134 .4594 L
s
.45552 .3808 m
.45552 .3808 L
s
.5028 .30955 m
.5028 .30955 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.45552 .3808 m
.49788 .43138 L
s
.52134 .4594 m
.52134 .4594 L
s
.45552 .3808 m
.45552 .3808 L
s
.52134 .4594 m
.52134 .4594 L
s
.5028 .30955 m
.5028 .30955 L
s
.45552 .3808 m
.5028 .30955 L
s
.45552 .3808 m
.45552 .3808 L
s
.50625 .3747 m
.50625 .3747 L
s
.51079 .37416 m
.5108 .37416 L
s
.5108 .37416 m
.5108 .37416 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.50625 .3747 m
.50625 .3747 L
s
.51079 .37416 m
.5108 .37416 L
s
.5108 .37416 m
.5108 .37416 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.41999 .52588 m
.41999 .52588 L
s
.441 .4401 m
.44109 .43974 L
s
.45552 .3808 m
.45552 .3808 L
s
.45552 .3808 m
.45552 .3808 L
s
.41999 .52588 m
.41999 .52588 L
s
.039 .916 .04 r
.52179 .45887 m
.52179 .45887 L
s
.52184 .4593 m
.52184 .4593 L
s
.52194 .46009 m
.52194 .46009 L
s
0 0 0 r
2 Mabswid
.76575 .33125 Mdot
.039 .916 .04 r
.5 Mabswid
.6937 .45746 m
.70517 .50184 L
s
0 0 0 r
2 Mabswid
.70517 .50184 Mdot
.039 .916 .04 r
.5 Mabswid
.66565 .70515 m
.6697 .71905 L
s
.66565 .70515 m
.66565 .70515 L
s
.64427 .63185 m
.66565 .70515 L
s
.59894 .65032 m
.61482 .69137 L
s
.59894 .65032 m
.59894 .65032 L
s
.58474 .61361 m
.59894 .65032 L
s
.47794 .42364 m
.48779 .41933 L
s
.44107 .43981 m
.44118 .43976 L
s
.48779 .41933 m
.48779 .41933 L
s
.50814 .4104 m
.50814 .4104 L
s
.51491 .40743 m
.51491 .40743 L
s
.51491 .40743 m
.51491 .40743 L
s
.21156 .47125 m
.29761 .46946 L
s
.31675 .46906 m
.39433 .46745 L
s
.29761 .46946 m
.31675 .46906 L
s
.54922 .42664 m
.54922 .42664 L
s
.60883 .56384 m
.60883 .56384 L
s
.56001 .45148 m
.56001 .45148 L
s
.56946 .47322 m
.56946 .47322 L
s
.50612 .37231 m
.50612 .37231 L
s
.52882 .50139 m
.52882 .50139 L
s
.54423 .48603 m
.54423 .48603 L
s
.55986 .47046 m
.55986 .47046 L
s
.5838 .44661 m
.5838 .44661 L
s
.67763 .58804 m
.70394 .63787 L
s
.70394 .63787 m
.70394 .63787 L
s
.70394 .63787 m
.75329 .73134 L
s
0 0 0 r
2 Mabswid
.75874 .32161 Mdot
.039 .916 .04 r
.5 Mabswid
.63459 .38262 m
.6892 .35579 L
s
.6892 .35579 m
.75874 .32161 L
s
0 g
.43728 .57895 m
.43728 .57895 L
s
.41999 .52588 m
.43728 .57895 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.51992 .46033 m
.52134 .4594 L
s
.41999 .52588 m
.51992 .46033 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.37505 .42357 m
.37505 .42357 L
s
.37505 .42357 m
.41999 .52588 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.43728 .57895 m
.43728 .57895 L
s
.41999 .52588 m
.43728 .57895 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.37505 .42357 m
.37505 .42357 L
s
.37505 .42357 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.41999 .52588 L
s
.41999 .52588 m
.42515 .66973 L
s
.41999 .52588 m
.41999 .52588 L
s
.42515 .66973 m
.42515 .66973 L
s
.54672 .60197 m
.54672 .60197 L
s
.41999 .52588 m
.41999 .52588 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.42515 .66973 m
.42515 .66973 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.52281 .61529 m
.54672 .60197 L
s
.42515 .66973 m
.52281 .61529 L
s
.42515 .66973 m
.42515 .66973 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.55248 .42281 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.60334 .36304 m
.60334 .36304 L
s
.64879 .39152 m
.64879 .39152 L
s
.60334 .36304 m
.64879 .39152 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.5028 .30955 m
.5028 .30955 L
s
.5028 .30955 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.64879 .39152 m
.64879 .39152 L
s
.60334 .36304 m
.64879 .39152 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.66236 .49991 m
.66236 .49991 L
s
.5028 .30955 m
.5028 .30955 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.63487 .43616 m
.63487 .43616 L
s
.66236 .49991 m
.66236 .49991 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.74693 .38536 L
s
.60334 .36304 m
.60334 .36304 L
s
.74693 .38536 m
.74693 .38536 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.60334 .36304 L
s
.60334 .36304 m
.74693 .38536 L
s
.74693 .38536 m
.74693 .38536 L
s
.039 .916 .04 r
.43697 .50882 m
.43697 .50882 L
s
.43697 .50882 m
.44933 .50549 L
s
.44933 .50549 m
.44933 .50549 L
s
.44933 .50549 m
.44933 .50549 L
s
.44933 .50549 m
.44933 .50549 L
s
.44933 .50549 m
.44933 .50549 L
s
.44933 .50549 m
.45231 .50469 L
s
.49818 .49233 m
.49818 .49233 L
s
.49818 .49233 m
.49818 .49233 L
s
.52588 .48487 m
.52588 .48487 L
s
.53997 .48108 m
.53997 .48108 L
s
.56931 .47318 m
.56931 .47318 L
s
0 0 0 r
2 Mabswid
.42246 .51272 Mdot
.039 .916 .04 r
.5 Mabswid
.27285 .69002 m
.34758 .64043 L
s
.34758 .64043 m
.43952 .57942 L
s
0 0 0 r
2 Mabswid
.73929 .28364 Mdot
.039 .916 .04 r
.5 Mabswid
.52622 .4584 m
.52622 .4584 L
s
.50861 .41925 m
.50861 .41925 L
s
.51932 .44306 m
.51932 .44306 L
s
.51932 .44306 m
.51932 .44306 L
s
.52483 .4553 m
.52483 .4553 L
s
.45254 .70275 m
.52446 .63293 L
s
.52446 .63293 m
.52446 .63293 L
s
.52446 .63293 m
.52446 .63293 L
s
.52446 .63293 m
.52446 .63293 L
s
.52446 .63293 m
.52446 .63293 L
s
.52446 .63293 m
.52446 .63293 L
s
.52446 .63293 m
.52446 .63293 L
s
.52446 .63293 m
.54546 .61254 L
s
0 0 0 r
2 Mabswid
.54546 .61254 Mdot
0 g
.5 Mabswid
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.74693 .38536 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.74693 .38536 L
s
.74693 .38536 m
.74693 .38536 L
s
0 0 0 r
2 Mabswid
.66862 .40771 Mdot
.27343 .37408 Mdot
0 g
.5 Mabswid
.65856 .48221 m
.75096 .58954 L
s
.75096 .58954 m
.88379 .74384 L
s
0 0 0 r
2 Mabswid
.69014 .73457 Mdot
0 g
.5 Mabswid
.60902 .56141 m
.60902 .56141 L
s
.54672 .60197 m
.60902 .56141 L
s
.60902 .56141 m
.60902 .56141 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.52837 .49888 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.52134 .4594 m
.52134 .4594 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.52134 .4594 m
.52134 .4594 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.43728 .57895 m
.43728 .57895 L
s
.43728 .57895 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.60902 .56141 m
.60902 .56141 L
s
.54672 .60197 m
.60902 .56141 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.43728 .57895 m
.43728 .57895 L
s
.43728 .57895 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.68751 .6451 L
s
.68751 .6451 m
.68751 .6451 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.66236 .49991 m
.66236 .49991 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.54672 .60197 L
s
.54672 .60197 m
.68751 .6451 L
s
.68751 .6451 m
.68751 .6451 L
s
0 0 0 r
2 Mabswid
.57101 .58986 Mdot
.59456 .58669 Mdot
.039 .916 .04 r
.5 Mabswid
.57497 .58358 m
.59456 .58669 L
s
.58347 .57804 m
.59374 .60518 L
s
0 0 0 r
2 Mabswid
.59374 .60518 Mdot
.6186 .56348 Mdot
.4756 .72288 Mdot
.039 .916 .04 r
.5 Mabswid
.4756 .72288 m
.52531 .59746 L
s
.59147 .44504 m
.59147 .44504 L
s
.57813 .47571 m
.57813 .47571 L
s
.53989 .56363 m
.53989 .56363 L
s
0 g
.66236 .49991 m
.66236 .49991 L
s
.60902 .56141 m
.60902 .56141 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.64879 .39152 m
.64879 .39152 L
s
.64879 .39152 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.60902 .56141 m
.60902 .56141 L
s
.60902 .56141 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.64879 .39152 m
.64879 .39152 L
s
.64879 .39152 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.66236 .49991 L
s
.66236 .49991 m
.68751 .6451 L
s
.66236 .49991 m
.68751 .6451 L
s
.68751 .6451 m
.68751 .6451 L
s
0 0 0 r
2 Mabswid
.75329 .73134 Mdot
.63704 .58484 Mdot
.039 .916 .04 r
.5 Mabswid
.45344 .45225 m
.46135 .44156 L
s
.46135 .44156 m
.49016 .40266 L
s
.45344 .45225 m
.45344 .45225 L
s
.36469 .57211 m
.41918 .49851 L
s
.41918 .49851 m
.45344 .45225 L
s
0 0 0 r
2 Mabswid
.49016 .40266 Mdot
.32772 .35311 Mdot
.53635 .57806 Mdot
.21156 .47125 Mdot
.039 .916 .04 r
.5 Mabswid
.50442 .34012 m
.50442 .34012 L
s
.50639 .33854 m
.50639 .33854 L
s
0 0 0 r
2 Mabswid
.6697 .71905 Mdot
.039 .916 .04 r
.5 Mabswid
.50603 .37062 m
.50603 .37062 L
s
.51035 .3706 m
.51035 .3706 L
s
.51035 .3706 m
.51035 .3706 L
s
0 0 0 r
2 Mabswid
.49121 .37067 Mdot
.039 .916 .04 r
.5 Mabswid
.61951 .37499 m
.6199 .37051 L
s
.6199 .37051 m
.6199 .37051 L
s
.6199 .37051 m
.63933 .15009 L
s
0 0 0 r
2 Mabswid
.61951 .37499 Mdot
.039 .916 .04 r
.5 Mabswid
.52055 .34772 m
.61951 .37499 L
s
.52055 .34772 m
.52055 .34772 L
s
.52055 .34772 m
.52055 .34772 L
s
.60279 .48572 m
.604 .48214 L
s
0 0 0 r
2 Mabswid
.604 .48214 Mdot
.039 .916 .04 r
.5 Mabswid
.59562 .56521 m
.59931 .52437 L
s
.59931 .52437 m
.60279 .48572 L
s
0 0 0 r
2 Mabswid
.60279 .48572 Mdot
.039 .916 .04 r
.5 Mabswid
.52395 .54983 m
.55292 .60443 L
s
.55292 .60443 m
.57837 .65241 L
s
.52395 .54983 m
.52395 .54983 L
s
.57837 .65241 m
.58196 .65918 L
s
0 0 0 r
2 Mabswid
.52395 .54983 Mdot
.039 .916 .04 r
.5 Mabswid
.52395 .54983 m
.55324 .52898 L
s
.55324 .52898 m
.55324 .52898 L
s
0 0 0 r
2 Mabswid
.50232 .20531 Mdot
.45254 .70275 Mdot
.55951 .5764 Mdot
0 g
.5 Mabswid
.65384 .28109 m
.65856 .48221 L
s
.64898 .0747 m
.65384 .28109 L
s
0 0 0 r
2 Mabswid
.56176 .57678 Mdot
.60015 .46487 Mdot
.039 .916 .04 r
.5 Mabswid
.50471 .34557 m
.50471 .34557 L
s
.5073 .34592 m
.5073 .34592 L
s
.5073 .34592 m
.5073 .34592 L
s
0 0 0 r
2 Mabswid
.49865 .34475 Mdot
.27285 .69002 Mdot
.57962 .48611 Mdot
.039 .916 .04 r
.5 Mabswid
.37692 .42803 m
.43052 .44361 L
s
.43052 .44361 m
.45281 .45009 L
s
0 0 0 r
2 Mabswid
.45281 .45009 Mdot
.57751 .41602 Mdot
.039 .916 .04 r
.5 Mabswid
.62619 .43794 m
.62619 .43794 L
s
.55646 .55302 m
.5631 .49953 L
s
.5631 .49953 m
.5631 .49953 L
s
.5631 .49953 m
.5631 .49953 L
s
.5631 .49953 m
.56804 .45982 L
s
.56804 .45982 m
.56804 .45982 L
s
.5512 .59534 m
.55646 .55302 L
s
.56804 .45982 m
.56804 .45982 L
s
0 0 0 r
2 Mabswid
.56804 .45982 Mdot
.50546 .3721 Mdot
.039 .916 .04 r
.5 Mabswid
.50611 .37199 m
.50611 .37199 L
s
.51044 .37126 m
.51044 .37126 L
s
.51044 .37126 m
.51044 .37126 L
s
0 0 0 r
2 Mabswid
.52055 .34772 Mdot
.52703 .46019 Mdot
.039 .916 .04 r
.5 Mabswid
.52703 .46019 m
.53084 .46613 L
s
.53084 .46613 m
.53084 .46613 L
s
0 g
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.60902 .56141 L
s
.60902 .56141 m
.60902 .56141 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.60902 .56141 L
s
.60902 .56141 m
.60902 .56141 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.64879 .39152 m
.64879 .39152 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.43728 .57895 m
.52134 .4594 L
s
.43728 .57895 m
.43728 .57895 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.64879 .39152 L
s
.64879 .39152 m
.64879 .39152 L
s
.47769 .52148 m
.51755 .46479 L
s
.43728 .57895 m
.47769 .52148 L
s
.52134 .4594 m
.52134 .4594 L
s
.51755 .46479 m
.52134 .4594 L
s
.43728 .57895 m
.43728 .57895 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.5028 .30955 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.5028 .30955 m
.5028 .30955 L
s
.37505 .42357 m
.49302 .45246 L
s
.37505 .42357 m
.37505 .42357 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.49302 .45246 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.5028 .30955 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.5028 .30955 m
.5028 .30955 L
s
.52134 .4594 m
.52134 .4594 L
s
.37505 .42357 m
.52134 .4594 L
s
.37505 .42357 m
.37505 .42357 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.52134 .4594 m
.52134 .4594 L
s
.039 .916 .04 r
.65478 .43937 m
.73668 .39656 L
s
.53108 .47072 m
.53108 .47072 L
s
0 0 0 r
2 Mabswid
.53171 .48335 Mdot
.53084 .46613 Mdot
.61715 .39049 Mdot
.039 .916 .04 r
.5 Mabswid
.51448 .37059 m
.63467 .37938 L
s
.51448 .37059 m
.51448 .37059 L
s
0 0 0 r
2 Mabswid
.51448 .37059 Mdot
.039 .916 .04 r
.5 Mabswid
.61733 .43975 m
.61733 .43975 L
s
0 0 0 r
2 Mabswid
.61116 .44941 Mdot
.55324 .52898 Mdot
.6396 .44397 Mdot
.61482 .69137 Mdot
.70338 .26875 Mdot
.039 .916 .04 r
.5 Mabswid
.45798 .4312 m
.53652 .47523 L
s
.53652 .47523 m
.55843 .48751 L
s
.55843 .48751 m
.55843 .48751 L
s
.55843 .48751 m
.55843 .48751 L
s
.55843 .48751 m
.59278 .50677 L
s
0 0 0 r
2 Mabswid
.59278 .50677 Mdot
.039 .916 .04 r
.5 Mabswid
.55367 .51912 m
.56505 .60398 L
s
.55367 .51912 m
.55367 .51912 L
s
.56505 .60398 m
.56668 .61619 L
s
0 0 0 r
2 Mabswid
.55367 .51912 Mdot
.5891 .44062 Mdot
.039 .916 .04 r
.5 Mabswid
.61106 .55905 m
.61106 .55905 L
s
.61106 .55905 m
.63312 .65673 L
s
0 0 0 r
2 Mabswid
.65066 .43076 Mdot
.039 .916 .04 r
.5 Mabswid
.56794 .51281 m
.65066 .43076 L
s
.65066 .43076 m
.65066 .43076 L
s
.61446 .43379 m
.61508 .33658 L
s
.61389 .52287 m
.61446 .43379 L
s
0 0 0 r
2 Mabswid
.61389 .52287 Mdot
.57534 .50382 Mdot
.63257 .42715 Mdot
.039 .916 .04 r
.5 Mabswid
.48228 .39026 m
.57295 .39249 L
s
.57295 .39249 m
.57295 .39249 L
s
.57295 .39249 m
.62786 .39385 L
s
.62786 .39385 m
.62786 .39385 L
s
.62786 .39385 m
.62786 .39385 L
s
0 0 0 r
2 Mabswid
.62786 .39385 Mdot
.5682 .52957 Mdot
.27934 .6656 Mdot
.73668 .39656 Mdot
.56721 .51369 Mdot
.56794 .51281 Mdot
.63933 .15009 Mdot
.58196 .65918 Mdot
.37692 .42803 Mdot
.63312 .65673 Mdot
0 g
.5 Mabswid
.42431 .5567 m
.65856 .48221 L
s
.18411 .63308 m
.42431 .5567 L
s
0 0 0 r
2 Mabswid
.48228 .39026 Mdot
.56668 .61619 Mdot
.45798 .4312 Mdot
.5512 .59534 Mdot
.36469 .57211 Mdot
.61508 .33658 Mdot
.59562 .56521 Mdot
.63467 .37938 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.431973 0.0136054 0.97619 0.557823 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.82601 .36453 m
.44321 .48622 L
s
.82601 .36453 m
.8835 .74145 L
s
0 0 0 r
2 Mabswid
.45134 .70138 Mdot
.44857 .56278 m .44857 .56278 L .56015 .50695 L .709 .738 .874 r
F
.62673 .40534 m .54239 .37617 L .54239 .37617 L .608 .039 0 r
F
.48156 .42133 m .48156 .42133 L .56015 .50695 L .393 .411 .76 r
F
.48156 .42133 m .56015 .50695 L .48156 .42133 L .794 .428 .364 r
F
.48156 .42133 m .56015 .50695 L .56015 .50695 L .393 .411 .76 r
F
.48156 .42133 m .56015 .50695 L .56015 .50695 L .794 .428 .364 r
F
.4817 .42149 m .56015 .50695 L .56015 .50695 L .393 .411 .76 r
F
.48167 .42146 m .56015 .50695 L .4817 .42149 L F
.44857 .56278 m .56015 .50695 L .56015 .50695 L .709 .738 .874 r
F
.44857 .56278 m .56015 .50695 L .56015 .50695 L .377 .05 .279 r
F
.44857 .56278 m .50702 .53353 L .44857 .56278 L F
.50702 .53353 m .56015 .50695 L .44857 .56278 L F
.44857 .56278 m .43555 .47045 L .43555 .47045 L .709 .738 .874 r
F
.68629 .53817 m .56015 .50695 L .56015 .50695 L .649 .697 .881 r
F
.68629 .53817 m .68629 .53817 L .62586 .52321 L .723 .328 .301 r
F
.48156 .42133 m .54239 .37617 L .56015 .50695 L .393 .411 .76 r
F
.48156 .42133 m .56015 .50695 L .48167 .42146 L F
.48156 .42133 m .48278 .42267 L .44165 .46427 L .794 .428 .364 r
F
.48278 .42267 m .56015 .50695 L .44165 .46427 L F
.44165 .46427 m .56015 .50695 L .43583 .47053 L F
.48156 .42133 m .43555 .47045 L .49114 .41422 L 0 0 0 r
F
.56015 .50695 m .43555 .47045 L .56015 .50695 L .709 .738 .874 r
F
.53818 .51794 m .43555 .47045 L .56015 .50695 L F
.48156 .42133 m .49114 .41422 L .49114 .41422 L 0 0 0 r
F
.48156 .42133 m .49114 .41422 L .49114 .41422 L F
.48156 .42133 m .54239 .37617 L .54239 .37617 L .393 .411 .76 r
F
.49114 .41422 m .49114 .41422 L .50098 .40691 L 0 0 0 r
F
.48156 .42133 m .48156 .42133 L .49114 .41422 L F
.48156 .42133 m .54239 .37617 L .48156 .42133 L .393 .411 .76 r
F
.44857 .56278 m .43555 .47045 L .43555 .47045 L .709 .738 .874 r
F
.35506 .57837 m .35506 .57837 L .40693 .50882 L 0 0 0 r
F
.57485 .6369 m .57485 .6369 L .56951 .58974 L .895 .725 .663 r
F
.57485 .6369 m .56015 .50695 L .57485 .6369 L .341 .32 .69 r
F
.57485 .6369 m .49085 .60029 L .49085 .60029 L .895 .725 .663 r
F
.57485 .6369 m .56015 .50695 L .56015 .50695 L .341 .32 .69 r
F
.44857 .56278 m .44857 .56278 L .49085 .60029 L .377 .05 .279 r
F
.57485 .6369 m .49085 .60029 L .56951 .58974 L .895 .725 .663 r
F
.60831 .60831 m .56015 .50695 L .62202 .57221 L .341 .32 .69 r
F
.6348 .58568 m .62202 .57221 L .6348 .58568 L F
.60831 .60831 m .62085 .5753 L .6348 .58568 L F
.62085 .5753 m .62202 .57221 L .6348 .58568 L F
.44857 .56278 m .43555 .47045 L .53818 .51794 L .709 .738 .874 r
F
.43555 .47045 m .56015 .50695 L .43555 .47045 L .794 .428 .364 r
F
.53009 .3853 m .43555 .47045 L .54239 .37617 L 0 0 0 r
F
.50098 .40691 m .43555 .47045 L .53009 .3853 L F
.43555 .47045 m .43555 .47045 L .53009 .3853 L F
.49114 .41422 m .43555 .47045 L .50098 .40691 L F
.56015 .50695 m .56015 .50695 L .4356 .47046 L .794 .428 .364 r
F
.56015 .50695 m .4356 .47046 L .43555 .47045 L F
.54239 .37617 m .43555 .47045 L .54239 .37617 L 0 0 0 r
F
.43555 .47045 m .49685 .41635 L .43555 .47045 L .707 .572 .701 r
F
.43555 .47045 m .43555 .47045 L .54239 .37617 L 0 0 0 r
F
.43555 .47045 m .43555 .47045 L .56015 .50695 L .709 .738 .874 r
F
.57485 .6369 m .56015 .50695 L .60831 .60831 L .341 .32 .69 r
F
.57485 .6369 m .57485 .6369 L .49085 .60029 L .609 .819 .981 r
F
.44857 .56278 m .49085 .60029 L .49085 .60029 L 0 .075 .622 r
F
.44857 .56278 m .53818 .51794 L .49085 .60029 L .377 .05 .279 r
F
.43816 .489 m .49085 .60029 L .43555 .47045 L 0 .075 .622 r
F
.44439 .53316 m .49085 .60029 L .43816 .489 L F
.49085 .60029 m .49085 .60029 L .43816 .489 L F
.57485 .6369 m .49085 .60029 L .49085 .60029 L .609 .819 .981 r
F
.54793 .417 m .56015 .50695 L .54239 .37617 L .879 .759 .726 r
F
.54239 .37617 m .54239 .37617 L .49685 .41635 L .707 .572 .701 r
F
.42103 .38564 m .54239 .37617 L .49685 .41635 L F
.48156 .42133 m .43555 .47045 L .43555 .47045 L 0 0 0 r
F
.48156 .42133 m .48156 .42133 L .43555 .47045 L .794 .428 .364 r
F
.48156 .42133 m .43555 .47045 L .48156 .42133 L 0 0 0 r
F
.48156 .42133 m .43555 .47045 L .43555 .47045 L .794 .428 .364 r
F
.42104 .38567 m .49685 .41635 L .43555 .47045 L .707 .572 .701 r
F
.41272 .33709 m .41272 .33709 L .4905 .36053 L .597 .053 0 r
F
.54239 .37617 m .54793 .417 L .54239 .37617 L .879 .759 .726 r
F
.56015 .50695 m .56015 .50695 L .55935 .38204 L F
.54239 .37617 m .54239 .37617 L .56014 .50695 L .393 .411 .76 r
F
.55971 .43827 m .56015 .50695 L .54239 .37617 L .879 .759 .726 r
F
.54239 .37617 m .54239 .37617 L .56014 .50695 L .393 .411 .76 r
F
.41272 .33709 m .54239 .37617 L .42103 .38564 L .707 .572 .701 r
F
.41272 .33709 m .43555 .47045 L .4484 .37162 L .018 .079 .585 r
F
.44857 .56278 m .44857 .56278 L .44439 .53316 L 0 .075 .622 r
F
.44857 .56278 m .49085 .60029 L .44439 .53316 L F
.44857 .56278 m .49085 .60029 L .44857 .56278 L F
.56951 .58974 m .49085 .60029 L .49085 .60029 L .895 .725 .663 r
F
.49085 .60029 m .63477 .58568 L .49085 .60029 L .609 .819 .981 r
F
.57485 .6369 m .63477 .58568 L .49085 .60029 L F
.57159 .70703 m .49085 .60029 L .49085 .60029 L .175 .317 .77 r
F
.57159 .70703 m .57159 .70703 L .49085 .60029 L F
.64364 .57753 m .6348 .58568 L .6348 .58568 L .723 .328 .301 r
F
.64522 .57607 m .6348 .58568 L .6065 .54461 L F
.68629 .53817 m .56015 .50695 L .59773 .48511 L .649 .697 .881 r
F
.62673 .40534 m .56015 .50695 L .56015 .50695 L .879 .759 .726 r
F
.62673 .40534 m .56032 .50668 L .62673 .40534 L F
.62673 .40534 m .62673 .40534 L .60503 .43846 L .32 .053 .343 r
F
.62673 .40534 m .54263 .37625 L .62673 .40534 L .608 .039 0 r
F
.55984 .50473 m .56015 .50695 L .54239 .37617 L .879 .759 .726 r
F
.54263 .37625 m .54243 .37619 L .61173 .40015 L .608 .039 0 r
F
.74979 .38672 m .74979 .38672 L .67901 .43629 L .048 0 .127 r
F
.62673 .40534 m .66575 .44558 L .66575 .44558 L .32 .053 .343 r
F
.56032 .50668 m .56015 .50695 L .62673 .40534 L .879 .759 .726 r
F
.62673 .40534 m .66575 .44558 L .60503 .43846 L .32 .053 .343 r
F
.62673 .40534 m .66575 .44558 L .66575 .44558 L F
.68629 .53817 m .60968 .49227 L .66575 .44558 L .649 .697 .881 r
F
.68629 .53817 m .56015 .50695 L .68629 .53817 L F
.68629 .53817 m .64522 .57607 L .64522 .57607 L .723 .328 .301 r
F
.68629 .53817 m .64522 .57607 L .62586 .52321 L F
.68629 .53817 m .68629 .53817 L .66987 .55332 L .985 .862 .632 r
F
.68629 .53817 m .64533 .57596 L .68629 .53817 L .723 .328 .301 r
F
.64533 .57596 m .64522 .57607 L .68629 .53817 L F
.68629 .53817 m .66585 .44601 L .68629 .53817 L .985 .862 .632 r
F
.66585 .44601 m .66575 .44558 L .68629 .53817 L F
.60968 .49227 m .59773 .48511 L .66575 .44558 L .649 .697 .881 r
F
.66575 .44558 m .66069 .46847 L .66575 .44558 L .641 .489 .661 r
F
.56015 .50695 m .66575 .44558 L .56015 .50695 L .32 .053 .343 r
F
.68629 .53817 m .66575 .44558 L .66987 .55332 L .985 .862 .632 r
F
.68629 .53817 m .68629 .53817 L .66575 .44558 L .649 .697 .881 r
F
.76432 .53612 m .66575 .44558 L .66575 .44558 L .797 .322 .097 r
F
.76432 .53612 m .76432 .53612 L .6348 .58568 L .709 .826 .937 r
F
.76432 .53612 m .6348 .58568 L .6348 .58568 L F
.57485 .6369 m .6348 .58568 L .6348 .58568 L .609 .819 .981 r
F
.57159 .70703 m .6348 .58568 L .6348 .58568 L .937 .856 .736 r
F
.57485 .6369 m .6348 .58568 L .6348 .58568 L .609 .819 .981 r
F
.57159 .70703 m .6348 .58568 L .57159 .70703 L .937 .856 .736 r
F
.66987 .55332 m .66678 .47245 L .66014 .5623 L .985 .862 .632 r
F
.66678 .47245 m .66575 .44558 L .66014 .5623 L F
.62586 .52321 m .64522 .57607 L .56015 .50695 L .723 .328 .301 r
F
.66014 .5623 m .66575 .44558 L .6348 .58568 L .985 .862 .632 r
F
.68629 .53817 m .66575 .44558 L .66575 .44558 L F
.66575 .44558 m .66575 .44558 L .5602 .50692 L .32 .053 .343 r
F
.68629 .53817 m .66575 .44558 L .66575 .44558 L .649 .697 .881 r
F
.76432 .53612 m .66006 .57602 L .66069 .46847 L .641 .489 .661 r
F
.64522 .57607 m .6348 .58568 L .6348 .58568 L .723 .328 .301 r
F
.64522 .57607 m .6348 .58568 L .64364 .57753 L F
.66006 .57602 m .6348 .58568 L .66069 .46847 L .641 .489 .661 r
F
.76432 .53612 m .66575 .44558 L .76432 .53612 L .797 .322 .097 r
F
.76432 .53612 m .66069 .46847 L .66575 .44558 L .641 .489 .661 r
F
.66575 .44558 m .66575 .44558 L .68792 .50755 L .797 .322 .097 r
F
.76432 .53612 m .66575 .44558 L .68792 .50755 L F
.60503 .43846 m .66575 .44558 L .56015 .50695 L .32 .053 .343 r
F
.66575 .44558 m .59773 .48511 L .66575 .44558 L .649 .697 .881 r
F
.66575 .44558 m .66575 .44558 L .6348 .58568 L .985 .862 .632 r
F
.66575 .44558 m .66873 .50038 L .66575 .44558 L .048 0 .127 r
F
.76432 .53612 m .66873 .50038 L .65964 .57617 L .709 .826 .937 r
F
.68792 .50755 m .66873 .50038 L .76432 .53612 L F
.68792 .50755 m .66575 .44558 L .66873 .50038 L .797 .322 .097 r
F
.76432 .53612 m .66873 .50038 L .66873 .50038 L .709 .826 .937 r
F
.65964 .57617 m .66873 .50038 L .6348 .58568 L F
.66006 .57602 m .6348 .58568 L .6348 .58568 L .641 .489 .661 r
F
.57485 .6369 m .6348 .58568 L .63477 .58569 L .609 .819 .981 r
F
.57485 .6369 m .63468 .58578 L .57485 .6369 L F
.63468 .58578 m .6348 .58568 L .57485 .6369 L F
.57485 .6369 m .6348 .58568 L .6348 .58568 L F
.57159 .70703 m .57159 .70703 L .6348 .58568 L .674 .491 .63 r
F
.57485 .6369 m .57485 .6369 L .60831 .60831 L .341 .32 .69 r
F
.57159 .70703 m .60948 .59256 L .6348 .58568 L .674 .491 .63 r
F
.57159 .70703 m .6348 .58568 L .6348 .58568 L F
.57159 .70703 m .6348 .58568 L .6348 .58568 L .937 .856 .736 r
F
.63477 .58569 m .6348 .58568 L .63477 .58568 L .609 .819 .981 r
F
.60948 .59256 m .61096 .5881 L .6348 .58568 L .674 .491 .63 r
F
.60948 .59256 m .6348 .58568 L .6348 .58568 L F
.57485 .6369 m .49085 .60029 L .49085 .60029 L .895 .725 .663 r
F
.57485 .6369 m .49085 .60029 L .57485 .6369 L F
.57159 .70703 m .49085 .60029 L .61096 .5881 L .674 .491 .63 r
F
.57159 .70703 m .62269 .60891 L .55343 .60245 L .937 .856 .736 r
F
.35506 .57837 m .49085 .60029 L .35506 .57837 L .574 .735 .952 r
F
.44857 .56278 m .49085 .60029 L .49085 .60029 L .377 .05 .279 r
F
.44857 .56278 m .43556 .47052 L .44857 .56278 L .709 .738 .874 r
F
.43556 .47052 m .43555 .47045 L .44857 .56278 L F
.35506 .57837 m .43555 .47045 L .48164 .57867 L .715 .544 .656 r
F
.35506 .57837 m .48164 .57868 L .49085 .60029 L F
.35506 .57837 m .49085 .60029 L .49083 .60027 L .574 .735 .952 r
F
.47106 .57865 m .47106 .57865 L .49085 .60029 L .953 .766 .613 r
F
.42315 .52627 m .49083 .60027 L .42315 .52627 L .574 .735 .952 r
F
.35506 .57837 m .46452 .59603 L .42315 .52627 L F
.46452 .59603 m .49083 .60027 L .42315 .52627 L F
.35506 .57837 m .49085 .60029 L .49085 .60029 L F
.35506 .57837 m .49085 .60029 L .49085 .60029 L F
.35506 .57837 m .49085 .60029 L .49085 .60029 L .715 .544 .656 r
F
.35506 .57837 m .35506 .57837 L .49085 .60029 L F
.35506 .57837 m .42314 .52627 L .42315 .52627 L 0 0 0 r
F
.49085 .60029 m .49085 .60029 L .43555 .47045 L 0 .075 .622 r
F
.43555 .47045 m .42315 .52627 L .43555 .47045 L 0 0 0 r
F
.40693 .50882 m .42315 .52627 L .43555 .47045 L F
.42315 .52627 m .42315 .52627 L .43555 .47045 L F
.35506 .57837 m .43555 .47045 L .43555 .47045 L .715 .544 .656 r
F
.35506 .57837 m .43555 .47045 L .35506 .57837 L F
.32929 .43314 m .32929 .43314 L .43555 .47045 L .716 .806 .92 r
F
.32929 .43314 m .43555 .47045 L .43555 .47045 L .815 .377 .201 r
F
.32929 .43314 m .43555 .47045 L .32929 .43314 L F
.32929 .43314 m .43235 .39075 L .43235 .39075 L .635 .481 .657 r
F
.32929 .43314 m .43235 .39075 L .43235 .39075 L F
.49085 .60029 m .42315 .52627 L .49085 .60029 L .953 .766 .613 r
F
.44974 .56759 m .42315 .52627 L .47106 .57865 L F
.42417 .55432 m .42315 .52627 L .44974 .56759 L F
.42417 .55432 m .42401 .55002 L .42417 .55432 L F
.42401 .55002 m .42315 .52627 L .42417 .55432 L F
.42417 .55432 m .47106 .57865 L .45942 .57862 L F
.42315 .52627 m .49083 .60027 L .42315 .52627 L .574 .735 .952 r
F
.49085 .60029 m .47106 .57865 L .49085 .60029 L .953 .766 .613 r
F
.45942 .57862 m .47106 .57865 L .49085 .60029 L F
.57159 .70703 m .52967 .60163 L .49085 .60029 L .175 .317 .77 r
F
.57159 .70703 m .55343 .60245 L .52967 .60163 L F
.57159 .70703 m .49085 .60029 L .49085 .60029 L .674 .491 .63 r
F
.57159 .70703 m .49085 .60029 L .57159 .70703 L F
.42842 .67106 m .55343 .60245 L .55343 .60245 L .659 .537 .704 r
F
.52896 .61589 m .51136 .60869 L .55343 .60245 L .163 0 0 r
F
.51136 .60869 m .49085 .60029 L .55343 .60245 L F
.55343 .60245 m .49085 .60029 L .55343 .60245 L F
.49085 .60029 m .49085 .60029 L .55343 .60245 L F
.49085 .60029 m .49085 .60029 L .52896 .61589 L F
.49085 .60029 m .56015 .50695 L .49085 .60029 L .377 .05 .279 r
F
.53818 .51794 m .56015 .50695 L .49085 .60029 L F
.49085 .60029 m .52967 .60163 L .49085 .60029 L .175 .317 .77 r
F
.43555 .47045 m .49085 .60029 L .43555 .47045 L 0 .075 .622 r
F
.49085 .60029 m .48164 .57868 L .49085 .60029 L .715 .544 .656 r
F
.56301 .53226 m .49085 .60029 L .56015 .50695 L .895 .725 .663 r
F
.56951 .58974 m .49085 .60029 L .56301 .53226 L F
.49058 .6006 m .42842 .67106 L .49067 .60049 L .953 .766 .613 r
F
.42842 .67106 m .42842 .67106 L .49058 .6006 L F
.49067 .60049 m .42842 .67106 L .49085 .60029 L F
.42842 .67106 m .49085 .60029 L .49085 .60029 L .163 0 0 r
F
.42842 .67106 m .49085 .60029 L .42842 .67106 L F
.42842 .67106 m .42842 .67106 L .4265 .61828 L .659 .537 .704 r
F
.42842 .67106 m .42417 .55432 L .49085 .60029 L .953 .766 .613 r
F
.42842 .67106 m .49085 .60029 L .52896 .61589 L .163 0 0 r
F
.4265 .61828 m .55343 .60245 L .49737 .56967 L .659 .537 .704 r
F
.42842 .67106 m .55343 .60245 L .42842 .67106 L F
.42842 .67106 m .52896 .61589 L .52896 .61589 L .163 0 0 r
F
.42842 .67106 m .42842 .67106 L .52896 .61589 L F
.42315 .52627 m .49737 .56967 L .42315 .52627 L .659 .537 .704 r
F
.4265 .61828 m .49737 .56967 L .42315 .52627 L F
.55343 .60245 m .42315 .52627 L .55343 .60245 L .687 .152 0 r
F
.55343 .60245 m .54746 .59896 L .55343 .60245 L F
.54746 .59896 m .42315 .52627 L .55343 .60245 L F
.6348 .58568 m .55969 .60116 L .6348 .58568 L .651 .149 .043 r
F
.55343 .60245 m .6348 .58568 L .55343 .60245 L .937 .856 .736 r
F
.56015 .50695 m .6348 .58568 L .56015 .50695 L .723 .328 .301 r
F
.62673 .40534 m .56015 .50695 L .56015 .50695 L .879 .759 .726 r
F
.62673 .40534 m .56015 .50695 L .55935 .38204 L F
.63913 .41813 m .62663 .4053 L .65783 .43741 L .608 .039 0 r
F
.6348 .58568 m .66575 .44558 L .6348 .58568 L .985 .862 .632 r
F
.62673 .40534 m .62673 .40534 L .63913 .41813 L .608 .039 0 r
F
.62673 .40534 m .66575 .44558 L .62673 .40534 L .32 .053 .343 r
F
.62673 .40534 m .62663 .4053 L .63913 .41813 L .608 .039 0 r
F
.55935 .38204 m .55971 .43827 L .54239 .37617 L .879 .759 .726 r
F
.62663 .4053 m .54239 .37617 L .54239 .37617 L .608 .039 0 r
F
.62663 .4053 m .54239 .37617 L .65783 .43741 L F
.65783 .43741 m .54239 .37617 L .66575 .44558 L F
.41736 .50968 m .4253 .51657 L .42315 .52627 L .815 .377 .201 r
F
.41736 .50968 m .42315 .52627 L .42315 .52627 L F
.35506 .57837 m .42315 .52627 L .40693 .50882 L 0 0 0 r
F
.32929 .43314 m .41736 .50968 L .42315 .52627 L .815 .377 .201 r
F
.54239 .37617 m .54239 .37617 L .65783 .43741 L .608 .039 0 r
F
.43555 .47045 m .45748 .38041 L .43555 .47045 L .716 .806 .92 r
F
.45748 .38041 m .54239 .37617 L .45748 .38041 L .92 .832 .742 r
F
.52371 .26189 m .54239 .37617 L .54239 .37617 L F
.66052 .30869 m .54239 .37617 L .54239 .37617 L .029 0 0 r
F
.66052 .30869 m .66052 .30869 L .66575 .44558 L .971 .779 .588 r
F
.66052 .30869 m .5424 .37616 L .66052 .30869 L .029 0 0 r
F
.62673 .40534 m .55935 .38204 L .54239 .37617 L .608 .039 0 r
F
.55935 .38204 m .55935 .38204 L .54239 .37617 L .879 .759 .726 r
F
.66052 .30869 m .60602 .41197 L .54239 .37617 L .663 .54 .704 r
F
.66052 .30869 m .66575 .44558 L .60602 .41197 L F
.66052 .30869 m .66575 .44558 L .66052 .30869 L F
.66052 .30869 m .61814 .35248 L .66575 .44558 L .971 .779 .588 r
F
.66052 .30869 m .66575 .44558 L .66052 .30869 L .663 .54 .704 r
F
.6074 .36358 m .66575 .44558 L .6074 .36358 L .597 .726 .934 r
F
.61814 .35248 m .61814 .35248 L .66575 .44558 L .971 .779 .588 r
F
.63886 .33107 m .56508 .36321 L .6074 .36358 L .029 0 0 r
F
.6602 .30902 m .6602 .30902 L .63886 .33107 L F
.6602 .30902 m .56508 .36321 L .63886 .33107 L F
.66575 .44558 m .61814 .35248 L .66575 .44558 L .971 .779 .588 r
F
.56508 .36321 m .54239 .37617 L .6074 .36358 L .029 0 0 r
F
.43555 .47045 m .43555 .47045 L .4484 .37162 L .018 .079 .585 r
F
.41272 .33709 m .45748 .38041 L .4905 .36053 L .597 .053 0 r
F
.41272 .33709 m .41272 .33709 L .42103 .38564 L .707 .572 .701 r
F
.41272 .33709 m .45748 .38041 L .45748 .38041 L .597 .053 0 r
F
.52371 .26189 m .52371 .26189 L .53941 .35798 L .258 .364 .781 r
F
.52371 .26189 m .45795 .37957 L .52371 .26189 L .671 .483 .623 r
F
.54239 .37617 m .53121 .37673 L .54239 .37617 L .597 .053 0 r
F
.4905 .36053 m .47032 .37268 L .54239 .37617 L F
.47032 .37268 m .45748 .38041 L .54239 .37617 L F
.45748 .38041 m .45748 .38041 L .43555 .47045 L .716 .806 .92 r
F
.52371 .26189 m .54239 .37617 L .45748 .38041 L .92 .832 .742 r
F
.45748 .38041 m .54154 .37097 L .45748 .38041 L .635 .803 .963 r
F
.52371 .26189 m .54239 .37617 L .52371 .26189 L .92 .832 .742 r
F
.6074 .36358 m .54239 .37617 L .56297 .37218 L .029 0 0 r
F
.6074 .36358 m .6074 .36358 L .54239 .37617 L .258 .364 .781 r
F
.54239 .37617 m .56015 .50695 L .54239 .37617 L .879 .759 .726 r
F
.55971 .43827 m .54239 .37617 L .54239 .37617 L F
.54239 .37617 m .60602 .41197 L .54239 .37617 L .663 .54 .704 r
F
.56015 .50695 m .54239 .37617 L .56015 .50695 L .393 .411 .76 r
F
.54239 .37617 m .54239 .37617 L .66575 .44558 L .608 .039 0 r
F
.45748 .38041 m .53349 .45964 L .45748 .38041 L .71 .283 .233 r
F
.6074 .36358 m .56297 .37218 L .6074 .36358 L .029 0 0 r
F
.60602 .41197 m .60602 .41197 L .54239 .37617 L .663 .54 .704 r
F
.66575 .44558 m .66575 .44558 L .6074 .36358 L .597 .726 .934 r
F
.66575 .44558 m .6074 .36358 L .66575 .44558 L .971 .779 .588 r
F
.54239 .37617 m .6074 .36358 L .54239 .37617 L .258 .364 .781 r
F
.66873 .50038 m .66873 .50038 L .66575 .44558 L .048 0 .127 r
F
.66602 .45048 m .66575 .44558 L .66602 .45048 L .797 .322 .097 r
F
.66602 .45048 m .66602 .45048 L .66873 .50038 L F
.66873 .50038 m .66602 .45048 L .66873 .50038 L F
.66575 .44558 m .66575 .44558 L .66873 .50038 L F
.66052 .30869 m .66575 .44558 L .66575 .44558 L .663 .54 .704 r
F
.74979 .38672 m .66575 .44558 L .66575 .44558 L .597 .726 .934 r
F
.74979 .38672 m .66575 .44558 L .74979 .38672 L F
.6074 .36358 m .61738 .38584 L .6074 .36358 L .033 .17 .676 r
F
.65932 .44931 m .5602 .50692 L .56015 .50695 L .32 .053 .343 r
F
.54239 .37617 m .56015 .50695 L .54239 .37617 L .879 .759 .726 r
F
.66575 .44558 m .54239 .37617 L .66575 .44558 L .608 .039 0 r
F
.66873 .50038 m .6074 .36358 L .66873 .50038 L .716 .541 .652 r
F
.45794 .37958 m .45748 .38041 L .52371 .26189 L .671 .483 .623 r
F
.52371 .26189 m .6074 .36358 L .53941 .35798 L .258 .364 .781 r
F
.52371 .26189 m .52371 .26189 L .60739 .36357 L .671 .483 .623 r
F
.52371 .26189 m .6074 .36358 L .52371 .26189 L .258 .364 .781 r
F
.53941 .35798 m .6074 .36358 L .54239 .37617 L F
.63987 .39498 m .6074 .36358 L .66575 .44558 L .971 .779 .588 r
F
.66699 .44471 m .66575 .44558 L .658 .43469 L .597 .726 .934 r
F
.66699 .44471 m .658 .43469 L .6074 .36358 L F
.61814 .35248 m .6074 .36358 L .6074 .36358 L .971 .779 .588 r
F
.61814 .35248 m .6074 .36358 L .63987 .39498 L F
.74979 .38672 m .66699 .44471 L .6074 .36358 L .597 .726 .934 r
F
.6591 .47889 m .6591 .47889 L .66873 .50038 L .716 .541 .652 r
F
.6074 .36358 m .6591 .47889 L .6591 .47889 L F
.6074 .36358 m .6074 .36358 L .6591 .47889 L F
.66575 .44558 m .66873 .50038 L .67901 .43629 L .048 0 .127 r
F
.66699 .44471 m .66763 .4802 L .66575 .44558 L F
.67901 .43629 m .66763 .4802 L .66699 .44471 L F
.67901 .43629 m .66873 .50038 L .66763 .4802 L F
.68463 .47808 m .6074 .36358 L .66873 .50038 L .716 .541 .652 r
F
.74979 .38672 m .6074 .36358 L .68463 .47808 L F
.66534 .39234 m .66873 .50038 L .61738 .38584 L .033 .17 .676 r
F
.74979 .38672 m .6074 .36358 L .6074 .36358 L .597 .726 .934 r
F
.66534 .39234 m .66534 .39234 L .66662 .43297 L .706 .752 .888 r
F
.66052 .30869 m .6074 .36358 L .6074 .36358 L .029 0 0 r
F
.74979 .38672 m .6074 .36358 L .6074 .36358 L .716 .541 .652 r
F
.66052 .30869 m .66052 .30869 L .6074 .36358 L .029 0 0 r
F
.74979 .38672 m .6074 .36358 L .74979 .38672 L .716 .541 .652 r
F
.45748 .38041 m .53349 .45964 L .45748 .38041 L .71 .283 .233 r
F
.53349 .45964 m .66873 .50038 L .53349 .45964 L .793 .399 .309 r
F
.66873 .50038 m .66873 .50038 L .53349 .45964 L F
.66873 .50038 m .53349 .45964 L .66873 .50038 L .706 .752 .888 r
F
.66873 .50038 m .66873 .50038 L .5513 .47893 L .793 .399 .309 r
F
.53349 .45964 m .53349 .45964 L .66873 .50038 L .706 .752 .888 r
F
.53349 .45964 m .6074 .36358 L .53349 .45964 L .311 0 .2 r
F
.53349 .45964 m .53349 .45964 L .6681 .48027 L .706 .752 .888 r
F
.54111 .46789 m .66873 .50038 L .53349 .45964 L .793 .399 .309 r
F
.66873 .50038 m .66873 .50038 L .53349 .45964 L F
.53349 .45964 m .5416 .51771 L .53349 .45964 L .893 .775 .724 r
F
.5513 .47893 m .53349 .45964 L .55343 .60245 L .347 .384 .758 r
F
.5513 .47893 m .5513 .47893 L .54111 .46789 L .793 .399 .309 r
F
.5513 .47893 m .66873 .50038 L .54111 .46789 L F
.6065 .54461 m .6348 .58568 L .56015 .50695 L .723 .328 .301 r
F
.57627 .52396 m .6348 .58568 L .56015 .50695 L F
.6348 .58568 m .61096 .5881 L .6348 .58568 L .674 .491 .63 r
F
.55343 .60245 m .66873 .50038 L .55343 .60245 L .707 .572 .7 r
F
.62269 .60891 m .6348 .58568 L .55343 .60245 L .937 .856 .736 r
F
.66462 .61557 m .55343 .60245 L .55969 .60116 L .651 .149 .043 r
F
.66462 .61557 m .55969 .60116 L .6348 .58568 L F
.69393 .64494 m .55343 .60245 L .66462 .61557 L F
.66873 .50038 m .62265 .54118 L .66873 .50038 L 0 0 0 r
F
.6348 .58568 m .66873 .50038 L .6348 .58568 L .709 .826 .937 r
F
.66873 .50038 m .66289 .51508 L .66873 .50038 L .129 .162 .627 r
F
.66873 .50038 m .66873 .50038 L .6348 .58568 L .709 .826 .937 r
F
.66873 .50038 m .66873 .50038 L .62346 .55708 L .707 .572 .7 r
F
.66873 .50038 m .62346 .55708 L .58066 .61069 L F
.66873 .50038 m .66873 .50038 L .58066 .61069 L F
.55792 .60381 m .66873 .50038 L .55343 .60245 L F
.58066 .61069 m .66873 .50038 L .55792 .60381 L F
.57159 .70703 m .55343 .60245 L .55343 .60245 L .937 .856 .736 r
F
.52896 .61589 m .55343 .60245 L .55343 .60245 L .163 0 0 r
F
.57159 .70703 m .55343 .60245 L .55343 .60245 L .937 .856 .736 r
F
.57159 .70703 m .55343 .60245 L .55343 .60245 L .175 .317 .77 r
F
.69393 .64494 m .58066 .61069 L .58066 .61069 L .707 .572 .7 r
F
.69393 .64494 m .69393 .64494 L .66462 .61557 L .651 .149 .043 r
F
.69393 .64494 m .66873 .50038 L .69393 .64494 L .707 .572 .7 r
F
.76432 .53612 m .66873 .50038 L .76432 .53612 L .709 .826 .937 r
F
.74979 .38672 m .66873 .50038 L .66873 .50038 L .716 .541 .652 r
F
.74979 .38672 m .66873 .50038 L .66873 .50038 L F
.76432 .53612 m .66873 .50038 L .66873 .50038 L .709 .826 .937 r
F
.74979 .38672 m .74979 .38672 L .66873 .50038 L .716 .541 .652 r
F
.76432 .53612 m .66873 .50038 L .66873 .50038 L .709 .826 .937 r
F
.69393 .64494 m .66289 .51508 L .66873 .50038 L .129 .162 .627 r
F
.74979 .38672 m .74979 .38672 L .66873 .50038 L .716 .541 .652 r
F
.69393 .64494 m .55343 .60245 L .55343 .60245 L .651 .149 .043 r
F
.53349 .45964 m .53349 .45964 L .55343 .60245 L .347 .384 .758 r
F
.55343 .60245 m .53349 .45964 L .55343 .60245 L F
.42872 .53609 m .42315 .52627 L .42315 .52627 L .687 .152 0 r
F
.42872 .53609 m .42315 .52627 L .55343 .60245 L F
.42872 .53609 m .42315 .52627 L .42872 .53609 L F
.53349 .45964 m .42315 .52627 L .53349 .45964 L .639 .706 .895 r
F
.42315 .52627 m .42315 .52627 L .53349 .45964 L F
.53349 .45964 m .53349 .45964 L .42315 .52627 L .248 0 .273 r
F
.42315 .52627 m .53349 .45964 L .42315 .52627 L F
.50532 .4526 m .42315 .52627 L .51559 .45517 L .639 .706 .895 r
F
.42315 .52627 m .42315 .52627 L .50532 .4526 L F
.41562 .46345 m .45748 .38041 L .43555 .47045 L .716 .806 .92 r
F
.32929 .43314 m .45748 .38041 L .41562 .46345 L F
.45752 .38054 m .43555 .47045 L .45748 .38041 L .018 .079 .585 r
F
.45748 .38041 m .43555 .47045 L .45748 .38041 L F
.45748 .38041 m .44409 .43731 L .45748 .38041 L .635 .481 .657 r
F
.43555 .47045 m .43555 .47045 L .45748 .38041 L .018 .079 .585 r
F
.45748 .38041 m .43555 .47045 L .45748 .38041 L F
.42944 .43365 m .44409 .43731 L .45748 .38041 L .635 .481 .657 r
F
.44409 .43731 m .44409 .43731 L .45748 .38041 L F
.45748 .38041 m .50532 .4526 L .45748 .38041 L .71 .283 .233 r
F
.32929 .43314 m .45748 .38041 L .45748 .38041 L .716 .806 .92 r
F
.45744 .38043 m .45748 .38041 L .32929 .43314 L F
.44064 .38734 m .42944 .43365 L .45748 .38041 L .635 .481 .657 r
F
.43235 .39075 m .43235 .39075 L .44064 .38734 L F
.43235 .39075 m .42944 .43365 L .44064 .38734 L F
.32929 .43315 m .43555 .47045 L .4253 .51657 L .815 .377 .201 r
F
.35957 .46319 m .42315 .52627 L .32929 .43314 L .635 .481 .657 r
F
.32929 .43314 m .43555 .47045 L .43555 .47045 L .716 .806 .92 r
F
.32929 .43314 m .42315 .52627 L .43235 .39075 L .635 .481 .657 r
F
.38721 .4231 m .38721 .4231 L .45748 .38041 L .71 .283 .233 r
F
.42315 .52627 m .4253 .51657 L .42315 .52627 L .815 .377 .201 r
F
.42944 .43365 m .42315 .52627 L .44409 .43731 L .635 .481 .657 r
F
.38721 .4231 m .45748 .38041 L .45748 .38041 L .971 .843 .66 r
F
.38721 .4231 m .45748 .38041 L .44104 .45023 L F
.42315 .52627 m .44104 .45023 L .42315 .52627 L F
.32929 .43314 m .42315 .52627 L .42315 .52627 L .635 .481 .657 r
F
.35506 .57837 m .35506 .57837 L .42315 .52627 L .574 .735 .952 r
F
.32929 .43314 m .42315 .52627 L .42315 .52627 L .635 .481 .657 r
F
.35506 .57837 m .42315 .52627 L .42315 .52627 L .574 .735 .952 r
F
.38721 .4231 m .42315 .52627 L .42315 .52627 L .639 .706 .895 r
F
.40071 .46186 m .44104 .45023 L .42315 .52627 L .971 .843 .66 r
F
.38721 .4231 m .44104 .45023 L .40071 .46186 L F
.38721 .4231 m .40071 .46186 L .40071 .46186 L F
.38721 .4231 m .42315 .52627 L .50532 .4526 L .639 .706 .895 r
F
.38721 .4231 m .42315 .52627 L .38721 .4231 L F
.45753 .38049 m .45752 .38054 L .45748 .38041 L .018 .079 .585 r
F
.38721 .4231 m .50532 .4526 L .45748 .38041 L .71 .283 .233 r
F
.38721 .4231 m .45748 .38041 L .38721 .4231 L .971 .843 .66 r
F
.50532 .4526 m .50532 .4526 L .45748 .38041 L .71 .283 .233 r
F
.50532 .4526 m .53349 .45964 L .45748 .38041 L F
.38721 .4231 m .38721 .4231 L .50532 .4526 L .639 .706 .895 r
F
.38721 .4231 m .38721 .4231 L .4007 .46184 L .971 .843 .66 r
F
.38721 .4231 m .50532 .4526 L .50532 .4526 L .639 .706 .895 r
F
.38721 .4231 m .50532 .4526 L .50532 .4526 L .71 .283 .233 r
F
.38721 .4231 m .50532 .4526 L .50532 .4526 L .639 .706 .895 r
F
.38721 .4231 m .50532 .4526 L .38721 .4231 L .71 .283 .233 r
F
.38721 .4231 m .50528 .4526 L .38721 .4231 L F
.32929 .43314 m .45748 .38041 L .45748 .38041 L .716 .806 .92 r
F
.41272 .33709 m .45748 .38041 L .41272 .33709 L .597 .053 0 r
F
.38721 .4231 m .45748 .38041 L .45748 .38041 L .971 .843 .66 r
F
.45343 .57966 m .45343 .57966 L .44298 .56123 L .248 0 .273 r
F
.53766 .59886 m .42872 .53609 L .55343 .60245 L .687 .152 0 r
F
.45343 .57966 m .42872 .53609 L .42872 .53609 L F
.45343 .57966 m .42872 .53609 L .53766 .59886 L F
.45343 .57966 m .42872 .53609 L .45343 .57966 L F
.45343 .57966 m .48792 .58752 L .5416 .51771 L .893 .775 .724 r
F
.45343 .57966 m .45343 .57966 L .53766 .59886 L .687 .152 0 r
F
.44298 .56123 m .53349 .45964 L .42315 .52627 L .248 0 .273 r
F
.45343 .57966 m .53349 .45964 L .44298 .56123 L F
.45343 .57966 m .5416 .51771 L .53349 .45964 L .893 .775 .724 r
F
.6074 .36358 m .57647 .40379 L .6074 .36358 L .911 .737 .654 r
F
.6074 .36358 m .6074 .36358 L .55862 .44682 L .311 0 .2 r
F
.55862 .44682 m .6074 .36358 L .53349 .45964 L F
.6074 .36358 m .6074 .36358 L .53349 .45964 L F
.66534 .39234 m .53349 .45964 L .66662 .43297 L .706 .752 .888 r
F
.66534 .39234 m .66873 .50038 L .66534 .39234 L .033 .17 .676 r
F
.66534 .39234 m .60759 .36368 L .66534 .39234 L .311 0 .2 r
F
.60759 .36368 m .6074 .36358 L .66534 .39234 L F
.66534 .39234 m .66534 .39234 L .55862 .44682 L F
.66534 .39234 m .61738 .38584 L .6074 .36358 L .033 .17 .676 r
F
.66534 .39234 m .6074 .36358 L .55862 .44682 L .311 0 .2 r
F
.66534 .39234 m .55862 .44682 L .55862 .44682 L F
.66534 .39234 m .55862 .44682 L .66534 .39234 L .706 .752 .888 r
F
.55862 .44682 m .53349 .45964 L .66534 .39234 L F
.53349 .45962 m .52044 .44604 L .53349 .45964 L .285 .28 .677 r
F
.60739 .36357 m .45748 .38041 L .6074 .36358 L .671 .483 .623 r
F
.6014 .35629 m .6074 .36358 L .6074 .36358 L .258 .364 .781 r
F
.52371 .26189 m .45748 .38041 L .60739 .36357 L .671 .483 .623 r
F
.48192 .35088 m .6074 .36358 L .45748 .38041 L .635 .803 .963 r
F
.51634 .30929 m .6074 .36358 L .48192 .35088 L F
.6074 .36358 m .6074 .36358 L .45748 .38041 L F
.45748 .38041 m .45748 .38041 L .6074 .36358 L .671 .483 .623 r
F
.54239 .37617 m .45748 .38041 L .54239 .37617 L .597 .053 0 r
F
.54154 .37097 m .6074 .36358 L .45748 .38041 L .635 .803 .963 r
F
.45748 .38041 m .6074 .36358 L .45748 .38041 L F
.6074 .36358 m .45748 .38041 L .6074 .36358 L .671 .483 .623 r
F
.53121 .37673 m .45748 .38041 L .54239 .37617 L .597 .053 0 r
F
.51634 .30929 m .53349 .45964 L .57646 .40379 L .911 .737 .654 r
F
.51634 .30929 m .45749 .3804 L .51634 .30929 L .285 .28 .677 r
F
.6074 .36358 m .56297 .37218 L .6074 .36358 L .029 0 0 r
F
.51634 .30929 m .57646 .40379 L .6074 .36358 L .911 .737 .654 r
F
.52371 .26189 m .45748 .38041 L .45748 .38041 L .92 .832 .742 r
F
.52371 .26189 m .45748 .38041 L .45748 .38041 L .671 .483 .623 r
F
.51634 .30929 m .45748 .38041 L .45748 .38041 L .285 .28 .677 r
F
.51634 .30929 m .6074 .36358 L .51634 .30929 L .635 .803 .963 r
F
.51634 .30929 m .51634 .30929 L .48192 .35088 L F
.53349 .45964 m .53349 .45964 L .45748 .38041 L .71 .283 .233 r
F
.51634 .30929 m .45748 .38041 L .52044 .44604 L .285 .28 .677 r
F
.51634 .30929 m .51634 .3093 L .53349 .45962 L F
.51634 .30929 m .6074 .36358 L .6074 .36358 L .635 .803 .963 r
F
.51634 .3093 m .52044 .44604 L .53349 .45962 L .285 .28 .677 r
F
.51634 .3093 m .53349 .45962 L .53349 .45962 L F
.51634 .3093 m .51634 .3093 L .53349 .45962 L F
.51634 .30929 m .53349 .45964 L .53349 .45964 L .911 .737 .654 r
F
.51634 .30929 m .53349 .45964 L .51634 .30929 L F
.66534 .39234 m .53349 .45964 L .53349 .45964 L .706 .752 .888 r
F
.66534 .39234 m .53349 .45964 L .66534 .39234 L F
.45343 .57966 m .53349 .45964 L .45343 .57966 L .248 0 .273 r
F
.5513 .47893 m .53349 .45964 L .53349 .45964 L .347 .384 .758 r
F
.69393 .64494 m .64592 .59682 L .66288 .5151 L .129 .162 .627 r
F
.64592 .59682 m .6348 .58568 L .6348 .58568 L F
.64592 .59682 m .6348 .58568 L .66288 .5151 L F
.6348 .58568 m .62202 .57221 L .6348 .58568 L .341 .32 .69 r
F
.69393 .64494 m .66873 .50038 L .58066 .61069 L .707 .572 .7 r
F
.62778 .56175 m .60203 .57585 L .62265 .54118 L 0 0 0 r
F
.60203 .57585 m .55343 .60245 L .62265 .54118 L F
.66873 .50038 m .66873 .50038 L .55343 .60245 L .707 .572 .7 r
F
.56015 .50695 m .57627 .52396 L .56015 .50695 L .723 .328 .301 r
F
.56015 .50695 m .56015 .50695 L .55984 .50473 L .879 .759 .726 r
F
.56015 .50695 m .56015 .50695 L .55984 .50473 L F
.62778 .56175 m .55401 .48186 L .55343 .60245 L .347 .384 .758 r
F
.62778 .56175 m .66873 .50038 L .62778 .56175 L .793 .399 .309 r
F
.62778 .56175 m .62778 .56175 L .5513 .47893 L F
.62778 .56175 m .62265 .54118 L .66873 .50038 L 0 0 0 r
F
.62778 .56175 m .66873 .50038 L .5513 .47893 L .793 .399 .309 r
F
.66662 .43297 m .53349 .45964 L .6681 .48027 L .706 .752 .888 r
F
.55862 .44682 m .55862 .44682 L .53349 .45964 L .311 0 .2 r
F
.62778 .56175 m .53349 .45964 L .5513 .47893 L .347 .384 .758 r
F
.62778 .56175 m .5513 .47893 L .62778 .56175 L F
.62778 .56175 m .5513 .47893 L .5513 .47893 L .793 .399 .309 r
F
.62778 .56175 m .66873 .50038 L .66873 .50038 L F
.62778 .56175 m .55133 .47896 L .62778 .56175 L .347 .384 .758 r
F
.55133 .47896 m .5513 .47893 L .62778 .56175 L F
.62778 .56175 m .53349 .45964 L .53349 .45964 L F
.69393 .64494 m .55343 .60245 L .69393 .64494 L .651 .149 .043 r
F
.60203 .57585 m .55343 .60245 L .55343 .60245 L 0 0 0 r
F
.55862 .44682 m .53349 .45964 L .53349 .45964 L .311 0 .2 r
F
.45343 .57966 m .53349 .45964 L .53349 .45964 L .248 0 .273 r
F
.48792 .58752 m .55343 .60245 L .55343 .60245 L .893 .775 .724 r
F
.48792 .58752 m .55343 .60245 L .5416 .51771 L F
.58066 .61069 m .58066 .61069 L .55792 .60381 L .707 .572 .7 r
F
.6681 .48027 m .53349 .45964 L .66873 .50038 L .706 .752 .888 r
F
.53349 .45964 m .52044 .44604 L .53349 .45964 L .285 .28 .677 r
F
.74979 .38672 m .74979 .38672 L .6074 .36358 L .597 .726 .934 r
F
.74979 .38672 m .6074 .36358 L .6074 .36358 L F
.52371 .26189 m .6074 .36358 L .6074 .36358 L .258 .364 .781 r
F
.66534 .39234 m .6074 .36358 L .6074 .36358 L .311 0 .2 r
F
.52371 .26189 m .6074 .36358 L .6014 .35629 L .258 .364 .781 r
F
.66534 .39234 m .66873 .50038 L .66873 .50038 L .033 .17 .676 r
F
.51559 .45517 m .42315 .52627 L .53349 .45964 L .639 .706 .895 r
F
.50532 .4526 m .50532 .4526 L .51559 .45517 L F
.50532 .4526 m .53349 .45964 L .53349 .45964 L .71 .283 .233 r
F
.50532 .4526 m .53349 .45964 L .50532 .4526 L F
.52371 .26189 m .52371 .26189 L .45748 .38041 L .92 .832 .742 r
F
.41272 .33709 m .4484 .37162 L .41272 .33709 L .597 .053 0 r
F
.66052 .30869 m .61814 .35248 L .61814 .35248 L .971 .779 .588 r
F
.66052 .30869 m .61814 .35248 L .61814 .35248 L F
.66052 .30869 m .61814 .35248 L .66052 .30869 L F
.45754 .38047 m .45753 .38049 L .45748 .38041 L .018 .079 .585 r
F
.4484 .37162 m .4484 .37162 L .45748 .38041 L F
.52896 .61589 m .52896 .61589 L .55343 .60245 L .163 0 0 r
F
.57159 .70703 m .57159 .70703 L .55343 .60245 L .937 .856 .736 r
F
.42842 .67106 m .55343 .60245 L .4265 .61828 L .659 .537 .704 r
F
.32929 .43314 m .45744 .38043 L .32929 .43314 L .716 .806 .92 r
F
.32929 .43314 m .35956 .46318 L .32929 .43314 L .635 .481 .657 r
F
.32929 .43314 m .32929 .43314 L .43235 .39075 L F
.42417 .55432 m .42315 .52627 L .42315 .52627 L .953 .766 .613 r
F
.35506 .57837 m .42315 .52627 L .35506 .57837 L 0 0 0 r
F
.57159 .70703 m .55343 .60245 L .57159 .70703 L .175 .317 .77 r
F
.69393 .64494 m .69393 .64494 L .58066 .61069 L .707 .572 .7 r
F
.69393 .64494 m .66873 .50038 L .66873 .50038 L F
.76432 .53612 m .68792 .50755 L .76432 .53612 L .709 .826 .937 r
F
.76432 .53612 m .76432 .53612 L .68792 .50755 L .797 .322 .097 r
F
.76432 .53612 m .68792 .50755 L .68792 .50755 L F
.41272 .33709 m .41272 .33709 L .4484 .37162 L .018 .079 .585 r
F
.41272 .33709 m .4484 .37162 L .4484 .37162 L F
0 g
.5 Mabswid
.22707 .23984 m
.25375 .27025 L
s
.25375 .27025 m
.26973 .28847 L
s
.26973 .28847 m
.37292 .4061 L
s
.37292 .4061 m
.37879 .41278 L
s
.44537 .66176 m
.44769 .8508 L
s
0 0 0 r
2 Mabswid
.82604 .43466 Mdot
.039 .916 .04 r
.5 Mabswid
.70633 .48143 m
.73769 .46918 L
s
.73769 .46918 m
.82604 .43466 L
s
.70633 .48143 m
.70633 .48143 L
s
.70633 .48143 m
.70633 .48143 L
s
.70633 .48143 m
.70633 .48143 L
s
.70525 .48186 m
.70633 .48143 L
s
.25777 .54861 m
.40003 .50348 L
s
.40003 .50348 m
.40003 .50348 L
s
.40003 .50348 m
.40003 .50348 L
s
.40003 .50348 m
.40014 .50344 L
s
.45134 .70138 m
.47861 .64352 L
s
.60297 .44572 m
.60297 .44572 L
s
.69008 .31644 m
.72282 .26762 L
s
.69008 .31644 m
.69008 .31644 L
s
.66239 .35773 m
.66239 .35773 L
s
.66239 .35773 m
.69008 .31644 L
s
0 0 0 r
2 Mabswid
.61657 .31543 Mdot
.039 .916 .04 r
.5 Mabswid
.60711 .3392 m
.61103 .32934 L
s
.61546 .31822 m
.61657 .31543 L
s
.61546 .31822 m
.61546 .31822 L
s
.61546 .31822 m
.61546 .31822 L
s
.61546 .31822 m
.61546 .31822 L
s
.61546 .31822 m
.61546 .31822 L
s
.61103 .32934 m
.61546 .31822 L
s
.49774 .45939 m
.49774 .45939 L
s
.44717 .8072 m
.46985 .64832 L
s
.4035 .29848 m
.42047 .3284 L
s
.42047 .3284 m
.42047 .3284 L
s
.42047 .3284 m
.42047 .3284 L
s
.42047 .3284 m
.428 .3417 L
s
.2554 .59456 m
.35492 .56384 L
s
.35492 .56384 m
.36917 .55945 L
s
.49651 .4605 m
.49651 .4605 L
s
0 0 0 r
2 Mabswid
.48725 .78231 Mdot
.039 .916 .04 r
.5 Mabswid
.52229 .68063 m
.53147 .65399 L
s
.53147 .65399 m
.53147 .65399 L
s
.52229 .68063 m
.52229 .68063 L
s
.48725 .78231 m
.52201 .68145 L
s
.52201 .68145 m
.52201 .68145 L
s
.52201 .68145 m
.52201 .68145 L
s
.52201 .68145 m
.52201 .68145 L
s
.52201 .68145 m
.52229 .68063 L
s
0 g
.55197 .51795 m
.55385 .51543 L
s
.59471 .48686 m
.59471 .48686 L
s
.619 .47275 m
.619 .47275 L
s
.619 .47275 m
.619 .47275 L
s
.55197 .51795 m
.55385 .51543 L
s
.59471 .48686 m
.59471 .48686 L
s
.619 .47275 m
.619 .47275 L
s
.619 .47275 m
.619 .47275 L
s
.47313 .48146 m
.47313 .48146 L
s
.55174 .50449 m
.5539 .50512 L
s
.55069 .43729 m
.55069 .43729 L
s
.55319 .4557 m
.55319 .4557 L
s
.55415 .46281 m
.55415 .46281 L
s
.55415 .46281 m
.55415 .46281 L
s
.55647 .47987 m
.55647 .47987 L
s
.47313 .48146 m
.47313 .48146 L
s
.55174 .50449 m
.5539 .50512 L
s
.55069 .43729 m
.55069 .43729 L
s
.55319 .4557 m
.55319 .4557 L
s
.55415 .46281 m
.55415 .46281 L
s
.55415 .46281 m
.55415 .46281 L
s
.55647 .47987 m
.55647 .47987 L
s
.039 .916 .04 r
.22819 .52023 m
.37052 .47405 L
s
.59521 .59247 m
.59521 .59247 L
s
.55141 .48502 m
.55397 .4913 L
s
.5529 .51507 m
.55385 .51487 L
s
.5529 .51507 m
.5529 .51507 L
s
.55193 .51526 m
.5529 .51507 L
s
.6031 .44569 m
.6031 .44569 L
s
.23016 .28403 m
.3721 .3817 L
s
.3721 .3817 m
.3721 .3817 L
s
.3721 .3817 m
.40288 .40287 L
s
.55157 .49478 m
.55394 .49583 L
s
.48917 .46708 m
.48917 .46708 L
s
0 0 0 r
2 Mabswid
.4035 .29848 Mdot
.039 .916 .04 r
.5 Mabswid
.51651 .44194 m
.51651 .44194 L
s
.59714 .4873 m
.59714 .4873 L
s
.60133 .47004 m
.60133 .47004 L
s
.60133 .47004 m
.60133 .47004 L
s
.5481 .56423 m
.5481 .56423 L
s
.55284 .56818 m
.55359 .5688 L
s
0 0 0 r
2 Mabswid
.45473 .2926 Mdot
.039 .916 .04 r
.5 Mabswid
.47305 .30818 m
.48986 .32246 L
s
.45473 .2926 m
.47305 .30818 L
s
.55172 .50315 m
.55391 .50322 L
s
0 0 0 r
2 Mabswid
.36006 .56403 Mdot
.039 .916 .04 r
.5 Mabswid
.36006 .56403 m
.36632 .56327 L
s
.59133 .48624 m
.59133 .48624 L
s
.57182 .45196 m
.57182 .45196 L
s
.58027 .46681 m
.58027 .46681 L
s
.58027 .46681 m
.58027 .46681 L
s
0 g
.44769 .8508 m
.8835 .74145 L
s
.1997 .63528 m
.34624 .76263 L
s
.34624 .76263 m
.44769 .8508 L
s
0 0 0 r
2 Mabswid
.76101 .27367 Mdot
.039 .916 .04 r
.5 Mabswid
.65968 .35215 m
.66716 .34635 L
s
.65968 .35215 m
.65968 .35215 L
s
.65968 .35215 m
.65968 .35215 L
s
.66716 .34635 m
.76101 .27367 L
s
.49315 .43424 m
.49315 .43424 L
s
.50055 .42531 m
.50055 .42531 L
s
.50055 .42531 m
.50055 .42531 L
s
.40274 .59708 m
.42548 .59027 L
s
.40274 .59708 m
.40274 .59708 L
s
.25297 .64199 m
.40274 .59708 L
s
.60261 .4883 m
.60261 .4883 L
s
.48357 .4721 m
.48357 .4721 L
s
.55131 .47943 m
.55182 .47949 L
s
.55809 .48017 m
.55809 .48017 L
s
.55139 .48387 m
.55401 .48317 L
s
.56233 .48094 m
.56233 .48094 L
s
.60241 .4702 m
.60241 .4702 L
s
.60241 .4702 m
.60241 .4702 L
s
.62271 .44177 m
.62271 .44177 L
s
0 0 0 r
2 Mabswid
.70623 .64535 Mdot
.039 .916 .04 r
.5 Mabswid
.70623 .64535 m
.72356 .57369 L
s
.72356 .57369 m
.72356 .57369 L
s
.72356 .57369 m
.72356 .57369 L
s
.72356 .57369 m
.72941 .54948 L
s
.72941 .54948 m
.72941 .54948 L
s
.73106 .58584 m
.84924 .64659 L
s
.6898 .56463 m
.6898 .56463 L
s
.73106 .58584 m
.73106 .58584 L
s
.6898 .56463 m
.73106 .58584 L
s
0 0 0 r
2 Mabswid
.72282 .26762 Mdot
.039 .916 .04 r
.5 Mabswid
.32626 .53477 m
.40625 .50951 L
s
.22531 .56664 m
.32626 .53477 L
s
.55222 .53232 m
.55377 .53299 L
s
.46049 .49279 m
.46049 .49279 L
s
.55212 .52647 m
.5538 .52695 L
s
.45405 .49857 m
.45405 .49857 L
s
.55703 .42905 m
.55703 .42905 L
s
.57083 .45216 m
.57083 .45216 L
s
.57952 .4667 m
.57952 .4667 L
s
.57952 .4667 m
.57952 .4667 L
s
.59118 .48621 m
.59118 .48621 L
s
.56982 .39336 m
.56982 .39336 L
s
.61854 .35327 m
.61854 .35327 L
s
.51399 .43931 m
.51399 .43931 L
s
.50268 .44862 m
.50268 .44862 L
s
0 0 0 r
2 Mabswid
.34295 .54312 Mdot
.039 .916 .04 r
.5 Mabswid
.37942 .51118 m
.39456 .49791 L
s
.37942 .51118 m
.37942 .51118 L
s
.34295 .54312 m
.37942 .51118 L
s
.25056 .4731 m
.33972 .44349 L
s
.25056 .4731 m
.25056 .4731 L
s
.19744 .49073 m
.25056 .4731 L
s
.62227 .47325 m
.62227 .47325 L
s
.62227 .47325 m
.62227 .47325 L
s
.63258 .43979 m
.63258 .43979 L
s
.61683 .4909 m
.61683 .4909 L
s
0 0 0 r
2 Mabswid
.68818 .68145 Mdot
.039 .916 .04 r
.5 Mabswid
.67847 .64026 m
.68818 .68145 L
s
.51488 .44024 m
.51488 .44024 L
s
.63778 .47562 m
.63778 .47562 L
s
.63778 .47562 m
.63778 .47562 L
s
.62939 .44043 m
.62939 .44043 L
s
.64254 .4956 m
.64254 .4956 L
s
.33565 .53566 m
.39115 .52373 L
s
.39115 .52373 m
.39115 .52373 L
s
.39115 .52373 m
.39115 .52373 L
s
.39115 .52373 m
.39115 .52373 L
s
.39115 .52373 m
.3967 .52254 L
s
.60486 .58038 m
.60486 .58038 L
s
.54908 .57128 m
.54908 .57128 L
s
.55291 .5719 m
.55358 .57201 L
s
0 g
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.4484 .37162 m
.45748 .38041 L
s
.41272 .33709 m
.4484 .37162 L
s
.41864 .37168 m
.42259 .39476 L
s
.41272 .33709 m
.41272 .33709 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.41272 .33709 m
.45748 .38041 L
s
.41272 .33709 m
.41272 .33709 L
s
.41272 .33709 m
.41272 .33709 L
s
.41272 .33709 m
.42259 .39476 L
s
.41272 .33709 m
.41272 .33709 L
s
.41272 .33709 m
.47175 .35488 L
s
0 0 0 r
2 Mabswid
.33565 .53566 Mdot
0 g
.5 Mabswid
.52371 .26189 m
.52371 .26189 L
s
.55708 .37333 m
.55708 .37333 L
s
.6074 .36358 m
.6074 .36358 L
s
.45748 .38041 m
.45748 .38041 L
s
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.6074 .36358 L
s
.55708 .37333 m
.55708 .37333 L
s
.66052 .30869 m
.66052 .30869 L
s
.59366 .34688 m
.60398 .34099 L
s
.65928 .07646 m
.75742 .24602 L
s
.75742 .24602 m
.82601 .36453 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.66052 .30869 m
.66052 .30869 L
s
.66052 .30869 m
.66052 .30869 L
s
.66052 .30869 m
.66052 .30869 L
s
.59366 .34688 m
.66052 .30869 L
s
.56808 .39063 m
.56808 .39063 L
s
.48703 .42501 m
.48703 .42501 L
s
.4942 .41869 m
.4942 .41869 L
s
.4942 .41869 m
.4942 .41869 L
s
.56808 .39063 m
.56808 .39063 L
s
.48703 .42501 m
.48703 .42501 L
s
.4942 .41869 m
.4942 .41869 L
s
.4942 .41869 m
.4942 .41869 L
s
.039 .916 .04 r
.64219 .43786 m
.64219 .43786 L
s
.44694 .38279 m
.44694 .38279 L
s
.44694 .38279 m
.45167 .3828 L
s
.45167 .3828 m
.45167 .3828 L
s
.45908 .38282 m
.45908 .38282 L
s
.4598 .38283 m
.4598 .38283 L
s
.4598 .38283 m
.4598 .38283 L
s
.5633 .38311 m
.5633 .38311 L
s
0 0 0 r
2 Mabswid
.35582 .60372 Mdot
.039 .916 .04 r
.5 Mabswid
.35582 .60372 m
.36599 .59695 L
s
.36599 .59695 m
.36599 .59695 L
s
.36599 .59695 m
.36599 .59695 L
s
.36599 .59695 m
.36599 .59695 L
s
.36599 .59695 m
.3863 .58342 L
s
.55823 .37514 m
.55823 .37514 L
s
.47016 .39954 m
.47016 .39954 L
s
.47471 .39837 m
.47471 .39837 L
s
.47471 .39837 m
.47471 .39837 L
s
0 g
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.32929 .43314 m
.32929 .43314 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.44932 .5028 m
.44932 .5028 L
s
.35506 .57837 m
.35506 .57837 L
s
.44932 .5028 m
.44932 .5028 L
s
0 0 0 r
2 Mabswid
.35264 .59767 Mdot
.039 .916 .04 r
.5 Mabswid
.40984 .58746 m
.41431 .58667 L
s
.35264 .59767 m
.40984 .58746 L
s
.41431 .58667 m
.41431 .58667 L
s
.55896 .37629 m
.55896 .37629 L
s
0 0 0 r
2 Mabswid
.84101 .57678 Mdot
.039 .916 .04 r
.5 Mabswid
.75433 .56293 m
.84101 .57678 L
s
.71196 .55616 m
.71196 .55616 L
s
.75433 .56293 m
.75433 .56293 L
s
.75433 .56293 m
.75433 .56293 L
s
.71196 .55616 m
.75433 .56293 L
s
.24066 .3375 m
.42287 .38129 L
s
.42287 .38129 m
.42287 .38129 L
s
0 0 0 r
2 Mabswid
.42287 .38129 Mdot
.039 .916 .04 r
.5 Mabswid
.4945 .43628 m
.4945 .43628 L
s
.50601 .431 m
.50601 .431 L
s
.50601 .431 m
.50601 .431 L
s
.57392 .39981 m
.57392 .39981 L
s
0 0 0 r
2 Mabswid
.27511 .36526 Mdot
.039 .916 .04 r
.5 Mabswid
.29481 .37484 m
.37554 .41412 L
s
.29481 .37484 m
.29481 .37484 L
s
.27511 .36526 m
.29481 .37484 L
s
0 0 0 r
2 Mabswid
.50792 .24664 Mdot
.039 .916 .04 r
.5 Mabswid
.5628 .28357 m
.62862 .32786 L
s
.62862 .32786 m
.62862 .32786 L
s
.62862 .32786 m
.62862 .32786 L
s
.62862 .32786 m
.62862 .32786 L
s
.62862 .32786 m
.62862 .32786 L
s
.50792 .24664 m
.5628 .28357 L
s
.27929 .59709 m
.37432 .56794 L
s
.37432 .56794 m
.37432 .56794 L
s
.37432 .56794 m
.42411 .55266 L
s
.22233 .61457 m
.27929 .59709 L
s
.5514 .48485 m
.554 .48358 L
s
.56021 .48055 m
.56021 .48055 L
s
.58647 .46776 m
.58647 .46776 L
s
.58647 .46776 m
.58647 .46776 L
s
0 0 0 r
2 Mabswid
.82575 .60587 Mdot
.039 .916 .04 r
.5 Mabswid
.68374 .58646 m
.82575 .60587 L
s
.6478 .47716 m
.6478 .47716 L
s
.6478 .47716 m
.6478 .47716 L
s
.65018 .49699 m
.65018 .49699 L
s
.58214 .48456 m
.58214 .48456 L
s
.58928 .46819 m
.58928 .46819 L
s
.58928 .46819 m
.58928 .46819 L
s
.59871 .44657 m
.59871 .44657 L
s
.63962 .33028 m
.63962 .33028 L
s
.55426 .43265 m
.55426 .43265 L
s
.48391 .4203 m
.48391 .4203 L
s
.49814 .4228 m
.49814 .4228 L
s
.49814 .4228 m
.49815 .4228 L
s
0 0 0 r
2 Mabswid
.81083 .42735 Mdot
.039 .916 .04 r
.5 Mabswid
.73444 .40824 m
.73444 .40824 L
s
.73444 .40824 m
.81083 .42735 L
s
.56401 .46432 m
.56401 .46432 L
s
.56401 .46432 m
.56401 .46432 L
s
.57626 .45107 m
.57626 .45107 L
s
0 0 0 r
2 Mabswid
.62862 .32786 Mdot
.039 .916 .04 r
.5 Mabswid
.44783 .38438 m
.44783 .38438 L
s
.44783 .38438 m
.45507 .37808 L
s
.39851 .54512 m
.39851 .54512 L
s
0 g
.66052 .30869 m
.66052 .30869 L
s
.66052 .30869 m
.66052 .30869 L
s
.66052 .30869 m
.66296 .37261 L
s
.66296 .37261 m
.66296 .37261 L
s
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.61814 .35248 L
s
.61814 .35248 m
.66052 .30869 L
s
.66052 .30869 m
.66052 .30869 L
s
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.64352 .32626 L
s
.64352 .32626 m
.66052 .30869 L
s
.66052 .30869 m
.66052 .30869 L
s
.66267 .36496 m
.66296 .37261 L
s
.66296 .37261 m
.66296 .37261 L
s
.66052 .30869 m
.66052 .30869 L
s
.66052 .30869 m
.66267 .36496 L
s
.039 .916 .04 r
.20324 .53461 m
.37545 .47894 L
s
.194 .5376 m
.20324 .53461 L
s
.38541 .55514 m
.38541 .55514 L
s
.47274 .48181 m
.47274 .48181 L
s
.55202 .52045 m
.55382 .52133 L
s
0 g
.74979 .38672 m
.74979 .38672 L
s
.6074 .36358 m
.6074 .36358 L
s
.74979 .38672 m
.74979 .38672 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.6074 .36358 L
s
.76432 .53612 m
.76432 .53612 L
s
.69117 .46892 m
.69117 .46892 L
s
.69117 .46892 m
.76432 .53612 L
s
.65423 .49773 m
.65423 .49773 L
s
.65841 .47879 m
.65841 .47879 L
s
.65841 .47879 m
.65841 .47879 L
s
.65423 .49773 m
.65423 .49773 L
s
.65841 .47879 m
.65841 .47879 L
s
.65841 .47879 m
.65841 .47879 L
s
.039 .916 .04 r
.51266 .2047 m
.54886 .2379 L
s
.54886 .2379 m
.54886 .2379 L
s
.54886 .2379 m
.54886 .2379 L
s
.54886 .2379 m
.58959 .27525 L
s
.58959 .27525 m
.58959 .27525 L
s
.58959 .27525 m
.64039 .32184 L
s
.64039 .32184 m
.64039 .32184 L
s
.64039 .32184 m
.64039 .32184 L
s
.64039 .32184 m
.64039 .32184 L
s
0 0 0 r
2 Mabswid
.64039 .32184 Mdot
.66054 .35811 Mdot
.039 .916 .04 r
.5 Mabswid
.61392 .47197 m
.61392 .47197 L
s
.61392 .47197 m
.61392 .47197 L
s
.61632 .44305 m
.61632 .44305 L
s
.62301 .36202 m
.62301 .36202 L
s
0 0 0 r
2 Mabswid
.62558 .33096 Mdot
.65968 .35215 Mdot
.039 .916 .04 r
.5 Mabswid
.56849 .39127 m
.56849 .39127 L
s
.48765 .42595 m
.48765 .42595 L
s
.49723 .42184 m
.49723 .42184 L
s
.49723 .42184 m
.49723 .42184 L
s
.39258 .54965 m
.39258 .54965 L
s
0 g
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.42842 .67106 m
.42842 .67106 L
s
.42842 .67106 m
.42842 .67106 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.57159 .70703 m
.57159 .70703 L
s
.5204 .63935 m
.5204 .63935 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42151 .5891 m
.42151 .5891 L
s
.55226 .59406 m
.55226 .59406 L
s
.55329 .59395 m
.55347 .59394 L
s
.59761 .58946 m
.59761 .58946 L
s
.57159 .70703 m
.57159 .70703 L
s
.51036 .62609 m
.57159 .70703 L
s
.35506 .57837 m
.35506 .57837 L
s
.35506 .57837 m
.42546 .58974 L
s
.59761 .58946 m
.59761 .58946 L
s
.55226 .59406 m
.55226 .59406 L
s
.55329 .59395 m
.55347 .59394 L
s
.42315 .52627 m
.42315 .52627 L
s
.35506 .57837 m
.42315 .52627 L
s
.35506 .57837 m
.35506 .57837 L
s
.35506 .57837 m
.35506 .57837 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42314 .52627 m
.42315 .52627 L
s
0 0 0 r
2 Mabswid
.41431 .58667 Mdot
.039 .916 .04 r
.5 Mabswid
.41431 .58667 m
.42531 .5857 L
s
0 g
.22707 .23984 m
.65928 .07646 L
s
.1997 .63528 m
.22707 .23984 L
s
0 0 0 r
2 Mabswid
.37385 .23399 Mdot
.039 .916 .04 r
.5 Mabswid
.37385 .23399 m
.44156 .30933 L
s
.46552 .33599 m
.48047 .35263 L
s
.46552 .33599 m
.46552 .33599 L
s
.44156 .30933 m
.46552 .33599 L
s
0 0 0 r
2 Mabswid
.69609 .22351 Mdot
.039 .916 .04 r
.5 Mabswid
.54092 .2828 m
.69609 .22351 L
s
0 0 0 r
2 Mabswid
.75329 .25428 Mdot
.039 .916 .04 r
.5 Mabswid
.75007 .25685 m
.75329 .25428 L
s
.75007 .25685 m
.75007 .25685 L
s
.75007 .25685 m
.75007 .25685 L
s
.61489 .3648 m
.75007 .25685 L
s
0 0 0 r
2 Mabswid
.65667 .36155 Mdot
.039 .916 .04 r
.5 Mabswid
.55193 .59169 m
.55193 .59169 L
s
.58186 .44995 m
.58186 .44995 L
s
.57483 .48323 m
.57483 .48323 L
s
.57836 .46652 m
.57836 .46652 L
s
.57836 .46652 m
.57836 .46652 L
s
.55315 .58592 m
.55352 .58415 L
s
0 0 0 r
2 Mabswid
.65492 .3419 Mdot
.039 .916 .04 r
.5 Mabswid
.52542 .45122 m
.52542 .45122 L
s
0 0 0 r
2 Mabswid
.4323 .38043 Mdot
.039 .916 .04 r
.5 Mabswid
.44767 .37724 m
.44767 .37724 L
s
.44767 .37724 m
.45305 .37612 L
s
.45305 .37612 m
.45305 .37612 L
s
0 0 0 r
2 Mabswid
.3774 .73118 Mdot
.039 .916 .04 r
.5 Mabswid
.38057 .5611 m
.38071 .55343 L
s
.38071 .55343 m
.38071 .55343 L
s
.38057 .5611 m
.38057 .5611 L
s
.38057 .5611 m
.38057 .5611 L
s
.3774 .73118 m
.38057 .5611 L
s
.38071 .55343 m
.38071 .55343 L
s
.38071 .55343 m
.38198 .48542 L
s
0 0 0 r
2 Mabswid
.63505 .32787 Mdot
.039 .916 .04 r
.5 Mabswid
.4796 .41379 m
.4796 .41379 L
s
.48457 .40865 m
.48457 .40865 L
s
.48457 .40865 m
.48457 .40865 L
s
0 0 0 r
2 Mabswid
.44717 .8072 Mdot
.039 .916 .04 r
.5 Mabswid
.63288 .49383 m
.63288 .49383 L
s
.63197 .47473 m
.63197 .47473 L
s
.63197 .47473 m
.63197 .47473 L
s
.63032 .44024 m
.63032 .44024 L
s
.58937 .34167 m
.62527 .33445 L
s
.62527 .33445 m
.62527 .33445 L
s
.62527 .33445 m
.62527 .33445 L
s
0 0 0 r
2 Mabswid
.62527 .33445 Mdot
0 g
.5 Mabswid
.69393 .64494 m
.69393 .64494 L
s
.69393 .64494 m
.69393 .64494 L
s
.55343 .60245 m
.55343 .60245 L
s
.5939 .59411 m
.5939 .59411 L
s
.66873 .50038 m
.66873 .50038 L
s
.69393 .64494 m
.69393 .64494 L
s
.69393 .64494 m
.69393 .64494 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.5939 .59411 m
.5939 .59411 L
s
.57159 .70703 m
.57159 .70703 L
s
.57159 .70703 m
.57159 .70703 L
s
.76432 .53612 m
.76432 .53612 L
s
.68055 .56817 m
.76432 .53612 L
s
.76432 .53612 m
.76432 .53612 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.57159 .70703 m
.57159 .70703 L
s
.57159 .70703 m
.61618 .62143 L
s
.76432 .53612 m
.76432 .53612 L
s
.68055 .56817 m
.76432 .53612 L
s
0 0 0 r
2 Mabswid
.32361 .56896 Mdot
.039 .916 .04 r
.5 Mabswid
.32361 .56896 m
.3816 .55816 L
s
.3816 .55816 m
.3816 .55816 L
s
.3816 .55816 m
.3816 .55816 L
s
.3816 .55816 m
.3816 .55816 L
s
.3816 .55816 m
.38613 .55731 L
s
.68454 .49811 m
.68454 .49811 L
s
0 0 0 r
2 Mabswid
.70394 .48149 Mdot
.039 .916 .04 r
.5 Mabswid
.3704 .47393 m
.38864 .54275 L
s
.38864 .54275 m
.38864 .54275 L
s
.38864 .54275 m
.38864 .54275 L
s
.38864 .54275 m
.38864 .54275 L
s
0 0 0 r
2 Mabswid
.38864 .54275 Mdot
.63971 .32704 Mdot
.32014 .56851 Mdot
.039 .916 .04 r
.5 Mabswid
.32014 .56851 m
.3302 .5612 L
s
.3302 .5612 m
.3302 .5612 L
s
.3302 .5612 m
.40421 .50748 L
s
.35759 .70183 m
.42755 .64712 L
s
.55293 .57305 m
.55358 .57275 L
s
.54955 .57462 m
.54955 .57462 L
s
0 0 0 r
2 Mabswid
.84924 .64659 Mdot
.039 .916 .04 r
.5 Mabswid
.65051 .32143 m
.7156 .19617 L
s
.65051 .32143 m
.65051 .32143 L
s
.65051 .32143 m
.65051 .32143 L
s
.64547 .33111 m
.65051 .32143 L
s
0 0 0 r
2 Mabswid
.64547 .33111 Mdot
.26374 .39233 Mdot
.039 .916 .04 r
.5 Mabswid
.35916 .467 m
.41874 .51361 L
s
.35916 .467 m
.35916 .467 L
s
.31908 .43563 m
.35916 .467 L
s
.31908 .43563 m
.31908 .43563 L
s
.26374 .39233 m
.31908 .43563 L
s
.75863 .35673 m
.76487 .33312 L
s
.75863 .35673 m
.75863 .35673 L
s
.72118 .49855 m
.74045 .42556 L
s
.74045 .42556 m
.74045 .42556 L
s
.74045 .42556 m
.74045 .42556 L
s
.74045 .42556 m
.74045 .42556 L
s
.74045 .42556 m
.75863 .35673 L
s
.72118 .49855 m
.72118 .49855 L
s
.72118 .49855 m
.72118 .49855 L
s
0 0 0 r
2 Mabswid
.72118 .49855 Mdot
.039 .916 .04 r
.5 Mabswid
.3178 .54601 m
.39974 .52026 L
s
.39974 .52026 m
.39974 .52026 L
s
.19044 .58602 m
.3178 .54601 L
s
.39974 .52026 m
.40876 .51743 L
s
.40876 .51743 m
.40876 .51743 L
s
.40876 .51743 m
.41895 .51423 L
s
.55206 .52268 m
.55381 .52292 L
s
.44374 .50781 m
.44374 .50781 L
s
.54768 .56122 m
.54768 .56122 L
s
.55281 .56617 m
.5536 .56694 L
s
.46896 .4852 m
.46896 .4852 L
s
0 0 0 r
2 Mabswid
.64289 .33204 Mdot
.35759 .70183 Mdot
.039 .916 .04 r
.5 Mabswid
.55075 .58326 m
.55075 .58326 L
s
.5531 .58331 m
.55353 .58332 L
s
.60176 .58426 m
.60176 .58426 L
s
0 0 0 r
2 Mabswid
.62703 .33743 Mdot
.039 .916 .04 r
.5 Mabswid
.52338 .4491 m
.52338 .4491 L
s
.57198 .39675 m
.57198 .39675 L
s
0 0 0 r
2 Mabswid
.7156 .19617 Mdot
.039 .916 .04 r
.5 Mabswid
.46575 .39289 m
.46575 .39289 L
s
.46686 .39019 m
.46686 .39019 L
s
.46686 .39019 m
.46686 .39019 L
s
0 0 0 r
2 Mabswid
.68789 .5553 Mdot
0 g
.5 Mabswid
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.76432 .53612 m
.76432 .53612 L
s
.68792 .50755 m
.76432 .53612 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.68792 .50755 L
s
.76432 .53612 m
.76432 .53612 L
s
0 0 0 r
2 Mabswid
.23016 .28403 Mdot
.039 .916 .04 r
.5 Mabswid
.68388 .6815 m
.69508 .73398 L
s
.67484 .63916 m
.68388 .6815 L
s
0 0 0 r
2 Mabswid
.38412 .55477 Mdot
.039 .916 .04 r
.5 Mabswid
.38479 .55562 m
.38479 .55562 L
s
.47589 .47899 m
.47589 .47899 L
s
.46507 .38832 m
.46507 .38832 L
s
.46507 .38832 m
.46507 .38832 L
s
.46559 .39264 m
.46559 .39264 L
s
0 0 0 r
2 Mabswid
.73578 .51614 Mdot
.69844 .55017 Mdot
.38613 .55731 Mdot
.039 .916 .04 r
.5 Mabswid
.38613 .55731 m
.42414 .55365 L
s
.3971 .5462 m
.3971 .5462 L
s
0 0 0 r
2 Mabswid
.39429 .54315 Mdot
.039 .916 .04 r
.5 Mabswid
.43297 .36369 m
.43976 .34094 L
s
.43297 .36369 m
.43297 .36369 L
s
.43297 .36369 m
.43297 .36369 L
s
.43297 .36369 m
.43297 .36369 L
s
.42385 .39424 m
.43297 .36369 L
s
.43976 .34094 m
.43976 .34094 L
s
.43976 .34094 m
.43976 .34094 L
s
.4538 .2939 m
.48852 .17757 L
s
.4538 .2939 m
.4538 .2939 L
s
.43976 .34094 m
.43976 .34094 L
s
.43976 .34094 m
.4538 .2939 L
s
.55218 .52851 m
.55377 .53145 L
s
.55218 .52851 m
.55218 .52851 L
s
.55216 .52847 m
.55218 .52851 L
s
.49031 .41463 m
.49031 .41463 L
s
.49031 .41463 m
.49031 .41463 L
s
0 g
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.57159 .70703 L
s
.57159 .70703 m
.57159 .70703 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.57159 .70703 L
s
.57159 .70703 m
.57159 .70703 L
s
.039 .916 .04 r
.58964 .48593 m
.58964 .48593 L
s
.49947 .44379 m
.49947 .44379 L
s
.53328 .45959 m
.53328 .45959 L
s
0 g
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.6074 .36358 L
s
.52371 .26189 m
.6074 .36358 L
s
.6074 .36358 m
.6074 .36358 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.52371 .26189 L
s
.52371 .26189 m
.52371 .26189 L
s
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.6074 .36358 L
s
.52371 .26189 m
.6074 .36358 L
s
.52371 .26189 m
.52371 .26189 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.52371 .26189 L
s
.52371 .26189 m
.52371 .26189 L
s
.039 .916 .04 r
.27739 .3725 m
.36837 .41624 L
s
.36837 .41624 m
.36837 .41624 L
s
.36837 .41624 m
.3693 .41668 L
s
.57622 .40342 m
.57622 .40342 L
s
.57906 .45051 m
.57906 .45051 L
s
0 0 0 r
2 Mabswid
.40404 .55369 Mdot
.039 .916 .04 r
.5 Mabswid
.62351 .33003 m
.71239 .2967 L
s
.62351 .33003 m
.62351 .33003 L
s
.71239 .2967 m
.71239 .2967 L
s
.71239 .2967 m
.74193 .28563 L
s
.59009 .34255 m
.62351 .33003 L
s
.46684 .39454 m
.46684 .39454 L
s
.46981 .39326 m
.46981 .39326 L
s
.46981 .39326 m
.46981 .39326 L
s
.33512 .35167 m
.39294 .3765 L
s
.39294 .3765 m
.39294 .3765 L
s
.39294 .3765 m
.42687 .39107 L
s
.42687 .39107 m
.42687 .39107 L
s
.42687 .39107 m
.42917 .39206 L
s
.63352 .33936 m
.71494 .27052 L
s
.63352 .33936 m
.63352 .33936 L
s
.63352 .33936 m
.63352 .33936 L
s
.62988 .34244 m
.63352 .33936 L
s
0 0 0 r
2 Mabswid
.62988 .34244 Mdot
.039 .916 .04 r
.5 Mabswid
.63027 .44025 m
.63027 .44025 L
s
.68328 .49459 m
.68328 .49459 L
s
0 0 0 r
2 Mabswid
.72363 .53595 Mdot
0 g
.5 Mabswid
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.32929 .43314 m
.45748 .38041 L
s
.32929 .43314 m
.32929 .43314 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42314 .52627 m
.42315 .52627 L
s
.32929 .43314 m
.42314 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42314 .52627 m
.42315 .52627 L
s
.32929 .43314 m
.42314 .52627 L
s
.32929 .43314 m
.32929 .43314 L
s
.45748 .38041 m
.45748 .38041 L
s
.32929 .43314 m
.32929 .43314 L
s
.45748 .38041 m
.45748 .38041 L
s
.039 .916 .04 r
.47575 .47911 m
.47575 .47911 L
s
0 0 0 r
2 Mabswid
.69118 .54179 Mdot
.76487 .33312 Mdot
.48852 .17757 Mdot
.51568 .29339 Mdot
.039 .916 .04 r
.5 Mabswid
.69659 .46131 m
.69659 .46131 L
s
.69659 .46131 m
.70536 .50234 L
s
0 0 0 r
2 Mabswid
.70536 .50234 Mdot
.039 .916 .04 r
.5 Mabswid
.29251 .66776 m
.35052 .50325 L
s
.35889 .4795 m
.37566 .43194 L
s
.35052 .50325 m
.35889 .4795 L
s
.37566 .43194 m
.37566 .43194 L
s
0 0 0 r
2 Mabswid
.37566 .43194 Mdot
.75905 .3235 Mdot
.039 .916 .04 r
.5 Mabswid
.64627 .38288 m
.6955 .35696 L
s
.6955 .35696 m
.75905 .3235 L
s
0 0 0 r
2 Mabswid
.36955 .44847 Mdot
.039 .916 .04 r
.5 Mabswid
.67233 .70487 m
.67714 .71868 L
s
.64642 .63057 m
.67233 .70487 L
s
.54652 .55294 m
.54652 .55294 L
s
.55258 .55301 m
.55367 .55302 L
s
.60579 .6506 m
.6268 .69149 L
s
.58614 .61234 m
.60579 .6506 L
s
.55137 .4832 m
.55337 .48117 L
s
.55494 .47959 m
.55494 .47959 L
s
.56925 .46512 m
.56925 .46512 L
s
.56925 .46512 m
.56925 .46512 L
s
.58484 .44935 m
.58484 .44935 L
s
.557 .42909 m
.557 .42909 L
s
.56672 .45298 m
.56672 .45298 L
s
.57182 .46552 m
.57182 .46552 L
s
.57182 .46552 m
.57182 .46552 L
s
.57937 .48405 m
.57937 .48405 L
s
.68582 .5984 m
.70725 .63766 L
s
.70725 .63766 m
.70725 .63766 L
s
.70725 .63766 m
.75777 .73022 L
s
.5257 .45151 m
.5257 .45152 L
s
.52665 .45793 m
.52665 .45793 L
s
0 g
.38721 .4231 m
.38721 .4231 L
s
.38721 .4231 m
.38721 .4231 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.45754 .38047 m
.50922 .43434 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.47397 .3976 m
.53349 .45964 L
s
.51634 .30929 m
.51634 .30929 L
s
.45748 .38041 m
.51624 .3094 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.38721 .4231 m
.38721 .4231 L
s
.38721 .4231 m
.45748 .38041 L
s
.51634 .30929 m
.51634 .30929 L
s
.45758 .3803 m
.51634 .30929 L
s
.45748 .38041 m
.45758 .3803 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.42315 .52627 m
.42315 .52627 L
s
.45748 .38041 m
.45748 .38041 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.45748 .38041 m
.45748 .38041 L
s
.55464 .3695 m
.55464 .3695 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.45748 .38041 m
.45748 .38041 L
s
.6074 .36358 m
.6074 .36358 L
s
.039 .916 .04 r
.56567 .38684 m
.56567 .38684 L
s
.48489 .42178 m
.48489 .42178 L
s
.49357 .41803 m
.49357 .41803 L
s
.49357 .41803 m
.49357 .41803 L
s
0 0 0 r
2 Mabswid
.24066 .3375 Mdot
.74193 .28563 Mdot
.039 .916 .04 r
.5 Mabswid
.32134 .46882 m
.4026 .46729 L
s
.2171 .4708 m
.32134 .46882 L
s
0 g
.70092 .48283 m
.824 .65718 L
s
.824 .65718 m
.8835 .74145 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.74979 .38672 L
s
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.74979 .38672 L
s
.74979 .38672 m
.74979 .38672 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.74979 .38672 L
s
.74979 .38672 m
.74979 .38672 L
s
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.74979 .38672 L
s
.53349 .45964 m
.55754 .42838 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.66534 .39234 m
.66534 .39234 L
s
.6074 .36358 m
.6074 .36358 L
s
.51634 .30929 m
.51634 .30929 L
s
.51634 .30929 m
.6074 .36358 L
s
.6074 .36358 m
.6074 .36358 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.66534 .39234 m
.66534 .39234 L
s
.6074 .36358 m
.66534 .39234 L
s
.6074 .36358 m
.6074 .36358 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.51634 .30929 m
.51634 .30929 L
s
.51634 .30929 m
.6074 .36358 L
s
.6074 .36358 m
.6074 .36358 L
s
.6074 .36358 m
.6074 .36358 L
s
.64082 .43814 m
.64082 .43814 L
s
.6591 .47889 m
.6591 .47889 L
s
.6591 .47889 m
.6591 .47889 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.42315 .52627 m
.42315 .52627 L
s
.45343 .57966 m
.45343 .57966 L
s
.42315 .52627 m
.45343 .57966 L
s
.45343 .57966 m
.45343 .57966 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.53349 .45964 m
.53349 .45964 L
s
.42315 .52627 m
.42315 .52627 L
s
.38721 .4231 m
.38721 .4231 L
s
.42315 .52627 m
.42315 .52627 L
s
.38721 .4231 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.45343 .57966 m
.45343 .57966 L
s
.42315 .52627 m
.45343 .57966 L
s
.38721 .4231 m
.38721 .4231 L
s
.38721 .4231 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42842 .67106 L
s
.42842 .67106 m
.42842 .67106 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.55343 .60245 m
.55343 .60245 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42315 .52627 L
s
.42315 .52627 m
.42842 .67106 L
s
.42842 .67106 m
.42842 .67106 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.42842 .67106 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.42842 .67106 m
.52896 .61589 L
s
.42842 .67106 m
.42842 .67106 L
s
.52896 .61589 m
.55343 .60245 L
s
0 0 0 r
2 Mabswid
.67304 .40853 Mdot
.039 .916 .04 r
.5 Mabswid
.46272 .70408 m
.53064 .63356 L
s
.53064 .63356 m
.5504 .61304 L
s
0 0 0 r
2 Mabswid
.5504 .61304 Mdot
.039 .916 .04 r
.5 Mabswid
.2822 .69254 m
.35564 .64194 L
s
.35564 .64194 m
.35564 .64194 L
s
.35564 .64194 m
.45136 .57599 L
s
.53657 .45564 m
.53657 .45564 L
s
.53816 .45871 m
.53816 .45871 L
s
0 0 0 r
2 Mabswid
.69508 .73398 Mdot
.039 .916 .04 r
.5 Mabswid
.58847 .60091 m
.58847 .60091 L
s
.59588 .4692 m
.59588 .4692 L
s
.59588 .4692 m
.59588 .4692 L
s
.55133 .48076 m
.55267 .48041 L
s
.55547 .47969 m
.55547 .47969 L
s
.44237 .50904 m
.44237 .50904 L
s
0 0 0 r
2 Mabswid
.427 .51302 Mdot
.75777 .73022 Mdot
0 g
.5 Mabswid
.66873 .50038 m
.66873 .50038 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.62778 .56175 m
.62778 .56175 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66534 .39234 m
.66534 .39234 L
s
.66534 .39234 m
.6681 .48027 L
s
.6681 .48027 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.53349 .45964 m
.53349 .45964 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.62778 .56175 m
.62778 .56175 L
s
.62778 .56175 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66534 .39234 m
.66534 .39234 L
s
.66534 .39234 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.69393 .64494 L
s
.69393 .64494 m
.69393 .64494 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.66873 .50038 L
s
.66873 .50038 m
.69393 .64494 L
s
.69393 .64494 m
.69393 .64494 L
s
0 0 0 r
2 Mabswid
.62527 .5638 Mdot
.64369 .58507 Mdot
.60131 .58703 Mdot
.039 .916 .04 r
.5 Mabswid
.58651 .58435 m
.60131 .58703 L
s
.60131 .58703 m
.60131 .58703 L
s
0 0 0 r
2 Mabswid
.57776 .59027 Mdot
0 g
.5 Mabswid
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.62778 .56175 m
.62778 .56175 L
s
.55343 .60245 m
.62778 .56176 L
s
.62778 .56176 m
.62778 .56175 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.54354 .53159 m
.55343 .60245 L
s
.53349 .45964 m
.53349 .45964 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.53349 .45964 m
.53349 .45964 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.45343 .57966 m
.45343 .57966 L
s
.45343 .57966 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.62778 .56175 m
.62778 .56175 L
s
.55343 .60245 m
.60203 .57585 L
s
.60203 .57585 m
.62778 .56175 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.45343 .57966 m
.45343 .57966 L
s
.45343 .57966 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.58026 .61056 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.55343 .60245 L
s
.58026 .61056 m
.69393 .64494 L
s
.69393 .64494 m
.69393 .64494 L
s
.69393 .64494 m
.69393 .64494 L
s
.55343 .60245 m
.55343 .60245 L
s
.55343 .60245 m
.69393 .64494 L
s
.69393 .64494 m
.69393 .64494 L
s
.039 .916 .04 r
.59263 .581 m
.60052 .60551 L
s
0 0 0 r
2 Mabswid
.60052 .60551 Mdot
.039 .916 .04 r
.5 Mabswid
.48294 .72412 m
.53284 .59776 L
s
.59953 .44641 m
.59953 .44641 L
s
.54795 .5632 m
.54795 .5632 L
s
.55257 .55273 m
.55368 .55022 L
s
.58264 .48465 m
.58264 .48465 L
s
.58987 .46828 m
.58987 .46828 L
s
.58987 .46828 m
.58987 .46828 L
s
0 0 0 r
2 Mabswid
.67714 .71868 Mdot
.27739 .3725 Mdot
.48294 .72412 Mdot
.039 .916 .04 r
.5 Mabswid
.4674 .45227 m
.47404 .44156 L
s
.47404 .44156 m
.47404 .44156 L
s
.47404 .44156 m
.47404 .44156 L
s
.47404 .44156 m
.49818 .40259 L
s
.4674 .45227 m
.4674 .45227 L
s
.39263 .57293 m
.4386 .49875 L
s
.4386 .49875 m
.4674 .45227 L
s
0 0 0 r
2 Mabswid
.49818 .40259 Mdot
.5445 .57854 Mdot
.039 .916 .04 r
.5 Mabswid
.55164 .49869 m
.55391 .50309 L
s
.62843 .37564 m
.62895 .37118 L
s
.62895 .37118 m
.65486 .15153 L
s
0 0 0 r
2 Mabswid
.62843 .37564 Mdot
.039 .916 .04 r
.5 Mabswid
.53253 .3477 m
.62843 .37564 L
s
.53253 .3477 m
.53253 .3477 L
s
.62843 .37564 m
.62843 .37564 L
s
.61218 .48615 m
.61305 .48257 L
s
.61218 .48615 m
.61218 .48615 L
s
.61218 .48615 m
.61218 .48615 L
s
0 0 0 r
2 Mabswid
.61305 .48257 Mdot
.039 .916 .04 r
.5 Mabswid
.61905 .52478 m
.62631 .56558 L
s
.61905 .52478 m
.61905 .52478 L
s
.61905 .52478 m
.61905 .52478 L
s
.61218 .48615 m
.61905 .52478 L
s
.61218 .48615 m
.61218 .48615 L
s
.61218 .48615 m
.61218 .48615 L
s
.61061 .48976 m
.61061 .48976 L
s
0 0 0 r
2 Mabswid
.61218 .48615 Mdot
.50049 .3705 Mdot
0 g
.5 Mabswid
.68387 .31648 m
.70092 .48283 L
s
.65928 .07646 m
.68387 .31648 L
s
0 0 0 r
2 Mabswid
.33512 .35167 Mdot
.039 .916 .04 r
.5 Mabswid
.5338 .55027 m
.56632 .6049 L
s
.5338 .55027 m
.5338 .55027 L
s
.56632 .6049 m
.56632 .6049 L
s
.56632 .6049 m
.59483 .65278 L
s
.59483 .65278 m
.59885 .65953 L
s
0 0 0 r
2 Mabswid
.5338 .55027 Mdot
.039 .916 .04 r
.5 Mabswid
.5338 .55027 m
.56575 .52937 L
s
.56575 .52937 m
.56575 .52937 L
s
.56575 .52937 m
.56575 .52937 L
s
0 0 0 r
2 Mabswid
.51266 .2047 Mdot
.56986 .57682 Mdot
.61084 .46532 Mdot
.57243 .5772 Mdot
.46272 .70408 Mdot
.039 .916 .04 r
.5 Mabswid
.66682 .43959 m
.66682 .43959 L
s
.66682 .43959 m
.74964 .39783 L
s
0 0 0 r
2 Mabswid
.59087 .48651 Mdot
.58894 .41642 Mdot
.039 .916 .04 r
.5 Mabswid
.63831 .43864 m
.63831 .43864 L
s
0 0 0 r
2 Mabswid
.2171 .4708 Mdot
.039 .916 .04 r
.5 Mabswid
.57825 .55344 m
.57905 .49992 L
s
.57905 .49992 m
.57905 .49992 L
s
.57905 .49992 m
.57905 .49992 L
s
.57905 .49992 m
.57905 .49992 L
s
.57905 .49992 m
.57905 .49992 L
s
.57905 .49992 m
.57964 .46019 L
s
.57825 .55344 m
.57825 .55344 L
s
.57762 .59581 m
.57825 .55344 L
s
0 0 0 r
2 Mabswid
.57964 .46019 Mdot
.51022 .34456 Mdot
.62899 .39111 Mdot
.71494 .27052 Mdot
.039 .916 .04 r
.5 Mabswid
.6294 .44042 m
.6294 .44042 L
s
0 0 0 r
2 Mabswid
.62309 .44992 Mdot
.53253 .3477 Mdot
.65154 .44459 Mdot
.51745 .37204 Mdot
.53905 .46045 Mdot
.039 .916 .04 r
.5 Mabswid
.53905 .46045 m
.54318 .46641 L
s
.54318 .46641 m
.54318 .46641 L
s
0 0 0 r
2 Mabswid
.6268 .69149 Mdot
0 g
.5 Mabswid
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.5513 .47893 m
.62778 .56175 L
s
.62778 .56175 m
.62778 .56175 L
s
.53349 .45964 m
.5513 .47893 L
s
.5513 .47893 m
.5513 .47893 L
s
.5513 .47893 m
.62778 .56175 L
s
.62778 .56175 m
.62778 .56175 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.5513 .47893 L
s
.45343 .57966 m
.53349 .45964 L
s
.45343 .57966 m
.45343 .57966 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.66534 .39234 m
.66534 .39234 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.45343 .57966 m
.53349 .45964 L
s
.45343 .57966 m
.45343 .57966 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.55862 .44682 L
s
.55862 .44682 m
.55862 .44682 L
s
.55862 .44682 m
.66533 .39235 L
s
.66533 .39235 m
.66534 .39234 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.66534 .39234 m
.66534 .39234 L
s
.53349 .45964 m
.53349 .45964 L
s
.50532 .4526 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.38721 .4231 m
.50532 .4526 L
s
.38721 .4231 m
.38721 .4231 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.51634 .30929 m
.53349 .45964 L
s
.51634 .30929 m
.51634 .30929 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.38721 .4231 m
.50532 .4526 L
s
.38721 .4231 m
.38721 .4231 L
s
.53349 .45964 m
.53349 .45964 L
s
.50532 .4526 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.53349 .45964 m
.53349 .45964 L
s
.51634 .30929 m
.53349 .45964 L
s
.51634 .30929 m
.51634 .30929 L
s
0 0 0 r
2 Mabswid
.5439 .48366 Mdot
.039 .916 .04 r
.5 Mabswid
.39458 .42763 m
.44397 .44351 L
s
.44397 .44351 m
.44397 .44351 L
s
.44397 .44351 m
.46443 .45009 L
s
.46443 .45009 m
.46443 .45009 L
s
.46443 .45009 m
.46443 .45009 L
s
0 0 0 r
2 Mabswid
.46443 .45009 Mdot
.54318 .46641 Mdot
.56575 .52937 Mdot
.039 .916 .04 r
.5 Mabswid
.52707 .37058 m
.66763 .38024 L
s
.52707 .37058 m
.52707 .37058 L
s
0 0 0 r
2 Mabswid
.52707 .37058 Mdot
.039 .916 .04 r
.5 Mabswid
.64681 .64459 m
.65007 .6568 L
s
.6251 .56322 m
.64681 .64459 L
s
.48256 .43117 m
.55447 .47556 L
s
.55447 .47556 m
.57445 .48789 L
s
.57445 .48789 m
.57445 .48789 L
s
.57445 .48789 m
.57445 .48789 L
s
.57445 .48789 m
.57445 .48789 L
s
.57445 .48789 m
.57445 .48789 L
s
.57445 .48789 m
.57445 .48789 L
s
.57445 .48789 m
.6057 .50718 L
s
0 0 0 r
2 Mabswid
.6057 .50718 Mdot
.60218 .44106 Mdot
.66358 .43146 Mdot
.039 .916 .04 r
.5 Mabswid
.58359 .5132 m
.66358 .43146 L
s
.58359 .5132 m
.58359 .5132 L
s
.58359 .5132 m
.58359 .5132 L
s
.66358 .43146 m
.66358 .43146 L
s
.66358 .43146 m
.66358 .43146 L
s
.56689 .51951 m
.58707 .60441 L
s
.58707 .60441 m
.58707 .60441 L
s
.56689 .51951 m
.56689 .51951 L
s
.56689 .51951 m
.56689 .51951 L
s
.58707 .60441 m
.58998 .61661 L
s
0 0 0 r
2 Mabswid
.56689 .51951 Mdot
.039 .916 .04 r
.5 Mabswid
.63501 .43436 m
.64349 .33738 L
s
.62724 .52327 m
.63501 .43436 L
s
.62724 .52327 m
.62724 .52327 L
s
0 0 0 r
2 Mabswid
.62724 .52327 Mdot
.64618 .42778 Mdot
.2822 .69254 Mdot
.74964 .39783 Mdot
.58925 .50422 Mdot
.039 .916 .04 r
.5 Mabswid
.50554 .39017 m
.59068 .3929 L
s
.59068 .3929 m
.59068 .3929 L
s
.59068 .3929 m
.59068 .3929 L
s
.59068 .3929 m
.64193 .39454 L
s
0 0 0 r
2 Mabswid
.64193 .39454 Mdot
.58295 .52996 Mdot
.65486 .15153 Mdot
.58285 .51409 Mdot
.58359 .5132 Mdot
.59885 .65953 Mdot
.65007 .6568 Mdot
.29251 .66776 Mdot
.39458 .42763 Mdot
0 g
.5 Mabswid
.70092 .48283 m
.1997 .63528 L
s
0 0 0 r
2 Mabswid
.58998 .61661 Mdot
.50554 .39017 Mdot
.48256 .43117 Mdot
.57762 .59581 Mdot
.64349 .33738 Mdot
.39263 .57293 Mdot
.62631 .56558 Mdot
.66763 .38024 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 365.688},
  ImageMargins->{{36, 0}, {0, 0}},
  ImageRegion->{{-0.0732177, 1.08863}, {-0.0954128, 1.16881}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00001KB000`400?l00000o`00003oo`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00j03oool200000?l0oooo<P3o
ool2000006<0oooo003U0?ooo`<0000000<0oooo0000003oool0o`3oool^0?ooo`<0000000<0oooo
0000003oool0HP3oool00><0oooo0P0000040?ooo`800000o`3oool[0?ooo`<00000103oool20000
0680oooo003P0?ooo`<000001P3oool00`000000oooo0000003o0?ooobP0oooo0P0000070?ooo`80
0000HP3oool00=h0oooo0P0000090?ooo`030000003oool000000?l0oooo9@3oool3000000T0oooo
00<000000?ooo`000000H@3oool00=/0oooo0`00000;0?ooo`040000003oool0oooo00000?l0oooo
8@3oool3000000`0oooo00@000000?ooo`3oool00000H03oool00=T0oooo0P00000>0?ooo`050000
003oool0oooo0?ooo`000000o`3ooolN0?ooo`800000403oool00`000000oooo0000001P0?ooo`00
e`3oool200000100oooo00D000000?ooo`3oool0oooo0000003o0?oooa/0oooo0`00000B0?ooo`04
0000003oool0oooo000005l0oooo003D0?ooo`<000004P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0?l0oooo5@3oool3000001D0oooo00@000000?ooo`3oool00000G`3oool00=80
oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`80
0000603oool01@000000oooo0?ooo`3oool0000005h0oooo003?0?ooo`<000005`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo3P3oool3000001X0oooo00D000000?ooo`3o
ool0oooo0000001N0?ooo`00c@3oool2000001X0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3o0?ooo``0oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0F`3oool00<X0oooo0`00000L0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
o`3oool80?ooo`<000007`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05X0oooo
00380?ooo`8000007`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo103o
ool300000280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1J0?ooo`00a@3oool3
00000240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooo`80oooo0P00000U
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0F@3oool00<<0oooo0P00000T0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o@3oool3000002L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1I0?ooo`00`03oool3000002H0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`3i0?ooo`<00000:`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo05P0oooo002n0?ooo`800000:@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0?L0oooo0P00000^0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
F03oool00;`0oooo0P00000[0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0l`3o
ool300000300oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1G0?ooo`00^@3oool3
000002d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3_0?ooo`<00000<`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo05L0oooo002g0?ooo`800000<03oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0>d0oooo0P00000f0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0EP3oool00;@0oooo0`00000b0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0j@3oool3000003P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`1E0?ooo`00/P3oool2000003H0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`3U0?ooo`<00000>`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05D0oooo
002_0?ooo`<00000>03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0>80oooo0P00
000n0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0E03oool00:d0oooo0P00000k
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0g`3oool300000400oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`1D0?ooo`00ZP3oool3000003d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`3K0?ooo`<00000A03oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo05<0oooo002X0?ooo`800000@03oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0=P0oooo0P0000170?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0D`3oool00:D0oooo0`0000120?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
e@3oool3000004T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1B0?ooo`00X`3o
ool2000004D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3A0?ooo`<00000C03o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0540oooo002Q0?ooo`800000A`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0<h0oooo0P00001?0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0D@3oool009h0oooo0`0000130?ooo`800000103oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0</0oooo0`00001<0?ooo`8000000`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0500oooo002L0?ooo`800000AP3oool2000000@0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`370?ooo`<00000C`3oool2000000<0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1@0?ooo`00V@3oool3000004T0oooo
00<02NX:0?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0<@0oooo
0P00001B0?ooo`0300WZ2P3oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`1?0?ooo`00U`3oool2000004`0oooo00<02NX:0?ooo`3oool00P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0<40oooo0`00001D0?ooo`0300WZ2P3oool0oooo0080oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`1?0?ooo`00U03oool3000004h0oooo00<02NX:
0?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0;h0oooo0P00001G
0?ooo`0300WZ2P3oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1>
0?ooo`00TP3oool200000540oooo00<02NX:0?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0;X0oooo0`00001I0?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`1=0?ooo`00S`3oool3000005<0oooo00<02NX:0?ooo`3o
ool00P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0;H0oooo0`00001K0?ooo`03
00WZ2P3oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1=0?ooo`00
S@3oool2000005D0oooo00<02NX:0?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo0;@0oooo0P00001N0?ooo`0300WZ2P3oool0oooo00@0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`1<0?ooo`00RP3oool3000005L0oooo00<02NX:0?ooo`3oool00`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0;00oooo0`00001P0?ooo`0300WZ2P3o
ool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1<0?ooo`00R03oool2
000005X0oooo00<02NX:0?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0:`0oooo0`00001S0?ooo`0300WZ2P3oool0oooo00@0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`1;0?ooo`00QP3oool2000005`0oooo00<02NX:0?ooo`3oool00`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0:X0oooo0P00001V0?ooo`0300WZ2P3oool0oooo
00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1;0?ooo`00P`3oool300000240
oooo0P00000k0?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`2V0?ooo`<000009@3oool200000440oooo00<02NX:0?ooo`3oool0103oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo04X0oooo00210?ooo`800000903oool2000003/0oooo
00<02NX:0?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0:80oooo
0`00000X0?ooo`800000@@3oool00`09jPX0oooo0?ooo`040?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0BP3oool007h0oooo0`00000W0?ooo`0300WZ2P3oool0oooo03T0oooo00<0
2NX:0?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0:00oooo0P00
000/0?ooo`0300WZ2P3oool0oooo03l0oooo00<02NX:0?ooo`3oool0103oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo04T0oooo001l0?ooo`800000:P3oool00`09jPX0oooo0?ooo`0i
0?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`2L
0?ooo`<00000;@3oool00`09jPX0oooo0?ooo`100?ooo`0300WZ2P3oool0oooo00@0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`180?ooo`00N@3oool3000002/0oooo00<02NX:0?oo
o`3oool0>P3oool00`09jPX0oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0V03oool300000300oooo00<02NX:0?ooo`3oool0?`3oool00`09jPX0oooo0?ooo`060?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0B03oool007L0oooo0P00000^0?ooo`03
00WZ2P3oool0oooo03X0oooo00<02NX:0?ooo`3oool00`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo09H0oooo0P00000c0?ooo`0300WZ2P3oool0oooo03l0oooo00<02NX:0?ooo`3o
ool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04L0oooo001d0?ooo`<00000
<03oool00`09jPX0oooo0?ooo`0j0?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?ooo`3oool0
5`3oool2000000<0oooo00<000000?ooo`3oool0TP3oool3000003@0oooo00<02NX:0?ooo`3oool0
@03oool00`09jPX0oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
A`3oool00780oooo0P00000b0?ooo`0300WZ2P3oool0oooo03X0oooo00<02NX:0?ooo`3oool0103o
ool00`000000oooo0?ooo`0G0?ooo`800000103oool00`000000oooo0?ooo`2>0?ooo`<00000=`3o
ool00`09jPX0oooo0?ooo`100?ooo`0300WZ2P3oool0oooo00H0oooo00<000000?ooo`3oool03P3o
ool2000000<0oooo00<000000?ooo`3oool0AP3oool006l0oooo0`00000d0?ooo`0300WZ2P3oool0
oooo03X0oooo00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`0300WZ2P3oool0
oooo00<0oooo00<000000?ooo`3oool0R`3oool2000003X0oooo00<02NX:0?ooo`3oool0@03oool0
0`09jPX0oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo0P0000030?ooo`030000003oool0
oooo04H0oooo001]0?ooo`800000=`3oool00`09jPX0oooo0?ooo`0j0?ooo`0300WZ2P3oool0oooo
00@0oooo00<000000?ooo`3oool05`3oool00`09jPX0oooo0?ooo`040?ooo`030000003oool0oooo
08P0oooo0`00000k0?ooo`0300WZ2P3oool0oooo0440oooo00<02NX:0?ooo`3oool01P3oool00`00
0000oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo0080oooo00<000000?ooo`3oool0A@3oool006/0
oooo0P00000h0?ooo`0300WZ2P3oool0oooo03/0oooo00<02NX:0?ooo`3oool0103oool00`000000
oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?ooo`3oool0Q03oool3000003h0
oooo00<02NX:0?ooo`3oool0@@3oool00`09jPX0oooo0?ooo`060?ooo`030000003oool0oooo00h0
oooo00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`140?ooo`00J03oool3000003X0oooo
00<02NX:0?ooo`3oool01@3oool2000003@0oooo00<02NX:0?ooo`3oool0103oool00`000000oooo
0?ooo`0F0?ooo`0300WZ2P3oool0oooo00L0oooo00<000000?ooo`3oool0P@3oool200000440oooo
00<02NX:0?ooo`3oool02@3oool2000003H0oooo00<02NX:0?ooo`3oool01P3oool00`000000oooo
0?ooo`0>0?ooo`0300WZ2P3oool0oooo00@0oooo00<000000?ooo`3oool0A03oool006H0oooo0P00
000m0?ooo`0300WZ2P3oool0oooo00D0oooo0P00000d0?ooo`0300WZ2P3oool0oooo00@0oooo00<0
00000?ooo`3oool05P3oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo07h0oooo0`00
00130?ooo`0300WZ2P3oool0oooo00T0oooo0P0000000`09jPX0oooo0?ooo`0c0?ooo`0300WZ2P3o
ool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`09jPX0oooo0?ooo`060?ooo`030000003o
ool0oooo04<0oooo001S0?ooo`<00000?`3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0
oooo0340oooo00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`0300WZ2P3oool0
oooo00T0oooo00<000000?ooo`3oool0NP3oool3000004D0oooo00<02NX:0?ooo`3oool03@3oool0
0`09jPX0oooo0?ooo`0a0?ooo`0300WZ2P3oool0oooo00P0oooo00<000000?ooo`3oool0303oool0
0`09jPX0oooo0?ooo`060?ooo`030000003oool0oooo04<0oooo001Q0?ooo`800000@@3oool00`09
jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo0300oooo00<02NX:0?ooo`3oool0103oool00`00
0000oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool0M`3oool20000
04P0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0`0?ooo`0300WZ2P3oool0oooo
00P0oooo00<000000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo
0480oooo001N0?ooo`<00000@`3oool00`09jPX0oooo0?ooo`0:0?ooo`802NX:<03oool00`09jPX0
oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo00<02NX:0?ooo`3oool02`3oool00`000000
oooo0?ooo`1d0?ooo`<00000BP3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo02l0
oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00T0
oooo00<000000?ooo`3oool0@P3oool005`0oooo0P0000160?ooo`0300WZ2P3oool0oooo00`0oooo
00<02NX:0?ooo`3oool0;@3oool00`09jPX0oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo
00<02NX:0?ooo`3oool03@3oool00`000000oooo0?ooo`1a0?ooo`800000C03oool00`09jPX0oooo
0?ooo`0A0?ooo`0300WZ2P3oool0oooo02h0oooo00<02NX:0?ooo`3oool0203oool00`000000oooo
0?ooo`0:0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool0@@3oool005T0oooo0`00
00170?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool0;03oool00`09jPX0oooo0?oo
o`040?ooo`030000003oool0oooo01<0oooo00<02NX:0?ooo`3oool03P3oool00`000000oooo0?oo
o`1]0?ooo`<00000CP3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo02d0oooo00<0
2NX:0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00`0oooo00<0
00000?ooo`3oool0@03oool005L0oooo0P00001:0?ooo`0300WZ2P3oool0oooo00l0oooo0P09jPX[
0?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?ooo`3oool0403oool300WZ2Q40oooo00<00000
0?ooo`3oool0JP3oool300000540oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0/
0?ooo`0300WZ2P3oool0oooo00P0oooo00<000000?ooo`3oool01@3oool200000080oooo00<02NX:
0?ooo`3oool0303oool00`000000oooo0?ooo`100?ooo`00E03oool3000004`0oooo00<02NX:0?oo
o`3oool04@3oool00`09jPX0oooo0?ooo`0X0?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?oo
o`3oool03@3oool300WZ2P80000000<02NX:0?ooo`3oool0403oool00`000000oooo0?ooo`1W0?oo
o`800000D`3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo02/0oooo00<02NX:0?oo
o`3oool0203oool00`000000oooo0?ooo`050?ooo`802NX:00<0oooo00WZ2P3oool03`3oool00`00
0000oooo0?ooo`0o0?ooo`00DP3oool2000004h0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0
oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?ooo`3oool02P3oool300WZ2P@0
oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`<00000E@3oool00`09jPX0
oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo02X0oooo00<02NX:0?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`<02NX:0`3oool00`09jPX0oooo0?ooo`0>0?ooo`030000003oool0oooo03l0
oooo001@0?ooo`800000D03oool00`09jPX0oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo02H0oooo
00<02NX:0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`802NX:1`3oool00`09jPX0oooo
0?ooo`0C0?ooo`030000003oool0oooo05l0oooo0`00001H0?ooo`0300WZ2P3oool0oooo01L0oooo
00<02NX:0?ooo`3oool0:@3oool00`09jPX0oooo0?ooo`080?ooo`030000003oool02NX:00802NX:
1@3oool00`09jPX0oooo0?ooo`0@0?ooo`030000003oool0oooo03h0oooo001=0?ooo`<00000DP3o
ool00`09jPX0oooo0?ooo`0E0?ooo`802NX:9P3oool00`09jPX0oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo0`09jPX80?ooo`0300WZ2P3oool0oooo01@0oooo00<000000?ooo`3oool0G@3o
ool2000005/0oooo00<02NX:0?ooo`3oool0603oool00`09jPX0oooo0?ooo`0W0?ooo`0300WZ2P3o
ool0oooo00T0oooo00<0000000WZ2P3oool01`3oool00`09jPX0oooo0?ooo`0@0?ooo`030000003o
ool0oooo03h0oooo001;0?ooo`800000;`3oool2000002@0oooo00<02NX:0?ooo`3oool05`3oool0
0`09jPX0oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo00H0oooo00<000000?ooo`3oool00P3oool2
00WZ2P/0oooo00<02NX:0?ooo`3oool05@3oool00`000000oooo0?ooo`1I0?ooo`<00000=03oool0
0`09jPX000000?ooo`0U0?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3oool09P3oool0
0`09jPX0oooo0?ooo`060?ooo`<02NX:00<0oooo0000003oool01P3oool00`09jPX0oooo0?ooo`0B
0?ooo`030000003oool0oooo03d0oooo00180?ooo`<00000<@3oool00`09jPX000000?ooo`0R0?oo
o`0300WZ2P3oool0oooo01T0oooo00<02NX:0?ooo`3oool08P3oool00`09jPX0oooo0?ooo`060?oo
o`030000003oool02NX:00802NX:303oool00`09jPX0oooo0?ooo`0G0?ooo`030000003oool0oooo
05D0oooo0`00000g0?ooo`0300WZ2P000000oooo02D0oooo00<02NX:0?ooo`3oool06`3oool200WZ
2RH0oooo00<02NX:0?ooo`3oool0103oool200WZ2P@0oooo00<000000?ooo`3oool01@3oool00`09
jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo03d0oooo00160?ooo`800000=03oool00`09jPX0
oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo01X0oooo0P09jPXR0?ooo`0300WZ2P3oool0oooo00D0
oooo00<02NX:00000009jPX03`3oool00`09jPX0oooo0?ooo`0G0?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0T0?ooo`0300WZ2P3oool0oooo01`0
oooo0P09jPXU0?ooo`0400WZ2P3oool0oooo0?ooo`<02NX:1P3oool00`000000oooo0?ooo`040?oo
o`0300WZ2P3oool0oooo01@0oooo00<000000?ooo`3oool0?03oool004<0oooo0`00000g0?ooo`03
00WZ2P3oool0oooo0240oooo00<02NX:0?ooo`3oool0703oool00`09jPX0oooo0?ooo`0O0?ooo`03
00WZ2P3oool0oooo00<0oooo0P09jPX00`3oool000000?ooo`0>0?ooo`0300WZ2P3oool0oooo01T0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0j0?ooo`0300WZ2P3oool0oooo0280
oooo00<02NX:0?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0R0?ooo`@02NX:2@3oool00`000000
oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01D0oooo00<000000?ooo`3oool0>`3oool00480oooo
00<000000?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo01h0oooo
00<02NX:0?ooo`3oool07P3oool00`09jPX0oooo0?ooo`0300WZ2P<0oooo00<000000?ooo`3oool0
3@3oool00`09jPX0oooo0?ooo`0J0?ooo`030000003oool0oooo0580oooo0P00000l0?ooo`0300WZ
2P3oool0oooo0240oooo00<02NX:0?ooo`3oool0803oool00`09jPX0oooo0?ooo`0P0?ooo`802NX:
303oool00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01H0oooo00<000000?ooo`3oool0
>`3oool00480oooo0P00000k0?ooo`0300WZ2P3oool0oooo01h0oooo00<02NX:0?ooo`3oool03`3o
ool200WZ2Ph0oooo00<02NX:0?ooo`3oool07@3oool300WZ2PH0oooo00<000000?ooo`3oool0303o
ool00`09jPX0oooo0?ooo`0K0?ooo`030000003oool0oooo0580oooo00<000000?ooo`000000?03o
ool00`09jPX0oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo00`0oooo00<0000000WZ2P09jPX04P3o
ool00`09jPX0oooo0?ooo`0L0?ooo`<02NX:00<0oooo00WZ2P3oool02`3oool00`000000oooo0?oo
o`020?ooo`0300WZ2P3oool0oooo01P0oooo00<000000?ooo`3oool0>P3oool00480oooo00<00000
0?ooo`000000>`3oool00`09jPX0oooo0?ooo`0M0?ooo`0300WZ2P3oool0oooo00l0oooo0P000000
0`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo01X0oooo0`09jPX80?ooo`030000003oool0
oooo00`0oooo00<02NX:0?ooo`3oool0703oool00`000000oooo0?ooo`1A0?ooo`040000003oool0
oooo000003`0oooo00<02NX:0?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0<0?ooo`80000000<0
oooo00WZ2P3oool04@3oool00`09jPX0oooo0?ooo`0H0?ooo`<02NX:103oool00`09jPX0oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo00<02NX:0?ooo`3oool0603oool00`000000oooo0?oo
o`0j0?ooo`00@P3oool010000000oooo0?ooo`00000k0?ooo`0300WZ2P3oool0oooo01`0oooo00<0
2NX:0?ooo`3oool04P3oool200WZ2Pd0oooo0P09jPXG0?ooo`<02NX:00<0oooo00WZ2P3oool0203o
ool00`000000oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo01T0oooo00<02NX:0000003oool00P3o
ool00`000000oooo0?ooo`1@0?ooo`050000003oool0oooo0?ooo`000000?03oool00`09jPX0oooo
0?ooo`0M0?ooo`0300WZ2P3oool0oooo0140oooo0P09jPXA0?ooo`0300WZ2P3oool0oooo01D0oooo
0P09jPX70?ooo`0300WZ2P3oool0oooo00X0oooo00D000000?ooo`3oool0oooo00WZ2P0L0?ooo`03
0000003oool0oooo03T0oooo00120?ooo`050000003oool0oooo0?ooo`000000>P3oool00`09jPX0
oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0
oooo0?ooo`0B0?ooo`802NX:103oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo00/0
oooo00<02NX:0?ooo`3oool05`3oool200WZ2P8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool00`09jPX0oooo0?ooo`0L0?ooo`03
00WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0A0?ooo`<0
2NX:203oool00`09jPX0oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`09jPX06@3oool200WZ
2P030?ooo`000000oooo03X0oooo00110?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0>03oool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo01H0oooo0P09jPX=0?ooo`03
00WZ2P3oool0oooo00h0oooo0`09jPX60?ooo`0300WZ2P3oool0oooo00L0oooo00<000000?ooo`3o
ool02P3oool00`09jPX0oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo00H0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03X0oooo00<02NX:0?ooo`3o
ool06`3oool00`09jPX0oooo0?ooo`0D0?ooo`802NX:403oool200WZ2Pl0oooo0P09jPX;0?ooo`03
00WZ2P3oool0oooo00/0oooo00@000000?ooo`3oool02NX:603oool300WZ2P040000003oool0oooo
000003X0oooo00110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>03oool00`09
jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0;0?ooo`802NX:2@3oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo
00T0oooo00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0k0?ooo`0300WZ2P3oool0oooo
01T0oooo00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo
00T0oooo0`09jPX=0?ooo`0300WZ2P3oool0oooo00`0oooo00<000000?ooo`09jPX05`3oool00`09
jPX0oooo0?ooo`050?ooo`030000003oool0oooo03L0oooo00110?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0>03oool00`09jPX0oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo01D0
oooo00<000000?ooo`3oool00P3oool200WZ2P`0oooo00<02NX:0?ooo`3oool01`3oool300WZ2P/0
oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`0300WZ2P3oool0oooo01D0
oooo0P09jPX;0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0j0?ooo`0300WZ2P3oool0oooo01T0oooo00<02NX:0?ooo`3oool05@3oool00`000000
oooo0?ooo`0200WZ2Q00oooo00<02NX:0?ooo`3oool01@3oool300WZ2Q00oooo00<02NX:0?ooo`3o
ool0303oool00`0000002NX:0?ooo`0F0?ooo`0300WZ2P3oool0oooo00H0oooo00<000000?ooo`3o
ool0=`3oool00440oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0h0?ooo`0300WZ
2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00X0oooo0P09jPX40?ooo`<02NX:3P3oool00`09jPX0oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<02NX:0?ooo`3oool04@3oool200000080oooo00<02NX:0?ooo`3oool0
303oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
>P3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo01D0oooo00<000000?ooo`3oool0
0P3oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo0080oooo0P09jPXC0?ooo`0300WZ
2P3oool0oooo00`0oooo00<0000000WZ2P3oool05@3oool00`09jPX0oooo0?ooo`080?ooo`030000
003oool0oooo03H0oooo00110?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0>03o
ool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo01@0oooo00<000000:IfWP0000001P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0400WZ2P3oool02NX:00WZ2Q40oooo00<02NX:0?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0140oooo0P0000000`3oool02NX:
0?ooo`0?0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0j0?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool05@3oool00`000000Zg^O
000000040?ooo`0300WZ2P3oool0oooo00h0oooo1009jPXE0?ooo`0300WZ2P3oool0oooo00`0oooo
00<000000?ooo`3oool03P3oool2000000<0oooo0P09jPX;0?ooo`030000003oool0oooo03H0oooo
00110?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=`3oool00`09jPX0oooo0?oo
o`0D0?ooo`0300WZ2P3oool0oooo01D0oooo00@000000:IfWP2VMYh000001P3oool200WZ2PX0oooo
0`09jPXC0?ooo`0300WZ2P3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`09jPX0oooo
0?ooo`060?ooo`8000002P3oool00`09jPX0oooo00WZ2P0B0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0j0?ooo`0300WZ2P3oool0oooo01D0oooo
00<02NX:0?ooo`3oool05@3oool010000000Zg^O0:]kW`0000040?ooo`802NX:303oool400WZ2QL0
oooo00<02NX:0?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`80000000<0oooo00000000
00000P3oool00`09jPX0oooo0?ooo`0<0?ooo`030000003oool0oooo03D0oooo00110?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0=`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ
2P3oool0oooo01@0oooo00<000000:IfWP2VMYh00P2VMYh00`000000oooo0?ooo`050?ooo`0300WZ
2P3oool0oooo00D0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:000000000000
2@3oool300WZ2Pd0oooo0P09jPX01@000000oooo0?ooo`3oool0000004`0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0j0?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3o
ool0503oool00`000000Zg^O0:]kW`020:]kW`030000003oool0oooo00<0oooo00<02NX:0?ooo`3o
ool01`3oool200WZ2P@0oooo00<02NX:0?ooo`3oool0503oool00`09jPX0oooo0?ooo`0;0?ooo`03
00WZ2P000000oooo00/0oooo00D02NX:000000000000oooo00WZ2P020?ooo`0300WZ2P3oool0oooo
00h0oooo00<000000?ooo`3oool0=03oool00400oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0g0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool04`3oool00`000000
YWJN0:IfWP040:IfWP030000003oool0oooo00D0oooo0P09jPX20?ooo`<02NX:1P3oool200WZ2Q00
oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00D0
oooo00<02NX:0?ooo`3oool02@3oool200WZ2Ph0oooo00@02NX:0?ooo`0000000000103oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0>`3oool00`09
jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01<0oooo00<000000:]kW`2[Nil0102[Nil00`00
0000oooo0?ooo`030?ooo`802NX:103oool300WZ2PL0oooo00<02NX:0?ooo`3oool04`3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P000000oooo00X0oooo00D02NX:0?ooo`3oool0oooo00WZ2P02
0?ooo`0300WZ2P3oool0oooo00X0oooo0P09jPX30?ooo`030000003oool0oooo03@0oooo00100?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0=`3oool00`09jPX0oooo0?ooo`0A0?oo
o`0300WZ2P3oool0oooo01<0oooo00<000000:IfWP2VMYh0102VMYh00`000000oooo0?ooo`060?oo
o`<02NX:2P3oool200WZ2Ph0oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`060?oo
o`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0<0?oo
o`0300WZ2P3oool0oooo00L0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo03/0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0D0?oo
o`030000002[Nil0Zg^O00@0Zg^O00<0@Ug70000003oool01@3oool01009jPX0oooo00WZ2P09jPX;
0?ooo`802NX:4P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0000000X0oooo00D02NX:
0?ooo`3oool0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:000000000000103o
ool00`000000oooo0?ooo`0c0?ooo`00@03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo03L0oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0C0?ooo`030000002VMYh0
YWJN00H0YWJN00<000000?ooo`3oool00`3oool200WZ2P80oooo0P09jPX;0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool02@3oool200WZ2Pd0oooo0P09jPX:0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0k0?ooo`0300WZ2P3oool0
oooo0100oooo00<02NX:0?ooo`3oool04`3oool00`000000Zg^O0:]kW`060:]kW`030000003oool0
oooo00<0oooo1009jPX>0?ooo`0300WZ2P3oool0oooo00l0oooo00<02NX:0?ooo`3oool02P3oool0
1009jPX0oooo0?ooo`0000090?ooo`0300WZ2P3oool0oooo0080oooo0`09jPX<0?ooo`0300WZ2P3o
ool0oooo00D0oooo00<000000?ooo`3oool0<`3oool00400oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0g0?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool04`3oool0
0`000000YWJN0:IfWP070:IfWP030000003oool02NX:00802NX:1P3oool00`09jPX0oooo0?ooo`09
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`05
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo00WZ2P0<
0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo03/0oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0C
0?ooo`030000002[Nil0Zg^O00L0Zg^O00<000000?ooo`09jPX00P09jPX40?ooo`0300WZ2P3oool0
oooo00`0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0:0?ooo`0500WZ2P3oool0
oooo0?ooo`0000001`3oool00`09jPX0oooo0?ooo`020?ooo`802NX:303oool200WZ2PT0oooo00<0
00000?ooo`3oool0<P3oool00400oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0f
0?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool04P3oool00`000000YWJN0:IfWP09
0:IfWP030000003oool0oooo00P0oooo0P09jPX:0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:
0?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:
0?ooo`3oool02@3oool00`09jPX0oooo00WZ2P050?ooo`0300WZ2P000000000000@0oooo00<02NX:
0?ooo`3oool03@3oool00`000000oooo0?ooo`160?ooo`040000003oool00000000000`0oooo00<0
00000?ooo`3oool0>`3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo01<0oooo00<0
00000:]kW`2[Nil02@2[Nil00`000000oooo0?ooo`060?ooo`802NX:3@3oool00`09jPX0oooo0?oo
o`0=0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX:0?ooo`80000000<02NX:0?ooo`3oool02@3o
ool00`000000oooo0?ooo`0b0?ooo`00@03oool010000000oooo00000000000?0?ooo`030000003o
ool0oooo03H0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0C0?ooo`030000002V
MYh0YWJN00T0YWJN00<000000?ooo`3oool02P3oool00`09jPX0oooo0?ooo`080?ooo`802NX:2@3o
ool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<02NX:0?ooo`3oool00P3o
ool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool02NX:00<0oooo0`09jPX00`3oool000000000
00020?ooo`802NX:403oool00`000000oooo0?ooo`160?ooo`050000003oool0000000000009jPX0
303oool00`000000oooo0?ooo`0k0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool0
4`3oool00`000000Zg^O0:]kW`0:0:]kW`030000003oool0oooo00L0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`802NX:1@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ
2P000000000000d0oooo00<000000?ooo`3oool0<@3oool00400oooo00@000000?ooo`0000000000
403oool00`000000oooo0?ooo`0f0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0
4P3oool00`000000YWJN0:IfWP0;0:IfWP030000003oool0oooo00X0oooo0P09jPX:0?ooo`0300WZ
2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0203oool200WZ2P80oooo00@02NX:0?ooo`09jPX0
2NX:1`3oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool00P3oool200WZ2P/0oooo00<000000?ooo`3oool0>P3oool00`09jPX0oooo0?ooo`0<0?ooo`03
00WZ2P3oool0oooo0180oooo00<000000:]kW`2[Nil02`2[Nil00`12GLL000000?ooo`080?ooo`80
2NX:303oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool02NX:00D0oooo0P09jPX80?ooo`D02NX:3`3oool00`00
0000oooo0?ooo`0`0?ooo`00@03oool010000000oooo0?ooo`3oool200WZ2Pl0oooo00<000000?oo
o`3oool0=P3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo0180oooo00<000000:If
WP2VMYh0302VMYh00`000000oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?oo
o`3oool01@3oool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00D02NX:0?oo
o`3oool0oooo00WZ2P0:0?ooo`0400WZ2P3oool0oooo0?ooo`<02NX:203oool00`09jPX0oooo0?oo
o`0C0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0103oool00`09jPX0oooo0?oo
o`080?ooo`030000003oool0oooo03/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX000000?oo
o`0C0?ooo`030000002[Nil0Zg^O00`0Zg^O00<0@Ug70000003oool02@3oool00`09jPX0oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?oo
o`030?ooo`040000003oool0oooo00WZ2PD0oooo0P09jPX60?ooo`<02NX:0P3oool00`09jPX0oooo
0?ooo`0?0?ooo`030000003oool0oooo0300oooo000o0?ooo`030000003oool0oooo00@0oooo00<0
2NX:0?ooo`3oool03@3oool00`000000oooo0?ooo`0f0?ooo`0300WZ2P3oool0oooo00P0oooo00H0
2NX:0?ooo`3oool0oooo00000009jPX?0?ooo`030000002VMYh0YWJN00800000302VMYh00`000000
oooo0?ooo`0;0?ooo`802NX:2@3oool200WZ2PD0oooo00<02NX:0?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02P3oool00`09jPX0oooo0?ooo`0300WZ
2PP0oooo0P09jPXF0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool01@3oool200WZ
2PT0oooo00<000000?ooo`3oool0>`3oool00`09jPX0oooo0?ooo`090?ooo`802NX:4`3oool00`00
0000Zg^O0:]kW`02000000`0Zg^O00<000000?ooo`3oool02@3oool200WZ2P/0oooo00<02NX:0?oo
o`3oool02@3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo00@0oooo00<000000?oo
o`09jPX01@3oool200WZ2P@0oooo0`09jPX40?ooo`0300WZ2P3oool0oooo0140oooo00<000000?oo
o`3oool0;`3oool003l0oooo00<000000?ooo`3oool01@3oool200WZ2Ph0oooo00<000000?ooo`3o
ool0=P3oool00`09jPX0oooo0?ooo`070?ooo`0400WZ2P3oool0oooo0?ooo`80000000<02NX:0?oo
o`3oool02`3oool010000000YWJN0:IfWP2VMYh2000000d0YWJN00<000000?ooo`3oool0303oool0
0`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`0400WZ2P3oool0oooo00WZ2PT0oooo0P09jPX01@3oool02NX:00WZ
2P3oool02NX:00P0oooo00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00P0oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`0k0?ooo`0300WZ
2P3oool0oooo00P0oooo00<02NX:0?ooo`09jPX04@3oool010000000Zg^O0:]kW`2[Nil2000000d0
Zg^O00<000000?ooo`3oool02P3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00P0
oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`040?ooo`0300000009jPX0oooo00@0
oooo00@02NX:0?ooo`09jPX0oooo0`09jPX60?ooo`0300WZ2P3oool0oooo0180oooo00<000000?oo
o`3oool0;`3oool003l0oooo00<000000?ooo`3oool01`3oool200WZ2Pd0oooo00<000000?ooo`3o
ool0;`3oool2000000@0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00X0oooo00<000000:IfWP2VMYh0402VMYh00`000000oooo0?ooo`0=0?ooo`80
2NX:2@3oool01@09jPX0oooo0?ooo`3oool02NX:00X0oooo00D000000?ooo`3oool0oooo00WZ2P02
0?ooo`0300WZ2P3oool0oooo00L0oooo1009jPX20?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:
0?ooo`3oool06@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00T0oooo00<02NX:
0?ooo`3oool01`3oool00`000000oooo0?ooo`0`0?ooo`8000002@3oool00`09jPX0oooo0?ooo`07
0?ooo`0400WZ2P3oool0oooo00WZ2Q00oooo00<000000:]kW`2[Nil04@2[Nil00`000000oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?oo
o`070?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0000003oool0103oool00`09jPX0oooo00WZ
2P0200WZ2PL0oooo0P09jPXF0?ooo`030000003oool0oooo02h0oooo000o0?ooo`030000003oool0
oooo00T0oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo0?ooo`0^0?ooo`8000001@3oool0
0`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0203oool0
0`000000YWJN0:IfWP0B0:IfWP030000003oool0oooo00h0oooo00<02NX:0?ooo`3oool01`3oool0
1009jPX0oooo0?ooo`09jPX:0?ooo`040000003oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool0
1`3oool200WZ2PD0oooo00<02NX:0?ooo`3oool0103oool200WZ2Q`0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0:0?ooo`802NX:203oool00`000000oooo0?ooo`0_0?ooo`800000
2P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX=0?ooo`030000
002[Nil0Zg^O0180Zg^O00<0@Ug70000003oool02`3oool200WZ2PX0oooo00<02NX:0?ooo`3oool0
1@3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`000000
0`3oool400WZ2PT0oooo00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`0]0?ooo`00?`3o
ool00`000000oooo0?ooo`0:0?ooo`802NX:303oool00`000000oooo0?ooo`0]0?ooo`0300WZ2P3o
ool0oooo00D0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3o
ool0oooo00L0oooo00<000000:IfWP2VMYh04`2VMYh00`000000oooo0?ooo`0>0?ooo`802NX:203o
ool200WZ2P/0oooo00H000000?ooo`3oool02NX:0?ooo`09jPX70?ooo`<02NX:1P3oool00`09jPX0
oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01d0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00H0oooo00<000000?ooo`3oool0;`3oool00`09jPX0
oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0
oooo0?ooo`0:0?ooo`030000002[Nil0Zg^O01<0Zg^O00<0@Ug70000003oool0303oool00`09jPX0
oooo0?ooo`080?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0
oooo0?ooo`030?ooo`0400WZ2P3oool0oooo00000080oooo0`09jPX00`3oool02NX:0?ooo`070?oo
o`0300WZ2P3oool0oooo01P0oooo00<000000?ooo`3oool0;@3oool003l0oooo00<000000?ooo`3o
ool0303oool200WZ2P/0oooo00<000000?ooo`3oool0;@3oool00`09jPX0oooo0?ooo`050?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`050?ooo`03
0000002VMYh0YWJN01D0YWJN00<000000?ooo`3oool03`3oool00`09jPX0oooo0?ooo`060?ooo`80
2NX:2P3oool01@000000oooo00WZ2P3oool02NX:00H0oooo1009jPX70?ooo`0300WZ2P3oool0oooo
00<0oooo00<02NX:0?ooo`3oool07`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
00d0oooo0P09jPX70?ooo`030000003oool0oooo02h0oooo00<02NX:0?ooo`3oool02P3oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0203oool00`00
0000Zg^O0:]kW`0E0:]kW`03049Ma`000000oooo00`0oooo0P09jPX90?ooo`0300WZ2P3oool0oooo
00<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`020?ooo`0700WZ2P3oool0oooo
0?ooo`09jPX0000000WZ2P030?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPXL0?ooo`030000003o
ool0oooo02`0oooo000o0?ooo`030000003oool0oooo00h0oooo00<02NX:0?ooo`3oool02@3oool0
0`000000oooo0?ooo`0/0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool00P3oool0
0`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00@0oooo00<000000:IfWP0000005@2VMYh0
0`000000oooo0?ooo`0@0?ooo`802NX:1P3oool00`09jPX0oooo00WZ2P090?ooo`040000003oool0
2NX:00WZ2P8000000P3oool300WZ2P030?ooo`09jPX0oooo00L0oooo00<02NX:0?ooo`3oool00P3o
ool200WZ2R<0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0?0?ooo`0300WZ2P3o
ool0oooo00D0oooo00<000000?ooo`3oool0;P3oool00`09jPX0oooo0?ooo`0:0?ooo`0500WZ2P3o
ool0oooo0?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`070?ooo`030000002[Nil0Zg^O00@0Zg^O
00<000000:]kW`2[Nil03`2[Nil00`000000oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00L0oooo
00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P00000000000080oooo
00<02NX:0?ooo`3oool00P09jPX00`3oool000000?ooo`020?ooo`0300WZ2P3oool0oooo00D0oooo
00<02NX:0?ooo`3oool0703oool00`000000oooo0?ooo`0/0?ooo`00?P3oool00`000000oooo0?oo
o`0@0?ooo`802NX:2P3oool00`000000oooo0?ooo`0/0?ooo`0300WZ2P3oool0oooo00H0oooo00D0
2NX:0?ooo`3oool0oooo00WZ2P0<0?ooo`0300WZ2P3oool0oooo0080oooo00<000000:IfWP2VMYh0
0P00000E0:IfWP030000003oool0oooo0140oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`0200WZ2PL0oooo00H0000000WZ2P09jPX000000?;2WP00000200WZ2P<0oooo00<02NX:0?oo
o`3oool01P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo02<0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0@0?ooo`802NX:1@3oool00`000000oooo0?ooo`0_0?oo
o`0300WZ2P3oool0oooo00X0oooo00@02NX:0?ooo`3oool02NX:2P3oool00`09jPX0oooo0?ooo`05
0?ooo`030000002[Nil0Zg^O00D0Zg^O0P00000A0:]kW`030000003oool0oooo00d0oooo0P09jPX8
0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01@3oool0100000002NX:0000000000020?ooo`@02NX:
00@0oooo00WZ2P09jPX000000`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01h0
oooo00<000000?ooo`3oool0:`3oool003h0oooo00<000000?ooo`3oool04P3oool200WZ2PT0oooo
00<000000?ooo`3oool0;03oool00`09jPX0oooo0?ooo`050?ooo`0400WZ2P3oool0oooo00WZ2Ph0
oooo00@02NX:0?ooo`3oool000000`2VMYh010000000h[NZ00000000000D0:IfWP030000003oool0
oooo0140oooo0P09jPX30?ooo`0600WZ2P3oool000000000003oool02NX:1P3oool00`0000002NX:
0000000300WZ2P<0oooo0P09jPX90?ooo`0500WZ2P3oool0oooo0?ooo`09jPX09`3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo0180oooo00<02NX:0?ooo`3oool00`3oool00`000000
oooo0?ooo`0^0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`09jPX02`3oool00`09jPX0
oooo0?ooo`030?ooo`030000002[Nil0Zg^O00H0Zg^O00@000000>VlY`00000000003`2[Nil00`12
GLL000000?ooo`0?0?ooo`0300WZ2P3oool0oooo00800000103oool01009jPX0oooo0?ooo`09jPX4
0?ooo`030000000700002NX:008000000`09jPX30?ooo`0400WZ2P3oool0oooo00000080oooo00<0
2NX:0?ooo`3oool00`3oool200WZ2R40oooo00<000000?ooo`3oool0:`3oool003h0oooo00<00000
0?ooo`3oool0503oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo02/0oooo00<02NX:
0?ooo`3oool01P3oool00`09jPX0oooo00WZ2P0?0?ooo`0300WZ2P3oool000000080YWJN0P000003
0>:gZP8000004`2VMYh00`000000oooo0?ooo`0B0?ooo`0700WZ2P3oool0oooo00WZ2P3oool02NX:
000000020?ooo`0300WZ2P3oool0oooo0080oooo0P00000200WZ2P80l/:N00@000000?ooo`3oool0
2NX:2P3oool00`09jPX0oooo0?ooo`0200WZ2RT0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0C0?ooo`802NX:103oool00`000000oooo0?ooo`0^0?ooo`0300WZ2P3oool0oooo00/0
oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`020?ooo`030000002[Nil0Zg^O00D0
Zg^O0P0000030>VlY`030000002[Nil0Zg^O00d0Zg^O00<0@Ug70000003oool03`3oool200WZ2P03
00000009jPX0oooo00@0oooo00<02NX:0?ooo`09jPX00P3oool20000000300L00009jPX0000000<0
2NX:103oool01`09jPX0oooo0?ooo`3oool000000?ooo`09jPX01@3oool00`09jPX0oooo0?ooo`0R
0?ooo`030000003oool0oooo02X0oooo000n0?ooo`030000003oool0oooo01D0oooo0P09jPX80?oo
o`030000003oool0oooo02/0oooo00<02NX:0?ooo`3oool01P3oool200WZ2Q00oooo00H000000:If
WP2VMYh00000030dY@0000050>:gZP8000004P2VMYh00`000000oooo0?ooo`0B0?ooo`D02NX:103o
ool00`09jPX0oooo0000000200WZ2P030000003b`Yh0l/:N0080l/:N00<000000?ooo`09jPX02`3o
ool00`09jPX0oooo00WZ2P0[0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool05@3o
ool00`09jPX0oooo0?ooo`020?ooo`030000003oool0oooo02d0oooo00<02NX:0?ooo`3oool02`3o
ool200WZ2Pd0oooo00@02NX:0?ooo`3oool000001`2[Nil00`000000B4N]000000040>VlY`800000
3P2[Nil00`12GLL000000?ooo`0@0?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPX2000000801`00
00D0000000WZ2P09jPX02NX:000000040?ooo`0300WZ2P3oool0oooo0080oooo00<000000?ooo`09
jPX0103oool00`09jPX0oooo0?ooo`0T0?ooo`030000003oool0oooo02T0oooo000n0?ooo`030000
003oool0oooo01L0oooo00<02NX:0?ooo`3oool01P3oool00`000000oooo0?ooo`0Z0?ooo`0300WZ
2P3oool0oooo00H0oooo0P09jPX@0?ooo`030000002VMYh000000080<3BU00<000000>:gZP3R]jX0
1@3R]jX200000100YWJN00<000000?ooo`3oool0503oool200WZ2PD0oooo00<0000000WZ2P09jPX0
0P09jPX00`000000l/:N0?;2WP020?;2WP0300000009jPX0oooo00X0oooo00<02NX:0?ooo`09jPX0
503oool200WZ2QL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0F0?ooo`0300WZ
2P3oool0oooo0080oooo00<000000?ooo`3oool0;@3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool02NX:00d0oooo00<02NX:0?ooo`0000001P2[Nil010000000B4N]04Q7[@0000060>VlY`80
00003@2[Nil00`000000oooo0?ooo`0?0?ooo`802NX:1P3oool200WZ2P8000000`09jPX0103haiH0
2NX:0?S7UP0000020?ooo`802NX:1@3oool00`0000002NX:0?ooo`020?ooo`802NX:9`3oool00`00
0000oooo0?ooo`0Y0?ooo`00?P3oool00`000000oooo0?ooo`0H0?ooo`802NX:1`3oool00`000000
oooo0?ooo`0Z0?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPX?0?ooo`040000002VMYh0YWJN0000
00<0<3BU00<000000>:gZP3R]jX01P3R]jX00`000000YWJN0:IfWP0>0:IfWP030000003oool0oooo
01<0oooo0`09jPX20?ooo`<02NX:00D0000000WZ2P0000002NX:000000030?;2WP802NX:2`3oool3
00WZ2Q<0oooo0P09jPX2000001P0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0G
0?ooo`802NX:0`3oool00`000000oooo0?ooo`0]0?ooo`0300WZ2P3oool0oooo00P0oooo00D02NX:
0?ooo`3oool0oooo00WZ2P0=0?ooo`030000002[Nil0Zg^O00@0Zg^O00<0000004Q7[@18Ajd00P18
Ajd00`000000jKbW0>VlY`050>VlY`8000002`2[Nil00`12GLL000000?ooo`0>0?ooo`0300WZ2P3o
ool0oooo00802NX:0`3oool00`0000002NX:00WZ2P0200WZ2P8000000P09jPX20?S7UP030000003o
ool02NX:00L0oooo00D000000?ooo`3oool0oooo00WZ2P0H0?ooo`802NX:00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0X0?ooo`00?P3oool00`000000oooo0?ooo`0J0?ooo`0300WZ2P3o
ool0oooo00D0oooo00<000000?ooo`3oool0:P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3o
ool02NX:00h0oooo00<000000:IfWP000000100`=:D00`000000h[NZ0>:gZP070>:gZP8000003`2V
MYh00`000000oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo00802NX:0`0000001@09jPX0l/:N00WZ
2P3b`Yh000000080l/:N00<02NX:0?;2WP0000002`3oool00`09jPX0oooo0?ooo`0A0?ooo`802NX:
703oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01T0oooo00D02NX:0?ooo`3oool0
oooo0000000^0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0
oooo0?ooo`0:0?ooo`030000002[Nil0Zg^O00<0Zg^O00<0000004Q7[@18Ajd00`18Ajd00`000000
jKbW0>VlY`070>VlY`030000002[Nil0Zg^O00T0Zg^O00<0@Ug70000003oool03@3oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P000000000000802NX:1000000200WZ2P<0n<NF00<0000000WZ2P3o
ool01`3oool010000000oooo0?ooo`09jPXG0?ooo`802NX:00<0oooo0000000000003`3oool00`00
0000oooo0?ooo`0X0?ooo`00?P3oool00`000000oooo0?ooo`0K0?ooo`802NX:1P3oool00`000000
oooo0?ooo`0Y0?ooo`0300WZ2P3oool0oooo00@0oooo00@02NX:0?ooo`3oool02NX:303oool00`00
0000YWJN00000005030dY@040000003R]jX0h[NZ09k:mPP0h[NZ0P00000>0:IfWP030000003oool0
oooo0100oooo1009jPX40000000800WZ2P00000000000000003b`Yh000000?;2WP09jPX20?;2WP03
0000003oool0oooo00P0oooo00<02NX:0?ooo`3oool0403oool200WZ2Ql0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0J0?ooo`802NX:0P3oool00`000000oooo0?ooo`0/0?ooo`80
2NX:203oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00P0oooo00<000000:]kW`2[
Nil00`2[Nil00`000000B4N]04Q7[@0404Q7[@030000003Y_:L0jKbW00P0jKbW0P00000:0:]kW`03
049Ma`000000oooo00`0oooo00<02NX:0?ooo`3oool00P3oool300WZ2P0300000009jPX000000080
00000P09jPX40?S7UP0300WZ2P3oool0oooo00H0oooo00@02NX:0000003oool02NX:5P3oool200WZ
2QD0oooo00<000000?ooo`3oool09`3oool003d0oooo00<000000?ooo`3oool07P3oool00`09jPX0
oooo0?ooo`040?ooo`030000003oool0oooo02T0oooo00<02NX:0?ooo`3oool00P3oool01@09jPX0
oooo0?ooo`3oool02NX:00/0oooo00@000000:IfWP2VMYh000001@0`=:D00`000000h[NZ0>:gZP0;
0>:gZP800000302VMYh00`000000oooo0?ooo`0?0?ooo`802NX:1P0000000`09jPX0l/:N00000002
000000030?;2WP0000002NX:00<0l/:N00<000000?ooo`3oool01P3oool300WZ2Q00oooo0P09jPX9
0?ooo`8000005`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01d0oooo00<02NX:
0?ooo`000000;P3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:
0?ooo`3oool01`3oool00`000000Zg^O0:]kW`030:]kW`0300000018Ajd0B4N]00@0B4N]00<00000
0>VlY`3Y_:L02P3Y_:L2000000T0Zg^O00<0@Ug70000003oool02P3oool01009jPX0oooo0?ooo`3o
ool300WZ2P<0000000@02NX:00L0000000002NX:0P0000030?S7UP0300WZ2P000000oooo00H0oooo
00@02NX:0?ooo`09jPX000005@3oool200WZ2QP0oooo00<000000?ooo`3oool09P3oool003d0oooo
00<000000?ooo`3oool07`3oool200WZ2PD0oooo00<000000?ooo`3oool0:03oool00`09jPX0oooo
0?ooo`020?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0203oool00`000000YWJN
00000006030dY@030000003R]jX0h[NZ00d0h[NZ0P00000;0:IfWP030000003oool0oooo00/0oooo
0`09jPX00`0000002NX:00WZ2P040000000300WZ2P3b`Yh0l/:N0080000000<0l/:N00WZ2P000000
103b`Yh00`000000oooo0?ooo`050?ooo`0300WZ2P3oool02NX:00l0oooo0P09jPX;0?ooo`800000
5`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01h0oooo0P09jPX00`000000oooo
0?ooo`0/0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo
0?ooo`050?ooo`030000002[Nil0Zg^O00<0Zg^O00<0000004Q7[@18Ajd01@18Ajd00`000000jKbW
0>VlY`0<0>VlY`800000202[Nil00`12GLL000000?ooo`090?ooo`@02NX:0P070002000000801`00
00<02NX:00000009jPX00`0000001@3haiH02NX:00WZ2P3haiH0000000L0oooo0P09jPX00`3oool0
00000?ooo`0C0?ooo`0300WZ2P3oool0oooo00L0oooo0P00000?0?ooo`030000003oool0oooo02H0
oooo000m0?ooo`030000003oool0oooo0240oooo00<02NX:0?ooo`3oool00`3oool00`000000oooo
0?ooo`0X0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01@3oool00`09jPX0oooo0?ooo`060?ooo`03
0000002VMYh0000000L0<3BU00<000000>:gZP3R]jX03`3R]jX2000000X0YWJN00<000000?ooo`3o
ool01`3oool300WZ2P8000000`09jPX40000000300WZ2P3b`Yh0l/:N00<0l/:N00<02NX:0?;2WP00
0000103b`Yh00`000000oooo0?ooo`040?ooo`0300WZ2P3oool02NX:00h0oooo0P09jPX>0?ooo`03
00WZ2P3oool0oooo01H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`050?ooo`80
00006@3oool00`09jPX000000?ooo`0X0?ooo`050000003oool0oooo0?ooo`09jPX01`3oool00`09
jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo00<0oooo00<000000:]kW`2[Nil00`2[Nil00`00
0000B4N]04Q7[@0604Q7[@030000003Y_:L0jKbW00h0jKbW0P0000060:]kW`03049Ma`000000oooo
00L0oooo0`09jPX00`0000001`0000L0000200WZ2P8000000P07000200WZ2P050?S7UP0000000000
0?S7UP09jPX00`3haiH00`000000oooo0?ooo`040?ooo`802NX:0P3oool00`000000oooo0?ooo`0@
0?ooo`802NX:2P3oool200000100oooo00<000000?ooo`3oool09@3oool003d0oooo00<000000?oo
o`3oool0103oool2000001`0oooo0P09jPX40?ooo`030000003oool0oooo0280oooo0`0000030?oo
o`0400WZ2P3oool0oooo00WZ2PH0oooo00<02NX:0?ooo`3oool01@3oool2000000P0<3BU00<00000
0>:gZP3R]jX04@3R]jX2000000T0YWJN00<000000?ooo`3oool00`3oool600WZ2P@0000000D02NX:
000000000000000000WZ2P050?;2WP0400WZ2P3b`Yh0l/:N000000@0l/:N00<000000?ooo`3oool0
0P3oool200WZ2P80oooo00<02NX:0?ooo`3oool02P3oool200WZ2Pl0oooo00<02NX:0?ooo`3oool0
603oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00D0oooo0P00000200WZ2QP0oooo
0P09jPXX0?ooo`<000000P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00P0oooo
00<02NX:0?ooo`3oool00`3oool00`000000Zg^O0:]kW`020:]kW`0300000018Ajd0B4N]00L0B4N]
00<000000>VlY`3Y_:L0403Y_:L00`000000Zg^O0:]kW`040:]kW`03049Ma`000000oooo00@0oooo
0P09jPX00`3oool02NX:00WZ2P0300WZ2P801`000P0000000`070000000000WZ2P020?S7UP800000
00<02NX:0?S7UP3haiH00P3haiH2000000@0oooo0P09jPX30?ooo`030000003oool0oooo00h0oooo
0P09jPX<0?ooo`0300WZ2P3oool0oooo00l0oooo00<000000?ooo`3oool09@3oool003d0oooo00<0
00000?ooo`3oool0103oool20000000300WZ2P3oool0oooo01/0oooo00D02NX:0?ooo`3oool0oooo
0000000T0?ooo`030000002J4P00VQ8000<0000000<02NX:0?ooo`09jPX01`3oool00`09jPX0oooo
0?ooo`040?ooo`030000002VMYh0000000L0<3BU00<02NX:0000003R]jX0503R]jX2000000P0YWJN
00<000000?ooo`09jPX01009jPX20?ooo`<0000000@02NX:0000000000002NX:0`0000001009jPX0
l/:N0?;2WP3b`Yh200WZ2P<0l/:N0`0000020?;2WP050000003oool0oooo0?ooo`09jPX00`3oool0
0`09jPX0oooo0?ooo`090?ooo`802NX:4@3oool00`09jPX0oooo0?ooo`0H0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool02@3oool400WZ2QH0oooo00<02NX:0?ooo`3oool09@3oool0
0`00000011BE00000003000000D0oooo00<02NX:0?ooo`3oool02@3oool01@09jPX0oooo0?ooo`3o
ool0000000@0Zg^O00<0000004Q7[@18Ajd02018Ajd00`000000jKbW0>VlY`0A0>VlY`8000001@2[
Nil00`12GLL000000?ooo`0700WZ2PL01`000P00000200WZ2P80n<NF0P09jPX30?S7UP@000000`3o
ool200WZ2P@0oooo00<000000?ooo`3oool0303oool200WZ2Pd0oooo00<02NX:0?ooo`3oool04@3o
ool00`000000oooo0?ooo`0T0?ooo`00?@3oool00`000000oooo0?ooo`070?ooo`D02NX:6@3oool2
00WZ2P80oooo00<000000?ooo`3oool08@3oool2000000@0VQ800P0000000`09jPX0oooo0?ooo`06
0?ooo`0300WZ2P3oool0oooo00<0oooo0P000005030dY@8000000P0`=:D00`000000h[NZ0>:gZP0E
0>:gZP8000001P2VMYh00`0000002NX:0?ooo`040?ooo`D0000000@02NX:0000000000002NX:0`00
00030?;2WP0300WZ2P3b`Yh0l/:N00<0l/:N0`0000020?;2WP040?ooo`000000oooo00WZ2P<0oooo
00<02NX:0?ooo`3oool0203oool200WZ2Q<0oooo00<02NX:0?ooo`3oool06@3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo00d0oooo1009jPXC0?ooo`802NX:9@3oool01000000011BE
00@DU@00000209P=00@0000000<0oooo00WZ2P3oool02`3oool01009jPX0oooo0?ooo`0000030:]k
W`0300000018Ajd0B4N]00D0B4N]0P00000204Q7[@030000003Y_:L0jKbW01<0jKbW0P0000040:]k
W`04049Ma`09jPX02NX:0?ooo`8000002P0700020000000300WZ2P3haiH0n<NF00802NX:103haiH2
000000040?ooo`000000oooo0?ooo`802NX:1@3oool00`000000oooo0?ooo`0:0?ooo`802NX:3`3o
ool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo02@0oooo000m0?ooo`030000003oool0
oooo00`0oooo1009jPXG0?ooo`0400WZ2P3oool0oooo00000280oooo00<000000000P00000001@2J
4P000`09jPX0000000000002000000D0oooo00@02NX:0?ooo`3oool0oooo0P000006030dY@800000
0P0`=:D00`09jPX000000>:gZP050>:gZP0309k:mP3R]jX0h[NZ00l0h[NZ0P0000050:IfWP030000
003oool0oooo0080oooo00<000000?ooo`0000000`0000001009jPX0000000000009jPX50?;2WP03
00WZ2P3b`Yh0l/:N00@0l/:N00<000000?;2WP3b`Yh00P3b`Yh00`2TQK<0000000WZ2P040?ooo`03
00WZ2P3oool0oooo00H0oooo0P09jPXD0?ooo`0300WZ2P3oool0oooo01/0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0A0?ooo`@02NX:403oool00`0000002NX:0?ooo`0S0?ooo`05
0000000459D011BE00@DU@0000001@2H3@000`09jPX000000000000<0?ooo`0300WZ2P000000Zg^O
0080Zg^O00<0000004Q7[@18Ajd01P18Ajd2000000<0B4N]00<000000>VlY`3Y_:L0503Y_:L20000
00<0Zg^O00@0@Ug700000000000000002P07000020000000n<NF0?S7UP09jPX0n<NF00WZ2P3haiH0
2NX:1`3haiH01@000000oooo00WZ2P3oool02NX:00D0oooo00<000000?ooo`3oool0203oool200WZ
2Q40oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`0S0?ooo`00?03oool00`000000
oooo0?ooo`0A0?ooo`@02NX:503oool200WZ2P030?ooo`000000oooo0200oooo00@000000000P000
080000000`2J4P000`09jPX0VQ8009XB000309XB00<000000`3oool00`09jPX0oooo0:IfWP020000
00/0<3BU00@000000>:gZP3R]jX0h[NZ0P00000200WZ2Q<0h[NZ0P0000040:IfWP030000003oool0
000000L0000000@02NX:0000000000002NX:0`3b`Yh200WZ2PL0l/:N00<000000?;2WP3b`Yh00P3b
`Yh00`09jPX000000?ooo`030?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPXF0?ooo`0300WZ2P3o
ool0oooo01`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0E0?ooo`@02NX:3@3o
ool00`0000002NX:0?ooo`0S0?ooo`050000000459D011BE00@DU@000000102H3@000`09jPX0V0d0
09P=0003000000X0oooo00D000000:]kW`2[Nil0Zg^O0000000=04Q7[@040000003Y_:L0jKbW0>Vl
Y`8000000P09jPXA0>VlY`040000002[Nil0Zg^O049Ma`8000002P07000010000000n<NF0?S7UP3h
aiH200WZ2P80n<NF00<02NX:0?S7UP3haiH01@3haiH0100000002NX:0?ooo`09jPX60?ooo`030000
003oool0oooo00H0oooo0P09jPXC0?ooo`0300WZ2P3oool0oooo01<0oooo00<000000?ooo`3oool0
8P3oool003`0oooo00<000000?ooo`3oool05@3oool500WZ2Q40oooo00<02NX:0?ooo`0000008@3o
ool00`00000000200000000309XB000300WZ2P2J4P00VQ8000H0VQ800`000000103oool02NX:0000
0000000<030dY@040000003R]jX0h[NZ0>:gZP8000000P3R]jX300WZ2Q80h[NZ00<000000:IfWP2V
MYh00P2VMYh90000000400WZ2P000000l/:N00WZ2P80l/:N00<02NX:0?;2WP3b`Yh01`3b`Yh01000
0000l/:N0?;2WP3b`Yh3000000@0oooo00<02NX:0?ooo`3oool00`3oool200WZ2QP0oooo00<02NX:
0?ooo`3oool0703oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01T0oooo1009jPX9
0?ooo`050000003oool02NX:00WZ2P3oool00P00000O0?ooo`030000000459D011BE008011BE00D0
000009P=002H3@00V0d000WZ2P0509P=00@000001@3oool01@000000Zg^O00WZ2P2[Nil0000000h0
B4N]00@000000>VlY`3Y_:L0jKbW0P0000020>VlY`<02NX:3`3Y_:L2000000030:]kW`12GLL00000
00T01`0000<000000?S7UP3haiH00P3haiH01@09jPX0n<NF0?S7UP3haiH02NX:00D0n<NF0`000000
0`3oool02NX:0?ooo`060?ooo`030000003oool0oooo00D0oooo00<02NX:0?ooo`3oool04`3oool0
0`09jPX0oooo0?ooo`0C0?ooo`030000003oool0oooo0280oooo000l0?ooo`030000003oool0oooo
01X0oooo1009jPX90?ooo`80000000<02NX:0?ooo`3oool00P09jPX00`000000oooo0?ooo`0N0?oo
o`04000000000800002000000080VQ8000<02NX:09XB002J4P002@2J4P03000000d0<3BU00<00000
0>:gZP3R]jX01P3R]jX00`2Nb_H0h[NZ00WZ2P0300WZ2Pl0h[NZ0P0000020:IfWPT0000000H02NX:
0?;2WP3b`Yh02NX:0?;2WP09jPX:0?;2WP040000003b`Yh0l/:N0?;2WP<000000`3oool00`09jPX0
oooo0?ooo`020?ooo`802NX:6@3oool00`09jPX0oooo0?ooo`0N0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool07@3oool400WZ2PH0oooo00@000000?ooo`3oool02NX:0P0000000`09
jPX0oooo0?ooo`0L0?ooo`030000000459D011BE00<011BE00<0000009P=0009jPX02P2H3@030000
00030?ooo`000000Zg^O0080Zg^O00<0000004Q7[@18Ajd03@18Ajd00`000000jKbW0>VlY`080>Vl
Y`@02NX:3@3Y_:L200000003049Ma`0000001`0000H01`0000<0000000WZ2P3haiH00P3haiH200WZ
2P<0n<NF00<02NX:0?S7UP3haiH00`3haiH3000000030?ooo`09jPX0oooo00H0oooo00<000000?oo
o`3oool00`3oool200WZ2QD0oooo00<02NX:0?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?oo
o`00?03oool00`000000oooo0?ooo`0N0?ooo`@02NX:1@3oool2000000070?ooo`09jPX02NX:00WZ
2P3oool02NX:0000000O0?ooo`0600000000080000200000P00000002NX:3@2J4P000`000000<3BU
030dY@0<030dY@030000003R]jX0h[NZ00`0h[NZ1009jPX=0>:gZP80000000<0YWJN000000000000
1@0000000`3b`Yh02NX:0?;2WP0300WZ2P/0l/:N00@000000?;2WP3b`Yh0l/:N0`0000020?ooo`04
00WZ2P3oool0oooo0?ooo`802NX:6`3oool200WZ2R00oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0Q0?ooo`@02NX:0`3oool00`000000oooo0?ooo`0200WZ2P030?ooo`09jPX02NX:
01`0oooo00<0000000@DU@0459D0100459D00`0000002NX:09P=000<09P=008000000P2[Nil00`00
0000B4N]04Q7[@0>04Q7[@030000003Y_:L0jKbW00`0jKbW0`09jPX<0>VlY`<000001@0700001000
0000n<NF0?S7UP3haiH200WZ2P050?S7UP09jPX0n<NF0?S7UP09jPX0203haiH00`0000002NX:0?oo
o`080?ooo`030000003oool0oooo00802NX:5`3oool00`09jPX0oooo0?ooo`0E0?ooo`030000003o
ool0oooo0240oooo000l0?ooo`030000003oool0oooo0280oooo1@09jPX00`3oool02NX:0?ooo`03
0?ooo`@02NX:7P3oool00`00000000200000P0020000P00300WZ2P2J4P00VQ8000X0VQ800P00000>
030dY@030000003R]jX0h[NZ0100h[NZ0`09jPX<0>:gZPL000000P3b`Yh01009jPX0l/:N00WZ2P09
jPX<0?;2WP040000003b`Yh0l/:N0?;2WP<000000P3oool01009jPX0oooo00WZ2P09jPXM0?ooo`03
00WZ2P3oool0oooo01l0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0U0?ooo`@0
2NX:00D000000?ooo`3oool0oooo00WZ2P020?ooo`<02NX:6@3oool00`00000011BE00@DU@0500@D
U@0300WZ2P2H3@00V0d000/0V0d000@000000:]kW`2[Nil000004@18Ajd00`000000jKbW0>VlY`0?
0>VlY`@02NX:2P3Y_:L2000000<01`0000D000000?S7UP3haiH0n<NF00WZ2P030?S7UP0400WZ2P3h
aiH0n<NF00WZ2PL0n<NF0P00000:0?ooo`0300000009jPX02NX:01T0oooo00<02NX:0?ooo`3oool0
5P3oool00`000000oooo0?ooo`0P0?ooo`00?03oool00`000000oooo0?ooo`0W0?ooo`@02NX:103o
ool300WZ2Qd0oooo00<000000000P00008000P0008000`09jPX0000009XB000:09XB00030000000`
=:D0<3BU00d0<3BU00<000000>:gZP3R]jX0203R]jX00`2Nb_H0h[NZ0>:gZP080>:gZP@02NX:2P3R
]jX4000000<0l/:N0`09jPX=0?;2WP040000003b`Yh0000000000080l/:N00<000000?ooo`09jPX0
0P09jPXO0?ooo`0300WZ2P3oool0oooo0200oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0Y0?ooo`L02NX:0`3oool200WZ2QL0oooo00<0000000@DU@0459D0100459D00`09jPX011BE
0000000<09P=00030000002[Nil000000180B4N]00<000000>VlY`3Y_:L04`3Y_:L300WZ2PP0jKbW
0P0000000`07000000000?S7UP020?S7UP0300WZ2P3haiH0n<NF0080n<NF00@02NX:0?S7UP3haiH0
2NX:1@3haiH4000000T0oooo00<02NX:0000003oool06P3oool00`09jPX0oooo0?ooo`0G0?ooo`03
0000003oool0oooo01l0oooo000l0?ooo`030000003oool0oooo02/0oooo1@09jPX20?ooo`802NX:
6`3oool01`00000000200000P00008002NX:0000P00000002P2J4P000`000000<3BU030dY@0>030d
Y@030000003R]jX0h[NZ01L0h[NZ1009jPX80>:gZP@0000000@0l/:N00WZ2P3b`Yh02NX:3@3b`Yh0
10000000l/:N0000000000020?;2WP0300000009jPX02NX:0200oooo00<02NX:0?ooo`3oool08@3o
ool200000300oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0400WZ2P<0oooo0P09
jPXF0?ooo`030000000459D011BE00<011BE0P09jPX00`0459D0000009P=000909P=00030000002[
Nil0000001<0B4N]00<000000>VlY`3Y_:L05P3Y_:L300WZ2PL0jKbW100000000`09jPX0n<NF00WZ
2P030?S7UP0400WZ2P3haiH0n<NF00WZ2PD0n<NF0P0000000`3haiH000000?ooo`060?ooo`802NX:
00<0oooo0000003oool06P3oool00`09jPX0oooo0?ooo`0G0?ooo`030000003oool0oooo01l0oooo
000l0?ooo`030000003oool0oooo01H0oooo0P00000H0?ooo`L02NX:603oool01@00000000200000
P00008002NX:0080002000<0000009XB002J4P001P2J4P0200000140<3BU00<000000>:gZP3R]jX0
6P3R]jX300WZ2PD0h[NZ0P0l02801P000000/XJV00000009jPX0000000WZ2P<000002P3b`Yh00`00
0000l/:N0?;2WP020?;2WP<02NX:8@3oool00`09jPX0oooo0?ooo`0N0?ooo`<0000000<0oooo0000
003oool0;`3oool00`000000oooo0?ooo`0C0?ooo`0300000009jPX02NX:01H0oooo00<000000?oo
o`3oool00P3oool500WZ2P040?ooo`09jPX02NX:00WZ2Q<0oooo00<0000000@DU@0459D00`0459D0
1@09jPX011BE00@DU@0459D0000000T0V0d000<000000:]kW`0000005018Ajd00`000000jKbW0>Vl
Y`0H0>VlY`@02NX:0`3Y_:L204l0<`L0000000D02NX:0?S7UP3haiH0n<NF00WZ2P080?S7UP030000
003oool0oooo00<0oooo0P09jPX30?ooo`030000003oool0oooo01P0oooo00<02NX:0?ooo`3oool0
5`3oool300000200oooo000k0?ooo`030000003oool0oooo01L0oooo00<0000000WZ2P09jPX06`3o
ool500WZ2QL0oooo00@000000000P00008002NX:0`0008000`000000VQ8009XB000509XB00030000
000`=:D0<3BU0100<3BU00<000000>:gZP3R]jX02@3R]jX00`2Nb_H0h[NZ0>:gZP0A0>:gZP@02NX:
00@0h[NZ03`08P0l0280?00R0P0000000`09jPX0/XJV00WZ2P030;:6YPH00000103b`Yh00`000000
l/:N0?;2WP0200WZ2P030?;2WP000000oooo0240oooo00<02NX:0?ooo`3oool06`3oool3000000@0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?ooo`80000000<0oooo00WZ2P09
jPX05@3oool00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00H02NX:4@3oool00`000000
11BE00@DU@0300@DU@0300WZ2P0459D011BE008011BE00<0000009P=002H3@001@2H3@000`000000
Zg^O0000000E04Q7[@030000003Y_:L0jKbW01`0jKbW0`09jPX404l0<`8000000`2gRZH01P09jPX0
00000000000000002NX:000000L0n<NF00@000000?ooo`3oool0oooo0P09jPX50?ooo`030000003o
ool0oooo01P0oooo00<02NX:0?ooo`3oool0503oool300000080oooo00<000000?ooo`3oool07P3o
ool003/0oooo00<000000?ooo`3oool06P3oool200WZ2QX0oooo00@000000?ooo`09jPX0oooo1@09
jPXB0?ooo`04000000000800002000WZ2P@0002000<0000009XB002J4P000`2J4P000`000000<3BU
030dY@08030dY@800000100`=:D200000004030dY@0000000000000000D02NX:1@3R]jX00`2Nb_H0
h[NZ0>:gZP0D0>:gZP@02NX:0P0l02800`09jPX0000000WZ2P090;:6YPL000000`3b`Yh00`000000
oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo01P0oooo0`0000070?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool06@3oool200WZ2Q<0oooo00<000000?ooo`3oool0103oool00`09jPX0
oooo0?ooo`030?ooo`@02NX:3`3oool00`00000011BE00@DU@0200@DU@0300WZ2P0459D011BE00@0
11BE00<0000009P=002H3@00102H3@02000000`0B4N]0P00000504Q7[@80000000@0B4N]00000000
000000001P09jPX40>VlY`030000003Y_:L0jKbW0140jKbW00<0C`0c00WZ2P09jPX00P09jPX204l0
<`80000000<0]hZV00WZ2P2gRZH00P2gRZH00`09jPX0]hZV00000005000000050?S7UP000000oooo
0?ooo`09jPX01`3oool00`000000oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo0140oooo0`000005
0?ooo`030000003oool0oooo01h0oooo000k0?ooo`030000003oool0oooo0180oooo0P0000080?oo
o`0300WZ2P3oool0oooo01P0oooo00@000000?ooo`09jPX02NX:0P3oool600WZ2Ph0oooo00<00000
0000P009jPX01@0008000`000000VQ8009XB000209XB00030000000`=:D0<3BU00T0<3BU0P000004
030dY@0300000009jPX0<3BU00<000001@3R]jX<00WZ2Pl0h[NZ1@0l028300WZ2P0303`08P09jPX0
/XJV00/0/XJV00@02NX:0000002bQZH0/XJV1P00000P0?ooo`0300WZ2P3oool0oooo01D0oooo0`00
000:0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool05@3oool20000000400WZ2P3o
ool0oooo0?ooo`802NX:4P3oool00`000000oooo0?ooo`040?ooo`802NX:1`3oool400WZ2P/0oooo
0P00000300@DU@0300WZ2P0459D011BE00D011BE00<0000009P=002H3@000P2H3@02000000d0B4N]
0P00000504Q7[@80000000@0B4N]00000000000000001P3Y_:L>00WZ2PT0jKbW1P1?03<300WZ2P03
04l0<`0000002NX:00<0]hZV00<02NX:0;N:YP2gRZH01@2gRZH6000000H0oooo00<000000?ooo`3o
ool0603oool00`09jPX0oooo0?ooo`0>0?ooo`<00000203oool00`000000oooo0?ooo`0N0?ooo`00
>`3oool00`000000oooo0?ooo`0B0?ooo`80000000<02NX:0?ooo`3oool01P3oool200WZ2QP0oooo
00D000000?ooo`3oool0oooo00WZ2P030?ooo`<02NX:00<0oooo00WZ2P09jPX00`09jPX90?ooo`03
0000000008002NX:00H0002000D0000009XB002J4P00VQ800000000B030dY@030000000`=:D00000
00d0h[NZ00<0iLjo0>:gZP3R]jX00`3R]jX=00WZ2P030>:gZP0l0280?00R00H0?00R0`09jPX20000
00P0/XJV0P09jPX00`2bQZH000000;:6YP070;:6YPH000006@3oool00`09jPX0oooo0?ooo`0C0?oo
o`<000003@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01D0oooo0P0000000`3o
ool02NX:00WZ2P030?ooo`802NX:4@3oool00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo
00L0oooo1@09jPX70?ooo`0300@DU@00000011BE008011BE00<02NX:00@DU@0459D01@0459D0102d
T[<0000000WZ2P2H3@02000001P0B4N]00<000000>VlY`3Y_:L02`3Y_:L200WZ2PL0jKbW3`09jPX3
04l0<`<02NX:0P0000000`2gRZH02NX:0;N:YP060;N:YP802NX:102gRZH5000000030?ooo`000000
oooo01P0oooo00<02NX:0?ooo`3oool0303oool3000000`0oooo00<000000?ooo`3oool07@3oool0
03/0oooo00<000000?ooo`3oool05@3oool200WZ2PP0oooo0P09jPXG0?ooo`040000003oool0oooo
0?ooo`802NX:103oool200WZ2P@0oooo1009jPX50?ooo`030000000008002NX:00L0002000<00000
09XB000000004`0`=:D00`09jPX0<3BU0000000>0>:gZP030?ooo`3R]jX0h[NZ00l0h[NZ3009jPX2
03`08P040000002bQZH0000000000080/XJV0P09jPX30;:6YP030000002bQZH0/XJV00`0/XJV1`00
000B0?ooo`0300WZ2P3oool0oooo0100oooo0`00000A0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool06P3oool200WZ2P<0oooo0P09jPX@0?ooo`030000003oool0oooo00D0oooo0P09
jPX90?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX40?ooo`050000000459D011BE00@DU@09jPX0
1P0459D400WZ2P0309P=00000000B4N]01P0B4N]00<000000>VlY`3Y_:L0703Y_:L704l0<`h02NX:
00<0]hZV00WZ2P09jPX02`2gRZH6000001D0oooo00<02NX:0?ooo`3oool02@3oool3000000l0oooo
00<000000?ooo`3oool07@3oool003/0oooo00<000000?ooo`3oool05`3oool300WZ2PL0oooo0P09
jPXF0?ooo`030000003oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool300WZ2PD0oooo1@09
jPX0100000002NX:000000000802000000@000200`00000E030dY@030000003R]jX0h[NZ01d0h[NZ
2P0l02800`09jPX0?00R03`08P0400WZ2P8000000P09jPX50;:6YP030000002bQZH0/XJV01<0/XJV
1P00000<0?ooo`0300WZ2P3oool0oooo00d0oooo0`00000D0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0703oool200WZ2P<0oooo0P09jPX?0?ooo`030000003oool0oooo00H0oooo
00<02NX:0?ooo`3oool0203oool300WZ2P80oooo1009jPX30000000400WZ2P0459D00000000000D0
11BE00<0]9:c00WZ2P0000000P00000I04Q7[@030000003Y_:L0jKbW01/0jKbW4@1?03<01009jPX0
00000;N:YP2gRZH700WZ2P800000202gRZH010000000]hZV0;N:YP2gRZH6000000l0oooo00<02NX:
0?ooo`3oool01@3oool400000180oooo00<000000?ooo`3oool07@3oool003/0oooo00<000000?oo
o`3oool06P3oool200WZ2PL0oooo0P09jPXE0?ooo`030000003oool0oooo0080oooo0P09jPX60?oo
o`802NX:203oool200WZ2P0400000000080000000000008000200P000000102bB400000000WZ2P09
jPXB030dY@0300WZ2P0`=:D0000001l0h[NZ2P0l02800`09jPX0?00R03`08P0503`08P030000002b
QZH0/XJV00H0/XJV00<000000;:6YP2bQZH0602bQZH7000000D0oooo00<02NX:0?ooo`3oool02P3o
ool3000001L0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0N0?ooo`802NX:0`3o
ool200WZ2Ph0oooo00<000000?ooo`3oool01P3oool200WZ2P/0oooo0P09jPX40?ooo`0500WZ2P00
0000000000WZ2P0459D00P00000400@DU@<0000000<0]DPk00000009jPX06@18Ajd00`000000jKbW
0>VlY`0=0>VlY`0300WZ2P3Y_:L0jKbW00X0jKbW4P1?03<01009jPX0C`0c0000000000070;N:YP80
0000202gRZH00`000000]hZV0;N:YP070;N:YPD000002P3oool00`09jPX0oooo0?ooo`020?ooo`<0
00005P3oool00`000000oooo0?ooo`0M0?ooo`00>P3oool00`000000oooo0?ooo`0M0?ooo`802NX:
1`3oool200WZ2Q@0oooo00<000000?ooo`3oool00`3oool00`09jPX0oooo0?ooo`050?ooo`802NX:
1`3oool00`09jPX000200000P0020000P0800000102bB4000`000000<3BU030dY@0A030dY@0300WZ
2P0`=:D000000100h[NZ00<0fkfk0>:gZP3R]jX02`3R]jX;03`08P0300WZ2P0l0280?00R00H0?00R
0P0000060;:6YP030000002bQZH0/XJV01l0/XJV0`0000020?ooo`0300WZ2P3oool0oooo00L0oooo
0`00000J0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0803oool200WZ2P<0oooo
0P09jPX=0?ooo`030000003oool0oooo00L0oooo00<02NX:0?ooo`3oool02P3oool200WZ2P80oooo
0P0000000`0459D02NX:00@DU@0400@DU@@000000`2eB3/00`000000B4N]04Q7[@0G04Q7[@030000
003Y_:L0jKbW01T0jKbW4`1?03<01009jPX0C`0c04l0<`1?03<2000000l0]hZV00<000000;N:YP2g
RZH0302gRZH6000000<0oooo00<02NX:0?ooo`3oool00`00000I0?ooo`030000003oool0oooo01d0
oooo000j0?ooo`030000003oool0oooo01l0oooo0`09jPX60?ooo`802NX:4`3oool00`000000oooo
0?ooo`030?ooo`802NX:1`3oool300WZ2P@0oooo00<02NX:0000P00000000P0000060;98@0030;2>
/`000000<3BU01@0<3BU00<000000>:gZP3R]jX03P3R]jX00`3K_K/0h[NZ0>:gZP090>:gZP`0?00R
00<02NX:03`08P0l0280200l0282000000@0/XJV00<000000;:6YP2bQZH08@2bQZH00`000000oooo
00WZ2P070?ooo`<000007@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0280oooo
0P09jPX30?ooo`802NX:303oool00`000000oooo0?ooo`070?ooo`802NX:303oool300WZ2P030000
000459D02NX:00<011BE100000060;E8>`0300000018Ajd02NX:01L0B4N]00<000000>VlY`3Y_:L0
3@3Y_:L00`09jPX0jKbW0>VlY`070>VlYa<0C`0c00<02NX:04l0<`1?03<0101?03<2000000d0]hZV
00<000000;N:YP2gRZH04P2gRZH6000001`0oooo00<000000?ooo`3oool07@3oool003X0oooo00<0
00000?ooo`3oool08P3oool200WZ2PH0oooo0P09jPXB0?ooo`030000003oool0oooo00@0oooo0P09
jPX80?ooo`802NX:00<0oooo00WZ2P0000000`0000080;98@0030;2>/`0000002NX:00H0<3BU0P00
000B00WZ2QD0h[NZ3@0l02800`09jPX0000003`08P0:03`08P8000000P2bQZH00`000000/XJV0;:6
YP0P0;:6YP040000003oool0oooo00WZ2P@0oooo0`00000P0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0903oool200WZ2P<0oooo0P09jPX:0?ooo`030000003oool0oooo00T0oooo
00<02NX:0?ooo`3oool02`3oool0100459D02NX:00WZ2P09jPX3000000030:9kZ0000000]DPk00P0
]DPk00<0000000WZ2P18Ajd03@18Ajd2000001402NX:1`3Y_:L00`09jPX0jKbW0>VlY`060>VlY`l0
C`0c0P00000204l0<`0300WZ2P1?03<0C`0c00H0C`0c0P00000;0;N:YP030000002gRZH0]hZV01@0
]hZV00<0000000WZ2P3oool07@3oool00`000000oooo0?ooo`0M0?ooo`00>P3oool00`000000oooo
0?ooo`0B0?ooo`800000403oool200WZ2PH0oooo0P09jPXA0?ooo`030000003oool0oooo00D0oooo
00<02NX:0?ooo`3oool01`3oool200WZ2P8000002P2bB4020;2>/`030000000`=:D0<3BU00@0<3BU
0P000009030dY@0300WZ2P0`=:D0000000H0h[NZ7@09jPX503`08P0300WZ2P000000?00R0080?00R
0P00000603`08P8000000P2bQZH00`000000/XJV0;:6YP0O0;:6YP060000003oool0oooo0?ooo`09
jPX0oooo0`00000S0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool03`3oool00`00
00002NX:00WZ2P0D0?ooo`802NX:0`3oool200WZ2PT0oooo00<000000?ooo`3oool02@3oool200WZ
2P`0oooo0`0000001009jPX0XW^X00000000000;0;E8>`0300000009jPX0B4N]00`0B4N]0P000007
04Q7[@030000003Y_:L0jKbW00L0jKbW7009jPX304l0<`8000000P1?03<00`09jPX0000000000007
04l0<`8000002P2gRZH00`000000]hZV0;N:YP0C0;N:YP0300000009jPX0oooo01l0oooo00<00000
0?ooo`3oool0703oool003X0oooo00<000000?ooo`3oool04P3oool00`0000002NX:00WZ2P0A0?oo
o`<02NX:1@3oool200WZ2Q00oooo00<000000?ooo`3oool01@3oool200WZ2PD0oooo1000000=0;98
@00300WZ2P0`=:D000000180<3BU00<000000>:gZP3R]jX0403R]jX00`3K_K/0h[NZ0>:gZP050>:g
ZPT0?00R2P09jPX2000000@0?00R0P0000001@2__><000000;:6YP2bQZH0000001l0/XJV0P000003
0?ooo`0300000009jPX0000002H0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0?
0?ooo`80000000<0oooo00WZ2P3oool0503oool200WZ2P<0oooo0P09jPX80?ooo`030000003oool0
oooo00X0oooo00<02NX:0?ooo`3oool0203oool20000000400WZ2P2RNjP00000000000d0]DPk00<0
2NX:00000018Ajd05@18Ajd00`000000jKbW0>VlY`0E0>VlY`h0C`0c2009jPX2000000D0C`0c0P00
00000`2d`><000000;N:YP090;N:YP030000002gRZH0]hZV0180]hZV00<000000?ooo`09jPX0803o
ool00`000000oooo0?ooo`0L0?ooo`00>P3oool00`000000oooo0?ooo`0E0?ooo`0300WZ2P3oool0
oooo0140oooo0P09jPX50?ooo`802NX:3`3oool00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0
oooo00<0000000<0W7FV0;98@02bB4003P2bB4000`09jPX000000000000A030dY@030000003R]jX0
h[NZ01L0h[NZ3`0l02800`09jPX0?00R03`08P0603`08P8000000`2__><010000000/XJV0;:6YP00
000N0;:6YP0300WZ2P000000000000<0000000<02NX:0?ooo`3oool09P3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo01<0oooo00<02NX:0?ooo`3oool0503oool200WZ2P<0oooo0P09
jPX70?ooo`030000003oool0oooo00X0oooo0P09jPX50?ooo`<000000`2RNjP00`000000]DPk0;E8
>`0?0;E8>`8000005018Ajd00`000000jKbW0>VlY`0@0>VlY`0400WZ2P3Y_:L0jKbW0>VlYaH0C`0c
00<02NX:04l0<`1?03<00`1?03<2000000<0]<3S00<000000;N:YP2gRZH0202gRZH00`000000]hZV
0;N:YP0B0;N:YP0400000009jPX00000000001l0oooo00<000000?ooo`3oool0703oool003X0oooo
00<000000?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0B0?ooo`802NX:1@3oool200WZ2Ph0oooo
00<000000?ooo`3oool01P3oool30000000309aeYP2bB400/TQ00100/TQ000@0/8jc00WZ2P000000
2NX:400`=:D00`000000h[NZ0>:gZP0A0>:gZP030=^m^`3R]jX0h[NZ0080h[NZ400l02800`09jPX0
?00R03`08P0403`08P8000001@2__><010000000/XJV0;:6YP00000L0;:6YP802NX:00<0/XJV0000
000000000`3oool00`09jPX0oooo0?ooo`0V0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0503oool00`09jPX0oooo0?ooo`0E0?ooo`802NX:0`3oool200WZ2PH0oooo00<000000?oo
o`3oool02`3oool00`09jPX0oooo0?ooo`02000000@0XW^X0P00000B0;E8>`0300WZ2P000000B4N]
01<0B4N]00<000000>VlY`3Y_:L04@3Y_:L00`09jPX0jKbW0>VlY`0F04l0<`0400WZ2P1?03<0C`0c
04l0<`8000001@2d`><00`000000]hZV0;N:YP080;N:YP030000002gRZH0]hZV0140]hZV0P09jPX0
0`3oool000000000000O0?ooo`030000003oool0oooo01`0oooo000j0?ooo`030000003oool0oooo
01L0oooo00<02NX:0?ooo`3oool04`3oool200WZ2PD0oooo0P09jPX=0?ooo`030000003oool0oooo
00<0oooo0`00000209aeYQ@0/TQ000<02NX:0;2>/`0000001P0`=:D2000000P0<3BU00<000000>:g
ZP3R]jX05@3R]jXA03`08P0300WZ2P0l0280?00R0080?00R0P0000070:nlh`040000002bQZH0/XJV
000001X0/XJV0P09jPX20;:6YP030000003oool0oooo00<0oooo00<02NX:0?ooo`3oool09P3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01H0oooo0P09jPXG0?ooo`802NX:0`3oool2
00WZ2PD0oooo00<000000?ooo`3oool02`3oool2000000@0XW^X0P00000F0;E8>`0300000018Ajd0
B4N]00D0B4N]0P00000:04Q7[@030000003Y_:L0jKbW0140jKbW00<02NX:0>VlY`1?03<05P1?03<0
1009jPX0C`0c0000000000070;C0h`030000002gRZH0]hZV00T0]hZV00<000000;N:YP2gRZH03P2g
RZH200WZ2P80oooo00<02NX:0?ooo`3oool07`3oool00`000000oooo0?ooo`0L0?ooo`00>@3oool0
0`000000oooo0?ooo`0I0?ooo`802NX:5@3oool300WZ2P@0oooo0P09jPX<0?ooo`030000003oool0
oooo008000000`2LMJHF0;98@00400WZ2P2`S[<0/8jc000000D0<3BU0P000008030dY@030000003R
]jX0h[NZ01@0h[NZ4P0l02800`09jPX0?00R03`08P02000000X0[kcS00<000000;:6YP000000602b
QZH200WZ2P<0/XJV00<02NX:00000009jPX0103oool00`09jPX0oooo0?ooo`0W0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0603oool00`09jPX0oooo0?ooo`0F0?ooo`802NX:0`3o
ool200WZ2P@0oooo00<000000?ooo`3oool01`3oool3000000D0XW^X00<000000;E8>`2eB3/05`2e
B3/00`000000B4N]04Q7[@0404Q7[@8000002P18Ajd00`000000jKbW0>VlY`0B0>VlYaP0C`0c00<0
2NX:0000002d`><0202d`><00`000000]hZV0;N:YP090;N:YP030000002gRZH0]hZV00`0]hZV0P09
jPX01@000000oooo0?ooo`3oool02NX:0240oooo00<000000?ooo`3oool0703oool003T0oooo00<0
00000?ooo`3oool06`3oool00`09jPX0oooo0?ooo`0E0?ooo`802NX:103oool200WZ2PX0oooo0`00
000309aeYQT0/TQ00`2`S[<01@000000<3BU030dY@0`=:D02NX:00X0<3BU00<0000000WZ2P3R]jX0
4`3R]jXC03`08P0300WZ2P000000000000`0[kcS00<000000;:6YP0000000`2bQZH200000140/XJV
0P09jPX50;:6YP030000003oool0oooo00D02NX::@3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo01T0oooo00<02NX:0?ooo`3oool05`3oool200WZ2P<0oooo0P09jPX30?ooo`030000
003oool0oooo00@0oooo0P0000060:9kZ08000006`2eB3/00`0000002NX:04Q7[@0304Q7[@0300WZ
2P18Ajd0B4N]00T0B4N]00<000000>VlY`3Y_:L04@3Y_:LG04l0<`80000000<02NX:0;C0h`2d`><0
202d`><00`000000]hZV0;N:YP02000000L0]hZV00<000000;N:YP2gRZH02P2gRZH200WZ2P040;N:
YP09jPX0000000WZ2P80oooo00<02NX:0?ooo`3oool07`3oool00`000000oooo0?ooo`0L0?ooo`00
>@3oool00`000000oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo01H0oooo0P09jPX40?ooo`802NX:
1P3oool3000000<0W7FV6`2bB4030;2>/`04030dY@000000<3BU00WZ2PT0<3BU00@02NX:030dY@0`
=:D00000503R]jXC03`08P0300WZ2P2__><0[kcS00`0[kcS00<000000;:6YP0000000`2bQZH20000
00l0/XJV0P09jPX60;:6YP030000003oool0oooo00@0oooo1@09jPXV0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool06P3oool00`09jPX0oooo0?ooo`0H0?ooo`802NX:0`3oool200WZ
2P80oooo00<000000?ooo`3oool00`0000060:9kZ08000007P2eB3/01@000000B4N]04Q7[@18Ajd0
2NX:00d0B4N]00<000000>VlY`3Y_:L0403Y_:LE04l0<`8000000P2d`><00`09jPX0]<3S0;C0h`08
0;C0h`030000002gRZH0]hZV008000001`2gRZH00`000000]hZV0;N:YP080;N:YP802NX:0`2gRZH0
0`000000oooo0?ooo`0400WZ2R40oooo00<000000?ooo`3oool06`3oool003T0oooo00<000000?oo
o`3oool07@3oool00`09jPX0oooo0?ooo`0G0?ooo`<02NX:0`3oool200WZ2P80oooo0P00000409ae
YQh0/TQ00`2`S[<00`0`=:D0000000WZ2P09030dY@040000000`=:D0<3BU000001<0h[NZ4P0l0282
0000000300WZ2P2__><0[kcS00`0[kcS00<000000;:6YP0000004P2bQZH200WZ2PL0/XJV00<00000
0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`020?ooo`@02NX:8P3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo01/0oooo00<02NX:0?ooo`3oool06@3oool200WZ2P<0oooo0P09jPX0
0`3oool00000000000080:9kZ0030000002eB3/0]DPk01`0]DPk00@02NX:0;E8>`2eB3/000000P18
Ajd00`09jPX0B4N]04Q7[@0;04Q7[@030000003Y_:L0jKbW00l0jKbW501?03<2000000@0]<3S00<0
2NX:0;C0h`2d`><0202d`><00`000000]hZV0;N:YP090;N:YP030000002gRZH0]hZV00H0]hZV0P09
jPX40;N:YP030000003oool0oooo0080oooo00<02NX:0?ooo`3oool01009jPXM0?ooo`030000003o
ool0oooo01/0oooo000i0?ooo`030000003oool0oooo01h0oooo0P09jPXJ0?ooo`802NX:0P3oool3
000000D0W7FV7`2bB4040;2>/`0300WZ2P000000<3BU00/0<3BU00<000000>:gZP3R]jX0403R]jX5
03`08P8000002P0l028200000080[kcS00<02NX:0:nlh`2__><0302__><00`000000/XJV0000000@
0;:6YP802NX:2@2bQZH00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00H0oooo1009jPXN
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0703oool200WZ2Q/0oooo0P09jPX0
103oool02NX:0000000000080:9kZ08000008`2eB3/00`0000002NX:04Q7[@0=04Q7[@030000003Y
_:L0jKbW00h0jKbW1`1?03<2000000X0C`0c0P0000060;C0h`0300WZ2P2d`><0]<3S00P0]<3S00<0
00000;N:YP2gRZH02@2gRZH00`000000]hZV0;N:YP040;N:YP802NX:1P2gRZH00`000000oooo0?oo
o`020?ooo`0300WZ2P3oool0oooo00@0oooo1009jPXI0?ooo`030000003oool0oooo01/0oooo000i
0?ooo`030000003oool0oooo0200oooo00<02NX:0?ooo`3oool06@3oool3000000D0W7FV8P2bB402
0;2>/`0300WZ2P2`S[<0000000`0<3BU00<000000>:gZP3R]jX03@3R]jX00`09jPX0000003`08P05
03`08P800000200l0282000000@0[kcS00<02NX:0:nlh`2__><0302__><00`000000/XJV0000000>
0;:6YP802NX:2P2bQZH00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00X0oooo0`09jPXK
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool07P3oool00`09jPX0oooo0?ooo`0I
0?ooo`<00000202RNjP2000002H0]DPk0P09jPX=04Q7[@030000003Y_:L0jKbW00d0jKbW201?03<2
000000P0C`0c0P0000080;C0h`0300WZ2P2d`><0]<3S00P0]<3S00<000000;N:YP2gRZH02@2gRZH0
0`000000]hZV0;N:YP020;N:YP802NX:1`2gRZH00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0
oooo00P0oooo0`09jPXF0?ooo`030000003oool0oooo01/0oooo000i0?ooo`030000003oool0oooo
0240oooo00<02NX:0?ooo`3oool05P3oool2000000H0W7FV902bB40700WZ2PL0<3BU00@02NX:030d
Y@0`=:D00000403R]jX?03`08P8000001P2__><00`09jPX0[kcS0:nlh`0<0:nlh`030000002bQZH0
000000d0/XJV00<02NX:0;:6YP2bQZH02@2bQZH00`000000oooo0?ooo`070?ooo`0300WZ2P3oool0
oooo00d0oooo1009jPXG0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool07`3oool0
0`09jPX0oooo0?ooo`0F0?ooo`8000002P2RNjP00`000000]DPk0;E8>`0S0;E8>`0500WZ2P2eB3/0
2NX:0;E8>`0000003@18Ajd00`000000jKbW0>VlY`0=0>VlYa40C`0c00<000000;C0h`2d`><01`2d
`><00`09jPX0]<3S0;C0h`090;C0h`030000002gRZH0]hZV00T0]hZV00D000000;N:YP2gRZH0]hZV
00WZ2P080;N:YP030000003oool0oooo00@0oooo00<02NX:0?ooo`3oool02`3oool400WZ2Q80oooo
00<000000?ooo`3oool06`3oool003P0oooo00<000000?ooo`3oool08`3oool00`09jPX0oooo0?oo
o`0B0?ooo`<00000102LMJH00`000000W7FV09aeYP0V0;98@0D02NX:00<00000030dY@0`=:D0200`
=:D00`000000h[NZ0>:gZP0<0>:gZP030000000l0280?00R00`0?00R0P0000080:nlh`0300WZ2P2_
_><0[kcS00`0[kcS00<000000;:6YP0000002`2bQZH200WZ2P`0/XJV00<000000?ooo`3oool01P3o
ool00`09jPX0oooo0?ooo`0B0?ooo`@02NX:4`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo0200oooo00<02NX:0?ooo`3oool04`3oool2000000/0XW^X0`00000U0;E8>`0600WZ2P2e
B3/0]DPk0;E8>`0000002NX:2`18Ajd00`000000jKbW0>VlY`0<0>VlYa00C`0c0P00000:0;C0h`03
00WZ2P2d`><0]<3S00T0]<3S0P00000:0;N:YP040000002gRZH02NX:00WZ2PT0]hZV00<000000?oo
o`3oool00`3oool00`09jPX0oooo0?ooo`0@0?ooo`@02NX:3P3oool00`000000oooo0?ooo`0K0?oo
o`00>03oool00`000000oooo0?ooo`0T0?ooo`0300WZ2P3oool0oooo00l0oooo0`00000609aeYP<0
00009@2bB40200WZ2P@0/8jc00<0<3BU00000009jPX01@0`=:D01@09jPX0<3BU030dY@0000002NX:
00d0h[NZ00<0000003`08P0l02802P0l0282000000X0[kcS00<02NX:0:nlh`2__><0302__><00`00
0000/XJV000000090;:6YP802NX:3@2bQZH00`000000oooo0?ooo`070?ooo`0300WZ2P3oool0oooo
01H0oooo1009jPX00`3oool000000000000<0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool08@3oool200WZ2Q00oooo0`00000=0:9kZ0030000002S]>D0XkCU00@000008@2eB3/200WZ
2P<0]DPk00<0000000WZ2P18Ajd02@18Ajd00`000000jKbW0>VlY`0;0>VlY`l0C`0c0P00000<0;C0
h`0300WZ2P2d`><0]<3S00T0]<3S0P00000:0;N:YP802NX:2P2gRZH00`000000oooo0?ooo`040?oo
o`0300WZ2P3oool0oooo01@0oooo1009jPX;0?ooo`030000003oool0oooo01X0oooo000h0?ooo`03
0000003oool0oooo02D0oooo0P09jPX=0?ooo`8000002@2LMJH20000000300WZ2P000000000000<0
00007`2bB4000`09jPX0/TQ00;98@0050;2>/`0300WZ2P000000<3BU00@0<3BU00D02NX:030dY@0`
=:D0000000WZ2P0<0>:gZP030000000l0280?00R00T0?00R0P00000<0:nlh`0300WZ2P2__><0[kcS
00<0[kcS0P0000080:nlh`8000001`2bQZH200WZ2Ph0/XJV00<000000?ooo`3oool0203oool00`09
jPX0oooo0?ooo`0J0?ooo`0300WZ2P000000000000`0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo00/0oooo0P00000@0:9kZ0050?SGZ00000000000
00000009jPX00P2S]>D4000001`0]DPk00<02NX:0;E8>`2eB3/0102eB3/00`000000B4N]04Q7[@08
04Q7[@030000003Y_:L0jKbW00X0jKbW3P1?03<2000000h0]<3S00@02NX:0;C0h`2d`><0]<3S0P00
00060;C0h`800000202gRZH200WZ2P030;N:YP000000]hZV00P0]hZV00<000000?ooo`3oool01@3o
ool00`09jPX0oooo0?ooo`0H0?ooo`802NX:00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0J0?ooo`00>03oool00`000000oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo00L0oooo0`00000;
09aeYP8000000P2M/ND300WZ2PD000005@2bB402000000@0/TQ000D02NX:0;98@02bB400/TQ00;2>
/`0400WZ2P80000000<02NX:030dY@0`=:D01@0`=:D00`000000h[NZ0>:gZP090>:gZP030000000l
0280?00R00P0?00R0P00000>0:nlh`0300WZ2P2__><0[kcS00<0[kcS0P0000060:nlh`0400000009
jPX00000000000D0/XJV0P09jPX?0;:6YP030000003oool0oooo00T0oooo00<02NX:0?ooo`3oool0
:@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02@0oooo00<02NX:0?ooo`3oool0
203oool2000001<0XW^X0`000000102S]>D02NX:00WZ2P09jPX30:>di@@000005`2eB3/2000000L0
]DPk00<0000000WZ2P18Ajd02018Ajd00`000000jKbW0>VlY`080>VlY`030000001?03<0C`0c00X0
C`0c0P00000@0;C0h`0400WZ2P2d`><0]<3S0;C0h`8000001@2d`><3000000H0]hZV0P09jPX30;N:
YP030000002gRZH0]hZV00L0]hZV00<000000?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0I0?oo
o`800000203oool00`000000oooo0?ooo`0J0?ooo`00>03oool00`000000oooo0?ooo`0X0?ooo`03
00WZ2P3oool0oooo00@0oooo0`00000=09aeYP8000001@2M/ND300WZ2P0309fai@3bdJl0000000<0
00004@2bB402000000<0/TQ000<02NX:0;98@02bB4000P2bB4001009jPX0/8jc00000037KF<200WZ
2P8000001`0`=:D00`000000h[NZ0>:gZP080>:gZP030000000l0280?00R00L0?00R0P00000@0:nl
h`0300WZ2P2__><0[kcS00/0[kcS00@02NX:00000000000000000`2bQZH200WZ2Q40/XJV00<00000
0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0V0?ooo`8000000`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02D0oooo00<02NX:0?ooo`3oool0103oool3000000l0XW^X0P000004
0:9kZ0030000002S]>D0XkCU00@0XkCU0`09jPX40:>di@@000004`2eB3/2000000P0]DPk00<00000
04Q7[@18Ajd01`18Ajd00`000000jKbW0>VlY`070>VlY`0300WZ2P000000C`0c00T0C`0c0P00000B
0;C0h`0300WZ2P2d`><0]<3S00P0]<3S00<0000000WZ2P000000102gRZH200WZ2PD0]hZV00<00000
0;N:YP2gRZH01P2gRZH00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo02@0oooo00<00000
0?ooo`3oool06P3oool003P0oooo00<000000?ooo`3oool0:@3oool00`09jPX0oooo0?ooo`020?oo
o`030000002LMJH0W7FV00h0W7FV0`00000709fai@<02NX:0P2M/ND00`3bdJl00000000000030000
00h0/TQ00`09jPX60;98@00300000009jPX02NX:00<02NX:00<00000030dY@0`=:D01@0`=:D00`00
0000h[NZ0>:gZP070>:gZP030000000l0280?00R00H0?00R0P00000B0:nlh`0300WZ2P2__><0[kcS
00X0[kcS00<02NX:0:nlh`2__><00P0000000`2bQZH02NX:00WZ2P0B0;:6YP030000003oool0oooo
00T0oooo00<02NX:0?ooo`3oool09@3oool200WZ2P050000003oool0oooo0?ooo`000000:`3oool0
0`000000oooo0?ooo`0V0?ooo`0300WZ2P3oool02NX:0080oooo0P00000A0:9kZ0800000102RNjP0
0`3hejP000000:>di@070:>di@<02NX:1@2S]>D4000000h0]DPk00@02NX:0;E8>`2eB3/02NX:0P2e
B3/00`09jPX0]DPk0;E8>`030;E8>`0300000018Ajd0B4N]00H0B4N]00<000000>VlY`3Y_:L01`3Y
_:L00`000000C`0c04l0<`0704l0<`800000502d`><00`09jPX0]<3S0;C0h`080;C0h`0300WZ2P00
000000000080]hZV0P09jPX70;N:YP030000002gRZH0]hZV00D0]hZV00<000000?ooo`3oool01P3o
ool00`09jPX0oooo0?ooo`0O0?ooo`802NX:00@000000?ooo`3oool00000703oool003P0oooo00<0
00000?ooo`3oool0:P3oool200WZ2P80oooo00<0000009aeYP2LMJH03@2LMJH01009jPX0W7FV09ae
YP00000:09fai@<02NX:0`2M/ND00`3bdJl0000000000003000000`0/TQ000<02NX:0;98@02bB400
102bB4000`09jPX0afeS0<M]H`020<M]H`802NX:00<00000030dY@0`=:D0100`=:D00`000000h[NZ
0>:gZP060>:gZP030000000l0280?00R00D0?00R0P00000D0:nlh`0300WZ2P2__><0[kcS0080[kcS
00@02NX:0:nlh`09jPX000000`2__><01@09jPX0[kcS0:nlh`2__><0000000802NX:4`2bQZH00`00
0000oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo0280oooo0`09jPX60?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool09`3oool200WZ2P@0oooo00<000000:9kZ02RNjP03@2RNjP00`09
jPX0XW^X0:9kZ0050:9kZ0030000002S]>D0XkCU00T0XkCU0`09jPX60:>di@@000002P2eB3/01009
jPX0]DPk0;E8>`2eB3/300WZ2PH0]DPk00<0000004Q7[@18Ajd01@18Ajd00`000000jKbW0>VlY`05
0>VlY`800000201?03<2000001H0]<3S00@02NX:0;C0h`2d`><000001P2d`><01009jPX0]<3S0000
0000000200WZ2PT0]hZV00<000000;N:YP2gRZH0102gRZH00`000000oooo0?ooo`070?ooo`0300WZ
2P3oool0oooo01`0oooo0`09jPX00`3oool00000000000020?ooo`030000003oool0oooo01X0oooo
000g0?ooo`030000003oool0oooo02d0oooo00@02NX:0?ooo`3oool000003P2LMJH01009jPX0W7FV
09aeYP00000=09fai@<02NX:102M/ND00`3bdJl0000000000003000000L0/TQ000@02NX:0;98@009
jPX02NX:1@2bB40300WZ2P050<M]H`09jPX0afeS00WZ2P0000001@0`=:D00`000000h[NZ0>:gZP05
0>:gZP030000000l0280?00R00@0?00R0P00000;0:nlh`800000202__><300WZ2PT0[kcS00<02NX:
0:nlh`2__><00P2__><00`09jPX000000;:6YP0B0;:6YP030000003oool0oooo00/0oooo00<02NX:
0?ooo`3oool07`3oool300WZ2PT0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Z
0?ooo`0300WZ2P3oool0oooo0080oooo00<000000:9kZ02RNjP0302RNjP00`09jPX0XW^X0:9kZ005
0:9kZ0030000002S]>D0XkCU00`0XkCU0`09jPX70:>di@@000001@2eB3/00`09jPX0]DPk0;E8>`04
0;E8>`802NX:1P2eB3/00`0000002NX:04Q7[@0404Q7[@030000003Y_:L0jKbW00D0jKbW00<00000
04l0<`1?03<01@1?03<2000000X0]<3S0P00000:0;C0h`<02NX:00<0]<3S00WZ2P2d`><01@2d`><0
1@09jPX0]<3S0;C0h`2d`><02NX:00/0]hZV00<000000;N:YP2gRZH0102gRZH00`000000oooo0?oo
o`070?ooo`0300WZ2P3oool0oooo01X0oooo0P09jPX80?ooo`030000003oool0oooo01X0oooo000g
0?ooo`030000003oool0oooo02h0oooo00@02NX:0?ooo`3oool000003@2LMJH01@09jPX0W7FV09ae
YP2LMJH0000000l0WK7U0`09jPX409fai@030?;A[`2cb^/0000000D0000000<0/TQ000WZ2P2bB400
0`2bB40200WZ2P@0/TQ00P37KF<400WZ2P03030dY@000000<3BU00<0<3BU00<000000>:gZP3R]jX0
103R]jX00`000000?00R03`08P0403`08P030000002__><0[kcS00/0[kcS0P0000060:nlh`0400WZ
2P2__><0[kcS00WZ2PP0[kcS00<0000000WZ2P2__><0102__><2000001<0/XJV00<000000?ooo`3o
ool02P3oool00`09jPX0oooo0?ooo`0M0?ooo`<02NX:303oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02/0oooo0P09jPX30?ooo`030000002RNjP0XW^X00/0XW^X00<02NX:0:9kZ02R
NjP01@2RNjP00`3hejP000000:>di@0?0:>di@@02NX:1`2S]>D40000000300WZ2P2eB3/0]DPk00L0
]DPk00<02NX:0;E8>`2eB3/0102eB3/00`000000B4N]04Q7[@0304Q7[@030000003Y_:L0jKbW00@0
jKbW00<0000004l0<`1?03<0101?03<2000000`0]<3S0P0000050;C0h`0300WZ2P2d`><02NX:00@0
]<3S00<02NX:0;C0h`2d`><01@2d`><00`09jPX0]<3S0;C0h`020;C0h`030000002gRZH0]hZV00T0
]hZV00<000000;N:YP2gRZH00`2gRZH00`000000oooo0?ooo`070?ooo`0300WZ2P3oool0oooo01P0
oooo0`09jPX;0?ooo`030000003oool0oooo01T0oooo000g0?ooo`030000003oool0oooo02l0oooo
00D02NX:0?ooo`3oool0000000WZ2P0:09aeYP0300WZ2P2LMJH0W7FV0080W7FV00<0000009fai@2M
/ND0402M/ND300WZ2PD0WK7U0P2`S[<00`09jPX0000000000003000000@0/TQ00P09jPX20;98@0<0
afeS1009jPX00`0`=:D00000030dY@02030dY@030000003R]jX0h[NZ00@0h[NZ00<0000003`08P0l
02800P0l028200000100[kcS0P09jPX70:nlh`0300WZ2P2__><0[kcS00H0[kcS00<02NX:0000002_
_><0102__><200000180/XJV00<000000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0J0?ooo`<0
2NX:3`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02d0oooo00D02NX:0?ooo`3o
ool02NX:0000000;0:9kZ00300WZ2P2RNjP0XW^X00L0XW^X00<000000:>di@2S]>D04@2S]>D300WZ
2PT0XkCU100000060;E8>`<02NX:1@2eB3/00`000000B4N]04Q7[@0204Q7[@030000003Y_:L0jKbW
00<0jKbW00<0000004l0<`1?03<00`1?03<2000000l0]<3S00<02NX:0;C0h`2d`><02P2d`><00`09
jPX0]<3S0;C0h`030;C0h`0300000009jPX0]<3S00@0]<3S00<000000;N:YP2gRZH02@2gRZH00`00
0000]hZV0;N:YP020;N:YP030000003oool0oooo00P0oooo00<02NX:0?ooo`3oool05@3oool300WZ
2Ph0oooo00<000000?ooo`3oool06@3oool003L0oooo00<000000?ooo`3oool0;`3oool300WZ2P03
0?ooo`000000W7FV00P0W7FV0P00000509aeYP030000002M/ND0WK7U0180WK7U1@09jPX409fai@03
00WZ2P2`S[<02NX:00D000000P2bB40200WZ2P030;98@037KF<02NX:0080afeS0P09jPX00`37KF<0
000000WZ2P02030dY@030000003R]jX0h[NZ00<0h[NZ00@0000003`08P0l0280?00R0P00000=0:nl
h`0300WZ2P2__><02NX:00/0[kcS00<02NX:0:nlh`2__><01@2__><00`09jPX0[kcS0:nlh`050:nl
h`8000004@2bQZH00`000000oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo01P0oooo0P09jPXB0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0;@3oool300WZ2P80oooo00<000000:9k
Z02RNjP01`2RNjP2000000T0XW^X00<000000:>di@2S]>D0502S]>D400WZ2P@0XkCU00<02NX:0:>d
i@2S]>D00P2S]>D4000000D0]DPk00<02NX:0;E8>`2eB3/00`2eB3/01@000000B4N]04Q7[@18Ajd0
000000D0jKbW00@0000004l0<`1?03<0C`0c0P00000@0;C0h`0300WZ2P2d`><0]<3S00/0]<3S00<0
2NX:0;C0h`2d`><00`2d`><00`09jPX000000;C0h`040;C0h`030000002gRZH0]hZV00T0]hZV00<0
00000;N:YP2gRZH00P2gRZH00`000000oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01<0oooo0P09
jPXA0?ooo`030000003oool0oooo01T0oooo000g0?ooo`030000003oool0oooo02`0oooo0`09jPX3
0?ooo`0300WZ2P3oool0000000P0W7FV0P00000509aeYP030000002M/ND0WK7U01L0WK7U00@02NX:
0000000000002NX:102M/ND30<M]H`D000000P09jPX40<M]H`<02NX:00@00000030dY@0`=:D00000
103R]jX00`000000?00R03`08P02000000P0[kcS00<000000:nlh`09jPX00P09jPX>0:nlh`800000
00<02NX:0:nlh`2__><0102__><00`09jPX0[kcS0:nlh`070:nlh`030000002bQZH0/XJV00l0/XJV
00<000000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0F0?ooo`<02NX:503oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo02X0oooo0`09jPX20?ooo`802NX:0P3oool00`000000XW^X
0:9kZ0060:9kZ08000002@2RNjP00`3hejP000000:>di@0H0:>di@0400WZ2P000000000000WZ2PT0
XkCU100000001009jPX0]DPk00WZ2P09jPX40;E8>`0400000018Ajd0B4N]000000@0jKbW00<00000
04l0<`1?03<00P00000:0;C0h`<02NX:3P2d`><2000000<0]<3S00<02NX:0;C0h`2d`><00P2d`><0
0`09jPX0]<3S0;C0h`050;C0h`030000002gRZH0]hZV00X0]hZV00@000000;N:YP2gRZH000002P3o
ool00`09jPX0oooo0?ooo`0A0?ooo`<02NX:4`3oool00`000000oooo0?ooo`0I0?ooo`00=`3oool0
0`000000oooo0?ooo`0Y0?ooo`<02NX:1`3oool00`09jPX0oooo0000000709aeYP0300WZ2P2LMJH0
W7FV00D0W7FV00<0000009fai@2M/ND05`2M/ND2000000T0WK7U0P37KF<00`09jPX0000000000002
00WZ2P80000000<0afeS00WZ2P09jPX00P09jPX010000000<3BU030dY@0000020>:gZP040000000l
02800000000000T0[kcS00<02NX:0:nlh`2__><04@2__><20000000300WZ2P2__><0[kcS00<0[kcS
00<02NX:0:nlh`2__><0202__><00`000000/XJV0;:6YP0>0;:6YP030000003oool0oooo00`0oooo
00<02NX:0?ooo`3oool04`3oool300WZ2QL0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0W0?ooo`<02NX:1`3oool01009jPX0oooo0?ooo`0000070:9kZ00300WZ2P2RNjP0XW^X00T0
XW^X00<000000:>di@2S]>D0602S]>D20000000300WZ2P2S]>D0XkCU00/0XkCU1000000200WZ2P<0
]DPk00@0000004Q7[@18Ajd000000P3Y_:L010000000C`0c0000000000070;C0h`@02NX:4P2d`><2
00000080]<3S00<02NX:0;C0h`2d`><00P2d`><00`09jPX0]<3S0;C0h`060;C0h`030000002gRZH0
]hZV00X0]hZV00<000000;N:YP0000002`3oool00`09jPX0oooo0?ooo`0?0?ooo`802NX:5P3oool0
0`000000oooo0?ooo`0I0?ooo`00=`3oool00`000000oooo0?ooo`0W0?ooo`802NX:2`3oool00`09
jPX0oooo0000000509aeYP0300WZ2P2LMJH0W7FV00H0W7FV00<0000009fai@2M/ND0602M/ND00`09
jPX0WK7U09fai@0;09fai@<0afeS0P09jPX400000080afeS00D00000030dY@000000h[NZ00WZ2P02
00000240[kcS00<02NX:0:nlh`2__><00P2__><00`09jPX0[kcS0:nlh`090:nlh`030000002bQZH0
/XJV00d0/XJV00<000000?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0@0?ooo`<02NX:6P3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02@0oooo0`09jPX;0?ooo`802NX:00<0oooo
0000002RNjP01@2RNjP00`09jPX0XW^X0:9kZ0090:9kZ0030000002S]>D0XkCU01T0XkCU00<02NX:
0:>di@2S]>D0402S]>D20000000800WZ2P000000]DPk0;E8>`000000B4N]00000009jPX3000000<0
]<3S00<000000;C0h`2d`><07@2d`><01@09jPX0]<3S0;C0h`2d`><02NX:00T0]<3S00<000000;N:
YP2gRZH02P2gRZH00`000000]hZV0000000;0?ooo`0300WZ2P3oool0oooo00`0oooo0`09jPXH0?oo
o`030000003oool0oooo01T0oooo000g0?ooo`030000003oool0oooo02@0oooo0`09jPX>0?ooo`80
2NX:00<0000009aeYP2LMJH00P2LMJH00`09jPX0W7FV09aeYP0609aeYP030000002M/ND0WK7U01L0
WK7U00<02NX:09fai@2M/ND0302M/ND00`0000002NX:00WZ2P0400WZ2P030<M]H`000000000000H0
00008`2__><01@09jPX0[kcS0:nlh`2__><02NX:00`0[kcS00<000000;:6YP2bQZH0302bQZH00`00
0000oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo00h0oooo0P09jPXM0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool08@3oool300WZ2Q00oooo00<02NX:0?ooo`000000102RNjP00`09
jPX0XW^X0:9kZ00:0:9kZ0030?SGZ0000000XkCU01P0XkCU00<02NX:0:>di@2S]>D0502S]>D200WZ
2PH000009@2d`><01009jPX0]<3S0;C0h`09jPX:0;C0h`030000002gRZH0]hZV00X0]hZV0P00000<
0?ooo`0300WZ2P3oool0oooo00X0oooo0P09jPXL0?ooo`030000003oool0oooo01P0oooo000f0?oo
o`030000003oool0oooo0280oooo0`09jPXC0?ooo`0300WZ2P000000W7FV0080W7FV00<02NX:09ae
YP2LMJH01`2LMJH00`000000WK7U09fai@0E09fai@0300WZ2P2M/ND0WK7U00`0WK7U0P09jPX01000
0000afeS00WZ2P37KF<700WZ2P8000000P09jPX00`000000[kcS0:nlh`0<0:nlh`8000004P2__><0
1009jPX0[kcS0:nlh`09jPX=0:nlh`030000002bQZH0/XJV00`0/XJV00<000000?ooo`3oool03@3o
ool00`09jPX0oooo0?ooo`0<0?ooo`<02NX:803oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo01h0oooo0`09jPXD0?ooo`0300WZ2P3oool0000000<0XW^X00<02NX:0:9kZ02RNjP02`2R
NjP00`000000XkCU0:>di@0G0:>di@0300WZ2P2S]>D0XkCU00X0XkCU0P09jPX:0:>di@802NX:0P00
00000`2d`><000000000000>0;C0h`800000502d`><00`09jPX0]<3S00WZ2P0;0;C0h`030000002g
RZH0]hZV00X0]hZV00<000000?ooo`3oool02P3oool00`09jPX0oooo0?ooo`080?ooo`<02NX:7P3o
ool00`000000oooo0?ooo`0H0?ooo`00=P3oool00`000000oooo0?ooo`0O0?ooo`<02NX:5`3oool0
1009jPX0000009aeYP09jPX:09aeYP030000002M/ND0WK7U01@0WK7U00<02NX:09fai@2M/ND03@2M
/ND20<M]H`802NX:1@37KF<300WZ2P<000000P09jPX00`000000[kcS0:nlh`0<0:nlh`8000004P2_
_><00`09jPX0[kcS00WZ2P0>0:nlh`030000002bQZH0/XJV00X0/XJV0P0000000`09jPX0oooo0?oo
o`0=0?ooo`0300WZ2P3oool0oooo00T0oooo0`09jPXS0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool06`3oool300WZ2QP0oooo0P09jPX010000000XW^X0:9kZ009jPX=0:9kZ0030000
002S]>D0XkCU01H0XkCU00<02NX:0:>di@2S]>D06@2S]>D01@09jPX000000<]VC`09jPX0000000D0
]<3S00<000000;C0h`2d`><01P2d`><2000001@0]<3S0P09jPX<0;C0h`030000002gRZH0]hZV00T0
]hZV0P00000<0?ooo`0300WZ2P3oool0oooo00D0oooo0`09jPXQ0?ooo`030000003oool0oooo01P0
oooo000f0?ooo`030000003oool0oooo01d0oooo0P09jPXK0?ooo`0300WZ2P0000002NX:00/0W7FV
00<0000009fai@2M/ND04`2M/ND00`09jPX0WK7U09fai@0<09fai@<0afeS00@02NX:0<M]H`09jPX0
2NX:0`37KF<400WZ2P0400000015E;h0000000WZ2P80000000<0afIF0:nlh`2__><02`2__><00`09
jPX0[kcS0:nlh`090:nlh`8000001@2__><200WZ2Pl0[kcS00<000000;:6YP2bQZH02P2bQZH01000
0000cETZ00000009jPX>0?ooo`0300WZ2P3oool0oooo00H0oooo0`09jPXV0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0603oool300WZ2Qd0oooo00<02NX:00000009jPX03P2RNjP0
0`3hejP000000:>di@0E0:>di@0300WZ2P2S]>D0XkCU01P0XkCU0P0o04D0100000002NX:00WZ2P3;
ITl2000000030<]VC`2d`><0]<3S00D0]<3S00@02NX:0;C0h`09jPX02NX:0P2d`><00`09jPX0]<3S
0;C0h`090;C0h`8000001`2d`><00`09jPX0]<3S0;C0h`0;0;C0h`030000002gRZH0]hZV00T0]hZV
0P00000<0?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPXT0?ooo`030000003oool0oooo01P0oooo
000f0?ooo`030000003oool0oooo01X0oooo0`09jPXL0?ooo`l02NX:00<0000000WZ2P2M/ND04P2M
/ND00`09jPX0WK7U09fai@0<09fai@<0afeS00<02NX:0<M]H`37KF<00P37KF<300WZ2P80000000D0
9P0b00000009jPX02NX:04ED_P03000000D0afIF2@2__><00`09jPX0[kcS0:nlh`090:nlh`800000
1@2__><00`09jPX0[kcS0:nlh`0>0:nlh`030000002bQZH0/XJV00T0/XJV00D000000<eI:P3=FBX0
cETZ00WZ2P0>0?ooo`0300WZ2P3oool0oooo00<0oooo0`09jPXY0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool05@3oool300WZ2R40oooo4@09jPX00`000000XkCU0:>di@0D0:>di@03
00WZ2P2S]>D0XkCU00T0XkCU00<02NX:0:>di@2S]>D02`2S]>D203l0A@050000003Ta[T0F6;205QR
`P09jPX00P0000040<]VC`T0]<3S0P09jPX20;C0h`802NX:1`2d`><2000000H0]<3S0P09jPX=0;C0
h`030000002gRZH0]hZV00P0]hZV00<0000000WZ2P000000303oool00`09jPX0oooo0?ooo`0300WZ
2RH0oooo00<000000?ooo`3oool0603oool003H0oooo0`00000A0?ooobP02NX:0P3oool00`09jPX0
cfA00000000;09aeYP030000002M/ND0WK7U0100WK7U00<02NX:09fai@2M/ND0302M/ND30<M]H`03
00WZ2P37KF<0afeS00@0afeS00@02NX:0000000V03809P0b0P0000020=k0^`802NX:00<0000000WZ
2P37IUH02037IUH20:nlh`0400WZ2P2__><0[kcS00WZ2Q40[kcS0P09jPX@0:nlh`030000002bQZH0
/XJV00T0/XJV00H000000<eI:P3=FBX0cETZ00WZ2P00000<0?ooo`0300WZ2P3oool0oooo0080oooo
0P09jPX/0?ooo`030000003oool0oooo02L0oooo00@000000?ooo`00000000004@3ooolY00WZ2P03
0000002RNjP0XW^X00`0XW^X00<000000:>di@2S]>D04`2S]>D00`09jPX0XkCU0:>di@0F0:>di@@0
?`1500<000000>C6^@1HH/800P1HH/8200WZ2PL0bfI?1`2d`><00`09jPX0]<3S0;C0h`030;C0h`04
00WZ2P2d`><0]<3S00WZ2PT0]<3S00<02NX:0;C0h`09jPX03@2d`><00`000000]hZV0;N:YP070;N:
YP80000000<02NX:0000003oool02P3oool01009jPX0oooo00WZ2P09jPXY0?ooo`030000003oool0
oooo01P0oooo000f0?ooo`<000004@09jPX30?ooo`<02NX:8`3oool01@09jPX0oooo0?ooo`3?I400
000000X0W7FV00<0000009fai@2M/ND03`2M/ND00`09jPX0WK7U09fai@0;09fai@H02NX:0`37KF<2
00WZ2P8000000P0V0382000000<0g/2k0P15E;h00`09jPX000000<MVEP0;0<MVEP@02NX:3`2__><0
0`09jPX0[kcS00WZ2P0@0:nlh`8000002@2bQZH00`000000cETZ0<eI:P020<eI:P0300WZ2P3=FBX0
000000/0oooo00<02NX:0?ooo`09jPX00P09jPX^0?ooo`030000003oool0oooo02L0oooo00@00000
0?ooo`00000000004`09jPXU0?ooo`0400WZ2P3oool0oooo000000d0XW^X00<0n=NX0000002S]>D0
4`2S]>D00`09jPX0XkCU0:>di@080:>di@0300WZ2P2S]>D0XkCU00T0XkCU1@0o04D010000000i<Ji
0>C6^@3Ta[T305QR`P0300000009jPX02NX:00T0bfI?0`2d`><00`09jPX0]<3S0;C0h`0;0;C0h`05
00WZ2P2d`><000000;C0h`09jPX00P2d`><00`09jPX0]<3S0;C0h`0;0;C0h`030000002gRZH0]hZV
00L0]hZV00@000000?ooo`00000000002P3oool300WZ2R/0oooo00<000000?ooo`3oool0603oool0
03H0oooo00<000000?ooo`3oool04P3oool200WZ2RH0oooo00H02NX:0?ooo`3oool0oooo0<mT@000
000:09aeYP030000002M/ND0WK7U00h0WK7U00<02NX:09fai@2M/ND02`2M/ND00`09jPX0afeS0<M]
H`0700WZ2P030000000V03809P0b00809P0b00<000000=k0^`3N`;/00P3N`;/304ED_P802NX:3037
IUH00`09jPX0afIF00WZ2P020:nlh`0300WZ2P2__><0[kcS00T0[kcS00@02NX:0:nlh`2__><02NX:
402__><2000000P0/XJV00<000000<eI:P3=FBX00`3=FBX01009jPX0cETZ0<eI:P0000090?ooo`<0
2NX:<@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00/0oooo1009jPXZ0?ooo`05
00WZ2P3oool0oooo00WZ2P0000003@2RNjP00`000000XkCU0:>di@0A0:>di@0300WZ2P2S]>D0XkCU
01@0XkCU1@0o04D00`000000i<Ji0>C6^@020>C6^@@0F6;200<000000<]VC`09jPX02`3;ITl00`09
jPX0]<3S0;C0h`0>0;C0h`0700WZ2P2d`><0]<3S0;C0h`09jPX0]<3S00WZ2P0;0;C0h`030000002g
RZH0]hZV00H0]hZV00H000000<aB603<DQP0oooo00WZ2P0000070?ooo`802NX:00<0oooo00WZ2P3o
ool0;03oool00`000000oooo0?ooo`0G0?ooo`00=@3oool00`000000oooo0?ooo`0@0?ooo`<02NX:
:03oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P000000W7FV00P0W7FV00<0000009fai@2M/ND0
3@2M/ND00`09jPX0WK7U09fai@0:09fai@0300WZ2P0000002NX:00<02NX:1037KF<2000000@09P0b
00<000000=k0^`3N`;/00`3N`;/504ED_P802NX:2P37IUH00`09jPX0afIF0<MVEP030<MVEP80[kcS
00<02NX:0:nlh`2__><01@2__><01@09jPX0[kcS0:nlh`2__><02NX:0100[kcS0P0000080;:6YP03
0000003=FBX0cETZ00@0cETZ00@02NX:0<eI:P3=FBX000001@3oool300WZ2P030?ooo`09jPX0oooo
0340oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`090?ooo`<02NX:;P3oool300WZ
2P040?ooo`09jPX0000000WZ2P/0XW^X00<000000:>di@2S]>D0402S]>D00`09jPX0XkCU0:>di@0C
0:>di@L0?`1500<000000>C6^@3Ta[T00P3Ta[T505QR`P040000003;ITl02NX:00WZ2PT0bfI?00<0
2NX:0<]VC`3;ITl03@2d`><00`09jPX0]<3S0;C0h`020;C0h`0300WZ2P2d`><0]<3S00<0]<3S00<0
2NX:0;C0h`2d`><01@2d`><2000000H0]hZV00<000000<aB603<DQP00P3<DQP00`09jPX000000?oo
o`040?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`0[0?ooo`030000003oool0oooo01L0oooo000e
0?ooo`030000003oool0oooo00d0oooo0`09jPXZ0?ooo`0300WZ2P3oool0oooo00<02NX:00<0oooo
00WZ2P000000202LMJH00`000000WK7U09fai@0<09fai@0300WZ2P2M/ND0WK7U00X0WK7U1009jPX3
00000080afeS0P00000502H0<P8000001@3N`;/00`15E;h02NX:04ED_P0204ED_P0400000037IUH0
2NX:00WZ2PP0afIF00<02NX:0<MVEP37IUH01`37IUH50:nlh`0300WZ2P2__><0[kcS0080[kcS00<0
2NX:0:nlh`2__><03P2__><2000000L0/XJV00<000000<eI:P3=FBX01@3=FBX00`09jPX0cETZ0<eI
:P02000000040?ooo`09jPX02NX:00WZ2P<0oooo00<02NX:0?ooo`3oool0<@3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo00H0oooo0`09jPX^0?ooo`<02NX:103oool200WZ2P030000
0009jPX0XW^X00T0XW^X00<0n=NX0000002S]>D0402S]>D00`09jPX0XkCU0:>di@070:>di@0300WZ
2P2S]>D0XkCU00L0XkCU200o04D00`000000i<Ji0>C6^@030>C6^@H0F6;200<000000<]VC`09jPX0
0P09jPX70<]VC`0300WZ2P3;ITl0bfI?00<0bfI?2@2d`><00`09jPX0]<3S0;C0h`030;C0h`0300WZ
2P2d`><0]<3S00P0]<3S00<000000;C0h`2d`><00P0000060;N:YP030000003<DQP0c58H0080c58H
00@02NX:000000000000oooo0`09jPX40?ooo`0300WZ2P3oool0oooo02`0oooo00<000000?ooo`3o
ool05`3oool003D0oooo00<000000?ooo`3oool02`3oool200WZ2Rd0oooo0`09jPX00`3oool02NX:
00WZ2P0200WZ2P030<mT@00000002NX:00L0W7FV00<0000009fai@2M/ND02`2M/ND00`09jPX0WK7U
09fai@0909fai@0400WZ2P2a^Ml0/KWO0;6ig`802NX:00@0/KWO0<M]H`00000000001P0V03820000
00L0g/2k0P15E;h20000000404ED_P0000002NX:0<MVEP802NX:1P37IUH00`09jPX0afIF0<MVEP0:
0<MVEP040:nlh`09jPX0000000000080[kcS00<02NX:0:nlh`2__><03@2__><4000000H0/XJV00<0
00000<eI:P3=FBX01P3=FBX00`09jPX0cETZ0<eI:P03000000H0oooo00<02NX:0?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00<0oooo0`09jPX^0?ooo`<02NX:0P3o
ool00`09jPX0oooo0?ooo`0400WZ2P030?ooo`0000002NX:00X0XW^X00<000000:>di@2S]>D03P2S
]>D00`09jPX0XkCU0:>di@070:>di@0300WZ2P2S]>D0XkCU00L0XkCU200o04D00`000000i<Ji0>C6
^@040>C6^@<0F6;20P0000000`1HH/80000000WZ2P030<]VC`802NX:103;ITl00`09jPX0bfI?0<]V
C`080<]VC`<0]<3S00<0000000WZ2P2d`><0102d`><00`09jPX0]<3S0;C0h`0<0;C0h`8000001@2g
RZH00`000000c58H0<aB60030<aB600400WZ2P0000000000000000L0oooo00<02NX:0?ooo`3oool0
;03oool00`000000oooo0?ooo`0G0?ooo`00=@3oool00`000000oooo0?ooo`080?ooo`<02NX:;03o
ool700WZ2P@0oooo00@02NX:0000002LMJH02NX:1P2LMJH00`000000WK7U09fai@0:09fai@0300WZ
2P2M/ND0WK7U00X0WK7U00L0/KWO00WZ2P2a^Ml0/KWO00WZ2P2a^Ml02NX:008000001`0V03800`00
0000g/2k0=k0^`060=k0^`0400WZ2P15E;h0000000000080AEBn00D000000<MVEP37IUH0afIF00WZ
2P050<MVEP0300WZ2P37IUH0afIF0080afIF0P0000060<MVEP0400WZ2P0000000000000000<02NX:
302__><300000080[kcS0P0000050;:6YP030000003=FBX0cETZ00L0cETZ00<02NX:0<eI:P3=FBX0
0`3=FBX00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0340oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0300WZ2Rh0oooo0`09jPX50?ooo`<02NX:0`3oool01@09jPX0oooo
0?ooo`0000002NX:00T0XW^X00<000000:>di@2S]>D03P2S]>D00`09jPX0XkCU0:>di@050:>di@03
00WZ2P2S]>D0XkCU00L0XkCU2P0o04D00`000000i<Ji0>C6^@040>C6^@<0F6;20P0000000`1HH/80
2NX:000000050<]VC`0300WZ2P3;ITl0bfI?00@02NX:2P3;ITl00`0000002NX:000000050;C0h`03
00WZ2P2d`><0]<3S00`0]<3S0P0000040;N:YP030000003<DQP0c58H00<0c58H100000000`3oool0
00000?ooo`050?ooo`0300WZ2P3oool0oooo02`0oooo00<000000?ooo`3oool05`3oool003D0oooo
00<000000?ooo`3oool01@3oool300WZ2R`0oooo0`09jPX0103oool02NX:00WZ2P09jPX70?ooo`03
00WZ2P3oool0000000802NX:1P2LMJH00`000000WK7U09fai@0809fai@0300WZ2P2M/ND0WK7U00P0
WK7U0P0000030;6ig`0600WZ2P2a^Ml02NX:0;6ig`0000002NX:1`0V0382000000L0g/2k00<0afeS
04ED_P15E;h01@15E;h0100000002NX:0<MVEP37IUH300WZ2P80afIF00<02NX:0<MVEP37IUH00P37
IUH2000000D0afIF00@02NX:0<MVEP00000000000`37IUH00`09jPX0[kcS0:nlh`070:nlh`<00000
1P2__><00`000000/XJV0;:6YP030;:6YP030000003=FBX0cETZ00P0cETZ00<02NX:0<eI:P3=FBX0
0`3=FBX01@000000oooo0?ooo`3oool02NX:03D0oooo00<000000?ooo`3oool09@3oool00`000000
2NX:00WZ2P0^0?ooo`<02NX:1@3oool300WZ2PH0oooo00D02NX:0?ooo`3oool0oooo0000000200WZ
2PL0XW^X00<0n=NX0000002S]>D03@2S]>D00`09jPX0XkCU0:>di@0>0:>di@/0?`1500<000000>C6
^@3Ta[T01@3Ta[T605QR`P0300WZ2P1HH/80000000D0bfI?1009jPX40<]VC`<0000000<02NX:0<]V
C`3;ITl00P3;ITl01009jPX000000<]VC`3;ITl40;C0h`0300WZ2P2d`><0]<3S00`0]<3S0P000004
0;N:YP030000003<DQP0c58H00<000000P3<DQP01@000000c58H0<aB603oool0000000@0oooo00<0
2NX:0?ooo`3oool0;@3oool00`000000oooo0?ooo`0G0?ooo`00=@3oool00`000000oooo0?ooo`02
0?ooo`<02NX:;03oool300WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:203oool01P09jPX0oooo
0?ooo`000000W7FV00WZ2PD0W7FV00<0000009fai@2M/ND01`2M/ND00`09jPX0WK7U09fai@0909fa
i@80000000D02NX:0;6ig`2a^Ml0/KWO00WZ2P02000000P09P0b0P0000070=k0^`80afeS2015E;h0
0`000000afIF0<MVEP020<MVEP802NX:00<0afIF00WZ2P37IUH02@37IUH01@09jPX0afIF0<MVEP37
IUH02NX:00<0afIF00<02NX:0<MVEP37IUH00P2__><00`09jPX0[kcS00000002000000T0[kcS0P00
00030;:6YP030000003=FBX0cETZ00<0cETZ00<0WWRX0<eI:P3=FBX00`3=FBX00`09jPX0cETZ0<eI
:P040<eI:P040000003oool0oooo00WZ2SD0oooo00<000000?ooo`3oool08P3oool300WZ2P030000
003oool0oooo02/0oooo0`09jPX50?ooo`<02NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`0800WZ
2P3oool0oooo0?ooo`09jPX000000:9kZ009jPX70:9kZ0030000002S]>D0XkCU00`0XkCU00<02NX:
0:>di@2S]>D03@2S]>D;03l0A@030000003Ta[T0i<Ji00H0i<Ji00<0bfeM05QR`P1HH/800`1HH/80
1009jPX0F6;205QR`P0000060<]VC`802NX:103;ITl2000000<0bfI?00<02NX:0<]VC`09jPX00P09
jPX50<]VC`030;C0h`09jPX0]<3S00d0]<3S0P0000030;N:YP@000001@3<DQP01P09jPX000000<aB
603<DQP0oooo000000<0oooo00<02NX:0?ooo`3oool0;@3oool00`000000oooo0?ooo`0G0?ooo`00
=@3oool00`000000oooo0?ooo`0200WZ2Rd0oooo0P09jPX0103oool02NX:00WZ2P09jPX40?ooo`03
00WZ2P3oool0oooo00L0oooo00H02NX:0?ooo`09jPX0000009aeYP09jPX509aeYP030000002M/ND0
WK7U00H0WK7U00<02NX:09fai@2M/ND0202M/ND010000000/KWO0;6ig`2a^Ml200WZ2P030;6ig`00
00002NX:00T09P0b00<000000=k0^`3N`;/01P3N`;/01037KF<0g/2k04ED_P09jPX704ED_P030000
0009jPX0afIF00<0afIF0P09jPX90<MVEP0300WZ2P37IUH0afIF0080afIF00D02NX:0<MVEP37IUH0
afIF00WZ2P030<MVEP<000000P2__><00`09jPX0[kcS0:nlh`070:nlh`050000002bQZH000000;:6
YP000000303=FBX00`09jPX0cETZ0<eI:P050<eI:P030000003oool02NX:03D0oooo00<000000?oo
o`3oool0803oool200WZ2P<0oooo00<000000?ooo`3oool0:03oool300WZ2PD0oooo0`09jPX50?oo
o`0300WZ2P3oool0oooo00D0oooo00P02NX:0?ooo`3oool02NX:0?ooo`000000XW^X00WZ2PH0XW^X
00<000000:>di@2S]>D02`2S]>D00`09jPX0XkCU0:>di@040:>di@0300WZ2P2S]>D0XkCU00D0XkCU
3@0o04D00`000000i<Ji0>C6^@070>C6^@D0F6;200D0I6W200WZ2P1HH/80F6;2000000060<]VC`<0
2NX:203;ITl01P09jPX0bfI?0<]VC`09jPX0bfI?00WZ2P@0bfI?00<02NX:0<]VC`2d`><0302d`><6
000000P0c58H00<02NX:0<aB600000000P3<DQP01@3oool000000?ooo`3oool02NX:0300oooo00<0
00000?ooo`3oool05P3oool003D0oooo00<000000?ooo`3oool0;03oool600WZ2PH0oooo00<02NX:
0?ooo`3oool0203oool01`09jPX0oooo00WZ2P3oool0000009aeYP09jPX0102LMJH00`000000WK7U
09fai@0509fai@0300WZ2P2M/ND0WK7U00P0WK7U00<000000;6ig`2a^Ml00`2a^Ml2000000X09P0b
00<0000000WZ2P3N`;/01P3N`;/01@2a^Ml0g/2k0=k0^`3N`;/02NX:00P0AEBn00<000000<MVEP37
IUH00P37IUH01009jPX0afIF00WZ2P09jPX60<MVEP0300WZ2P37IUH0afIF00<0afIF00D02NX:0<MV
EP37IUH0afIF00WZ2P03000000H0afIF2P2__><010000000/XJV00000000000<0<eI:P0300WZ2P3=
FBX0cETZ00H0cETZ00<0000000WZ2P3oool0=03oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo02D0oooo0`09jPX50?ooo`<02NX:1`3oool00`09jPX0oooo0?ooo`060?ooo`0400WZ2P3o
ool0oooo00WZ2P80oooo00@000000:9kZ009jPX02NX:102RNjP00`3hejP000000:>di@0:0:>di@03
00WZ2P2S]>D0XkCU00/0XkCU3P0o04D00`000000i<Ji0>C6^@080>C6^@D0F6;200<02NX:05QR`P1H
H/800P1HH/800`000000bfI?0<]VC`030<]VC`0400WZ2P3;ITl0bfI?00WZ2PH0bfI?00D02NX:0<]V
C`3;ITl0bfI?00WZ2P060<]VC`802NX:103;ITl80;C0h`<0000000<0]hZV0000003<DQP00P3<DQP0
0`09jPX0c58H0<aB60040<aB600300WZ2P3<DQP0000000@0c58H00<000000?ooo`09jPX0<03oool0
0`000000oooo0?ooo`0F0?ooo`00=03oool00`000000oooo0?ooo`0Z0?ooo`H02NX:2@3oool00`09
jPX0oooo0?ooo`080?ooo`0300WZ2P3oool02NX:0080oooo00<0000009aeYP09jPX0102LMJH00`00
0000WK7U09fai@0309fai@0300WZ2P2M/ND0WK7U00T0WK7U00H0000000WZ2P09jPX02NX:0;6ig`00
000;02H0<P8000001`3N`;/00`2a^Ml0g/2k0=k0^`020=k0^`T0AEBn00<000000<MVEP37IUH00P37
IUH01009jPX0afIF0<MVEP37IUH200WZ2P<0afIF00<02NX:0<MVEP37IUH01037IUH00`09jPX0afIF
00000002000000`0afIF00<0[kcS00WZ2P09jPX0102__><010000000/XJV00000000000;0<eI:P03
09ihZ009jPX0cETZ00L0cETZ0P00000e0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool08P3oool300WZ2PD0oooo0`09jPX:0?ooo`0300WZ2P3oool0oooo00H0oooo00@02NX:0?ooo`3o
ool02NX:0`3oool010000000XW^X0:9kZ009jPX40:9kZ0030000002S]>D0XkCU00T0XkCU00<02NX:
0:>di@2S]>D02P2S]>D?03l0A@030000003Ta[T0i<Ji00P0i<Ji1@1HH/800`1TJL802NX:05QR`P03
05QR`P030000003;ITl0bfI?0080bfI?00@02NX:0<]VC`3;ITl0bfI?0P09jPX30<]VC`0300WZ2P3;
ITl0bfI?00<0bfI?00<02NX:0<]VC`3;ITl00`3;ITl00`09jPX0bfI?0<]VC`020<]VC`0500WZ2P3;
ITl0bfI?00WZ2P2d`><0100000020;C0h`030000002gRZH0000000X0c58H00@02NX:0<aB603<DQP0
00000`3<DQP200000340oooo00<000000?ooo`3oool05P3oool003@0oooo00<000000?ooo`3oool0
9`3oool600WZ2P`0oooo00<02NX:0?ooo`3oool02@3oool200WZ2P<0oooo00@0000009aeYP09jPX0
2NX:0P2LMJH00`000000WK7U09fai@0209fai@0300WZ2P2M/ND0WK7U00T0WK7U0P2bQjL010000000
/KWO00000000000<02H0<P030000003N`;/0g/2k00D0g/2k00<0/KWO0=k0^`3N`;/00`3N`;/00`00
0000AEBn04ED_P0704ED_P0500000037IUH0afIF0<MVEP09jPX01@37IUH300WZ2PD0afIF10000002
0<MVEP0300WZ2P37IUH0afIF00d0afIF0`2__><300000080cETZ00<000000<eI:P3=FBX02P3=FBX0
0`09jPX0cETZ0<eI:P050<eI:P<00000=03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo01l0oooo0`09jPX50?ooo`<02NX:3@3oool00`09jPX0oooo0?ooo`060?ooo`0400WZ2P3oool0
oooo00WZ2P<0oooo00D02NX:0000002RNjP0XW^X00WZ2P030:9kZ0030000002S]>D0XkCU00P0XkCU
00<02NX:0:>di@2S]>D00`2S]>D00`09jPX0XkCU0:>di@030:>diA00?`1500<000000>C6^@3Ta[T0
2@3Ta[T505QR`P0300WZ2P1HH/80F6;200@0F6;200@000000<]VC`3;ITl0bfI?0P09jPX40<]VC`<0
2NX:1P3;ITl00`09jPX0bfI?0<]VC`030<]VC`0300WZ2P3;ITl0bfI?00@0bfI?100000000`3;ITl0
]<3S0;C0h`020;C0h`800000103<DQP00`09jPX0c58H0<aB60050<aB600400WZ2P3<DQP0c58H0000
0080c58H0`00000`0?ooo`030000003oool0oooo01H0oooo000d0?ooo`030000003oool0oooo02@0
oooo1P09jPX>0?ooo`0300WZ2P3oool0oooo00X0oooo0P09jPX40?ooo`0600000009jPX0W7FV00WZ
2P2LMJH00000102M/ND00`09jPX0WK7U09fai@0809fai@@0/XNW00<0000002H0<P0V03802`0V0380
0`000000g/2k0=k0^`050=k0^`030;6ig`3N`;/0g/2k00@0g/2k00<0000004ED_P15E;h02015E;h0
10000000afIF0<MVEP09jPX60<MVEP<02NX:00@0afIF00000000000000000P37IUH01@09jPX0afIF
0<MVEP37IUH02NX:0180afIF00H0[kcS00000000000000000<eI:P00000<0<eI:P8000002@3=FBX0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0703oool3
00WZ2PD0oooo0`09jPX?0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`09jPX00P3oool0
1009jPX0oooo0?ooo`0000020:9kZ00500WZ2P2RNjP0XW^X0?SGZ00000002@2S]>D01@09jPX0XkCU
0:>di@2S]>D0000000D0XkCU4@0o04D00`000000i<Ji0>C6^@0:0>C6^@D0F6;200<02NX:05QR`P1H
H/801@1HH/8010000000bfI?0<]VC`09jPX60<]VC`802NX:1P3;ITl00`09jPX0bfI?0<]VC`030<]V
C`0400WZ2P3;ITl0bfI?0<]VC`<00000203;ITl00`2d`><000000000000<0<aB608000000P3<DQP0
0`000000c58H0<aB60020<aB60800000;P3oool00`000000oooo0?ooo`0F0?ooo`00=03oool00`00
0000oooo0?ooo`0Q0?ooo`H02NX:4@3oool00`09jPX0oooo0?ooo`0:0?ooo`802NX:103oool01`09
jPX0000009aeYP2LMJH02NX:09aeYP0000000P2M/ND00`09jPX0WK7U09fai@0809fai@<0/XNW00<0
2NX:0000000V0380300V0382000000H0g/2k00<0/KWO0=k0^`3N`;/01@3N`;/00`000000AEBn04ED
_P0904ED_P0300000037IUH02NX:00<0afIF0P0000000`09jPX0afIF000000020000000300WZ2P37
IUH0afIF0080afIF00D02NX:0<MVEP37IUH0afIF00WZ2P0C0<MVEP030000002acnl0/Lo_00<00000
00<0cETZ00WZ2P3=FBX0203=FBX2000000030<eI:P2NN:P0cETZ00L0cETZ00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01T0oooo0`09jPX50?ooo`<02NX:
4P3oool00`09jPX0oooo0?ooo`080?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool200WZ2P03
0000002RNjP0XW^X00802NX:00<0XW^X0000002S]>D01`2S]>D00`09jPX0XkCU0:>di@070:>diA80
?`1500<000000>C6^@3Ta[T02P3Ta[T505QR`P802NX:1`1HH/800`000000bfI?00WZ2P030<]VC`80
000000<02NX:0<]VC`3;ITl00P09jPX40<]VC`0300WZ2P3;ITl0bfI?00<0bfI?00@02NX:00000000
00000000303;ITl00`000000]M?_00000002000000T0c58H0P0000020<aB60030000003<DQP0c58H
00<0c58H00<0oooo0000003oool0;03oool00`000000oooo0?ooo`0F0?ooo`00=03oool00`000000
oooo0?ooo`0O0?ooo`D02NX:503oool00`09jPX0oooo0?ooo`0:0?ooo`802NX:0`3oool02P09jPX0
oooo0?ooo`0000002NX:09aeYP09jPX0000009fai@09jPX909fai@D02NX:3`0V03800`000000g/2k
0=k0^`040=k0^`030;6ig`3N`;/0g/2k00H0g/2k00<0000000WZ2P15E;h02P15E;h00`0000002NX:
0<MVEP020<MVEP@000000`37IUH200000080afIF00<02NX:0<MVEP37IUH00P37IUH00`09jPX0afIF
0<MVEP0@0<MVEP8000001@2acnl3000001D0cETZ00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo01H0oooo0`09jPX50?ooo`<02NX:5@3oool00`09jPX0oooo
0?ooo`080?ooo`0300WZ2P3oool02NX:00@02NX:0`3oool01P000000XW^X0:9kZ02RNjP02NX:0000
00L0XkCU00D02NX:0:>di@2S]>D0XkCU00WZ2P040:>diA<0?`1500<000000>C6^@3Ta[T02`3Ta[T0
0`2e_=l0F6;205QR`P0205QR`P030;Flg`000000F6;200L0F6;200<0000000WZ2P3;ITl00P3;ITl2
000000D0bfI?0P0000020<]VC`0300WZ2P3;ITl0bfI?00@000003P3;ITl2000000@0]M?_0P00000<
0<aB60030000003<DQP0c58H00<0c58H00<0oooo0000003oool0;03oool00`000000oooo0?ooo`0E
0?ooo`00=03oool00`000000oooo0?ooo`0L0?ooo`D02NX:5P3oool00`09jPX0oooo0?ooo`0<0?oo
o`0300WZ2P3oool0oooo00@02NX:00@0oooo00000009jPX0W7FV0P09jPX909fai@<02NX:0P00000?
02H0<P030000003N`;/0g/2k00@0g/2k00<0/KWO0=k0^`3N`;/0203N`;/00`000000AEBn04ED_P0:
04ED_P0300000037IUH00000008000001P37IUH200000080afIF00<02NX:0<MVEP37IUH00P37IUH0
0`09jPX0afIF0<MVEP0?0<MVEP030000002_S[<0000000H0/Lo_00<000000;7?k`0000000P00000C
0<eI:P030000003oool0oooo02h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0C
0?ooo`<02NX:1@3oool300WZ2QL0oooo00<02NX:0?ooo`3oool02@3oool400WZ2PH0oooo00<02NX:
00000009jPX00P2RNjP00`09jPX000000:>di@050:>di@0400WZ2P2S]>D0XkCU00WZ2P<0XkCU500o
04D00`000000i<Ji0>C6^@0<0>C6^@030;Flg`1HH/80F6;20080F6;200<0]KcO05QR`P1HH/801`1H
H/800`0000002NX:0<]VC`020<]VC`0300WZ2P3;ITl0bfI?00@0bfI?0P0000020<]VC`<000000`3;
ITl00`09jPX0bfI?0<]VC`0;0<]VC`030000002dT[<0000000H0]M?_0P00000;0<aB60030000003<
DQP0c58H00<0c58H00<0oooo0000003oool0:`3oool00`000000oooo0?ooo`0E0?ooo`00=03oool0
0`000000oooo0?ooo`0I0?ooo`D02NX:6@3oool00`09jPX0oooo0?ooo`0<0?ooo`@02NX:0`3oool2
00WZ2P040000002LMJH0W7FV00WZ2P<0WK7U0P00000409fai@030;:7Y`000000000001009P0b00<0
00000;6ig`3N`;/0103N`;/00`2a^Ml0g/2k0=k0^`090=k0^`0300000015E;h0AEBn00T0AEBn1000
00000`09jPX0afIF0<MVEP090<MVEP0300WZ2P37IUH0afIF0080afIF00<02NX:0<MVEP37IUH03P37
IUH01@000000[hjc0:n>/`2_S[<0000000H0/Lo_00@000000;7?k`2acnl0/Lo_0`00000:0<eI:P03
09ihZ03=FBX0cETZ00@0cETZ00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0140oooo0`09jPX50?ooo`<02NX:6P3oool00`09jPX0oooo0?ooo`070?ooo`D0
2NX:1@3oool300WZ2P030?ooo`000000XW^X0080XW^X00<000000:>di@2S]>D00P0000000`2S]>D0
2NX:0:>di@050:>diAD0?`1500<000000>C6^@3Ta[T03@3Ta[T405QR`P030;Flg`1HH/80F6;200P0
F6;200@000000<]VC`0000000000203;ITl3000000030<]VC`09jPX0bfI?0080bfI?00<02NX:0<]V
C`3;ITl0303;ITl010000000]9:c0;BB/`0000070;GCk`<00000203<DQP00`000000c58H0<aB6004
0<aB60030?ooo`000000oooo02X0oooo00<000000?ooo`3oool05@3oool003<0oooo00<000000?oo
o`3oool05`3oool500WZ2Q/0oooo00<02NX:0?ooo`3oool02`3oool400WZ2P80oooo0`09jPX30?oo
o`0400000009jPX02NX:00000080WK7U0P00000309fai@030;:7Y`0000009P0b01009P0b0P000005
0=k0^`030;6ig`3N`;/0g/2k00X0g/2k00<0000004ED_P15E;h01P15E;h30000000400WZ2P15E;h0
0000000000`0afIF00<02NX:0<MVEP37IUH00P37IUH00`09jPX0afIF0<MVEP0=0<MVEP030000002_
S[<0[hjc0080[hjc00<000000;7?k`2acnl01@2acnl00`000000/Lo_0;7?k`030;7?k`0300000009
jPX0000000`0cETZ0P0000000`3=FBX000000?ooo`0^0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool03P3oool300WZ2PD0oooo0`09jPXM0?ooo`0300WZ2P3oool0oooo00@0oooo0`09
jPX00`3oool02NX:0?ooo`0200WZ2P80oooo1009jPX20?ooo`030;N;Y`00000000000080XW^X00<0
000000WZ2P2S]>D00P0000000`2S]>D02NX:0:>di@030:>diAH0?`1500<000000>C6^@3Ta[T03P3T
a[T405QR`P03060<A`09jPX0F6;200P0F6;200@02NX:0000000000000000103;ITl4000000@0bfI?
00D02NX:0<]VC`3;ITl0bfI?00WZ2P0=0<]VC`050000002dT[<0]9:c0;BB/`0000002P2ednl30000
00H0c58H00<000000<aB603<DQP0103<DQP00`3oool000000?ooo`0Y0?ooo`030000003oool0oooo
01D0oooo000c0?ooo`030000003oool0oooo01@0oooo1@09jPXN0?ooo`0300WZ2P3oool0oooo00P0
oooo0`09jPX20?ooo`H02NX:0P3oool300WZ2P030000002LMJH0000000H0WK7U0P00000B02H0<P03
0000003N`;/0g/2k00<0g/2k00<0/KWO0=k0^`3N`;/02`3N`;/00`000000AEBn04ED_P0304ED_P<0
00000`15E;h01009jPX0AEBn00000000000<0<MVEP0300WZ2P37IUH0afIF0080afIF00<02NX:0<MV
EP37IUH03037IUH00`000000[hjc0:n>/`030:n>/`030000002acnl0/Lo_00H0/Lo_00<000000;7?
k`2acnl01@2acnl3000000T0cETZ0P0000020<eI:P030000003oool0oooo02`0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0;0?ooo`<02NX:1@3oool300WZ2Ql0oooo00<02NX:0?oo
o`3oool00P3oool300WZ2P<0oooo00<02NX:0?ooo`3oool01009jPX00`3oool02NX:0?ooo`030?oo
o`80000000D02NX:00000009jPX0n=NX000000030:>di@0400WZ2P2S]>D0XkCU0:>diAL0?`1500<0
00000>C6^@3Ta[T03`3Ta[T405QR`P802NX:2@1HH/800`09jPX00000000000020<]VC`<00000203;
ITl01@09jPX0bfI?0<]VC`3;ITl02NX:00`0bfI?00<000000;BB/`2dT[<00P2dT[<00`000000]M?_
0;GCk`0;0;GCk`<00000103<DQP010000000c58H0<aB603<DQP200000080c58H00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0E0?ooo`00<`3oool00`000000oooo0?ooo`0A0?ooo`D02NX:
8@3oool00`09jPX0oooo0?ooo`050?ooo`<02NX:0`3oool400WZ2P030?ooo`09jPX0oooo0080oooo
00@02NX:0?ooo`09jPX0oooo0`00000509fai@030000000V03809P0b01409P0b00<000000;6ig`3N
`;/00`3N`;/00`2a^Ml0g/2k0=k0^`0<0=k0^`0300000009jPX0000000<000000`15E;h200000003
04ED_P09jPX0AEBn0080AEBn00<000000<MVEP37IUH02@37IUH00`09jPX0afIF0<MVEP020<MVEP03
00WZ2P37IUH0afIF00/0afIF00<000000:n>/`2_S[<0102_S[<00`000000/Lo_0;7?k`070;7?k`03
0000002acnl0/Lo_00L0/Lo_0`0000060<eI:P0309ihZ03=FBX0cETZ0080cETZ00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo0`09jPX50?ooo`<0
2NX:8P3oool500WZ2PD0oooo00<02NX:0?ooo`09jPX00`09jPX20?ooo`0600WZ2P3oool0oooo0?oo
o`09jPX000000`09jPX2000000050:9kZ0000000XkCU0:>di@09jPX00`2S]>DH03l0A@030000003T
a[T0i<Ji00l0i<Ji101HH/800`000000F6;205QR`P0305QR`P8000000`1HH/800`09jPX0F6;20000
0002000000/0bfI?00D02NX:0<]VC`3;ITl0bfI?00WZ2P0<0<]VC`030000002dT[<0]9:c0080]9:c
00<000000;GCk`2ednl03P2ednl3000000030<aB60000000c58H0080c58H0P0000030<aB60030000
003oool0oooo02H0oooo00<000000?ooo`3oool05@3oool003<0oooo00<000000?ooo`3oool0403o
ool300WZ2R<0oooo00<02NX:0?ooo`3oool00`3oool300WZ2P<0oooo1009jPX01@3oool02NX:00WZ
2P09jPX0oooo00<02NX:0P3oool00`09jPX000000000000300000080WK7U0P00000C02H0<P800000
4`3N`;/3000000L0AEBn0P0000000`15E;h02NX:04ED_P0304ED_P0300000037IUH0afIF00P0afIF
00<02NX:0<MVEP37IUH00P37IUH2000000/0afIF00<000000:n>/`2_S[<01@2_S[<00`000000/Lo_
0;7?k`070;7?k`030000002acnl0/Lo_00X0/Lo_0`0000090<eI:P030000003oool0oooo02X0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`060?ooo`802NX:1@3oool300WZ2R<0oooo
0`09jPX80?ooo`<02NX:0P3oool400WZ2P80oooo1009jPX700000080XkCU00<02NX:0:>di@0o04D0
600o04D00`000000i<Ji0>C6^@0@0>C6^@@0F6;20P09jPX405QR`P80000000<0F6;2000000000000
0P00000205QR`P030000003;ITl0bfI?00X0bfI?00@02NX:0<]VC`00000000002`3;ITl00`000000
]9:c0;BB/`030;BB/`030000002ednl0]M?_0140]M?_0`0000080<aB60030000003oool0oooo02D0
oooo00<000000?ooo`3oool05@3oool003<0oooo00<000000?ooo`3oool03@3oool300WZ2RH0oooo
00<02NX:0?ooo`3oool00`09jPX30?ooo`<02NX:0P3oool00`09jPX0oooo0?ooo`0400WZ2P030?oo
o`09jPX02NX:00802NX:1P0000000`2M/ND0000002H0<P0D02H0<P030000003N`;/0g/2k00l0g/2k
0`0000020=k0^`0300000015E;h0AEBn00D0AEBn00@02NX:04ED_P15E;h02NX:1@15E;h00`000000
afIF0<MVEP070<MVEP0300WZ2P37IUH0afIF0080afIF0P00000:0<MVEP030000002_S[<0[hjc00H0
[hjc00<000000;7?k`2acnl0202acnl00`000000/Lo_0;7?k`0<0;7?k`<000001`3=FBX00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02P3oool300WZ2R<0
oooo0`09jPX00`3oool02NX:0?ooo`050?ooo`<02NX:1@3oool800WZ2PX0000000<02NX:03l0A@0o
04D0600o04D00`000000i<Ji0>C6^@0A0>C6^@04060<A`1HH/80F6;205QR`P802NX:101HH/830000
0080F6;200<02NX:05QR`P1HH/800P1HH/800`000000bfI?0<]VC`090<]VC`0400WZ2P3;ITl00000
000000X0bfI?00<000000;BB/`2dT[<0102dT[<00`000000]M?_0;GCk`0D0;GCk`8000001`3<DQP0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01@0oooo000c0?ooo`030000003oool0oooo
00X0oooo0`09jPXX0?ooo`@02NX:0`3oool300WZ2P@0oooo00<02NX:0?ooo`09jPX01P09jPX20?oo
o`0300WZ2P000000000000H000005@0V03800`000000/KWO0=k0^`0=0=k0^`<000001@3N`;/00`00
0000AEBn04ED_P0504ED_P0400WZ2P15E;h0AEBn00WZ2PH0AEBn00<000000<MVEP37IUH01P37IUH0
0`09jPX0afIF0<MVEP0=0<MVEP030000002_S[<0[hjc00P0[hjc00<000000;7?k`2acnl0202acnl0
0`000000/Lo_0;7?k`0>0;7?k`<000000P3=FBX0102NN:P0cETZ0<eI:P00000Z0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool01`3oool300WZ2R<0oooo0`09jPX40?ooo`0400WZ2P3o
ool0oooo0?ooo`D02NX:0`3oool600WZ2P@0oooo2P0000000`09jPX0000003l0A@0I03l0A@030000
003Ta[T0i<Ji0140i<Ji00@0H0a705QR`P1HH/80F6;20P09jPX01P1HH/800000000000000000F6;2
00WZ2P<0F6;200<02NX:05QR`P1HH/800`1HH/800`000000bfI?0<]VC`080<]VC`0300WZ2P3;ITl0
bfI?00/0bfI?00<000000;BB/`2dT[<01@2dT[<00`000000]M?_0;GCk`0D0;GCk`@000001@3<DQP0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01@0oooo000c0?ooo`030000003oool0oooo
00L0oooo0`09jPXY0?ooo`<02NX:0`3oool300WZ2PH0oooo1P09jPX00`3oool02NX:0?ooo`030?oo
o`0300WZ2P000000000000@0000000<0S;Sd0000000V03804`0V0382000000`0g/2k0`0000080=k0
^`0300000015E;h0AEBn00@0AEBn0P00000200WZ2P80AEBn0P00000304ED_P0300000037IUH0afIF
00H0afIF00<02NX:0<MVEP37IUH03037IUH00`000000[hjc0:n>/`090:n>/`030000002acnl0/Lo_
00T0/Lo_00<000000;7?k`2acnl0402acnl3000000<0cETZ00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo0`09jPXS0?ooo`<02NX:1`3oool400WZ
2P80oooo00<02NX:0?ooo`09jPX02009jPX40?ooo`X0000000<0T[cc00WZ2P0o04D06@0o04D00`00
0000i<Ji0>C6^@0C0>C6^@80F6;21000000205QR`P0300WZ2P0000002NX:00<0F6;200<02NX:0000
00000000101HH/800`000000bfI?0<]VC`070<]VC`0300WZ2P3;ITl0bfI?00X0bfI?00<000000;BB
/`2dT[<01P2dT[<00`000000]M?_0;GCk`0D0;GCk`040000002ednl0]M?_0;GCk`<000000`3<DQP0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01@0oooo000c0?ooo`030000003oool0oooo
00@0oooo0`09jPXY0?ooo`<02NX:00<0oooo00WZ2P3oool00`09jPX60?ooo`H02NX:0P3oool00`09
jPX0oooo00WZ2P030?ooo`0300WZ2P000000000000@000000P2<^?@2000001<09P0b00<000000=k0
^`3N`;/0203N`;/3000000/0g/2k00<0000004ED_P15E;h00`15E;h00`09jPX000000000000200WZ
2P80AEBn0P00000404ED_P0300000037IUH0afIF00D0afIF00<02NX:0<MVEP37IUH02`37IUH00`00
0000afIF0:n>/`0:0:n>/`030000002acnl0/Lo_00X0/Lo_00<000000;7?k`2acnl04P2acnl30000
00030<eI:P000000oooo02L0oooo00<000000?ooo`3oool08`3oool010000000oooo0?ooo`3oool3
00WZ2R<0oooo0`09jPX80?ooo`<02NX:0`3oool900WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool:
0000000409:ll`09jPX00000000001P0?`1500<000000>C6^@3Ta[T04`3Ta[T30000000305QR`P3U
^JT02NX:0080F6;200@02NX:05QR`P0000002NX:0`1HH/800`09jPX000000000000505QR`P030000
003;ITl0bfI?00H0bfI?00<02NX:0<]VC`3;ITl02@3;ITl00`000000]9:c0;BB/`070;BB/`030000
002ednl0]M?_01D0]M?_00<000000;GCk`2ednl00`2ednl3000000030<aB60000000oooo02<0oooo
00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool00`3oool200WZ2RT0oooo0`09
jPX30?ooo`<02NX:0P3oool2000000D02NX:00@0oooo00WZ2P3oool02NX:103oool01P09jPX0oooo
0?ooo`09jPX0oooo00WZ2PH000000`2<^?@2000001809P0b00<000000;6ig`3N`;/01P3N`;/30000
00h0g/2k00<0000004ED_P15E;h00P15E;h01009jPX0AEBn04ED_P15E;h200WZ2PT0AEBn00<00000
0<MVEP37IUH01037IUH00`09jPX0afIF0<MVEP0;0<MVEP030000002_S[<0[hjc00X0[hjc00<00000
0;7?k`2acnl02`2acnl00`000000/Lo_0;7?k`060;7?k`800000302acnl3000002L0oooo00<00000
0?ooo`3oool08`3oool0100000002NX:00WZ2P09jPXR0?ooo`@02NX:203oool200WZ2P8000002@09
jPX20?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`09jPX00P3oool90000000309:ll`09
jPX0T[cc00800000600o04D00`000000i<Ji0>C6^@0@0>C6^@<0000000D0i<Ji0000001HH/80F6;2
0>FiZ@0300WZ2P<0F6;200D02NX:05QR`P1HH/80F6;200WZ2P0805QR`P030000003;ITl0bfI?00D0
bfI?00<02NX:0<]VC`3;ITl0203;ITl00`000000]9:c0;BB/`080;BB/`030000002ednl0]M?_01H0
]M?_00<000000;GCk`2ednl01@2ednl3000002<0oooo00<000000?ooo`3oool0503oool00380oooo
00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0V0?ooo`<02NX:0`3oool300WZ2P030?oo
o`09jPX0oooo0080oooo0`09jPX40?ooo`0300WZ2P3oool02NX:00D0oooo00<02NX:0?ooo`3oool0
0P09jPX6000000@0S;Sd0P00000A02H0<P030000002bQjL0g/2k0080g/2k00<0/KWO000000000000
0P00000A0=k0^`0300000015E;h0AEBn00802NX:1015E;h200WZ2PX0AEBn00<000000<MVEP37IUH0
0P37IUH00`09jPX0afIF0<MVEP0;0<MVEP030000002_S[<0[hjc00D0[hjc00<000000:n>/`2_S[<0
0`2_S[<00`000000/Lo_0;7?k`0<0;7?k`030000002acnl0/Lo_00D0/Lo_0P00000>0;7?k`<00000
9@3oool00`000000oooo0?ooo`0P0?ooo`<02NX:00<000000?ooo`3oool0803oool300WZ2PP0oooo
1009jPX20?ooo`80000000<02NX:0?ooo`3oool00`09jPX40?ooo`0300WZ2P3oool0oooo00<0oooo
00@02NX:0?ooo`09jPX0oooo2000000309:ll`0500WZ2P2B_?<000000:R9]00000005P0o04D00`00
0000i<Ji0>C6^@0=0>C6^@@00000103Ta[T01@000000F6;205QR`P3U^JT02NX:00H0F6;200@02NX:
05QR`P1HH/802NX:2@1HH/800`000000bfI?0<]VC`040<]VC`0300WZ2P3;ITl0bfI?00P0bfI?00<0
00000;BB/`2dT[<0202dT[<00`000000]M?_0;GCk`0@0;GCk`800000102ednl00`000000]M?_0;GC
k`070;GCk`8000008P3oool00`000000oooo0?ooo`0D0?ooo`00<P3oool01@000000oooo0?ooo`3o
ool02NX:02H0oooo0`09jPX30?ooo`<02NX:0`3oool00`09jPX0oooo00WZ2P0200WZ2PH0oooo0`09
jPX60?ooo`0300WZ2P3oool0oooo00802NX:1000000608bhm0030000002RQ;<0000000l09P0b0P00
00020=k0^`<000005P3N`;/00`0000002NX:04ED_P0504ED_P802NX:2`15E;h01@000000afIF0<MV
EP37IUH02NX:00`0afIF00<000000:n>/`2_S[<01@2_S[<00`000000[hjc0:n>/`050:n>/`030000
002acnl0/Lo_00/0/Lo_00<000000;7?k`2acnl04P2acnl3000002P0oooo00<000000?ooo`3oool0
7P3oool200WZ2P<0oooo00<000000?ooo`3oool07@3oool300WZ2PP0oooo0`09jPX70?ooo`D02NX:
103oool200WZ2PH0oooo00<02NX:0?ooo`09jPX02000000309:ll`0400WZ2P2B_?<0T[cc00000080
Z8Vd00<0000003l0A@0o04D04P0o04D00`000000i<Ji0>C6^@0;0>C6^@<00000203Ta[T010000000
F6;200WZ2P09jPX705QR`P0400WZ2P1HH/80F6;200WZ2PT0F6;200<000000<]VC`3;ITl01@3;ITl0
0`09jPX0bfI?0<]VC`060<]VC`030000002dT[<0]9:c00X0]9:c00<000000;GCk`2ednl03`2ednl2
000000D0]M?_00<000000;GCk`2ednl00`2ednl3000002D0oooo00<000000?ooo`3oool04`3oool0
0380oooo00<000000?ooo`3oool09@3oool300WZ2P<0oooo0`09jPX50?ooo`<02NX:1P3oool20000
00802NX:203oool01009jPX0oooo0?ooo`09jPX4000000L0S;Sd00<000000::4/`0000003`0V0384
000000030;6ig`3N`;/0g/2k01H0g/2k00<02NX:04ED_P15E;h01@15E;h200WZ2P`0AEBn00@00000
0<MVEP37IUH02NX:2`37IUH00`000000[hjc0:n>/`050:n>/`0300WZ2P2_S[<0[hjc00H0[hjc00<0
00000;7?k`2acnl01@2acnl2000000D0/Lo_00<000000;7?k`2acnl03P2acnl3000002`0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0J0?ooo`<02NX:1`3oool400WZ2PL0oooo1009
jPX20000000300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0000
0007000000@0T[cc00@02NX:09:ll`2B_?<000000P2XRK@00`000000?`1503l0A@0B03l0A@030000
003Ta[T0i<Ji00P0i<Ji0`00000;0>C6^@0400000009jPX0F6;20>FiZ@L0F6;200@02NX:05QR`P1H
H/802NX:2P1HH/800`000000bfI?0<]VC`040<]VC`0300WZ2P3;ITl0bfI?00D0bfI?00<000000;BB
/`2dT[<02`2dT[<00`000000]M?_0;GCk`020;GCk`8000004`2ednl00`000000]M?_000000020000
02P0oooo00<000000?ooo`3oool04`3oool00380oooo00<000000?ooo`3oool08P3oool300WZ2P<0
oooo0`09jPX50?ooo`@02NX:203oool00`0000002NX:00WZ2P090?ooo`0300WZ2P3oool02NX:00@0
00001`2<^?@0102bQjL000000::4/`00000=02H0<P<000000P3N`;/00`2bQjL0g/2k0=k0^`0E0=k0
^`802NX:00<0000004ED_P15E;h01@15E;h200WZ2Pd0AEBn00<000000<MVEP09jPX02P37IUH00`00
0000[hjc0:n>/`0?0:n>/`030000002acnl0/Lo_00D0/Lo_0P0000060;7?k`030000002acnl0/Lo_
00/0/Lo_0P0000000`2acnl0oooo0?ooo`0/0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool05`3oool300WZ2PL0oooo0`09jPX80?ooo`<02NX:0`3oool00`09jPX0000000WZ2P030?oo
o`802NX:2@3oool00`09jPX0oooo00000006000000@0T[cc00D02NX:09:ll`2B_?<0T[cc00000003
0:R9]0030000000o04D0?`150100?`1500<000000>C6^@3Ta[T01@3Ta[T4000000h0i<Ji00<02NX:
0000001HH/80201HH/801009jPX0F6;205QR`P09jPX;05QR`P030000003;ITl0bfI?00<0bfI?00<0
2NX:0<]VC`3;ITl01@3;ITl00`000000]9:c0;BB/`0;0;BB/`030000002ednl0]M?_0080]M?_0P00
000C0;GCk`800000:`3oool00`000000oooo0?ooo`0C0?ooo`00<P3oool00`000000oooo0?ooo`0O
0?ooo`<02NX:0`3oool300WZ2PD0oooo0`09jPX30?ooo`0300WZ2P3oool0oooo00H0oooo0P09jPX:
0?ooo`802NX:1000000908bhm0040000002RQ;<0XXBc000000T09P0b1@0000020=k0^`030;:7Y`3N
`;/0g/2k01D0g/2k00@02NX:0=k0^`3N`;/000001`15E;h200WZ2Pd0AEBn00<000000<MVEP09jPX0
2@37IUH00`000000[hjc0:n>/`0@0:n>/`030000002acnl0/Lo_00h0/Lo_00<000000;7?k`2acnl0
1`2acnl300000340oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0D0?ooo`<02NX:
1`3oool300WZ2PL0oooo1009jPX50?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
2@3oool00`09jPX0000000000004000000802NX:0`2B_?<00`09jPX0T[cc09:ll`0209:ll`050000
002XRK@0Z8Vd0:R9]00000004@0o04D00`000000i<Ji0>C6^@030>C6^@<00000403Ta[T200WZ2P03
0>C6^@000000F6;200T0F6;200<02NX:05QR`P09jPX0301HH/800`000000bfI?0<]VC`020<]VC`03
00WZ2P3;ITl0bfI?00@0bfI?00<000000;BB/`2dT[<0302dT[<00`000000]M?_0;GCk`0D0;GCk`<0
000000<0oooo0000003oool0:P3oool00`000000oooo0?ooo`0C0?ooo`00<P3oool00`000000oooo
0?ooo`0M0?ooo`802NX:0`3oool300WZ2PD0oooo0`09jPX50?ooo`0300WZ2P3oool0oooo00H0oooo
00<02NX:0?ooo`3oool02P3oool200WZ2P<000002P2<^?@010000000XXBc0::4/`00000602H0<P<0
00000`0V038010000000g/2k0=k0^`2bQjLF0=k0^`0300000009jPX0g/2k0080g/2k0P00000604ED
_P802NX:3P15E;h00`0000002NX:0<MVEP070<MVEP030000002_S[<0[hjc00<0[hjc00<02NX:0:n>
/`2_S[<02`2_S[<00`000000/Lo_0;7?k`090;7?k`800000102acnl00`000000/Lo_0;7?k`030;7?
k`<0000000<0WWRX0?ooo`3oool0<@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
01<0oooo0P09jPX60?ooo`@02NX:1`3oool300WZ2PT0oooo00@02NX:0?ooo`3oool0oooo0P09jPX<
0?ooo`0300WZ2P000000000000<000001P2B_?<00`09jPX0T[cc09:ll`0209:ll`030000002XRK@0
Z8Vd0080Z8Vd00<0000003l0A@0o04D03P0o04D00`000000i<Ji0>C6^@0300000140i<Ji00<00000
00WZ2P3Ta[T00P3Ta[T00`000000F6;205QR`P0805QR`P0300WZ2P1HH/802NX:00d0F6;200D00000
0<]VC`3;ITl0bfI?00WZ2P050<]VC`030000002dT[<0]9:c00d0]9:c00<000000;GCk`2ednl01@2e
dnl2000000/0]M?_0P0000050?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool04`3o
ool00340oooo00<000000?ooo`3oool0803oool300WZ2PD0oooo0`09jPX80?ooo`0300WZ2P3oool0
oooo00D0oooo00<02NX:0?ooo`3oool02`3oool01009jPX0000000000000000;08bhm0040000002R
Q;<0XXBc000000<09P0b0`00000502H0<P040000002d<000g/2k0;:7YaL0g/2k00<02NX:0000003N
`;/00P3N`;/00`000000AEBn04ED_P0504ED_P802NX:3`15E;h00`000000afIF0<MVEP050<MVEP03
0000002_S[<0[hjc0080[hjc00<02NX:0:n>/`2_S[<03@2_S[<00`000000/Lo_0;7?k`090;7?k`80
00001@2acnl00`000000/Lo_0;7?k`02000000030;7?k`3oool02NX:03@0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0H0?ooo`<02NX:203oool300WZ2P`0oooo00@02NX:0?ooo`3o
ool02NX:3@3oool00`0000002NX:00000003000000H0T[cc00<02NX:09:ll`2B_?<00`2B_?<00`00
0000Z8Vd0:R9]0020:R9]00303l0A@000000?`1500d0?`151000000D0>C6^@0300WZ2P000000i<Ji
0080i<Ji00@0000005QR`P1HH/802NX:1`1HH/800`09jPX0F6;200WZ2P0>05QR`P040000003;ITl0
bfI?00WZ2PD0bfI?00<000000;BB/`2dT[<03@2dT[<00`000000]M?_0;GCk`050;GCk`800000202e
dnl30000000300WZ2P3oool0oooo00D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0C0?ooo`00<@3oool00`000000oooo0?ooo`0M0?ooo`<02NX:1@3oool300WZ2P/0oooo00<02NX:
0?ooo`3oool00`3oool200WZ2Pd0oooo0P09jPX2000000H0S;Sd0P00000400WZ2P040000002RQ;<0
XXBc0::4/`<000001`0V03800`000000]3000=k0^`0I0=k0^`0300WZ2P3N`;/0g/2k00<0g/2k00<0
000004ED_P15E;h01015E;h200WZ2Pl0AEBn00<02NX:00000037IUH01037IUH00`000000[hjc0:n>
/`0D0:n>/`030000002acnl0/Lo_00@0/Lo_0P0000090;7?k`<00000103oool00`09jPX0oooo0?oo
o`0b0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0503oool400WZ2PP0oooo0`09
jPX>0?ooo`0400WZ2P3oool0oooo00WZ2Ph0oooo00@0000000WZ2P00000000001P2B_?<00`000000
2NX:09:ll`0209:ll`@02NX:00<000000:R9]02XRK@00P2XRK@00`000000?`1503l0A@0903l0A@@0
00005`3Ta[T00`09jPX0i<Ji0>C6^@020>C6^@040000001HH/80F6;200WZ2PL0F6;200<02NX:05QR
`P09jPX03`1HH/800`000000bfI?00WZ2P040<]VC`030000002dT[<0]9:c00l0]9:c00<000000;GC
k`2ednl00P0000090;GCk`<000000`3oool00`09jPX0oooo0?ooo`050?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool04`3oool00340oooo00<000000?ooo`3oool06P3oool300WZ2PD0
oooo0`09jPX=0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0
000000WZ2P02000000H02NX:0P00000300WZ2P0308bhm0000000000000<000002@0V03800`000000
g/2k0=k0^`0J0=k0^`0300WZ2P3N`;/0g/2k0080g/2k00<0000004ED_P15E;h01015E;h200WZ2Pl0
AEBn00<02NX:04ED_P0000000`37IUH00`000000[hjc0:n>/`0E0:n>/`030000002acnl0/Lo_00@0
/Lo_0P0000070;7?k`80000000<02NX:00000009jPX00`3oool00`09jPX0oooo0?ooo`0c0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool04@3oool300WZ2PP0oooo1009jPXA0?ooo`<0
2NX:3P3oool20000000400WZ2P000000000000000080T[cc0`09jPX00`0000002NX:00WZ2P0400WZ
2P80T[cc00<000000:R9]02XRK@00`2XRK@00`000000?`1503l0A@0503l0A@<000000P0o04D00`00
0000i<Ji0>C6^@0G0>C6^@0500WZ2P3Ta[T0i<Ji0>C6^@0000002`1HH/8200WZ2Q00F6;200<00000
00WZ2P3;ITl00P3;ITl00`000000]9:c0;BB/`0@0;BB/`030000002ednl0]M?_008000001`2ednl2
000000<02NX:0`3oool00`09jPX0oooo0?ooo`060?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool04P3oool00340oooo00<000000?ooo`3oool05`3oool300WZ2PD0oooo0`09jPX@0?oo
o`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool03@3oool400WZ2P800000102<^?@300WZ
2P0308bhm00000000000008000000`2RQ;<00`0000009P0b02H0<P0602H0<P030000003N`;/0g/2k
01/0g/2k00<02NX:0=k0^`3N`;/00P3N`;/00`000000AEBn04ED_P0404ED_P802NX:3P15E;h01P09
jPX0AEBn04ED_P15E;h000000<MVEP802NX:00<0[hjc0000002_S[<0502_S[<00`000000/Lo_0;7?
k`0:0;7?k`<00000103oool00`0000002NX:00WZ2P0500WZ2S80oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0>0?ooo`<02NX:203oool300WZ2QD0oooo00<02NX:0?ooo`3oool03@3o
ool00`0000002NX:00WZ2P0600WZ2P<0T[cc1009jPX509:ll`030000002XRK@0Z8Vd00<0Z8Vd00@0
000003l0A@0o04D0?`151000000403l0A@030000003Ta[T0i<Ji01P0i<Ji00D02NX:0>C6^@3Ta[T0
i<Ji0000000;05QR`P802NX:4@1HH/801@0000002NX:0<]VC`3;ITl000000180]9:c00<000000;GC
k`2ednl01P2ednl3000000D0oooo1P09jPX70?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool04P3oool00340oooo00<000000?ooo`3oool0503oool300WZ2PD0oooo0`09jPXB0?ooo`04
00WZ2P3oool0oooo0?ooo`802NX:2`3oool500WZ2P8000000P09jPX308bhm0<02NX:00@0S;Sd0000
0000000000000`2<^?@00`000000XXBc0::4/`020::4/`030000000V03809P0b00@09P0b00<00000
0=k0^`3N`;/07@3N`;/01@09jPX0g/2k0=k0^`3N`;/0000000H0AEBn0P09jPX>04ED_P0400WZ2P15
E;h0AEBn04ED_P8000000P09jPXG0:n>/`030000002acnl0/Lo_00L0/Lo_0`0000000`2NN:P0oooo
0?ooo`050?ooo`040000003oool0oooo00WZ2P<0oooo1P09jPX/0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool02P3oool400WZ2PP0oooo0`09jPXF0?ooo`802NX:2`3oool600WZ2P80
000000<02NX:09:ll`2B_?<00`2B_?<400WZ2PP0T[cc00<000000:R9]02XRK@0102XRK@3000000P0
?`1500<000000>C6^@3Ta[T06@3Ta[T01@09jPX0i<Ji0>C6^@3U^JT0000000X0F6;20P09jPXB05QR
`P<000004`2dT[<00`000000]M?_0;GCk`040;GCk`8000002P3oool01009jPX0oooo0?ooo`3oool5
00WZ2P80oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0B0?ooo`00<@3oool00`00
0000oooo0?ooo`0A0?ooo`<02NX:1@3oool300WZ2QD0oooo00@02NX:0?ooo`3oool02NX:1`3oool8
00WZ2P070?ooo`09jPX000000000002<^?@02NX:08bhm00300WZ2P0408bhm00000000000000000L0
S;Sd00D000000::4/`2RQ;<0XXBc0000000602H0<P030000003N`;/0g/2k01d0g/2k00H02NX:0=k0
^`3N`;/0g/2k00000009jPX504ED_P0300WZ2P15E;h02NX:00d0AEBn0P0000001@15E;h000000:n>
/`2_S[<02NX:0080[hjc0P00000D0:n>/`030000002acnl0/Lo_00D0/Lo_0P00000200WZ2PX0oooo
00<000000?ooo`09jPX02@3oool600WZ2RH0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`070?ooo`<02NX:2@3oool300WZ2QP0oooo00<02NX:0?ooo`09jPX01@3oool900WZ2P030?oo
o`00000000000080T[cc00<02NX:09:ll`2B_?<00`09jPX209:ll`0300WZ2P2B_?<0T[cc00L0T[cc
00@000000:R9]02XRK@0Z8Vd0`0000000`0o04D0000003l0A@0703l0A@030000003Ta[T0i<Ji01/0
i<Ji00@02NX:0>C6^@3Ta[T02NX:2`1HH/800`09jPX0F6;205QR`P0@05QR`P0300WZ2P000000]9:c
01<0]9:c00@000000;GCk`2ednl0]M?_0`00000<0?ooo`0300WZ2P3oool0oooo00H0oooo0`09jPX0
0`0000002NX:00WZ2P0U0?ooo`030000003oool0oooo0180oooo000a0?ooo`030000003oool0oooo
00l0oooo0P09jPX50?ooo`<02NX:5`3oool01009jPX0oooo00000009jPX30?ooo`D02NX:00@0oooo
00WZ2P09jPX02NX:1@3oool00`09jPX0000000WZ2P0300WZ2P0408bhm00000000000000000X0S;Sd
00D000000::4/`2RQ;<0XXBc0000000502H0<P030000003N`;/0g/2k01l0g/2k00@02NX:0=k0^`3N
`;/000001@15E;h01009jPX0AEBn04ED_P09jPX=04ED_P<00000102_S[<01009jPX0[hjc00000000
000D0:n>/`030000002acnl0/Lo_0080/Lo_0`000000102NN:P0oooo0?ooo`3oool200WZ2PT0oooo
00<0000000WZ2P3oool03P3oool600WZ2R00oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`050?ooo`802NX:203oool400WZ2QX0oooo00<02NX:0?ooo`09jPX02009jPX30?ooo`800000
0P3oool2000000<0T[cc0`09jPX409:ll`0300WZ2P2B_?<0T[cc00P0T[cc100000040:R9]0030000
000o04D0?`1500D0?`1500<000000>C6^@3Ta[T0703Ta[T01P09jPX0i<Ji0>C6^@000000F6;200WZ
2PT0F6;200<02NX:05QR`P1HH/803P1HH/84000001@0]9:c1000000200WZ2Pd0oooo00<02NX:0?oo
o`3oool02P3oool00`000000oooo00WZ2P0500WZ2Ql0oooo00<000000?ooo`3oool04P3oool00340
oooo00<000000?ooo`3oool04`3oool300WZ2QX0oooo00@02NX:0?ooo`09jPX000000`09jPX30?oo
o`<02NX:1`3oool01@09jPX0000000WZ2P09jPX0S;Sd00<000003@2<^?@00`000000XXBc0::4/`02
0::4/`050000000V03809P0b02H0<P0000008`3N`;/01009jPX0g/2k0=k0^`00000404ED_P0400WZ
2P15E;h0AEBn00WZ2Pd0AEBn00<0000004ED_P09jPX0102_S[<00`09jPX0[hjc0:n>/`0F0:n>/`@0
000000<0/Lo_0?ooo`3oool01P3oool200WZ2PL0oooo00<02NX:0000003oool0503oool600WZ2Q/0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0<0?ooo`<02NX:703oool00`000000
2NX:00WZ2P0200WZ2P80oooo0`09jPX90?ooo`8000001@09jPX609:ll`0300WZ2P2B_?<0T[cc00D0
T[cc100000080:R9]0030000000o04D0?`1500@0?`1500<000000>C6^@3Ta[T07@3Ta[T01@09jPX0
i<Ji0000001HH/802NX:00T0F6;200<02NX:05QR`P1HH/80301HH/8200000080]9:c0P00000D0;BB
/`800000103oool200WZ2P/0oooo00<02NX:0?ooo`3oool02P3oool00`000000oooo0?ooo`050?oo
o`H02NX:6@3oool00`000000oooo0?ooo`0B0?ooo`00<03oool00`000000oooo0?ooo`0A0?ooo`<0
2NX:7@3oool00`09jPX0oooo0?ooo`0200000080oooo0`09jPX70?ooo`80000000<02NX:0000002<
^?@00`0000000`09jPX0S;Sd08bhm00=08bhm0030000002RQ;<0XXBc0080XXBc00@0000002H0<P0V
03800000903N`;/01009jPX0g/2k0=k0^`00000404ED_P0400WZ2P15E;h0AEBn00WZ2P/0AEBn0P00
00000`09jPX0[hjc0:n>/`040:n>/`0300WZ2P2_S[<0[hjc01H0[hjc00<000000;7?k`2NN:P0303o
ool200WZ2PD0oooo00<02NX:0?ooo`0000006P3oool600WZ2QD0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`090?ooo`<02NX:7`3oool4000000<02NX:2`3oool00`0000002NX:00WZ
2P0409:ll`0300WZ2P2B_?<0T[cc00<0T[cc00<02NX:09:ll`2B_?<00`2B_?<3000000<0T[cc00<0
00000:R9]02XRK@01P2XRK@00`000000?`1503l0A@0303l0A@030000003Ta[T0i<Ji01h0i<Ji00@0
2NX:0>C6^@0000002NX:2P1HH/800`09jPX0F6;205QR`P0:05QR`P8000001@2dT[<00`09jPX0]9:c
0;BB/`0C0;BB/`030000003oool0oooo00@0oooo0P09jPX80?ooo`0300WZ2P3oool0oooo00`0oooo
00<000000?ooo`3oool02P3oool500WZ2Q@0oooo00<000000?ooo`3oool04P3oool00300oooo00<0
00000?ooo`3oool03P3oool300WZ2Ql0oooo00<02NX:0?ooo`3oool00P3oool300WZ2PP0oooo0P09
jPX5000000<0S;Sd00<02NX:08bhm02<^?@03@2<^?@00`000000XXBc0::4/`020::4/`040000000V
03809P0b000002D0g/2k00<02NX:0=k0^`0000001015E;h01009jPX0AEBn04ED_P09jPX:04ED_P03
00000015E;h0[hjc00L0[hjc00<02NX:0:n>/`2_S[<05P2_S[<00`000000oooo0?ooo`0>0?ooo`80
2NX:0`3oool01009jPX0oooo0?ooo`00000O0?ooo`H02NX:3`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00H0oooo0`09jPXS0?ooo`<02NX:2`3oool200WZ2P030000002B_?<0T[cc
00D0T[cc00<02NX:09:ll`2B_?<00P2B_?<200000080T[cc0`00000609:ll`030000002XRK@0Z8Vd
00L0Z8Vd00D0000003l0A@0o04D0?`150000000R0>C6^@0400WZ2P0000002NX:00WZ2PT0F6;20P09
jPX905QR`P8000001`2dT[<00`09jPX0]9:c0;BB/`0C0;BB/`030000003oool0oooo00H0oooo0P09
jPX60?ooo`0300WZ2P3oool0oooo00d0oooo00<000000?ooo`3oool03P3oool600WZ2Pl0oooo00<0
00000?ooo`3oool04@3oool00300oooo00<000000?ooo`3oool02`3oool300WZ2R80oooo00<02NX:
0?ooo`09jPX00P09jPX80?ooo`<02NX:1000000608bhm00300WZ2P2<^?@0S;Sd00d0S;Sd00<00000
0::4/`2RQ;<00`2RQ;<2000002H0g/2k00<02NX:0=k0^`0000001015E;h01@09jPX0AEBn00000009
jPX0000000L0AEBn0P0000000`09jPX0[hjc0:n>/`070:n>/`0300WZ2P2_S[<0[hjc01H0[hjc00<0
00000?ooo`3oool0403oool01009jPX0oooo0?ooo`09jPX20?ooo`030000003oool0oooo02<0oooo
1P09jPX20?ooo`8000001@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo
1009jPXS0?ooo`<02NX:0P3oool00`09jPX0oooo0?ooo`060?ooo`<02NX:00<0oooo0000002B_?<0
1`2B_?<00`09jPX0T[cc09:ll`0209:ll`@000002@2B_?<00`000000Z8Vd0:R9]0070:R9]0802NX:
0P0o04D00`000000i<Ji0>C6^@0Q0>C6^@0300WZ2P1HH/80F6;200D0F6;20`0000000`1HH/802NX:
00WZ2P0705QR`P<00000202dT[<00`09jPX0]9:c0;BB/`0C0;BB/`030000003oool0oooo00P0oooo
0`09jPX30?ooo`0300WZ2P3oool0oooo00h0oooo00<000000?ooo`3oool04`3oool600WZ2P80oooo
0P0000050?ooo`030000003oool0oooo0140oooo000`0?ooo`030000003oool0oooo00P0oooo0`09
jPXT0?ooo`<02NX:1`3oool400WZ2P<000000P3oool4000000@0S;Sd00<02NX:08bhm02<^?@03@2<
^?@00`000000XXBc0::4/`030::4/`<000009@3N`;/0100000002NX:00000009jPX304ED_P0500WZ
2P15E;h0000000WZ2P0000001P15E;h0100000002NX:04ED_P09jPX:0:n>/`0300WZ2P2_S[<0[hjc
01D0[hjc00<000000?ooo`3oool04@3oool300WZ2P<0oooo00<000000?ooo`3oool0:03oool300WZ
2P030000003oool0oooo00<0oooo00<000000?ooo`3oool0803oool00`000000oooo00WZ2P0200WZ
2R@0oooo0`09jPX50?ooo`0300WZ2P3oool0oooo0080oooo1009jPX30?ooo`@000001P2B_?<00`09
jPX0T[cc00000002000000d0T[cc00<000000:R9]02XRK@01P2XRK@00`09jPX0Z8Vd000000020000
0280i<Ji0P0000000`09jPX0000005QR`P0505QR`P<0000000<0F6;200WZ2P09jPX01@1HH/830000
00/0]9:c00<02NX:0;BB/`2dT[<04P2dT[<00`000000oooo0?ooo`0;0?ooo`802NX:00<0oooo00WZ
2P3oool03`3oool00`000000oooo0?ooo`0I0?ooo`<02NX:00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0A0?ooo`00<03oool00`000000oooo0?ooo`050?ooo`<02NX:903oool400WZ2PH0
oooo0`09jPX0103oool000000000000000090?ooo`@0000000<02NX:0000002<^?@03@2<^?@00`00
0000XXBc0::4/`030::4/`802NX:00<0XXBc0000000000000`00000P0=k0^`0300000009jPX00000
00@0AEBn00D02NX:04ED_P15E;h0AEBn00WZ2P0404ED_P80000000<0AEBn00WZ2P2_S[<02`2_S[<0
0`09jPX0[hjc0:n>/`0E0:n>/`030000003oool0oooo01<0oooo0P09jPX30?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool07`3oool300WZ2R@0oooo0`09jPX70?ooo`0300WZ2P3oool0
oooo00<02NX:2`3oool800000100T[cc00<000000:R9]02XRK@0102XRK@200WZ2P<0Z8Vd0`00000Q
0>C6^@80000000<0i<Ji00WZ2P1HH/802@1HH/8200WZ2P<0F6;200<0000000WZ2P0000000`2dT[<0
0`09jPX0]9:c0;BB/`070;BB/`0300WZ2P2dT[<0]9:c0180]9:c00<000000?ooo`3oool03@3oool2
00WZ2Q40oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0A0?ooo`00<03oool00`00
0000oooo0?ooo`020?ooo`<02NX:903oool300WZ2P80oooo00<02NX:0?ooo`3oool00P3oool300WZ
2P040?ooo`000000000000000100oooo00<02NX:0?ooo`0000001@00000808bhm0030000002RQ;<0
XXBc0080XXBc00<02NX:0::4/`2RQ;<01@2RQ;<00`2d<000000000000002000001h0g/2k00<02NX:
00000015E;h00P15E;h01@09jPX0AEBn04ED_P15E;h02NX:00<0AEBn00H0000000WZ2P09jPX02NX:
0:n>/`09jPX;0:n>/`0300WZ2P2_S[<0[hjc00D0[hjc0P00000?0:n>/`030000003oool0oooo0140
oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0703oool300WZ2P030000003oool0oooo0240oooo0`09jPX:0?ooo`<02NX:3`3oool500000003
00WZ2P0000000000008000003@2B_?<00`000000Z8Vd0:R9]0030:R9]00300WZ2P2XRK@0Z8Vd00H0
Z8Vd1@00000O0>C6^@802NX:2@1HH/801009jPX0F6;200WZ2P1HH/820000000500WZ2P2dT[<0]9:c
0;BB/`09jPX02P2dT[<00`09jPX0]9:c0;BB/`020;BB/`8000003`2dT[<00`000000oooo0?ooo`0<
0?ooo`0400WZ2P3oool02NX:00WZ2Q00oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0A0?ooo`00<03oool00`000000oooo0?ooo`0200WZ2R@0oooo0`09jPX50?ooo`D02NX:00@0oooo
00000000000000004`3oool01009jPX0oooo0?ooo`09jPX30?ooo`L0000000<0S;Sd00WZ2P000000
0P2RQ;<200WZ2Pd0XXBc1000000J0=k0^`0300WZ2P000000AEBn0080AEBn00D02NX:04ED_P15E;h0
AEBn00WZ2P0204ED_P0300000015E;h0[hjc0080[hjc1009jPX2000000L0[hjc00<02NX:0:n>/`2_
S[<01@2_S[<2000000l0[hjc00<0000000WZ2P09jPX00P09jPX?0?ooo`0300WZ2P3oool0oooo0080
oooo0P09jPX00`3oool000000?ooo`0_0?ooo`030000003oool0oooo01X0oooo0P09jPX30?ooo`03
0000003oool0oooo01h0oooo0`09jPX:0?ooo`@02NX:3P3oool3000000D0oooo0P09jPX30?ooo`H0
00000P2B_?<20000000409:ll`09jPX02NX:000000<0Z8Vd0P09jPX>0:R9]0@000006`3Ta[T00`00
00002NX:05QR`P0805QR`P0400WZ2P1HH/802NX:000000<02NX:0P2dT[<00`0000002NX:0;BB/`09
0;BB/`0300WZ2P2dT[<0]9:c0080]9:c0P00000?0;BB/`0300000009jPX02NX:00802NX:2P3oool0
1009jPX0oooo0?ooo`3oool200WZ2Ph0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0A0?ooo`00;`3oool00`000000oooo0?ooo`0T0?ooo`<02NX:1P3oool300WZ2P80oooo0`00000F
0?ooo`<02NX:203oool300WZ2P<0000000<0XXBc00WZ2P2RQ;<04P2RQ;<5000001H0g/2k00@02NX:
04ED_P15E;h02NX:1015E;h00`09jPX0000000000002000000@0[hjc00<02NX:0:n>/`2_S[<00P09
jPX80:n>/`0300WZ2P2_S[<0[hjc01D0[hjc00<000000?ooo`3oool00P3oool800WZ2PL0oooo00<0
2NX:0?ooo`3oool0103oool200WZ2P030000003oool0oooo02d0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0K0?ooo`<02NX:2@3oool400WZ2P80oooo00<02NX:0?ooo`3oool02P3o
ool3000000L0oooo0P09jPX80?ooo`802NX:0`00000200WZ2P0309:ll`00000000000080Z8Vd00<0
2NX:0:R9]02XRK@04P2XRK@5000001H0i<Ji00<0000005QR`P09jPX0201HH/800`09jPX0000000WZ
2P040;BB/`<02NX:00<000000;BB/`2dT[<02@2dT[<00`09jPX0]9:c0;BB/`0B0;BB/`030000003o
ool0oooo0080oooo1`09jPX30?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPX=0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0403oool002l0oooo00<000000?ooo`3oool08@3oool3
00WZ2PH0oooo0`09jPX00`3oool02NX:00000002000001P0oooo0P09jPX50?ooo`D02NX:1@3oool2
00WZ2QP0XXBc00<0]3000000000000000P00000B0=k0^`0400WZ2P15E;h0AEBn00WZ2P@0AEBn00<0
2NX:04ED_P2_S[<00P0000050:n>/`0300WZ2P2_S[<0[hjc00T0[hjc00<02NX:0:n>/`2_S[<05@2_
S[<00`000000oooo0?ooo`0:0?ooo`P02NX:203oool00`09jPX000000?ooo`0]0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0603oool300WZ2PT0oooo0`09jPX60?ooo`0300WZ2P3o
ool0oooo00H0oooo100000090?ooo`0300WZ2P3oool02NX:0080oooo1P09jPX70?ooo`<0000000<0
Z8Vd00WZ2P2XRK@06@2XRK@400000180i<Ji00<0000000WZ2P09jPX01P1HH/820000000300WZ2P2d
T[<02NX:00@0]9:c00<02NX:0;BB/`2dT[<0302dT[<00`09jPX0]9:c0;BB/`0B0;BB/`030000003o
ool0oooo00T0oooo1`09jPX40?ooo`802NX:303oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0100oooo000_0?ooo`030000003oool0oooo01l0oooo0P09jPX60?ooo`<02NX:00<0oooo
0000000000000P00000J0?ooo`0300WZ2P3oool02NX:00D02NX:203oool200WZ2P030000002RQ;<0
XXBc01`0XXBc1@00000=0=k0^`0400000009jPX0AEBn00WZ2P80AEBn0P0000000`09jPX0[hjc0:n>
/`070:n>/`0300WZ2P2_S[<0[hjc00T0[hjc00<02NX:0:n>/`2_S[<05@2_S[<00`0000002NX:0?oo
o`0A0?ooo`P02NX:0P3oool00`0000002NX:00WZ2P0/0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool05@3oool300WZ2PT0oooo0`09jPX90?ooo`0300WZ2P3oool0oooo00<0oooo0`00
000;0?ooo`L02NX:2`3oool300WZ2P030?ooo`09jPX02NX:01l0Z8Vd1000000>0>C6^@80000000<0
F6;200WZ2P1HH/800P1HH/82000000030;BB/`0000002NX:0080]9:c00D02NX:0;BB/`2dT[<0]9:c
00WZ2P0>0;BB/`0300WZ2P2dT[<0]9:c0180]9:c00<000000?ooo`3oool02`3oool00`09jPX0oooo
0?ooo`020?ooo`P02NX:2P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0100oooo
000_0?ooo`030000003oool0oooo02<0oooo1009jPX0103oool000000000000000020?ooo`0300WZ
2P3oool0oooo0180oooo0P0000020?ooo`H02NX:203oool600WZ2P030?ooo`000000XXBc0240XXBc
00<0]3000000000000000P0000090=k0^`80000000L02NX:000000000000000004ED_P2_S[<02NX:
00T0[hjc00<02NX:0:n>/`2_S[<02@2_S[<00`09jPX0[hjc0:n>/`0E0:n>/`0300000009jPX0oooo
0140oooo00<02NX:0?ooo`3oool01@3oool300WZ2P0400000009jPX02NX:00WZ2R/0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?ooo`802NX:2@3oool300WZ2P/0oooo00@02NX:
0?ooo`3oool0oooo0`00000:0?ooo`H02NX:0P3oool00`09jPX0oooo0?ooo`080?ooo`<02NX:0`3o
ool00`09jPX000000:R9]00S0:R9]0D000002@3Ta[T0102/OJ40000005QR`P09jPX205QR`P800000
0P2dT[<200000080]9:c00<02NX:0;BB/`2dT[<00P2dT[<00`09jPX0]9:c0;BB/`0;0;BB/`0300WZ
2P2dT[<0]9:c0180]9:c00<000000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`090?ooo`L02NX:
1@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0100oooo000_0?ooo`030000003o
ool0oooo0200oooo0`09jPX20?ooo`<000001@3oool00`09jPX0oooo0?ooo`0B0?ooo`0300000009
jPX02NX:00802NX:103oool00`09jPX0oooo0?ooo`030?ooo`<02NX:0P3oool200WZ2P<0oooo00<0
00000::4/`2RQ;<09@2RQ;<20000000300WZ2P000000g/2k00D0g/2k00@0000000WZ2P0000000000
102_S[<00`09jPX0[hjc0:n>/`070:n>/`0300WZ2P2_S[<0[hjc00P0[hjc00<02NX:0:n>/`2_S[<0
5P2_S[<00`0000002NX:0?ooo`0?0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`09jPX0
1`09jPXT0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06P3oool400WZ2Ph0oooo
100000090?ooo`0500000009jPX02NX:00WZ2P3oool00P09jPX50?ooo`0300WZ2P3oool0oooo00@0
oooo1009jPX40?ooo`802NX:00<0oooo0000002XRK@0:02XRK@20000000300WZ2P000000i<Ji00D0
i<Ji00D0000005QR`P1HH/802NX:000000040;BB/`8000000P2dT[<00`09jPX0]9:c0;BB/`020;BB
/`0300WZ2P2dT[<0]9:c00`0]9:c00<02NX:0;BB/`2dT[<04P2dT[<00`000000oooo0?ooo`0:0?oo
o`0300WZ2P3oool0oooo00`0oooo0P09jPX20?ooo`H02NX:00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0@0?ooo`00;`3oool00`000000oooo0?ooo`0M0?ooo`<02NX:0P3oool3000000L0
oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00<0
2NX:103oool00`09jPX0oooo0?ooo`030?ooo`030000002RQ;<0XXBc02L0XXBc00<02NX:0::4/`00
000010000000103N`;/0000000000009jPX50:n>/`0300WZ2P2_S[<0[hjc00L0[hjc00<02NX:0:n>
/`2_S[<02@2_S[<00`09jPX0[hjc0:n>/`0E0:n>/`0300000009jPX0oooo00l0oooo00<02NX:0?oo
o`3oool02`3oool00`000000oooo0?ooo`0200WZ2P@0oooo1`09jPXM0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool05`3oool300WZ2Pl0oooo0`0000000`09jPX0oooo0?ooo`0:0?oo
o`80000000<0oooo00WZ2P09jPX01`3oool01009jPX0oooo0?ooo`3oool300WZ2PL0oooo00<02NX:
0?ooo`3oool00P3oool00`000000Z8Vd0:R9]00X0:R9]00300WZ2P2XRK@0000000@0000000H0i<Ji
00000000000000000;BB/`09jPX80;BB/`802NX:0`2dT[<00`09jPX0]9:c0;BB/`0<0;BB/`0300WZ
2P2dT[<0]9:c0180]9:c00<000000?ooo`3oool02@3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ
2P3oool0oooo00H0oooo00<0000000WZ2P09jPX01009jPXH0?ooo`030000003oool0oooo0100oooo
000_0?ooo`030000003oool0oooo01X0oooo0`09jPX20?ooo`<000002P3oool00`09jPX0oooo0?oo
o`0E0?ooo`0300WZ2P000000oooo00@0oooo0`09jPX50?ooo`802NX:1P3oool00`000000XXBc0::4
/`0V0::4/`0300WZ2P2RQ;<0XXBc00D0XXBc0`0000000`09jPX0[hjc0:n>/`030:n>/`0300WZ2P2_
S[<0[hjc00L0[hjc00<02NX:0:n>/`2_S[<02@2_S[<00`09jPX0[hjc0:n>/`0E0:n>/`030000003o
ool02NX:00l0oooo00<02NX:0?ooo`3oool0303oool010000000oooo0?ooo`3oool200WZ2PT0oooo
1P09jPXG0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0503oool300WZ2Pl0oooo
0`0000020?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0000003oool01`3oool400WZ2PP0oooo
0P09jPX50?ooo`030000002XRK@0Z8Vd02L0Z8Vd00<02NX:0:R9]02XRK@01@2XRK@4000000030;BB
/`09jPX0]9:c00P0]9:c00<02NX:0;BB/`2dT[<00P2dT[<00`09jPX0]9:c0;BB/`0;0;BB/`0300WZ
2P2dT[<0]9:c0180]9:c00<0000000WZ2P3oool02@3oool00`09jPX0oooo0?ooo`0@0?ooo`802NX:
1P3oool00`000000oooo0?ooo`040?ooo`L02NX:4@3oool00`000000oooo0?ooo`0@0?ooo`00;`3o
ool00`000000oooo0?ooo`0G0?ooo`<02NX:0P3oool3000000d0oooo00<02NX:0?ooo`3oool05@3o
ool2000000030?ooo`09jPX02NX:00<02NX:1P3oool00`09jPX0oooo0?ooo`060?ooo`030000002R
Q;<0XXBc02H0XXBc00<02NX:0::4/`2RQ;<00`2RQ;<20000000500dm_0000000jM>o0>WC_`09jPX0
0P0000020:n>/`0300WZ2P2_S[<0[hjc00P0[hjc0P0000090:n>/`0300WZ2P2_S[<0[hjc01D0[hjc
00@000000?ooo`3oool02NX:3P3oool00`09jPX0oooo0?ooo`0=0?ooo`030000003oool0oooo0080
oooo0P09jPX=0?ooo`L02NX:00<0oooo0000000000003@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0100oooo1009jPX>0?ooo`@000001@3oool00`09jPX0oooo0?ooo`0=0?ooo`80
00001@3oool400WZ2PX0oooo00<02NX:0?ooo`3oool01@3oool00`000000Z8Vd0:R9]00W0:R9]003
00WZ2P2XRK@0Z8Vd00<0Z8Vd0P000000100/DLD000000>oK_03_fk`20000000300WZ2P000000]9:c
00H0]9:c00<02NX:0;BB/`2dT[<00P2dT[<2000000d0]9:c00<02NX:0;BB/`2dT[<04@2dT[<00`00
00002NX:0?ooo`090?ooo`0300WZ2P3oool0oooo0180oooo0P09jPX50?ooo`030000003oool0oooo
00X0oooo1009jPX00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo000^0?ooo`03
0000003oool0oooo01D0oooo0`09jPX20?ooo`<000003`3oool00`09jPX0oooo0?ooo`0F0?ooo`<0
2NX:103oool00`09jPX0oooo0?ooo`020?ooo`802NX:2@3oool00`000000XXBc0::4/`0V0::4/`04
00WZ2P2RQ;<0XXBc0::4/`8000000`0=?K`010000000jM>o0>WC_`09jPX20>WC_`80000000<02NX:
0:n>/`2_S[<0202_S[<2000000T0[hjc00<02NX:0:n>/`2_S[<05@2_S[<010000000oooo0?ooo`09
jPX>0?ooo`0300WZ2P3oool0oooo00h0oooo00<000000?ooo`3oool00`3oool200WZ2Q80oooo0`09
jPX=0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03@3oool300WZ2Pl0oooo0`00
00090?ooo`0300WZ2P3oool0oooo0140oooo0`09jPX30?ooo`0300WZ2P3oool0oooo00H0oooo0P09
jPX80?ooo`030000002XRK@0Z8Vd02L0Z8Vd00@02NX:0:R9]02XRK@0Z8Vd0P00000302aAa@030000
003_fk`0km^l0080km^l00<02NX:0000000000000P0000040;BB/`0300WZ2P2dT[<0]9:c0080]9:c
0P00000=0;BB/`0300WZ2P2dT[<0]9:c0140]9:c00<000000?ooo`09jPX02@3oool00`09jPX0oooo
0?ooo`0D0?ooo`802NX:103oool00`000000oooo0?ooo`0<0?ooo`8000003@3oool00`000000oooo
0?ooo`0?0?ooo`00;P3oool00`000000oooo0?ooo`0B0?ooo`<02NX:0P3oool300000180oooo00<0
2NX:0?ooo`3oool04`3oool300WZ2PL0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0;0?ooo`030000
002RQ;<0XXBc02D0XXBc00H02NX:0::4/`2RQ;<0XXBc0000002RQ;<500dm_0040000003Ydkl0jM>o
00WZ2P<0jM>o00<02NX:0000000000000P00000B0:n>/`0300WZ2P2_S[<0[hjc01D0[hjc00@00000
0?ooo`3oool02NX:303oool00`09jPX0oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo0P09
jPXP0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02P3oool300WZ2Pl0oooo0`00
000;0?ooo`0300WZ2P3oool0oooo00l0oooo0`09jPX60?ooo`0300WZ2P3oool0oooo00D0oooo00<0
2NX:0?ooo`3oool0203oool00`000000Z8Vd0:R9]00V0:R9]00300WZ2P2XRK@0Z8Vd00<00000100/
DLD00`000000km^l0>oK_0030>oK_00300WZ2P3_fk`0km^l00D0000000<02NX:0;BB/`2dT[<04@2d
T[<00`09jPX0]9:c0;BB/`0B0;BB/`0300000009jPX0oooo00L0oooo00<02NX:0?ooo`3oool05`3o
ool200WZ2P80oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0?0?ooo`00;P3oool0
0`000000oooo0?ooo`0@0?ooo`802NX:00<0oooo0000000000000P00000D0?ooo`0300WZ2P3oool0
oooo0140oooo0`09jPX:0?ooo`0400WZ2P3oool02NX:00WZ2P`0oooo00<000000::4/`2RQ;<09@2R
Q;<01009jPX0XXBc00000000000500dm_0<000000P3Ydkl01@09jPX0jM>o0>WC_`3Ydkl02NX:00@0
jM>o0`0000000`09jPX0[hjc0:n>/`0<0:n>/`0300WZ2P2_S[<0[hjc01D0[hjc00@000000?ooo`3o
ool02NX:303oool00`09jPX0oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo0P09jPXN0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool300WZ2Ph0oooo1000000>0?oo
o`0300WZ2P3oool0oooo00/0oooo1009jPX90?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?oo
o`3oool02@3oool00`000000Z8Vd0:R9]00V0:R9]00400WZ2P0000000000000000@0;5750P000000
0`0/DLD000000>oK_0040>oK_00300WZ2P3_fk`0km^l00<0km^l0P0000000`09jPX000000;BB/`0@
0;BB/`0300WZ2P2dT[<0]9:c0180]9:c00<000000?ooo`09jPX01`3oool00`09jPX0oooo0?ooo`0I
0?ooo`802NX:00<0oooo0000003oool06`3oool00`000000oooo0?ooo`0?0?ooo`00;P3oool00`00
0000oooo0?ooo`0@0?ooo`<00000603oool00`09jPX0oooo0?ooo`0>0?ooo`<02NX:3@3oool200WZ
2Ph0oooo00<000000::4/`2RQ;<0902RQ;<01009jPX000000000002RQ;<500dm_00400WZ2P000000
0000000000<0jM>o00<02NX:0>WC_`3Ydkl00P0000060>WC_`<00000302_S[<00`09jPX0[hjc0:n>
/`0E0:n>/`050000003oool0oooo0?ooo`09jPX02`3oool00`09jPX0oooo0?ooo`0A0?ooo`030000
003oool0oooo00L0oooo0P09jPXL0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1@3oool200WZ2Ph0oooo0`00000A0?ooo`0300WZ2P3oool0oooo00T0oooo0`09jPX=0?ooo`0300WZ
2P3oool0oooo0080oooo0P09jPX<0?ooo`030000002XRK@0Z8Vd02D0Z8Vd00<02NX:000000000000
1P0/DLD20000000302aAa@000000km^l00@0km^l00<02NX:0>oK_03_fk`00`3_fk`00`09jPX00000
00000004000000l0]9:c00<02NX:0;BB/`2dT[<04@2dT[<00`000000oooo00WZ2P070?ooo`0300WZ
2P3oool0oooo01/0oooo0P09jPX00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0oooo
000^0?ooo`030000003oool0oooo00d0oooo0`00000J0?ooo`0300WZ2P3oool0oooo00/0oooo1009
jPX?0?ooo`802NX:3`3oool00`000000XXBc0::4/`0S0::4/`0300000009jPX0XXBc00H03Cfl00D0
2NX:00dm_00=?K`03Cfl000000030>WC_`0300WZ2P3Ydkl0jM>o008000001`3Ydkl00`09jPX0jM>o
00000003000000P0[hjc00<02NX:0:n>/`2_S[<05@2_S[<01@000000oooo0?ooo`3oool02NX:00/0
oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01T0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooo`<00000503oool00`09jPX0
oooo0?ooo`060?ooo`<02NX:403oool01@09jPX0oooo0?ooo`3oool02NX:00h0oooo00<000000:R9
]02XRK@08`2XRK@20000000300WZ2P0/DLD0;57500H0;57500@02NX:02aAa@0/DLD000001P3_fk`0
0`09jPX0km^l0>oK_0030>oK_08000000`3_fk`5000000/0]9:c00<02NX:0;BB/`2dT[<04@2dT[<0
10000000oooo0?ooo`09jPX60?ooo`0300WZ2P3oool0oooo01d0oooo00<0000000WZ2P3oool06@3o
ool00`000000oooo0?ooo`0?0?ooo`00;P3oool00`000000oooo0?ooo`0:0?ooo`<000007@3oool0
0`09jPX0oooo0?ooo`080?ooo`<02NX:4P3oool00`09jPX0oooo00WZ2P0?0?ooo`030000002RQ;<0
XXBc0240XXBc0P0000000`2RQ;<02NX:00dm_00500dm_00300WZ2P0=?K`03Cfl00<03Cfl00D00000
0>WC_`3Ydkl0jM>o00WZ2P0:0>WC_`0300WZ2P3Ydkl0jM>o00<0jM>o0`0000060:n>/`0300WZ2P2_
S[<0[hjc01@0[hjc00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3o
ool0oooo01<0oooo00<000000?ooo`3oool0203oool200WZ2QT0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0?0?ooo`@000005`3oool00`09jPX0oooo0?ooo`020?ooo`@02NX:4`3o
ool01009jPX0oooo00WZ2P09jPX?0?ooo`030000002XRK@0Z8Vd0280Z8Vd0P0000000`0/DLD02NX:
02aAa@0602aAa@0500WZ2P0/DLD0;57502aAa@0000001P3_fk`00`09jPX0km^l0>oK_0030>oK_003
00WZ2P3_fk`0km^l00H0km^l100000080;BB/`0300WZ2P2dT[<0]9:c0140]9:c00@000000?ooo`3o
ool02NX:1P3oool00`09jPX0oooo0?ooo`0N0?ooo`0300000009jPX02NX:01T0oooo00<000000?oo
o`3oool03P3oool002h0oooo00<000000?ooo`3oool01`3oool300000200oooo00<02NX:0?ooo`3o
ool01@3oool300WZ2Q<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00d0oooo00<000000::4/`2R
Q;<0802RQ;<0100000004P0000dm_009jPX600dm_00300WZ2P0=?K`03Cfl00@03Cfl00D000000>WC
_`3Ydkl0jM>o00WZ2P0:0>WC_`0300WZ2P3Ydkl0jM>o00H0jM>o100000020:n>/`0300WZ2P2_S[<0
[hjc01@0[hjc00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0
oooo01@0oooo00<000000?ooo`3oool02@3oool200WZ2QP0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0<0?ooo`<000006P3oool00`09jPX0oooo0?ooo`0300WZ2QL0oooo0P09jPXA
0?ooo`030000002XRK@0Z8Vd0200Z8Vd0`0000000`0/DLD02NX:02aAa@0602aAa@0300WZ2P0/DLD0
;5750080;57500<000000>oK_03_fk`01@3_fk`00`09jPX0km^l0>oK_0030>oK_00300WZ2P3_fk`0
km^l00L0km^l1@0000050;BB/`0300WZ2P2dT[<0]9:c0140]9:c00D000000?ooo`3oool0oooo00WZ
2P040?ooo`0300WZ2P3oool0oooo0200oooo00@000000?ooo`09jPX02NX:5`3oool00`000000oooo
0?ooo`0>0?ooo`00;@3oool00`000000oooo0?ooo`050?ooo`<000008P3oool00`09jPX0oooo0?oo
o`030?ooo`<02NX:503oool200WZ2P@0oooo00<02NX:0?ooo`3oool03@3oool00`000000XXBc0::4
/`0N0::4/`8000000P3oool00`0=?K`02NX:00dm_00400dm_00300WZ2P0=?K`03Cfl00D03Cfl00<0
00000>WC_`3Ydkl00P3Ydkl00`09jPX0jM>o0>WC_`080>WC_`0300WZ2P3Ydkl0jM>o00P0jM>o0`00
00000`09jPX0[hjc0:n>/`0E0:n>/`030000003oool0oooo0080oooo00<02NX:0?ooo`3oool01P3o
ool00`09jPX0oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo0P09jPXF0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool02@3oool3000001d0oooo0`09jPXI0?ooo`802NX:4P3o
ool00`000000Z8Vd0:R9]00N0:R9]0<000000`0/DLD00`09jPX0;57502aAa@0402aAa@0300WZ2P0/
DLD0;57500<0;57500<000000>oK_03_fk`01P3_fk`00`09jPX0km^l0>oK_0020>oK_00300WZ2P3_
fk`0km^l00L0km^l00<000000?ooo`3oool00P3oool3000000<0]9:c00<02NX:0;BB/`2dT[<04@2d
T[<010000000oooo0?ooo`09jPX40?ooo`0300WZ2P3oool0oooo0240oooo00<000000?ooo`3oool0
0P09jPXE0?ooo`030000003oool0oooo00h0oooo000]0?ooo`030000003oool0oooo0080oooo0`00
000U0?ooo`0300WZ2P3oool02NX:00<02NX:5P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3o
ool0oooo00d0oooo00<000000::4/`2RQ;<0702RQ;<2000000@0oooo00<02NX:00dm_00=?K`00`0=
?K`00`09jPX03Cfl00dm_00600dm_0030000003Ydkl0jM>o0080jM>o00<02NX:0>WC_`3Ydkl0203Y
dkl00`09jPX0jM>o0>WC_`080>WC_`040000003oool0oooo00WZ2P<00000502_S[<00`000000oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool05P3oool00`000000oooo
0?ooo`0<0?ooo`802NX:503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00D0oooo
1000000L0?ooo`D02NX:6P3oool00`09jPX0oooo00WZ2P0B0?ooo`030000002XRK@0Z8Vd01`0Z8Vd
1000000302aAa@0300WZ2P0/DLD0;57500@0;57500<02NX:02aAa@0/DLD01@0/DLD00`000000km^l
0>oK_0050>oK_00300WZ2P3_fk`0km^l00<0km^l00<02NX:0>oK_03_fk`01@3_fk`00`000000oooo
0?ooo`060?ooo`<0000000<02NX:0;BB/`2dT[<04@2dT[<01@000000oooo0?ooo`3oool02NX:00<0
oooo00<02NX:0?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`802NX:4`3oool00`000000
oooo0?ooo`0>0?ooo`00;@3oool00`000000oooo00000002000002L0oooo0`09jPXH0?ooo`802NX:
1`3oool00`09jPX0oooo0?ooo`0=0?ooo`030000002RQ;<0XXBc01X0XXBc0P0000000`09jPX0oooo
0?ooo`030?ooo`0300WZ2P0=?K`03Cfl00803Cfl00<02NX:00dm_00=?K`0200=?K`00`000000jM>o
0>WC_`020>WC_`0300WZ2P3Ydkl0jM>o00L0jM>o00<02NX:0>WC_`3Ydkl01`3Ydkl01@000000oooo
0?ooo`3oool02NX:00<0oooo1000000@0:n>/`030000003oool0oooo00<0oooo00<02NX:0?ooo`3o
ool01@3oool00`09jPX0oooo0?ooo`0G0?ooo`030000003oool0oooo00d0oooo0P09jPXB0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool3000001d0oooo0`09jPX30?ooo`03
00WZ2P3oool0oooo01L0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo0100oooo00<000000:R9]02X
RK@06`2XRK@200000080oooo00D0000002aAa@0/DLD0;57500WZ2P0502aAa@0300WZ2P0/DLD0;575
00H0;57500<000000>oK_03_fk`01P3_fk`00`09jPX0km^l0>oK_0020>oK_00300WZ2P3_fk`0km^l
00D0km^l00<000000?ooo`3oool02@3oool01009jPX0000000000000000@0;BB/`050000003oool0
oooo0?ooo`09jPX00`3oool00`09jPX0oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo0P09
jPXA0?ooo`030000003oool0oooo00h0oooo000]0?ooo`8000009`3oool400WZ2QT0oooo00<02NX:
0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0=0?ooo`030000002RQ;<0XXBc01P0XXBc0P000000
0`2RQ;<0oooo00WZ2P050?ooo`0300WZ2P3oool03Cfl00<02NX:2P0=?K`00`000000jM>o0>WC_`03
0>WC_`0300WZ2P3Ydkl0jM>o00L0jM>o00<02NX:0>WC_`3Ydkl01P3Ydkl00`000000oooo0?ooo`02
0?ooo`0300WZ2P3oool0oooo00@0oooo0`00000=0:n>/`030000003oool0oooo00@0oooo00<02NX:
0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0H0?ooo`030000003oool0oooo00h0oooo0P09jPX@
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000000P00000M0?ooo`<02NX:1P3oool0
0`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0403oool0
0`000000Z8Vd0:R9]00I0:R9]08000001@3oool010000000;57502aAa@09jPX402aAa@0300WZ2P0/
DLD0;57500L0;57500<000000>oK_03_fk`01`3_fk`00`09jPX0km^l0>oK_0020>oK_00300WZ2P3_
fk`0km^l00<0km^l00<000000?ooo`3oool02`3oool200WZ2P040?ooo`0000000000000000d0]9:c
00<000000?ooo`3oool00P3oool00`09jPX0oooo00WZ2P0V0?ooo`030000003oool0oooo00@0oooo
00<02NX:0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`00;`3oool00`000000oooo0?oo
o`0Q0?ooo`<02NX:0P3oool00`09jPX0oooo0?ooo`0F0?ooo`802NX:2P3oool00`09jPX0oooo0?oo
o`0>0?ooo`030000002RQ;<0XXBc01H0XXBc00D000000180003oool0oooo00WZ2P050?ooo`0400WZ
2P3oool0oooo00WZ2Pd03Cfl00<000000>WC_`3Ydkl00`3Ydkl00`09jPX0jM>o0>WC_`070>WC_`03
00WZ2P3Ydkl0jM>o00D0jM>o00<000000?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<000002P2_S[<00`000000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0
oooo00<02NX:0?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`802NX:3P3oool00`000000
oooo0?ooo`0L0?ooo`800000703oool400WZ2PT0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0
oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0100oooo00<000000:R9]02XRK@05`2XRK@3000000L0
oooo00<0000000WZ2P0/DLD00`0/DLD00`09jPX0;57502aAa@0802aAa@030000003_fk`0km^l00L0
km^l00<02NX:0>oK_03_fk`00`3_fk`00`09jPX0km^l0>oK_0020>oK_0030000003oool0oooo00/0
oooo00<02NX:0?ooo`09jPX00`3oool4000000T0]9:c00<000000?ooo`3oool00P3oool00`09jPX0
oooo00WZ2P0V0?ooo`030000003oool0oooo00D0oooo0P09jPX>0?ooo`030000003oool0oooo00h0
oooo000`0?ooo`030000003oool0oooo01d0oooo0`09jPX50?ooo`0300WZ2P3oool0oooo01D0oooo
00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0>0?ooo`030000002RQ;<0XXBc01@0XXBc
0P0000040?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`09jPX0oooo3@0=?K`2000000D0
jM>o00<02NX:0>WC_`3Ydkl01P3Ydkl00`09jPX0jM>o0>WC_`050>WC_`030000003oool0oooo00<0
oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`@000001P2_S[<00`000000
oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool06P3oool00`000000
oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0F0?ooo`<02NX:303oool00`09jPX0oooo0?ooo`0D0?ooo`802NX:1P3oool00`09jPX0
oooo0?ooo`0@0?ooo`030000002XRK@0Z8Vd01D0Z8Vd0`00000:0?ooo`0500WZ2P0/DLD0;57502aA
a@09jPX02`0/DLD00`000000km^l0>oK_0080>oK_00300WZ2P3_fk`0km^l0080km^l00D02NX:0>oK
_03_fk`0km^l0000000>0?ooo`0300WZ2P3oool02NX:00H0oooo100000060;BB/`030000003oool0
oooo00<0oooo0P09jPXW0?ooo`030000003oool0oooo00H0oooo0P09jPX=0?ooo`030000003oool0
oooo00d0oooo000a0?ooo`030000003oool0oooo01X0oooo0P09jPX80?ooo`0300WZ2P3oool0oooo
01<0oooo0P09jPX=0?ooo`0300WZ2P3oool0oooo00h0oooo00<000000::4/`2RQ;<04P2RQ;<20000
000300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool00`3oool200WZ2P<0oooo3@0=?K`00`00
0000jM>o0>WC_`030>WC_`0300WZ2P3Ydkl0jM>o00L0jM>o00<02NX:0>WC_`3Ydkl00`3Ydkl00`00
0000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool01P3oool30000
00@0[hjc00<000000?ooo`3oool0103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo
01`0oooo00<000000?ooo`3oool0403oool200WZ2P/0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0B0?ooo`<02NX:3`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo
00H0oooo00<02NX:0?ooo`3oool0403oool00`000000Z8Vd0:R9]00D0:R9]0800000303oool01009
jPX0000002aAa@09jPX<02aAa@030000003_fk`0km^l00T0km^l00<02NX:0>oK_03_fk`00P3_fk`0
1009jPX0km^l0>oK_000000>0?ooo`0300WZ2P3oool02NX:00T0oooo00@02NX:0000000000000000
102dT[<00`000000oooo0?ooo`020?ooo`802NX::03oool00`000000oooo0?ooo`070?ooo`802NX:
2`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool2000002<0oooo00<02NX:0?ooo`3oool04`3o
ool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00h0oooo00<000000::4/`2RQ;<0402R
Q;<200000080oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`802NX:1@3o
ool<00dm_0030000003Ydkl0jM>o00@0jM>o00<02NX:0>WC_`3Ydkl01P3Ydkl00`09jPX0jM>o0>WC
_`020>WC_`030000003oool0oooo00H0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?oo
o`080?ooo`0600WZ2P00000000000000002_S[<000001`3oool01@09jPX0oooo0?ooo`3oool02NX:
01l0oooo00<000000?ooo`3oool04@3oool200WZ2PT0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0?0?ooo`802NX:4P3oool00`09jPX0oooo0?ooo`0A0?ooo`802NX:2@3oool00`09
jPX0oooo0?ooo`0@0?ooo`030000002XRK@0Z8Vd0180Z8Vd0P00000=0?ooo`0400WZ2P3oool00000
00WZ2Ph0;57500<000000>oK_03_fk`0203_fk`00`09jPX0km^l0>oK_0020>oK_00300WZ2P3_fk`0
00000100oooo00<02NX:0?ooo`09jPX0203oool01009jPX0oooo00WZ2P3oool3000000030;BB/`00
0000oooo00<0oooo0P09jPXX0?ooo`030000003oool0oooo00T0oooo0P09jPX90?ooo`030000003o
ool0oooo00d0oooo000d0?ooo`030000003oool0oooo0200oooo00<02NX:0?ooo`3oool04@3oool2
00WZ2Q00oooo00<02NX:0?ooo`3oool03P3oool00`000000XXBc0::4/`0>0::4/`80000000D04P00
0?ooo`3oool0oooo00WZ2P040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool<00dm_0030000003Ydkl0jM>o00@0jM>o00<02NX:0>WC_`3Ydkl01P3Ydkl00`09jPX0jM>o0>WC
_`020>WC_`030000003oool0oooo00H0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?oo
o`080?ooo`0400WZ2P3oool0oooo0?ooo`8000001`3oool01@09jPX0oooo0?ooo`0000002NX:01l0
oooo00<000000?ooo`3oool04`3oool200WZ2PL0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0
oooo0?ooo`0@0?ooo`030000002XRK@0Z8Vd0100Z8Vd0`00000>0?ooo`0400WZ2P3oool02NX:0000
00h0;57500<000000>oK_03_fk`02@3_fk`00`09jPX0km^l0>oK_0020>oK_00300WZ2P3oool0oooo
00l0oooo00<02NX:0?ooo`09jPX0203oool00`09jPX0oooo00WZ2P040?ooo`8000000`3oool00`00
00002NX:00WZ2P0Y0?ooo`030000003oool0oooo00X0oooo00<02NX:0000000000001P3oool00`00
0000oooo0?ooo`0=0?ooo`00=@3oool00`000000oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo0140
oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`0>0?ooo`030000002RQ;<0XXBc00`0
XXBc0`0000040?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0
oooo0?ooo`060?ooo``03Cfl00<000000>WC_`3Ydkl0103Ydkl00`09jPX0jM>o0>WC_`060>WC_`04
00WZ2P3Ydkl0jM>o000000T0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`070?oo
o`0500WZ2P3oool0oooo0?ooo`09jPX02@3oool01009jPX0oooo00000000000P0?ooo`030000003o
ool0oooo01<0oooo0P0000060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0803o
ool00`09jPX0oooo0?ooo`0?0?ooo`802NX:2`3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P00
0000Z8Vd00l0Z8Vd00D02NX:000000000000oooo00WZ2P0=0?ooo`0300WZ2P3oool02NX:0080oooo
00<0000002aAa@0/DLD02`0/DLD00`000000km^l0>oK_0090>oK_00300WZ2P3_fk`0km^l0080km^l
00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo00WZ2P090?ooo`802NX:2@3oool2000000030?oo
o`09jPX0oooo02P0oooo00<000000?ooo`3oool02P3oool2000000H0oooo00<000000?ooo`3oool0
3@3oool003H0oooo00<000000?ooo`3oool07@3oool00`09jPX0oooo0?ooo`0?0?ooo`802NX:4`3o
ool00`09jPX0oooo0?ooo`0>0?ooo`030000002RQ;<0XXBc00/0XXBc00@000000180003oool00000
103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX90?ooo`/03Cfl
00<000000>WC_`3Ydkl0103Ydkl00`09jPX0jM>o0>WC_`060>WC_`802NX:00<0jM>o0000003oool0
203oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00P0oooo00D02NX:0?ooo`3oool0
oooo00WZ2P080?ooo`0300WZ2P3oool0oooo0280oooo00<000000?ooo`3oool04P3oool2000000L0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo00h0
oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0?0?ooo`0400WZ2P3oool0oooo0000
00h0Z8Vd0P0000020?ooo`0300WZ2P3oool0oooo00`0oooo0P09jPX30?ooo`030000000/DLD0;575
00/0;57500<000000>oK_03_fk`02P3_fk`01P09jPX0km^l0>oK_0000000oooo00WZ2Q00oooo00@0
2NX:0?ooo`3oool02NX:203oool00`09jPX0oooo00WZ2P0;0?ooo`0300WZ2P3oool0oooo02P0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`00=`3oool2000001`0oooo00<0
2NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00d0oooo00<0
2NX:0000002RQ;<02P2RQ;<2000000<0oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo0?oo
o`020?ooo`0700WZ2P3oool0oooo0?ooo`09jPX0oooo00WZ2P0:0?ooo`X03Cfl00<000000>WC_`3Y
dkl01@3Ydkl00`09jPX0jM>o0>WC_`050>WC_`0300WZ2P3Ydkl0000000X0oooo00<02NX:0?ooo`3o
ool01@3oool00`09jPX0oooo0?ooo`080?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02@3oool00`09
jPX0oooo0?ooo`0R0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool08`3oool20000
01h0oooo00<02NX:0?ooo`3oool03@3oool200WZ2Ph0oooo00<02NX:0?ooo`3oool03P3oool01@09
jPX0oooo0?ooo`3oool0000000`0Z8Vd0P0000001@3oool02NX:0?ooo`3oool02NX:00h0oooo00<0
2NX:0?ooo`3oool00`3oool00`000000;57502aAa@0:02aAa@030000003_fk`0km^l00/0km^l00D0
2NX:0>oK_0000000oooo00WZ2P0A0?ooo`0300WZ2P3oool02NX:00P0oooo00<02NX:0?ooo`09jPX0
303oool00`09jPX0oooo0?ooo`0W0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
3@3oool003T0oooo00<000000?ooo`3oool06@3oool00`09jPX0oooo0?ooo`0=0?ooo`802NX:5P3o
ool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0000000T0XXBc0P0000000`0B0000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00D02NX:0?ooo`3oool0oooo00WZ2P030?ooo`0300WZ
2P3oool02NX:00/0oooo2P0=?K`00`000000jM>o0>WC_`050>WC_`0300WZ2P3Ydkl0jM>o00H0jM>o
00<02NX:0000003oool02P3oool2000000D0oooo00<02NX:0?ooo`3oool0203oool01@09jPX0oooo
0?ooo`3oool02NX:00T0oooo00<02NX:0?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool06`3oool00`09jPX0oooo0?ooo`0<0?ooo`03
00WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`020?ooo`03
0000002XRK@0Z8Vd00P0Z8Vd0P0000030?ooo`0300WZ2P3oool02NX:00h0oooo00<02NX:0?ooo`3o
ool01@3oool00`000000;57502aAa@0902aAa@030000003_fk`0km^l00/0km^l00<02NX:0000003o
ool00P3oool00`09jPX0oooo0?ooo`0>0?ooo`80000000<02NX:0?ooo`3oool01P3oool00`09jPX0
oooo00WZ2P0=0?ooo`0300WZ2P3oool0oooo02L0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0<0?ooo`00>P3oool00`000000oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00`0oooo
00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0;0?ooo`0400WZ2P3oool0oooo000000L0
XXBc0P0000000`0B0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D02NX:0?ooo`3o
ool0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo00WZ2P`0oooo00<03Cfl00WZ2P0=?K`01`0=?K`0
0`000000jM>o0>WC_`050>WC_`8000001P3Ydkl00`09jPX0oooo0?ooo`0:0?ooo`8000001P3oool0
0`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool01`3oool0
0`09jPX0oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00X0oooo0P09jPXA0?ooo`0300WZ2P3oool0
oooo00/0oooo0P09jPX50?ooo`030000002XRK@0Z8Vd00L0Z8Vd0P0000040?ooo`0300WZ2P3oool0
2NX:00d0oooo0P09jPX70?ooo`0300WZ2P000000;57500X0;57500<000000>oK_03_fk`02`3_fk`0
1@09jPX0oooo0?ooo`3oool02NX:0100oooo0P0000000`3oool02NX:0?ooo`070?ooo`802NX:3@3o
ool00`09jPX0oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0303o
ool003/0oooo00<000000?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0;0?ooo`802NX:6@3oool0
0`09jPX0oooo0?ooo`090?ooo`802NX:0`3oool00`000000XXBc0::4/`030::4/`80000000<04P00
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool02NX:00<0oooo00@02NX:0?ooo`3oool02NX:
0P3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P0=?K`03Cfl00H03Cfl00<000000>WC_`3Ydkl0
1@3Ydkl2000000H0jM>o00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ
2P3oool0oooo0080oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0T0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0H0?ooo`0300WZ
2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00D0oooo00<000000:R9]02XRK@01@2XRK@2000000D0oooo00<02NX:0?ooo`09jPX0
3@3oool200WZ2PL0oooo00<02NX:0?ooo`0000002`0/DLD00`000000km^l0>oK_00:0>oK_0<00000
0`3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo00H0oooo0P09jPX>0?ooo`0300WZ
2P3oool0oooo02L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`00?03o
ool2000001H0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3o
ool0oooo00P0oooo00<02NX:0?ooo`3oool00`3oool00`000000XXBc0::4/`020::4/`030000000B
0000oooo00T0oooo00D000000?ooo`3oool0oooo00WZ2P030?ooo`0300WZ2P3oool02NX:00<0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX03Cfl00dm_00700dm_0030000003Ydkl0jM>o00`0jM>o
00<000000?ooo`09jPX04`3oool00`09jPX0oooo0?ooo`080?ooo`0500WZ2P3oool0oooo0?ooo`09
jPX02P3oool00`09jPX0oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo00P0oooo0P09jPXD0?ooo`03
00WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool01P3oool00`000000Z8Vd0:R9]0030:R9]080
00001`3oool00`09jPX0oooo00WZ2P0<0?ooo`0300WZ2P3oool02NX:00L0oooo00@02NX:0?ooo`3o
ool000002P0/DLD00`000000km^l0>oK_00:0>oK_0<000000`3oool00`09jPX0oooo0?ooo`0@0?oo
o`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`09jPX03@3oool00`09jPX0oooo0?ooo`0X0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool003h0oooo00<000000?ooo`3o
ool04P3oool2000000X0oooo0P09jPXL0?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3o
ool0103oool00`000000XXBc0::4/`02000000`0oooo00D000000?ooo`3oool0oooo00WZ2P020?oo
o`0300WZ2P3oool02NX:00@0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo00dm_00700dm
_0030000003Ydkl0jM>o00`0jM>o00<000000?ooo`09jPX04`3oool00`09jPX0oooo0?ooo`080?oo
o`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0S0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0F0?oo
o`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool0503oool00`09jPX0oooo0?ooo`070?oo
o`802NX:2@3oool010000000Z8Vd0:R9]02XRK@3000000P0oooo0P09jPX<0?ooo`0400WZ2P3oool0
oooo00WZ2PL0oooo00D02NX:0?ooo`3oool0oooo0000000902aAa@030000003_fk`0km^l00T0km^l
00<000000?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo00D0oooo
00<02NX:0?ooo`09jPX03P3oool00`09jPX0oooo0?ooo`0X0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0303oool003l0oooo00<000000?ooo`3oool04@3oool2000000T0oooo00<0
2NX:0?ooo`3oool0703oool00`09jPX0oooo0?ooo`050?ooo`802NX:1`3oool3000000030180003o
ool0oooo00/0oooo00D000000?ooo`3oool0oooo00WZ2P020?ooo`802NX:103oool00`09jPX0oooo
0?ooo`0<0?ooo`0300WZ2P3oool0oooo00P03Cfl00<000000>WC_`3Ydkl02P3Ydkl01@000000oooo
0?ooo`3oool02NX:01<0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`020?ooo`03
00WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0903oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool04`3oool2000000P0oooo0P09jPXG0?ooo`03
00WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool02@3oool010000000Z8Vd0:R9]00000020?oo
o`030000003oool0oooo00H0oooo0P09jPX;0?ooo`0400WZ2P3oool0oooo00WZ2PL0oooo00<02NX:
0?ooo`3oool00`3oool00`000000;57502aAa@0602aAa@030000003_fk`0km^l00T0km^l00<00000
0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:
0?ooo`09jPX03P3oool00`09jPX0oooo0?ooo`0X0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0303oool00400oooo00<000000?ooo`3oool06@3oool200WZ2Ql0oooo00<02NX:0?oo
o`3oool0103oool00`09jPX0oooo0?ooo`070?ooo`030000000B0000oooo00h0oooo00H000000?oo
o`3oool0oooo00WZ2P3oool200WZ2PD0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`020?ooo`L03Cfl00<000000>WC_`3Ydkl02@3Ydkl00`000000oooo0?ooo`020?ooo`0300WZ2P3o
ool0oooo0140oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3o
ool0oooo00T0oooo00<02NX:0?ooo`3oool0903oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool04P3oool2000000L0oooo00<02NX:0?ooo`3oool05`3o
ool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00X0oooo0`0000030?ooo`030000003o
ool0oooo00H0oooo00<02NX:0?ooo`3oool02@3oool01@09jPX0oooo0?ooo`3oool02NX:00L0oooo
00<02NX:0?ooo`3oool00`3oool00`000000;57502aAa@0602aAa@030000003_fk`0km^l00P0km^l
00<000000?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo00H0oooo
0P09jPX?0?ooo`0300WZ2P3oool0oooo02P0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0;0?ooo`00@@3oool2000001P0oooo00<02NX:0?ooo`3oool07`3oool00`09jPX0oooo0?oo
o`030?ooo`0300WZ2P3oool0oooo01T0oooo00L000000?ooo`3oool0oooo00WZ2P3oool02NX:00D0
oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`020?ooo`L03Cfl00<000000>WC_`3Y
dkl02@3Ydkl00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3o
ool01`3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3o
ool09@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02`0oooo0P00000I0?ooo`80
2NX:6P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00P0oooo00D02NX:0?ooo`3o
ool0oooo00WZ2P080?ooo`0300WZ2P3oool0oooo00@0oooo00<0000002aAa@0/DLD01P0/DLD00`00
0000km^l0>oK_0070>oK_0030000003oool0oooo00P0oooo00<02NX:0?ooo`3oool03`3oool00`09
jPX0oooo0?ooo`050?ooo`802NX:3`3oool00`09jPX0oooo0?ooo`0Y0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool02`3oool004<0oooo00<000000?ooo`3oool04`3oool200WZ2R80
oooo00@02NX:0?ooo`3oool0oooo0P09jPXL0?ooo`050000003oool0oooo00WZ2P3oool00P09jPX5
0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool00`3oool600dm_0030000003Ydkl0
jM>o00P0jM>o00<000000?ooo`3oool0103oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0
oooo00H0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0
oooo02D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo01D0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:503oool0
0`000000oooo0?ooo`050?ooo`802NX:2@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0
oooo00D0oooo00<02NX:0?ooo`3oool01P3oool00`000000;57502aAa@0502aAa@030000003_fk`0
km^l00H0km^l00<000000?ooo`3oool02@3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0
oooo00D0oooo0P09jPX@0?ooo`0300WZ2P3oool0oooo02T0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0;0?ooo`00A03oool00`000000oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo
0280oooo00@02NX:0?ooo`3oool02NX:7P3oool00`000000oooo0?ooo`0300WZ2PH0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`050?ooo`H03Cfl00<000000>WC_`3Ydkl01`3Ydkl0
0`000000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool01`3oool0
0`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool09@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool04P3oool2
00WZ2Qd0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0F0?ooo`030000003oool0oooo00D0oooo00<0
2NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00D0oooo00<0
2NX:0?ooo`3oool01`3oool00`000000;57502aAa@0402aAa@030000003_fk`0km^l00H0km^l00<0
00000?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo00D0oooo00<0
2NX:0?ooo`09jPX0403oool00`09jPX0oooo0?ooo`0X0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02`3oool004D0oooo00<000000?ooo`3oool03P3oool200WZ2RD0oooo00<02NX:
0?ooo`09jPX07`3oool01P000000oooo0?ooo`09jPX0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool0
303oool00`09jPX0oooo0?ooo`060?ooo`D03Cfl00<000000>WC_`3Ydkl01P3Ydkl00`000000oooo
0?ooo`060?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool09@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0403oool00`09jPX0oooo
0?ooo`0M0?ooo`0400WZ2P3oool0oooo00WZ2QL0oooo00<000000?ooo`3oool01@3oool00`09jPX0
oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0
oooo0?ooo`070?ooo`030000000/DLD0;57500@0;57500<000000>oK_03_fk`01@3_fk`00`000000
oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00l0oooo00<02NX:0?ooo`3oool01@3oool200WZ2P03
0000003oool0oooo00d0oooo00<02NX:0?ooo`3oool0:@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00160?ooo`8000003@3oool00`09jPX0oooo0?ooo`0U0?ooo`802NX:
7`3oool00`000000oooo0?ooo`0300WZ2PH0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo
0?ooo`060?ooo`D03Cfl00<000000>WC_`3Ydkl01P3Ydkl00`000000oooo0?ooo`060?ooo`0300WZ
2P3oool0oooo0100oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P000000oooo00T0oooo00<02NX:0?ooo`3oool09P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool03@3oool200WZ2R00oooo00<02NX:0?ooo`09jPX0
603oool00`000000oooo0?ooo`040?ooo`802NX:1`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00D0oooo0P09jPX:0?ooo`030000000/DLD0;57500<0;57500<000000>oK_03_fk`0
1@3_fk`00`000000oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool0
1@3oool200WZ2P030000003oool0oooo00h0oooo00<02NX:0?ooo`3oool0:@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00180?ooo`030000003oool0oooo00P0oooo0P09
jPXW0?ooo`802NX:803oool010000000oooo00WZ2P3oool200WZ2PD0oooo00<02NX:0?ooo`3oool0
3@3oool00`09jPX0oooo0?ooo`070?ooo`@03Cfl0P0000060>WC_`030000003oool0oooo00P0oooo
00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00<0oooo
0P00000;0?ooo`0300WZ2P3oool0oooo02H0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00/0oooo00<02NX:0?ooo`3oool0803oool200WZ2QT0oooo
00<000000?ooo`3oool0103oool200WZ2PH0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`060?ooo`0300WZ2P3oool0oooo00X0oooo00<0000002aAa@0/DLD00P0/DLD00`000000km^l
0>oK_0040>oK_0030000003oool0oooo00d0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo
0?ooo`050?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0:@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00190?ooo`030000003oool0oooo00H0oooo00<0
2NX:0?ooo`3oool09P3oool00`09jPX0oooo00WZ2P0P0?ooo`0500000009jPX0oooo0?ooo`09jPX0
1P3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00P0oooo100=?K`00`000000jM>o
0>WC_`040>WC_`030000003oool0oooo00P0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo
0?ooo`060?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool09`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0203oool200WZ2R80oooo
0P09jPXJ0?ooo`030000003oool0oooo00<0oooo00<02NX:0?ooo`09jPX01@3oool00`09jPX0oooo
0?ooo`050?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0303oool00`000000;575
02aAa@0202aAa@030000003_fk`0km^l0080km^l00<000000?ooo`3oool03`3oool00`09jPX0oooo
0?ooo`0>0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo
0?ooo`0Y0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool004X0oooo0P00
00040?ooo`800000:03oool01009jPX0oooo0?ooo`09jPXP0?ooo`0300WZ2P3oool0oooo00802NX:
1P3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00X0oooo0`0=?K`00`000000jM>o
0>WC_`030>WC_`030000003oool0oooo00T0oooo0P00000A0?ooo`0300WZ2P3oool0oooo00H0oooo
00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0W0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0<`3oool2000000L0oooo00<02NX:0?ooo`3oool08@3oool00`09jPX0oooo
00WZ2P0J0?ooo`030000003oool0oooo00<0oooo00<02NX:0?ooo`09jPX0103oool00`09jPX0oooo
0?ooo`060?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0303oool00`000000;575
02aAa@0202aAa@030000003_fk`0km^l0080km^l00<000000?ooo`3oool03`3oool2000000l0oooo
00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo02X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`00C03oool010000000oooo0?oo
o`3oool2000002H0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo01d0oooo00@02NX:0000003oool0
oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool02P3oool300dm_003
0000003Ydkl0jM>o00<0jM>o00<000000?ooo`3oool02@3oool200000140oooo00<02NX:0?ooo`3o
ool01`3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo02P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00<0oooo0P00000Q0?ooo`80
2NX:0P3oool00`09jPX0oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00@02NX:0?ooo`3o
ool02NX:0`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?oo
o`3oool03@3oool01@000000;57502aAa@0/DLD0000000<0km^l00<000000?ooo`3oool0403oool2
000000l0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0
oooo02X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`00C@3oool00`00
0000oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0703oool00`09
jPX0oooo000000020?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool03@3oool00`09
jPX0oooo0?ooo`0;0?ooo`<03Cfl00D000000>WC_`3Ydkl0jM>o0000000P0?ooo`0300WZ2P3oool0
oooo00H0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0W0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`800000803oool0
0`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01P0oooo00<000000?ooo`3oool00P3oool0
0`09jPX0oooo00WZ2P030?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool01@3oool0
0`09jPX0oooo0?ooo`0?0?ooo`040000000/DLD0;575000000<0km^l00<000000?ooo`3oool08P3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool0:P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo001>0?ooo`030000003oool0
oooo02D0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0K0?ooo`0400WZ2P3oool0
oooo00000080oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3o
ool0oooo00d0oooo0P0=?K`010000000jM>o0>WC_`00000Q0?ooo`0300WZ2P3oool0oooo00H0oooo
00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0X0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo00<0oooo
00<02NX:0?ooo`3oool0603oool01@000000oooo0?ooo`3oool02NX:0080oooo00@02NX:0?ooo`3o
ool02NX:2P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo0100oooo00<0000002aA
a@0000000P3_fk`00`000000oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?oo
o`3oool04P3oool00`09jPX0oooo0?ooo`0Z0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02P3oool004l0oooo0P00000S0?ooo`0300000009jPX0oooo00H0oooo00<02NX:0?ooo`3o
ool06P3oool01P09jPX0oooo0?ooo`3oool000000?ooo`802NX:1@3oool00`09jPX0oooo0?ooo`0=
0?ooo`0300WZ2P3oool0oooo00d0oooo0P0=?K`010000000jM>o0>WC_`00000Q0?ooo`0300WZ2P3o
ool0oooo00H0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0X0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0P0?ooo`0300WZ2P3o
ool0oooo00@0oooo00<02NX:0?ooo`3oool0603oool01@000000oooo0000000000002NX:0080oooo
00<02NX:0?ooo`09jPX02P3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo0100oooo
00<0000002aAa@0000000P3_fk`00`000000oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo00@0oooo
00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0Z0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02P3oool00540oooo00<000000?ooo`3oool0803oool2000000L0oooo00<0
2NX:0?ooo`3oool06@3oool2000000<0oooo00@000000?ooo`09jPX000001@3oool00`09jPX0oooo
0?ooo`0=0?ooo`0300WZ2P3oool0oooo00h0oooo00@03Cfl0000003Ydkl000008`3oool00`09jPX0
oooo0?ooo`050?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0:@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool07@3oool2000000L0
oooo00<02NX:0?ooo`3oool0603oool010000000oooo00000009jPX30?ooo`802NX:2`3oool00`09
jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo0180oooo00@0000002aAa@00000000009`3oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0:P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo001B0?ooo`030000003oool0oooo
02P0oooo00<02NX:0?ooo`3oool06@3oool2000000<0oooo00<000000?ooo`09jPX01@3oool00`09
jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo0100oooo00<03Cfl0000000000008`3oool200WZ
2PH0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0Y0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`8000001`3oool00`09
jPX0oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`0300WZ2P3oool0oooo
00H0oooo00<02NX:0?ooo`3oool04`3oool3000002L0oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo02X0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`090?ooo`00D`3oool00`000000oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo01h0
oooo00<000000?ooo`09jPX01@3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo0140
oooo00<000000?ooo`3oool08P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo01<0
oooo00<02NX:0?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0903oool00`09jPX0oooo0?ooo`0H0?ooo`030000003oool0oooo00@0
oooo0P00000:0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0503oool2000002L0
oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo02/0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`00E03oool2000002L0oooo
00<02NX:0?ooo`3oool07P3oool00`000000oooo00WZ2P050?ooo`0300WZ2P3oool0oooo00d0oooo
00<02NX:0?ooo`3oool0=`3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo01<0oooo
00<02NX:0?ooo`3oool0:P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03/0oooo
0P00000T0?ooo`0300WZ2P3oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`09jPX0oooo
0?ooo`090?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0?`3oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool0:P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00T0oooo001F0?ooo`030000003oool0oooo02@0oooo00<0
2NX:0?ooo`3oool07P3oool00`000000oooo00WZ2P040?ooo`0300WZ2P3oool0oooo00d0oooo00<0
2NX:0?ooo`3oool0>03oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo01@0oooo00<0
2NX:0?ooo`3oool0:@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool08@3oool00`09jPX0oooo0?ooo`0H0?ooo`030000003oool0oooo00<0oooo00<0
2NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo03l0oooo00<0
2NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo02/0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`00E`3oool00`000000oooo0?ooo`0S
0?ooo`0300WZ2P3oool0oooo01h0oooo00<000000?ooo`09jPX0103oool00`09jPX0oooo0?ooo`0=
0?ooo`0300WZ2P3oool0oooo03P0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0D
0?ooo`0300WZ2P3oool0oooo02X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo0200oooo00<02NX:0?ooo`3oool0603oool00`000000oooo0?ooo`03
0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0o
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`0[
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool005P0oooo00<000000?oo
o`3oool08P3oool00`09jPX0oooo0?ooo`0N0?ooo`0300000009jPX0oooo00<0oooo00<02NX:0?oo
o`3oool03P3oool00`09jPX0oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?oo
o`3oool05@3oool00`09jPX0oooo0?ooo`0Z0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo01P0oooo00<000000?oo
o`3oool00`3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?oo
o`3oool0@@3oool2000000@0oooo00<02NX:0?ooo`3oool0503oool00`09jPX0oooo0?ooo`0/0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool005T0oooo0P00000R0?ooo`03
00WZ2P3oool0oooo01h0oooo00<0000000WZ2P3oool00`3oool00`09jPX0oooo0?ooo`0=0?ooo`03
00WZ2P3oool0oooo03T0oooo0P0000060?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3o
ool0:`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool07P3oool00`09jPX0oooo0?ooo`0H0?ooo`030000003oool0oooo00<0oooo00<02NX:0?ooo`3o
ool0203oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo0440oooo0P0000040?ooo`03
00WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0:`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo001K0?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool0
7P3oool0100000002NX:0?ooo`3oool20000000300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3o
ool0>@3oool2000000H0oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0[0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0M0?ooo`03
00WZ2P3oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`09jPX0oooo0?ooo`080?ooo`03
00WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0A`3oool00`09jPX0oooo0?ooo`0F0?ooo`03
00WZ2P3oool0oooo02/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`00
G03oool00`000000oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo01h0oooo00H0000000WZ2P3oool0
oooo00000009jPX@0?ooo`0300WZ2P3oool0oooo0440oooo00<02NX:0?ooo`3oool05P3oool00`09
jPX0oooo0?ooo`0/0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`09
jPX0oooo0?ooo`060?ooo`800000203oool00`09jPX0oooo0?ooo`180?ooo`0300WZ2P3oool0oooo
01H0oooo00<02NX:0?ooo`3oool0;03oool01@000000oooo0?ooo`3oool0000000X0oooo001M0?oo
o`030000003oool0oooo01d0oooo00<02NX:0?ooo`3oool07P3oool00`0000002NX:0?ooo`0B0?oo
o`0300WZ2P3oool0oooo04<0oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0/0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0@`3oool2000001`0oooo00<02NX:0?oo
o`3oool0603oool00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00H0oooo0P0000080?oo
o`0300WZ2P3oool0oooo04P0oooo00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`0[0?oo
o`050000003oool0oooo0?ooo`0000002P3oool005h0oooo0P00000M0?ooo`0300WZ2P000000oooo
01h0oooo00<0000000WZ2P3oool04P3oool00`09jPX0oooo0?ooo`130?ooo`0300WZ2P3oool0oooo
01H0oooo00<02NX:0?ooo`3oool0;03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool0603oool00`0000002NX:0?ooo`0I0?ooo`030000003oool0oooo
0080oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`190?ooo`0300WZ2P3oool0oooo
01H0oooo0P00000]0?ooo`040000003oool0oooo000000X0oooo001P0?ooo`030000003oool0oooo
01X0oooo0P00000O0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0@`3oool00`09
jPX0oooo0?ooo`0F0?ooo`800000;P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool05`3oool00`0000002NX:0?ooo`0I0?ooo`030000003oool0oooo
0080oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`1:0?ooo`0300WZ2P3oool0oooo
01H0oooo0P00000^0?ooo`030000003oool0000000X0oooo001Q0?ooo`030000003oool0oooo03X0
oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`140?ooo`8000005`3oool2000002l0
oooo00D000000?ooo`3oool0oooo000000180?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool00P3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo04X0oooo0P0000180?oo
o`8000002P3oool00680oooo00<000000?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0A0?ooo`03
00WZ2P3oool0oooo04@0oooo0P0000190?ooo`040000003oool0oooo000004T0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?oo
o`3oool0BP3oool2000004P0oooo00<000000?ooo`0000002@3oool006<0oooo0P00000i0?ooo`03
00WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool0T03oool00`000000oooo0000001:0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0?0?ooo`03
00WZ2P3oool0oooo09H0oooo0P0000090?ooo`00I@3oool00`000000oooo0?ooo`0f0?ooo`0300WZ
2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0TP3oool2000004/0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00l0oooo00<02NX:0?ooo`3oool0
U@3oool3000000T0oooo001V0?ooo`030000003oool0oooo03@0oooo00<02NX:0000003oool04@3o
ool00`09jPX0oooo0?ooo`2A0?ooo`<00000C03oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0080oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`2A0?ooo`@00000303o
ool006L0oooo0P00000d0?ooo`0300WZ2P000000oooo0140oooo00<02NX:0?ooo`3oool0S@3oool4
00000500oooo0P00000^0?ooo`030000003oool0oooo0080oooo00<02NX:0?ooo`3oool03P3oool0
0`09jPX0oooo0?ooo`2>0?ooo`@00000403oool006T0oooo00<000000?ooo`3oool0<@3oool00`09
jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo08X0oooo1000001F0?ooo`030000003oool0oooo
02/0oooo00D000000?ooo`3oool0oooo00WZ2P0A0?ooo`0300WZ2P3oool0oooo08X0oooo1000000D
0?ooo`00JP3oool00`000000oooo0?ooo`0`0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?oo
o`3oool0QP3oool4000005/0oooo00<000000?ooo`3oool0:P3oool01@000000oooo0?ooo`3oool0
2NX:0140oooo00<02NX:0?ooo`3oool0QP3oool4000001P0oooo001[0?ooo`030000003oool0oooo
02l0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`220?ooo`@00000H03oool00`00
0000oooo0?ooo`0Y0?ooo`050000003oool0oooo0?ooo`09jPX0403oool00`09jPX0oooo0?ooo`23
0?ooo`@00000703oool006`0oooo0P00000_0?ooo`0300WZ2P3oool0oooo00l0oooo00<02NX:0?oo
o`3oool0O`3oool4000006D0oooo00<000000?ooo`3oool0:03oool01@000000oooo0?ooo`3oool0
2NX:0100oooo00<02NX:0?ooo`3oool0O`3oool400000200oooo001^0?ooo`030000003oool0oooo
02/0oooo00<02NX:0000003oool0403oool00`09jPX0oooo0?ooo`1k0?ooo`@00000JP3oool00`00
0000oooo0?ooo`0X0?ooo`040000003oool0oooo00WZ2Q00oooo00<02NX:0?ooo`3oool0N`3oool4
000002@0oooo001_0?ooo`030000003oool0oooo02X0oooo00<02NX:0000003oool0403oool00`09
jPX0oooo0?ooo`1f0?ooo`D00000K`3oool00`000000oooo0?ooo`0W0?ooo`040000003oool0oooo
00WZ2Pl0oooo00<02NX:0?ooo`3oool0N03oool4000002P0oooo001`0?ooo`800000:P3oool00`09
jPX000000?ooo`0?0?ooo`0300WZ2P3oool0oooo07<0oooo1000001e0?ooo`8000009`3oool01000
0000oooo0?ooo`09jPX?0?ooo`0300WZ2P3oool0oooo07@0oooo1000000/0?ooo`00LP3oool00`00
0000oooo0?ooo`0W0?ooo`0300WZ2P000000oooo00l0oooo00<02NX:0?ooo`3oool0K`3oool40000
07/0oooo00<000000?ooo`3oool0903oool00`000000oooo00WZ2P0@0?ooo`0300WZ2P3oool0oooo
0700oooo1000000`0?ooo`00L`3oool00`000000oooo0?ooo`0V0?ooo`0300WZ2P000000oooo00l0
oooo00<02NX:0?ooo`3oool0J`3oool400000800oooo00<000000?ooo`3oool08`3oool00`000000
oooo00WZ2P0?0?ooo`0300WZ2P3oool0oooo06d0oooo1000000d0?ooo`00M03oool00`000000oooo
0?ooo`0U0?ooo`0300WZ2P000000oooo00h0oooo00<02NX:0?ooo`3oool0J03oool4000008D0oooo
00<000000?ooo`3oool08P3oool00`000000oooo00WZ2P0?0?ooo`0300WZ2P3oool0oooo06T0oooo
1000000h0?ooo`00M@3oool2000002@0oooo00<02NX:0?ooo`0000003`3oool00`09jPX0oooo0?oo
o`1T0?ooo`@00000RP3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool02NX:00l0oooo00<0
2NX:0?ooo`3oool0I@3oool4000003`0oooo001g0?ooo`030000003oool0oooo0240oooo00<02NX:
0?ooo`0000003`3oool00`09jPX0oooo0?ooo`1P0?ooo`@00000S`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool02NX:00h0oooo00<02NX:0?ooo`3oool0HP3oool400000400oooo001h0?oo
o`030000003oool0oooo0200oooo00<02NX:0?ooo`0000003P3oool00`09jPX0oooo0?ooo`1M0?oo
o`@00000U03oool200000200oooo00<000000?ooo`09jPX03P3oool00`09jPX0oooo0?ooo`1N0?oo
o`@00000A03oool007T0oooo0P00000P0?ooo`0300WZ2P3oool0000000h0oooo00<02NX:0000003o
ool0F@3oool4000009X0oooo00<000000?ooo`3oool07@3oool00`000000oooo00WZ2P0=0?ooo`03
00000009jPX0oooo05/0oooo100000180?ooo`00N`3oool00`000000oooo0?ooo`0M0?ooo`0300WZ
2P3oool0000000h0oooo0P00001F0?ooo`@00000W`3oool00`000000oooo0?ooo`0L0?ooo`030000
0009jPX0oooo00d0oooo00<02NX:0000003oool0E`3oool4000004`0oooo001l0?ooo`030000003o
ool0oooo01/0oooo00@02NX:0?ooo`3oool00000HP3oool400000:@0oooo00<000000?ooo`3oool0
6`3oool00`0000002NX:0?ooo`1S0?ooo`@00000D03oool007d0oooo0P00000K0?ooo`0400WZ2P3o
ool0oooo000005h0oooo1000002Y0?ooo`030000003oool0oooo01X0oooo00<0000000WZ2P3oool0
G`3oool4000005@0oooo001o0?ooo`030000003oool0oooo01P0oooo00@02NX:0?ooo`3oool00000
FP3oool400000:h0oooo00<000000?ooo`3oool06@3oool00`0000002NX:0?ooo`1K0?ooo`@00000
F03oool00800oooo00<000000?ooo`3oool05`3oool01009jPX0oooo0?ooo`00001F0?ooo`@00000
/`3oool2000001T0oooo00<0000000WZ2P3oool0E`3oool4000005`0oooo00210?ooo`030000003o
ool0oooo01H0oooo00@02NX:0?ooo`3oool00000D@3oool500000;T0oooo00<000000?ooo`3oool0
5P3oool00`0000002NX:0?ooo`1C0?ooo`@00000H03oool00880oooo0P00000F0?ooo`0400WZ2P3o
ool0oooo000004d0oooo1000002o0?ooo`030000003oool0oooo01D0oooo00<0000000WZ2P3oool0
C`3oool4000006@0oooo00240?ooo`030000003oool0oooo0180oooo00D02NX:0?ooo`3oool0oooo
000000190?ooo`@00000a03oool00`000000oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo04/0oooo
1000001X0?ooo`00Q@3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool00`000000oooo0?oo
o`130?ooo`@00000b@3oool00`000000oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo04L0oooo1000
001/0?ooo`00QP3oool200000140oooo0P0000020?ooo`030000003oool0oooo03l0oooo1000003>
0?ooo`8000004`3oool2000004@0oooo1000001`0?ooo`00R03oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo03/0oooo1000003D0?ooo`030000003oool0oooo0100oooo0P0000100?oo
o`@00000M03oool008T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0g0?ooo`@0
0000f@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03/0oooo1000001h0?ooo`00
RP3oool200000140oooo00<000000?ooo`3oool0<`3oool400000=h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0g0?ooo`@00000O03oool008`0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0`0?ooo`@00000h`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo03<0oooo100000200?ooo`00S@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo02`0oooo1000003X0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0;`3oool4
000008@0oooo002>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0:03oool40000
0>d0oooo0P00000<0?ooo`030000003oool0oooo02/0oooo100000280?ooo`00S`3oool2000000/0
oooo00<000000?ooo`3oool0903oool400000?<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0W0?ooo`@00000S03oool00940oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0P0?ooo`@00000n03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02<0oooo
1000002@0?ooo`00TP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo1000
003m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07`3oool4000009@0oooo002C
0?ooo`8000001`3oool00`000000oooo0?ooo`0G0?ooo`D00000o`3oool30?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool06`3oool4000009P0oooo002E0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool04`3oool400000?l0oooo2@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01L0oooo1000002L0?ooo`00UP3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00l0oooo1000003o0?ooo`h0oooo0P0000050?ooo`030000003oool0oooo01<0
oooo1000002P0?ooo`00U`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
1000003o0?oooa@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`@00000
Y03oool009P0oooo0P0000020?ooo`030000003oool0oooo00L0oooo1000003o0?oooaT0oooo00D0
00000?ooo`3oool0oooo0000000=0?ooo`@00000Z03oool009X0oooo00<000000?ooo`0000001@3o
ool400000?l0oooo7P3oool010000000oooo0?ooo`0000090?ooo`@00000[03oool009/0oooo0P00
00000`3oool000000000000200000?l0oooo8`3oool00`000000oooo000000050?ooo`@00000/03o
ool009`0oooo0P00003o0?ooobP0oooo0P0000000`3oool000000000000200000;@0oooo003o0?oo
olL0oooo0P00002h0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00\
\>"],
  ImageRangeCache->{{{-46.8125, 695.688}, {399.562, -61.6875}} -> {0.0823899, \
-0.255321, 0.00282831, 0.00282831}, {{-29.125, 374.938}, {370.938, -33.0625}} -> \
{0.07201, -0.223553, 0.00247527, 0.00247527}, {{273.875, 678}, {370.938, \
-33.0625}} -> {-0.678075, -0.223553, 0.00247527, 0.00247527}},
  CellTags->"CustomPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Curved Optical Fibers with CustomFiber and CustomFiberMirror", \
"Subsection",
  CellTags->"CustomFiber"],

Cell[CellGroupData[{

Cell["?CustomFiber", "Input",
  CellTags->"CustomFiber"],

Cell[BoxData[
    \("CustomFiber[{fx, fy, fz}, {corediameter, claddingdiameter}, length, \
label, options] designates a curved, stepped-index optical fiber that follows \
a curve specified in the parametric functions, {fx, fy, fz}. \n\nThe \
refractive core and cladding materials are given by the option, \
ComponentMedium -> {corematerial, claddingmaterial}. CustomFiber[{fx, fy, \
fz}, corediameter, length, options] indicates a bare optical fiber. \
CustomFiber can also have an elliptical cross section with the option \
EllipseRatio. The user-named label parameter is optional and can be omitted. \
When it is present, its text content is used to identify the object in both \
the rendered graphics and the output cell expression. When it is omitted, \
Optica uses the default setting of the Labels option with the rendered \
graphics.\n \nSee also: Fiber, CustomFiberMirror, and CreateFiberShape."\)], \
"Print",
  CellTags->{"Info3251466833-6576689", "CustomFiber"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["?CustomFiberMirror", "Input",
  CellTags->"CustomFiber"],

Cell[BoxData[
    \("CustomFiberMirror[{fx, fy, fz}, diameter, length, label, options] \
designates a curved, reflective, fiber-like tube that follows a curve \
specified in the parametric functions, {fx, fy, fz}.\n\nCustomFiberMirror can \
also have an elliptical cross section with the option EllipseRatio. The \
user-named label parameter is optional and can be omitted. When it is \
present, its text content is used to identify the object in both the rendered \
graphics and the output cell expression. When it is omitted, Optica uses the \
default setting of the Labels option with the rendered graphics.\n \nSee \
also: Fiber, CustomFiber, and CreateFiberShape."\)], "Print",
  CellTags->{"Info3251466841-4933577", "CustomFiber"}]
}, Open  ]],

Cell["\<\
points2 = {{1.14228, -0.00812587}, {1.80828, 0.0687198}, 
{2.42305, 0.196796}, {2.96096, 0.401718}, 
{3.47327, 0.760331}, {3.88311, 1.2214}, 
{4.26734, 1.78494}, {4.57472, 2.3997}, 
{4.60034, 3.0657}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"CustomFiber"],

Cell[CellGroupData[{

Cell["\<\
Timing[fiber = CustomFiberMirror[points2, .5, EllipseRatio->2., \
EllipseAngle->45.]]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"CustomFiber"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.287409 0.273906 0.0263272 0.309836 [
[.12345 -0.0125 -9 -9 ]
[.12345 -0.0125 9 0 ]
[.2604 -0.0125 -3 -9 ]
[.2604 -0.0125 3 0 ]
[.39736 -0.0125 -9 -9 ]
[.39736 -0.0125 9 0 ]
[.53431 -0.0125 -3 -9 ]
[.53431 -0.0125 3 0 ]
[.67126 -0.0125 -9 -9 ]
[.67126 -0.0125 9 0 ]
[.80821 -0.0125 -3 -9 ]
[.80821 -0.0125 3 0 ]
[.94517 -0.0125 -9 -9 ]
[.94517 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02633 -6 -4.5 ]
[-0.0125 .02633 0 4.5 ]
[-0.0125 .18125 -18 -4.5 ]
[-0.0125 .18125 0 4.5 ]
[-0.0125 .33616 -6 -4.5 ]
[-0.0125 .33616 0 4.5 ]
[-0.0125 .49108 -18 -4.5 ]
[-0.0125 .49108 0 4.5 ]
[-0.0125 .646 -6 -4.5 ]
[-0.0125 .646 0 4.5 ]
[-0.0125 .80092 -18 -4.5 ]
[-0.0125 .80092 0 4.5 ]
[-0.0125 .95583 -6 -4.5 ]
[-0.0125 .95583 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12345 0 m
.12345 .00625 L
s
[(1.5)] .12345 -0.0125 0 1 Mshowa
.2604 0 m
.2604 .00625 L
s
[(2)] .2604 -0.0125 0 1 Mshowa
.39736 0 m
.39736 .00625 L
s
[(2.5)] .39736 -0.0125 0 1 Mshowa
.53431 0 m
.53431 .00625 L
s
[(3)] .53431 -0.0125 0 1 Mshowa
.67126 0 m
.67126 .00625 L
s
[(3.5)] .67126 -0.0125 0 1 Mshowa
.80821 0 m
.80821 .00625 L
s
[(4)] .80821 -0.0125 0 1 Mshowa
.94517 0 m
.94517 .00625 L
s
[(4.5)] .94517 -0.0125 0 1 Mshowa
.125 Mabswid
.15084 0 m
.15084 .00375 L
s
.17823 0 m
.17823 .00375 L
s
.20562 0 m
.20562 .00375 L
s
.23301 0 m
.23301 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31518 0 m
.31518 .00375 L
s
.34257 0 m
.34257 .00375 L
s
.36996 0 m
.36996 .00375 L
s
.42475 0 m
.42475 .00375 L
s
.45214 0 m
.45214 .00375 L
s
.47953 0 m
.47953 .00375 L
s
.50692 0 m
.50692 .00375 L
s
.5617 0 m
.5617 .00375 L
s
.58909 0 m
.58909 .00375 L
s
.61648 0 m
.61648 .00375 L
s
.64387 0 m
.64387 .00375 L
s
.69865 0 m
.69865 .00375 L
s
.72604 0 m
.72604 .00375 L
s
.75343 0 m
.75343 .00375 L
s
.78082 0 m
.78082 .00375 L
s
.8356 0 m
.8356 .00375 L
s
.86299 0 m
.86299 .00375 L
s
.89039 0 m
.89039 .00375 L
s
.91778 0 m
.91778 .00375 L
s
.09606 0 m
.09606 .00375 L
s
.06867 0 m
.06867 .00375 L
s
.04128 0 m
.04128 .00375 L
s
.01389 0 m
.01389 .00375 L
s
.97256 0 m
.97256 .00375 L
s
.99995 0 m
.99995 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02633 m
.00625 .02633 L
s
[(0)] -0.0125 .02633 1 0 Mshowa
0 .18125 m
.00625 .18125 L
s
[(0.5)] -0.0125 .18125 1 0 Mshowa
0 .33616 m
.00625 .33616 L
s
[(1)] -0.0125 .33616 1 0 Mshowa
0 .49108 m
.00625 .49108 L
s
[(1.5)] -0.0125 .49108 1 0 Mshowa
0 .646 m
.00625 .646 L
s
[(2)] -0.0125 .646 1 0 Mshowa
0 .80092 m
.00625 .80092 L
s
[(2.5)] -0.0125 .80092 1 0 Mshowa
0 .95583 m
.00625 .95583 L
s
[(3)] -0.0125 .95583 1 0 Mshowa
.125 Mabswid
0 .05731 m
.00375 .05731 L
s
0 .08829 m
.00375 .08829 L
s
0 .11928 m
.00375 .11928 L
s
0 .15026 m
.00375 .15026 L
s
0 .21223 m
.00375 .21223 L
s
0 .24321 m
.00375 .24321 L
s
0 .2742 m
.00375 .2742 L
s
0 .30518 m
.00375 .30518 L
s
0 .36715 m
.00375 .36715 L
s
0 .39813 m
.00375 .39813 L
s
0 .42911 m
.00375 .42911 L
s
0 .4601 m
.00375 .4601 L
s
0 .52206 m
.00375 .52206 L
s
0 .55305 m
.00375 .55305 L
s
0 .58403 m
.00375 .58403 L
s
0 .61502 m
.00375 .61502 L
s
0 .67698 m
.00375 .67698 L
s
0 .70797 m
.00375 .70797 L
s
0 .73895 m
.00375 .73895 L
s
0 .76993 m
.00375 .76993 L
s
0 .8319 m
.00375 .8319 L
s
0 .86288 m
.00375 .86288 L
s
0 .89387 m
.00375 .89387 L
s
0 .92485 m
.00375 .92485 L
s
0 .98682 m
.00375 .98682 L
s
.25 Mabswid
0 0 m
0 1 L
s
.12345 .99375 m
.12345 1 L
s
.2604 .99375 m
.2604 1 L
s
.39736 .99375 m
.39736 1 L
s
.53431 .99375 m
.53431 1 L
s
.67126 .99375 m
.67126 1 L
s
.80821 .99375 m
.80821 1 L
s
.94517 .99375 m
.94517 1 L
s
.125 Mabswid
.15084 .99625 m
.15084 1 L
s
.17823 .99625 m
.17823 1 L
s
.20562 .99625 m
.20562 1 L
s
.23301 .99625 m
.23301 1 L
s
.28779 .99625 m
.28779 1 L
s
.31518 .99625 m
.31518 1 L
s
.34257 .99625 m
.34257 1 L
s
.36996 .99625 m
.36996 1 L
s
.42475 .99625 m
.42475 1 L
s
.45214 .99625 m
.45214 1 L
s
.47953 .99625 m
.47953 1 L
s
.50692 .99625 m
.50692 1 L
s
.5617 .99625 m
.5617 1 L
s
.58909 .99625 m
.58909 1 L
s
.61648 .99625 m
.61648 1 L
s
.64387 .99625 m
.64387 1 L
s
.69865 .99625 m
.69865 1 L
s
.72604 .99625 m
.72604 1 L
s
.75343 .99625 m
.75343 1 L
s
.78082 .99625 m
.78082 1 L
s
.8356 .99625 m
.8356 1 L
s
.86299 .99625 m
.86299 1 L
s
.89039 .99625 m
.89039 1 L
s
.91778 .99625 m
.91778 1 L
s
.09606 .99625 m
.09606 1 L
s
.06867 .99625 m
.06867 1 L
s
.04128 .99625 m
.04128 1 L
s
.01389 .99625 m
.01389 1 L
s
.97256 .99625 m
.97256 1 L
s
.99995 .99625 m
.99995 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02633 m
1 .02633 L
s
.99375 .18125 m
1 .18125 L
s
.99375 .33616 m
1 .33616 L
s
.99375 .49108 m
1 .49108 L
s
.99375 .646 m
1 .646 L
s
.99375 .80092 m
1 .80092 L
s
.99375 .95583 m
1 .95583 L
s
.125 Mabswid
.99625 .05731 m
1 .05731 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .11928 m
1 .11928 L
s
.99625 .15026 m
1 .15026 L
s
.99625 .21223 m
1 .21223 L
s
.99625 .24321 m
1 .24321 L
s
.99625 .2742 m
1 .2742 L
s
.99625 .30518 m
1 .30518 L
s
.99625 .36715 m
1 .36715 L
s
.99625 .39813 m
1 .39813 L
s
.99625 .42911 m
1 .42911 L
s
.99625 .4601 m
1 .4601 L
s
.99625 .52206 m
1 .52206 L
s
.99625 .55305 m
1 .55305 L
s
.99625 .58403 m
1 .58403 L
s
.99625 .61502 m
1 .61502 L
s
.99625 .67698 m
1 .67698 L
s
.99625 .70797 m
1 .70797 L
s
.99625 .73895 m
1 .73895 L
s
.99625 .76993 m
1 .76993 L
s
.99625 .8319 m
1 .8319 L
s
.99625 .86288 m
1 .86288 L
s
.99625 .89387 m
1 .89387 L
s
.99625 .92485 m
1 .92485 L
s
.99625 .98682 m
1 .98682 L
s
.25 Mabswid
1 0 m
1 1 L
s
.008 w
.02547 .02381 Mdot
.20789 .04762 Mdot
.37628 .0873 Mdot
.52361 .15079 Mdot
.66394 .2619 Mdot
.7762 .40476 Mdot
.88144 .57937 Mdot
.96563 .76984 Mdot
.97265 .97619 Mdot
.5 Mabswid
.02381 .02576 m
.03107 .02589 L
.03781 .02604 L
.05308 .0265 L
.06788 .0271 L
.08364 .02793 L
.1173 .03034 L
.1476 .03333 L
.17623 .03692 L
.20701 .04167 L
.26657 .05371 L
.32273 .06883 L
.37557 .08678 L
.43052 .10967 L
.48203 .13545 L
.53522 .16691 L
.58476 .20116 L
.63071 .23769 L
.67757 .28033 L
.72051 .32491 L
.76357 .37588 L
.80229 .42827 L
.83671 .48144 L
.86997 .54066 L
.89842 .59993 L
.92215 .65863 L
.94316 .72254 L
.95886 .78496 L
.96543 .81923 L
.97027 .85174 L
.9721 .86733 L
.97368 .88387 L
.97473 .89797 L
.97518 .90553 L
.97557 .91349 L
.97584 .92079 L
.97596 .92493 L
.97605 .92877 L
.97611 .93231 L
.97616 .93553 L
.97617 .93731 L
.97618 .93923 L
.97619 .94105 L
.97619 .94273 L
.97619 .94454 L
.97618 .94648 L
.97616 .94832 L
.97615 .94999 L
.97612 .95195 L
.97609 .95408 L
Mistroke
.976 .95796 L
.97589 .962 L
.97575 .9663 L
.97541 .97401 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool3000000@0oooo00<000000?ooo`3oool00P3oool3000001X0oooo1@00000I0?oo
o`D000000`3oool00`000000oooo0?ooo`020?ooo`<00000703oool3000001/0oooo0`0000040?oo
o`030000003oool0oooo0080oooo0`00000L0?ooo`<00000703oool3000000<0oooo00<000000?oo
o`3oool00P3oool3000000T0oooo000_0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3o
ool0oooo0000000J0?ooo`040000003oool0oooo000001X0oooo00@000000?ooo`3oool000001`3o
ool01@000000oooo0?ooo`3oool0000001X0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`05
0000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000001`0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000203o
ool002l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`D000006P3oool5
000000/0oooo00<000000?ooo`3oool01P3oool002l0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0J0?ooo`800000703oool2000000`0oooo00<000000?ooo`3oool05`3oool01000
0000oooo0?ooo`00000K0?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool01P3o
ool002l0oooo00<000000?ooo`3oool01`3oool4000001X0oooo00D000000?ooo`3oool0oooo0000
000I0?ooo`050000003oool0oooo0?ooo`0000001`3oool4000001l0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`050?ooo`@000006`3oool00`000000oooo0000000L0?ooo`030000
003oool0000000P0oooo100000090?ooo`00;P3oool2000000T0oooo00<000000?ooo`3oool06`3o
ool01@000000oooo0?ooo`3oool0000001T0oooo00D000000?ooo`3oool0oooo000000070?ooo`03
0000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo0?ooo`0M0?ooo`8000007@3oool2000000P0oooo00<00000
0?ooo`3oool02P3oool002l0oooo00<000000?ooo`3oool01`3oool5000001X0oooo0`00000K0?oo
o`<00000203oool5000001/0oooo0`00000K0?ooo`<00000203oool5000001`0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`060?ooo`D00000203oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001D0ooooo`00000;00000040oooo000E0?ooo`05
0000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00/0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`003P3oool2000000D0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`4000000@3oool000d0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`030?ooo`800000o`3oool20?ooo`4000000@3oool000d0oooo00@000000?oo
o`3oool00000103oool2000000@0oooo2`00003g0?ooo`8000000@3oool000d0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0>0?oooa<00000i@3oool100000040oooo000=0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool08@3oool800000=d0oooo0@000001
0?ooo`003@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02T0oooo2000003E
0?ooo`4000000@3oool000h0oooo0P0000050?ooo`030000003oool0oooo0340oooo1P00003?0?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0=`3oool400000</0oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`0c0?ooo`8000001P3oool400000<L0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`0c0?ooo`8000002P3oool400000<<0oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`130?ooo`@00000_`3oool100000040oooo000E0?ooo`800000B03oool40000
0;X0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`1;0?ooo`<00000^03oool100000040
oooo000E0?ooo`030000003oool0oooo04h0oooo1000002d0?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool0DP3oool400000;00oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1F
0?ooo`<00000[@3oool100000040oooo000E0?ooo`030000003oool0oooo05T0oooo1000002Y0?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0G@3oool300000:H0oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`1P0?ooo`<00000X`3oool100000040oooo000E0?ooo`800000H@3o
ool2000000030?ooo`00000000000:00oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`1U
0?ooo`800000W`3oool100000040oooo000E0?ooo`030000003oool0oooo06L0oooo0P00002M0?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0J@3oool2000009/0oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`1[0?ooo`800000V@3oool100000040oooo000E0?ooo`030000003o
ool0oooo06d0oooo0P00002G0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0K`3oool2
000009D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1a0?ooo`<00000TP3oool10000
0040oooo000E0?ooo`800000M@3oool2000008l0oooo0P0000010?ooo`005@3oool00`000000oooo
0?ooo`1f0?ooo`800000SP3oool100000040oooo000E0?ooo`030000003oool0oooo07P0oooo0`00
002;0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0N`3oool2000008T0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`1m0?ooo`800000Q`3oool100000040oooo000E0?ooo`03
0000003oool0oooo07l0oooo00<000000?ooo`3oool0Q03oool100000040oooo000E0?ooo`030000
003oool0oooo0800oooo0P0000240?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0PP3o
ool00`000000oooo0?ooo`210?ooo`4000000@3oool001D0oooo0P0000240?ooo`8000000P3oool2
000007`0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`250?ooo`@00000O@3oool10000
0040oooo000E0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0O03oool100000040
oooo000E0?ooo`030000003oool0oooo08P0oooo0P00001l0?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool0RP3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0R`3oool2000007T0oooo0@0000010?ooo`000P3oool2000000@0oooo00<000000?oo
o`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1f0?oo
o`4000000@3oool000050?ooo`000000oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool0SP3oool2000007H0oooo0@0000010?ooo`0000D0oooo0000
003oool0oooo0000000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`1c0?ooo`4000000@3oool000050?ooo`000000oooo0?ooo`0000002`3oool0
0`000000oooo0?ooo`020?ooo`800000TP3oool200000780oooo0P0000010?ooo`0000D0oooo0000
003oool0oooo000000070?ooo`@000001@3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0
oooo0700oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1_0?ooo`4000000@3oool0
0080oooo0P0000080?ooo`D00000103oool00`000000oooo0?ooo`2E0?ooo`800000K`3oool10000
0040oooo000E0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0K03oool100000040
oooo000E0?ooo`030000003oool0oooo09P0oooo0P00001/0?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool0VP3oool00`000000oooo0?ooo`1Y0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0V`3oool00`000000oooo0?ooo`1X0?ooo`4000000@3oool001D0oooo0P00002M0?oo
o`030000003oool0oooo06H0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`2M0?ooo`03
0000003oool0oooo06H0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2N0?ooo`800000
IP3oool100000040oooo000E0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0H`3o
ool100000040oooo000E0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0HP3oool1
00000040oooo000E0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0H@3oool10000
0040oooo000E0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0H03oool100000040
oooo000E0?ooo`030000003oool0oooo0:@0oooo0P00001P0?ooo`4000000@3oool001D0oooo0P00
002W0?ooo`030000003oool0oooo05`0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`2W
0?ooo`030000003oool0oooo05`0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2X0?oo
o`030000003oool0oooo05/0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2Y0?ooo`03
0000003oool0oooo05X0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2Z0?ooo`800000
00<0oooo000000000000E`3oool100000040oooo000E0?ooo`030000003oool0oooo0:`0oooo0`00
001G0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`1F
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1E0?oo
o`4000000@3oool001D0oooo0P00002`0?ooo`030000003oool0oooo05<0oooo0P0000010?ooo`00
5@3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo05<0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0580oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0580oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`2b0?ooo`030000003oool0oooo0540oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`2c0?ooo`030000003oool0oooo0500oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`2d0?ooo`030000003oool0oooo04l0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`2e0?ooo`030000003oool0oooo04h0oooo0@0000010?ooo`005@3oool200000;L0oooo00<00000
0?ooo`3oool0C03oool200000040oooo000E0?ooo`030000003oool0oooo0;L0oooo00<000000?oo
o`3oool0C03oool100000040oooo000E0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3o
ool0B`3oool100000040oooo000E0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0
BP3oool100000040oooo000E0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0B@3o
ool100000040oooo000E0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0B03oool1
00000040oooo000=0?ooo`<000001@3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo
04L0oooo0@0000010?ooo`003P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0;`0
oooo00<000000?ooo`3oool0A`3oool100000040oooo000>0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`160?ooo`4000000@3oool000h0oooo00<0
00000?ooo`3oool0103oool200000;l0oooo00<000000?ooo`3oool0A03oool200000040oooo000>
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`14
0?ooo`4000000@3oool000d0oooo0P0000060?ooo`030000003oool0oooo0<00oooo00<000000?oo
o`3oool0@`3oool100000040oooo000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0`@3oool00`000000oooo0?ooo`120?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
`P3oool00`000000oooo0?ooo`110?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0``3o
ool00`000000oooo0?ooo`100?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0a03oool0
0`000000oooo0?ooo`0o0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0a@3oool00`00
0000oooo0?ooo`0n0?ooo`4000000@3oool001D0oooo0P0000370?ooo`030000003oool0oooo03`0
oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo03`0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03/0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03/0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo03X0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo03T0oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03P0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03P0oooo0@0000010?ooo`005@3oool2
00000<d0oooo00<000000?ooo`3oool0=P3oool200000040oooo000E0?ooo`030000003oool0oooo
0<X0oooo0P0000000`3oool000000?ooo`0g0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0bP3oool2000000030?ooo`000000oooo03L0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo03D0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`3?0?ooo`030000003oool0oooo03@0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3@
0?ooo`030000003oool0oooo03<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3@0?oo
o`030000003oool0oooo03<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3A0?ooo`03
0000003oool0oooo0380oooo0@0000010?ooo`005@3oool200000=<0oooo00<000000?ooo`3oool0
<03oool200000040oooo000E0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0<@3o
ool100000040oooo000E0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0<03oool1
00000040oooo000E0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool0;`3oool10000
0040oooo000E0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool0;`3oool100000040
oooo000E0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0;P3oool100000040oooo
000E0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0;@3oool100000040oooo000E
0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0;@3oool100000040oooo000E0?oo
o`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0;03oool100000040oooo000E0?ooo`80
0000f03oool00`000000oooo0?ooo`0[0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0
f03oool00`000000oooo0?ooo`0[0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0f@3o
ool00`000000oooo0?ooo`0Z0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0f@3oool0
0`000000oooo0?ooo`0Z0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0fP3oool00`00
0000oooo0?ooo`0Y0?ooo`4000000@3oool000040?ooo`0000000000000000@0oooo00<000000?oo
o`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`0X0?oo
o`4000000@3oool00080oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`0X0?ooo`4000000@3oool00080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0=`0
oooo00<000000?ooo`3oool09`3oool100000040oooo00020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool200000=d0oooo00<000000?ooo`3oool09P3oool200000040oooo
00020?ooo`030000003oool0oooo00L0oooo100000050?ooo`030000003oool0oooo0=d0oooo00<0
00000?ooo`3oool09P3oool100000040oooo00000`3oool00000000000090?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0gP3oool00`000000oooo0?ooo`0U0?ooo`4000000@3oool0
0080oooo00<000000?ooo`3oool01`3oool5000000@0oooo00<000000?ooo`3oool0gP3oool00`00
0000oooo0?ooo`0U0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0g`3oool00`000000
oooo0?ooo`0T0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0g`3oool00`000000oooo
0?ooo`0T0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?oo
o`0S0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`0S
0?ooo`4000000@3oool001D0oooo0P00003R0?ooo`030000003oool0oooo0240oooo0P0000010?oo
o`005@3oool00`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo0280oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0oooo0240oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo0200oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`3S0?ooo`030000003oool0oooo0200oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`3T0?ooo`030000003oool0oooo01l0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`3T0?ooo`030000003oool0oooo01l0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`3U0?ooo`030000003oool0oooo01h0oooo0@0000010?ooo`005@3oool200000>H0oooo00<0
00000?ooo`3oool07@3oool200000040oooo000E0?ooo`030000003oool0oooo0>H0oooo00<00000
0?ooo`3oool07@3oool100000040oooo000E0?ooo`030000003oool0oooo0>H0oooo00<000000?oo
o`3oool07@3oool100000040oooo000E0?ooo`030000003oool0oooo0>H0oooo00<000000?ooo`3o
ool07@3oool100000040oooo000E0?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool0
703oool100000040oooo000E0?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool0703o
ool100000040oooo000E0?ooo`030000003oool0oooo0>P0oooo00<000000?ooo`3oool06`3oool1
00000040oooo000E0?ooo`030000003oool0oooo0>H0oooo0`00000M0?ooo`4000000@3oool001D0
oooo0P00003W0?ooo`80000000<0oooo0000003oool06P3oool200000040oooo000E0?ooo`030000
003oool0oooo0>T0oooo00<000000?ooo`3oool06P3oool100000040oooo000E0?ooo`030000003o
ool0oooo0>T0oooo00<000000?ooo`3oool06P3oool100000040oooo000E0?ooo`030000003oool0
oooo0>X0oooo00<000000?ooo`3oool06@3oool100000040oooo000E0?ooo`030000003oool0oooo
0>X0oooo00<000000?ooo`3oool06@3oool100000040oooo000E0?ooo`030000003oool0oooo0>/0
oooo00<000000?ooo`3oool0603oool100000040oooo000E0?ooo`030000003oool0oooo0>/0oooo
00<000000?ooo`3oool0603oool100000040oooo000E0?ooo`030000003oool0oooo0>`0oooo00<0
00000?ooo`3oool05`3oool100000040oooo000E0?ooo`030000003oool0oooo0>`0oooo00<00000
0?ooo`3oool05`3oool100000040oooo000E0?ooo`800000kP3oool00`000000oooo0?ooo`0E0?oo
o`8000000@3oool001D0oooo00<000000?ooo`3oool0k@3oool00`000000oooo0?ooo`0F0?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool0kP3oool00`000000oooo0?ooo`0E0?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool0kP3oool00`000000oooo0?ooo`0E0?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool0k`3oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool0
00`0oooo1@0000040?ooo`030000003oool0oooo0>l0oooo00<000000?ooo`3oool0503oool10000
0040oooo000=0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0k`3oool00`00
0000oooo0?ooo`0D0?ooo`4000000@3oool000h0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3`0?ooo`030000003oool0oooo01<0oooo0@0000010?ooo`003`3oool00`000000oooo
0?ooo`030?ooo`800000l@3oool00`000000oooo0?ooo`0B0?ooo`8000000@3oool000`0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0
4P3oool100000040oooo000<0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`3a0?ooo`030000003oool0oooo0180oooo0@0000010?ooo`003@3oool3000000D0oooo00<0
00000?ooo`3oool0lP3oool00`000000oooo0?ooo`0A0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0lP3oool00`000000oooo0?ooo`0A0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0lP3oool00`000000oooo0?ooo`0A0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0l`3oool00`000000oooo0?ooo`0@0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
l`3oool00`000000oooo0?ooo`0@0?ooo`4000000@3oool001D0oooo0P00003d0?ooo`030000003o
ool0oooo00l0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0
oooo00l0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo
00l0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo00l0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo00h0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo00h0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo00h0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo00h0oooo0@0000010?oo
o`005@3oool200000?L0oooo00<000000?ooo`3oool0303oool200000040oooo000E0?ooo`030000
003oool0oooo0?H0oooo00<000000?ooo`3oool03@3oool100000040oooo000E0?ooo`030000003o
ool0oooo0?H0oooo00<000000?ooo`3oool03@3oool100000040oooo000E0?ooo`030000003oool0
oooo0?L0oooo00<000000?ooo`3oool0303oool100000040oooo000E0?ooo`030000003oool0oooo
0?L0oooo00<000000?ooo`3oool0303oool100000040oooo000E0?ooo`030000003oool0oooo0?L0
oooo00<000000?ooo`3oool0303oool100000040oooo000E0?ooo`030000003oool0oooo0?L0oooo
00<000000?ooo`3oool0303oool100000040oooo000E0?ooo`030000003oool0oooo0?P0oooo00<0
00000?ooo`3oool02`3oool100000040oooo000E0?ooo`030000003oool0oooo0?P0oooo00<00000
0?ooo`3oool02`3oool100000040oooo000E0?ooo`800000n@3oool00`000000oooo0?ooo`0:0?oo
o`8000000@3oool001D0oooo00<000000?ooo`3oool0n03oool00`000000oooo0?ooo`0;0?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`0:0?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`0:0?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool001D0
oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`02000000L0oooo0@0000010?ooo`005@3o
ool200000?/0oooo00<000000?ooo`3oool00P0000060?ooo`8000000@3oool001D0oooo00<00000
0?ooo`3oool0nP3oool00`000000oooo0?ooo`090?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0nP3oool00`000000oooo0?ooo`090?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0n`3oool00`000000oooo0?ooo`080?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
n`3oool00`000000oooo0?ooo`080?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0n`3o
ool00`000000oooo0?ooo`080?ooo`4000000@3oool000D000000`3oool00`000000oooo0?ooo`02
0?ooo`<000001@3oool00`000000oooo0?ooo`3k0?ooo`030000003oool0oooo00P0oooo0@000001
0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`000P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo0P00003m0?ooo`030000003oool0
oooo00H0oooo0P0000010?ooo`000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0o03oool00`000000oooo0?ooo`070?ooo`4000000@3oool00005
0000003oool0oooo0?ooo`0000001`3oool4000000D0oooo00<000000?ooo`3oool0o03oool00`00
0000oooo0?ooo`070?ooo`4000000@3oool000050000003oool0oooo0?ooo`0000001`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0?`0oooo00<000000?ooo`3oool01`3oool10000
0040oooo0000103oool000000000000000080?ooo`D00000103oool00`000000oooo0?ooo`3m0?oo
o`030000003oool0oooo00H0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3m0?ooo`03
0000003oool0oooo00H0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3m0?ooo`030000
003oool0oooo00H0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3m0?ooo`030000003o
ool0oooo00H0oooo0@0000010?ooo`005@3oool200000?h0oooo00<000000?ooo`3oool01@3oool2
00000040oooo000E0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3oool01P3oool10000
0040oooo000E0?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool01@3oool100000040
oooo000E0?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool01@3oool100000040oooo
000E0?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool01@3oool100000040oooo000E
0?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool01@3oool100000040oooo000E0?oo
o`030000003oool0oooo0?h0oooo00<000000?ooo`3oool01@3oool100000040oooo000E0?ooo`03
0000003oool0oooo0?h0oooo00<000000?ooo`3oool01@3oool100000040oooo000E0?ooo`030000
003oool0oooo0?h0oooo00<000000?ooo`3oool01@3oool100000040oooo000E0?ooo`800000o`3o
ool10?ooo`030000003oool0oooo00<0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`3o
0?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?oo
o`030000003oool0oooo00@0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`03
0000003oool0oooo00@0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`030000
003oool0oooo00@0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`030000003o
ool0oooo00@0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`030000003oool0
oooo00@0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo
00@0oooo0@0000010?ooo`005@3oool200000?l0oooo0P3oool00`000000oooo0?ooo`020?ooo`80
00000@3oool001D0oooo00<000000?ooo`3oool0o`3oool10?ooo`030000003oool0oooo00<0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3oool00`3o
ool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`03
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool10?ooo`030000003oool0oooo
00<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3o
ool00`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000oooo
0?ooo`030?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool10?ooo`030000003o
ool0oooo00<0oooo0@0000010?ooo`005@3oool200000?l0oooo0P3oool00`000000oooo0?ooo`02
0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool10?ooo`030000003oool0oooo
00<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3o
ool00`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000oooo
0?ooo`030?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool10?ooo`030000003o
ool0oooo00<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`40oooo00<00000
0?ooo`3oool00`3oool100000040oooo000=0?ooo`<000001@3oool00`000000oooo0?ooo`3o0?oo
o`40oooo00<000000?ooo`3oool00`3oool100000040oooo000<0?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3oool00`3oool10000
0040oooo000@0?ooo`030000003oool0oooo0080oooo0P00003o0?ooo`80oooo00<000000?ooo`3o
ool00P3oool200000040oooo000>0?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`40oooo
00<000000?ooo`3oool00`3oool100000040oooo000@0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3oool10?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`00303oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0o`3oool10?ooo`030000003o
ool0oooo00<0oooo0@0000010?ooo`003@3oool3000000D0oooo00<000000?ooo`3oool0o`3oool1
0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?oo
o`8000001@3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo0P0000050?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo0P00
003o0?ooo`L0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00/0oooo0@0000010?oo
o`005@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`4000000@3oool001D0ooooo`00000;00000040oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {0.756175, -0.290169, 0.0137482, \
0.0121539}},
  CellTags->"CustomFiber"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(46.5`\ Second\), ",", 
        TagBox[\(CustomFiberMirror[{\(-0.001582803748677895`\)\ \
\((\(-6.031362702896911`\) + #1)\)\ \((\(\(3.599634926466395`\)\(\
\[InvisibleSpace]\)\) + #1)\)\ \
\((\(\(102.35488754422377`\)\(\[InvisibleSpace]\)\) + 
                      10.679821765897334`\ #1 + #1\^2)\), \
\(-0.002633480022876776`\)\ \((\(-7.702428225902068`\) + #1)\)\ \
\((\(\(2.492064893512121`\)\(\[InvisibleSpace]\)\) + #1)\)\ \
\((\(\(2.8364346406535677`\)\(\[InvisibleSpace]\)\) + #1)\)\ \
\((\(\(5.683257168683909`\)\(\[InvisibleSpace]\)\) + #1)\), 0} &, 0.5`, 
            5.152129906681198`, {EllipseAngle \[Rule] 45.`, 
              EllipseRatio \[Rule] 2.`}]\),
          HoldForm]}], "}"}]], "Output",
  CellTags->"CustomFiber"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[DrawSystem[{SingleRay[],fiber,Move[Boundary[6],{0,2}]},\
PlotType->TopView,SurfacePoints->Mesh]][[1]]\
\>", "Input",
  CellTags->"CustomFiber"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.18254 0.15873 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.008 w
.1826 .20267 Mdot
.26226 .20547 Mdot
.18287 .24363 Mdot
.18287 .24363 Mdot
.25888 .24629 Mdot
.26226 .20547 Mdot
.26226 .20547 Mdot
.33779 .21604 Mdot
.25888 .24629 Mdot
.25888 .24629 Mdot
.32965 .25619 Mdot
.33779 .21604 Mdot
.33779 .21604 Mdot
.40934 .23562 Mdot
.32965 .25619 Mdot
.32965 .25619 Mdot
.3958 .27428 Mdot
.40934 .23562 Mdot
.40934 .23562 Mdot
.47675 .26492 Mdot
.3958 .27428 Mdot
.3958 .27428 Mdot
.45769 .30118 Mdot
.47675 .26492 Mdot
.47675 .26492 Mdot
.53947 .30417 Mdot
.45769 .30118 Mdot
.45769 .30118 Mdot
.51521 .33718 Mdot
.53947 .30417 Mdot
.53947 .30417 Mdot
.5965 .35304 Mdot
.51521 .33718 Mdot
.51521 .33718 Mdot
.56763 .38209 Mdot
.5965 .35304 Mdot
.5965 .35304 Mdot
.6464 .41058 Mdot
.56763 .38209 Mdot
.56763 .38209 Mdot
.61355 .43505 Mdot
.6464 .41058 Mdot
.6464 .41058 Mdot
.68732 .47516 Mdot
.61355 .43505 Mdot
.61355 .43505 Mdot
.65113 .49435 Mdot
.68732 .47516 Mdot
.68732 .47516 Mdot
.71709 .54448 Mdot
.65113 .49435 Mdot
.65113 .49435 Mdot
.6782 .55735 Mdot
.71709 .54448 Mdot
.71709 .54448 Mdot
.73331 .61551 Mdot
.6782 .55735 Mdot
.6782 .55735 Mdot
.69265 .62047 Mdot
.73331 .61551 Mdot
.73331 .61551 Mdot
.73354 .68456 Mdot
.69265 .62047 Mdot
.69265 .62047 Mdot
.69291 .67935 Mdot
.73354 .68456 Mdot
.18287 .24363 Mdot
.25888 .24629 Mdot
.18288 .24511 Mdot
.18288 .24511 Mdot
.25875 .24776 Mdot
.25888 .24629 Mdot
.25888 .24629 Mdot
.32965 .25619 Mdot
.25875 .24776 Mdot
.25875 .24776 Mdot
.32936 .25764 Mdot
.32965 .25619 Mdot
.32965 .25619 Mdot
.3958 .27428 Mdot
.32936 .25764 Mdot
.32936 .25764 Mdot
.39531 .27568 Mdot
.3958 .27428 Mdot
.3958 .27428 Mdot
.45769 .30118 Mdot
.39531 .27568 Mdot
.39531 .27568 Mdot
.457 .30249 Mdot
.45769 .30118 Mdot
.45769 .30118 Mdot
.51521 .33718 Mdot
.457 .30249 Mdot
.457 .30249 Mdot
.51433 .33837 Mdot
.51521 .33718 Mdot
.51521 .33718 Mdot
.56763 .38209 Mdot
.51433 .33837 Mdot
.51433 .33837 Mdot
.56658 .38314 Mdot
.56763 .38209 Mdot
.56763 .38209 Mdot
.61355 .43505 Mdot
.56658 .38314 Mdot
.56658 .38314 Mdot
.61237 .43594 Mdot
.61355 .43505 Mdot
.61355 .43505 Mdot
.65113 .49435 Mdot
.61237 .43594 Mdot
.61237 .43594 Mdot
.64982 .49504 Mdot
.65113 .49435 Mdot
.65113 .49435 Mdot
.6782 .55735 Mdot
.64982 .49504 Mdot
.64982 .49504 Mdot
.6768 .55782 Mdot
.6782 .55735 Mdot
.6782 .55735 Mdot
.69265 .62047 Mdot
.6768 .55782 Mdot
.6768 .55782 Mdot
.69118 .62065 Mdot
.69265 .62047 Mdot
.69265 .62047 Mdot
.69291 .67935 Mdot
.69118 .62065 Mdot
.69118 .62065 Mdot
.69144 .67916 Mdot
.69291 .67935 Mdot
.18288 .24511 Mdot
.25875 .24776 Mdot
.18262 .20617 Mdot
.18262 .20617 Mdot
.26198 .20895 Mdot
.25875 .24776 Mdot
.25875 .24776 Mdot
.32936 .25764 Mdot
.26198 .20895 Mdot
.26198 .20895 Mdot
.3371 .21946 Mdot
.32936 .25764 Mdot
.32936 .25764 Mdot
.39531 .27568 Mdot
.3371 .21946 Mdot
.3371 .21946 Mdot
.40819 .23892 Mdot
.39531 .27568 Mdot
.39531 .27568 Mdot
.457 .30249 Mdot
.40819 .23892 Mdot
.40819 .23892 Mdot
.47512 .26802 Mdot
.457 .30249 Mdot
.457 .30249 Mdot
.51433 .33837 Mdot
.47512 .26802 Mdot
.47512 .26802 Mdot
.5374 .30699 Mdot
.51433 .33837 Mdot
.51433 .33837 Mdot
.56658 .38314 Mdot
.5374 .30699 Mdot
.5374 .30699 Mdot
.59404 .35552 Mdot
.56658 .38314 Mdot
.56658 .38314 Mdot
.61237 .43594 Mdot
.59404 .35552 Mdot
.59404 .35552 Mdot
.6436 .41266 Mdot
.61237 .43594 Mdot
.61237 .43594 Mdot
.64982 .49504 Mdot
.6436 .41266 Mdot
.6436 .41266 Mdot
.68423 .4768 Mdot
.64982 .49504 Mdot
.64982 .49504 Mdot
.6768 .55782 Mdot
.68423 .4768 Mdot
.68423 .4768 Mdot
.71377 .54558 Mdot
.6768 .55782 Mdot
.6768 .55782 Mdot
.69118 .62065 Mdot
.71377 .54558 Mdot
.71377 .54558 Mdot
.72985 .61593 Mdot
.69118 .62065 Mdot
.69118 .62065 Mdot
.69144 .67916 Mdot
.72985 .61593 Mdot
.72985 .61593 Mdot
.73007 .68412 Mdot
.69144 .67916 Mdot
.18262 .20617 Mdot
.26198 .20895 Mdot
.18226 .15181 Mdot
.18226 .15181 Mdot
.26647 .15477 Mdot
.26198 .20895 Mdot
.26198 .20895 Mdot
.3371 .21946 Mdot
.26647 .15477 Mdot
.26647 .15477 Mdot
.34791 .16619 Mdot
.3371 .21946 Mdot
.3371 .21946 Mdot
.40819 .23892 Mdot
.34791 .16619 Mdot
.34791 .16619 Mdot
.42616 .18761 Mdot
.40819 .23892 Mdot
.40819 .23892 Mdot
.47512 .26802 Mdot
.42616 .18761 Mdot
.42616 .18761 Mdot
.50043 .2199 Mdot
.47512 .26802 Mdot
.47512 .26802 Mdot
.5374 .30699 Mdot
.50043 .2199 Mdot
.50043 .2199 Mdot
.5696 .26319 Mdot
.5374 .30699 Mdot
.5374 .30699 Mdot
.59404 .35552 Mdot
.5696 .26319 Mdot
.5696 .26319 Mdot
.63236 .31696 Mdot
.59404 .35552 Mdot
.59404 .35552 Mdot
.6436 .41266 Mdot
.63236 .31696 Mdot
.63236 .31696 Mdot
.68719 .38018 Mdot
.6436 .41266 Mdot
.6436 .41266 Mdot
.68423 .4768 Mdot
.68719 .38018 Mdot
.68719 .38018 Mdot
.73226 .45134 Mdot
.68423 .4768 Mdot
.68423 .4768 Mdot
.71377 .54558 Mdot
.73226 .45134 Mdot
.73226 .45134 Mdot
.76538 .5285 Mdot
.71377 .54558 Mdot
.71377 .54558 Mdot
.72985 .61593 Mdot
.76538 .5285 Mdot
.76538 .5285 Mdot
.78381 .60935 Mdot
.72985 .61593 Mdot
.72985 .61593 Mdot
.73007 .68412 Mdot
.78381 .60935 Mdot
.78381 .60935 Mdot
.78399 .69103 Mdot
.73007 .68412 Mdot
.18226 .15181 Mdot
.26647 .15477 Mdot
.18202 .11696 Mdot
.18202 .11696 Mdot
.26935 .12004 Mdot
.26647 .15477 Mdot
.26647 .15477 Mdot
.34791 .16619 Mdot
.26935 .12004 Mdot
.26935 .12004 Mdot
.35483 .13203 Mdot
.34791 .16619 Mdot
.34791 .16619 Mdot
.42616 .18761 Mdot
.35483 .13203 Mdot
.35483 .13203 Mdot
.43768 .15472 Mdot
.42616 .18761 Mdot
.42616 .18761 Mdot
.50043 .2199 Mdot
.43768 .15472 Mdot
.43768 .15472 Mdot
.51665 .18906 Mdot
.50043 .2199 Mdot
.50043 .2199 Mdot
.5696 .26319 Mdot
.51665 .18906 Mdot
.51665 .18906 Mdot
.59024 .23511 Mdot
.5696 .26319 Mdot
.5696 .26319 Mdot
.63236 .31696 Mdot
.59024 .23511 Mdot
.59024 .23511 Mdot
.65693 .29225 Mdot
.63236 .31696 Mdot
.63236 .31696 Mdot
.68719 .38018 Mdot
.65693 .29225 Mdot
.65693 .29225 Mdot
.71513 .35936 Mdot
.68719 .38018 Mdot
.68719 .38018 Mdot
.73226 .45134 Mdot
.71513 .35936 Mdot
.71513 .35936 Mdot
.76305 .43502 Mdot
.73226 .45134 Mdot
.73226 .45134 Mdot
.76538 .5285 Mdot
.76305 .43502 Mdot
.76305 .43502 Mdot
.79847 .51755 Mdot
.76538 .5285 Mdot
.76538 .5285 Mdot
.78381 .60935 Mdot
.79847 .51755 Mdot
.79847 .51755 Mdot
.8184 .60513 Mdot
.78381 .60935 Mdot
.78381 .60935 Mdot
.78399 .69103 Mdot
.8184 .60513 Mdot
.8184 .60513 Mdot
.81856 .69546 Mdot
.78399 .69103 Mdot
.18202 .11696 Mdot
.26935 .12004 Mdot
.18207 .12401 Mdot
.18207 .12401 Mdot
.26877 .12707 Mdot
.26935 .12004 Mdot
.26935 .12004 Mdot
.35483 .13203 Mdot
.26877 .12707 Mdot
.26877 .12707 Mdot
.35343 .13894 Mdot
.35483 .13203 Mdot
.35483 .13203 Mdot
.43768 .15472 Mdot
.35343 .13894 Mdot
.35343 .13894 Mdot
.43535 .16138 Mdot
.43768 .15472 Mdot
.43768 .15472 Mdot
.51665 .18906 Mdot
.43535 .16138 Mdot
.43535 .16138 Mdot
.51337 .1953 Mdot
.51665 .18906 Mdot
.51665 .18906 Mdot
.59024 .23511 Mdot
.51337 .1953 Mdot
.51337 .1953 Mdot
.58606 .24079 Mdot
.59024 .23511 Mdot
.59024 .23511 Mdot
.65693 .29225 Mdot
.58606 .24079 Mdot
.58606 .24079 Mdot
.65196 .29724 Mdot
.65693 .29225 Mdot
.65693 .29225 Mdot
.71513 .35936 Mdot
.65196 .29724 Mdot
.65196 .29724 Mdot
.70948 .36357 Mdot
.71513 .35936 Mdot
.71513 .35936 Mdot
.76305 .43502 Mdot
.70948 .36357 Mdot
.70948 .36357 Mdot
.75682 .43832 Mdot
.76305 .43502 Mdot
.76305 .43502 Mdot
.79847 .51755 Mdot
.75682 .43832 Mdot
.75682 .43832 Mdot
.79178 .51977 Mdot
.79847 .51755 Mdot
.79847 .51755 Mdot
.8184 .60513 Mdot
.79178 .51977 Mdot
.79178 .51977 Mdot
.8114 .60598 Mdot
.8184 .60513 Mdot
.8184 .60513 Mdot
.81856 .69546 Mdot
.8114 .60598 Mdot
.8114 .60598 Mdot
.81157 .69457 Mdot
.81856 .69546 Mdot
.18207 .12401 Mdot
.26877 .12707 Mdot
.18237 .16842 Mdot
.18237 .16842 Mdot
.2651 .17133 Mdot
.26877 .12707 Mdot
.26877 .12707 Mdot
.35343 .13894 Mdot
.2651 .17133 Mdot
.2651 .17133 Mdot
.3446 .18247 Mdot
.35343 .13894 Mdot
.35343 .13894 Mdot
.43535 .16138 Mdot
.3446 .18247 Mdot
.3446 .18247 Mdot
.42067 .2033 Mdot
.43535 .16138 Mdot
.43535 .16138 Mdot
.51337 .1953 Mdot
.42067 .2033 Mdot
.42067 .2033 Mdot
.49269 .23461 Mdot
.51337 .1953 Mdot
.51337 .1953 Mdot
.58606 .24079 Mdot
.49269 .23461 Mdot
.49269 .23461 Mdot
.55976 .27658 Mdot
.58606 .24079 Mdot
.58606 .24079 Mdot
.65196 .29724 Mdot
.55976 .27658 Mdot
.55976 .27658 Mdot
.62065 .32875 Mdot
.65196 .29724 Mdot
.65196 .29724 Mdot
.70948 .36357 Mdot
.62065 .32875 Mdot
.62065 .32875 Mdot
.67386 .39011 Mdot
.70948 .36357 Mdot
.70948 .36357 Mdot
.75682 .43832 Mdot
.67386 .39011 Mdot
.67386 .39011 Mdot
.71758 .45912 Mdot
.75682 .43832 Mdot
.75682 .43832 Mdot
.79178 .51977 Mdot
.71758 .45912 Mdot
.71758 .45912 Mdot
.74961 .53372 Mdot
.79178 .51977 Mdot
.79178 .51977 Mdot
.8114 .60598 Mdot
.74961 .53372 Mdot
.74961 .53372 Mdot
.76731 .61136 Mdot
.8114 .60598 Mdot
.8114 .60598 Mdot
.81157 .69457 Mdot
.76731 .61136 Mdot
.76731 .61136 Mdot
.76751 .68892 Mdot
.81157 .69457 Mdot
.18237 .16842 Mdot
.2651 .17133 Mdot
.18273 .22168 Mdot
.18273 .22168 Mdot
.26069 .22441 Mdot
.2651 .17133 Mdot
.2651 .17133 Mdot
.3446 .18247 Mdot
.26069 .22441 Mdot
.26069 .22441 Mdot
.33402 .23467 Mdot
.3446 .18247 Mdot
.3446 .18247 Mdot
.42067 .2033 Mdot
.33402 .23467 Mdot
.33402 .23467 Mdot
.40306 .25356 Mdot
.42067 .2033 Mdot
.42067 .2033 Mdot
.49269 .23461 Mdot
.40306 .25356 Mdot
.40306 .25356 Mdot
.46791 .28174 Mdot
.49269 .23461 Mdot
.49269 .23461 Mdot
.55976 .27658 Mdot
.46791 .28174 Mdot
.46791 .28174 Mdot
.52821 .31949 Mdot
.55976 .27658 Mdot
.55976 .27658 Mdot
.62065 .32875 Mdot
.52821 .31949 Mdot
.52821 .31949 Mdot
.5831 .36652 Mdot
.62065 .32875 Mdot
.62065 .32875 Mdot
.67386 .39011 Mdot
.5831 .36652 Mdot
.5831 .36652 Mdot
.63116 .42193 Mdot
.67386 .39011 Mdot
.67386 .39011 Mdot
.71758 .45912 Mdot
.63116 .42193 Mdot
.63116 .42193 Mdot
.67053 .48407 Mdot
.71758 .45912 Mdot
.71758 .45912 Mdot
.74961 .53372 Mdot
.67053 .48407 Mdot
.67053 .48407 Mdot
.69905 .55046 Mdot
.74961 .53372 Mdot
.74961 .53372 Mdot
.76731 .61136 Mdot
.69905 .55046 Mdot
.69905 .55046 Mdot
.71445 .61781 Mdot
.76731 .61136 Mdot
.76731 .61136 Mdot
.76751 .68892 Mdot
.71445 .61781 Mdot
.71445 .61781 Mdot
.71469 .68214 Mdot
.76751 .68892 Mdot
.5 Mabswid
[ ] 0 setdash
.1826 .20267 m
.26226 .20547 L
.18287 .24363 L
.1826 .20267 L
s
.18287 .24363 m
.25888 .24629 L
.26226 .20547 L
.18287 .24363 L
s
.26226 .20547 m
.33779 .21604 L
.25888 .24629 L
.26226 .20547 L
s
.25888 .24629 m
.32965 .25619 L
.33779 .21604 L
.25888 .24629 L
s
.33779 .21604 m
.40934 .23562 L
.32965 .25619 L
.33779 .21604 L
s
.32965 .25619 m
.3958 .27428 L
.40934 .23562 L
.32965 .25619 L
s
.40934 .23562 m
.47675 .26492 L
.3958 .27428 L
.40934 .23562 L
s
.3958 .27428 m
.45769 .30118 L
.47675 .26492 L
.3958 .27428 L
s
.47675 .26492 m
.53947 .30417 L
.45769 .30118 L
.47675 .26492 L
s
.45769 .30118 m
.51521 .33718 L
.53947 .30417 L
.45769 .30118 L
s
.53947 .30417 m
.5965 .35304 L
.51521 .33718 L
.53947 .30417 L
s
.51521 .33718 m
.56763 .38209 L
.5965 .35304 L
.51521 .33718 L
s
.5965 .35304 m
.6464 .41058 L
.56763 .38209 L
.5965 .35304 L
s
.56763 .38209 m
.61355 .43505 L
.6464 .41058 L
.56763 .38209 L
s
.6464 .41058 m
.68732 .47516 L
.61355 .43505 L
.6464 .41058 L
s
.61355 .43505 m
.65113 .49435 L
.68732 .47516 L
.61355 .43505 L
s
.68732 .47516 m
.71709 .54448 L
.65113 .49435 L
.68732 .47516 L
s
.65113 .49435 m
.6782 .55735 L
.71709 .54448 L
.65113 .49435 L
s
.71709 .54448 m
.73331 .61551 L
.6782 .55735 L
.71709 .54448 L
s
.6782 .55735 m
.69265 .62047 L
.73331 .61551 L
.6782 .55735 L
s
.73331 .61551 m
.73354 .68456 L
.69265 .62047 L
.73331 .61551 L
s
.69265 .62047 m
.69291 .67935 L
.73354 .68456 L
.69265 .62047 L
s
.18287 .24363 m
.25888 .24629 L
.18288 .24511 L
.18287 .24363 L
s
.18288 .24511 m
.25875 .24776 L
.25888 .24629 L
.18288 .24511 L
s
.25888 .24629 m
.32965 .25619 L
.25875 .24776 L
.25888 .24629 L
s
.25875 .24776 m
.32936 .25764 L
.32965 .25619 L
.25875 .24776 L
s
.32965 .25619 m
.3958 .27428 L
.32936 .25764 L
.32965 .25619 L
s
.32936 .25764 m
.39531 .27568 L
.3958 .27428 L
.32936 .25764 L
s
.3958 .27428 m
.45769 .30118 L
.39531 .27568 L
.3958 .27428 L
s
.39531 .27568 m
.457 .30249 L
.45769 .30118 L
.39531 .27568 L
s
.45769 .30118 m
.51521 .33718 L
.457 .30249 L
.45769 .30118 L
s
.457 .30249 m
.51433 .33837 L
.51521 .33718 L
.457 .30249 L
s
.51521 .33718 m
.56763 .38209 L
.51433 .33837 L
.51521 .33718 L
s
.51433 .33837 m
.56658 .38314 L
.56763 .38209 L
.51433 .33837 L
s
.56763 .38209 m
.61355 .43505 L
.56658 .38314 L
.56763 .38209 L
s
.56658 .38314 m
.61237 .43594 L
.61355 .43505 L
.56658 .38314 L
s
.61355 .43505 m
.65113 .49435 L
.61237 .43594 L
.61355 .43505 L
s
.61237 .43594 m
.64982 .49504 L
.65113 .49435 L
.61237 .43594 L
s
.65113 .49435 m
.6782 .55735 L
.64982 .49504 L
.65113 .49435 L
s
.64982 .49504 m
.6768 .55782 L
.6782 .55735 L
.64982 .49504 L
s
.6782 .55735 m
.69265 .62047 L
.6768 .55782 L
.6782 .55735 L
s
.6768 .55782 m
.69118 .62065 L
.69265 .62047 L
.6768 .55782 L
s
.69265 .62047 m
.69291 .67935 L
.69118 .62065 L
.69265 .62047 L
s
.69118 .62065 m
.69144 .67916 L
.69291 .67935 L
.69118 .62065 L
s
.18288 .24511 m
.25875 .24776 L
.18262 .20617 L
.18288 .24511 L
s
.18262 .20617 m
.26198 .20895 L
.25875 .24776 L
.18262 .20617 L
s
.25875 .24776 m
.32936 .25764 L
.26198 .20895 L
.25875 .24776 L
s
.26198 .20895 m
.3371 .21946 L
.32936 .25764 L
.26198 .20895 L
s
.32936 .25764 m
.39531 .27568 L
.3371 .21946 L
.32936 .25764 L
s
.3371 .21946 m
.40819 .23892 L
.39531 .27568 L
.3371 .21946 L
s
.39531 .27568 m
.457 .30249 L
.40819 .23892 L
.39531 .27568 L
s
.40819 .23892 m
.47512 .26802 L
.457 .30249 L
.40819 .23892 L
s
.457 .30249 m
.51433 .33837 L
.47512 .26802 L
.457 .30249 L
s
.47512 .26802 m
.5374 .30699 L
.51433 .33837 L
.47512 .26802 L
s
.51433 .33837 m
.56658 .38314 L
.5374 .30699 L
.51433 .33837 L
s
.5374 .30699 m
.59404 .35552 L
.56658 .38314 L
.5374 .30699 L
s
.56658 .38314 m
.61237 .43594 L
.59404 .35552 L
.56658 .38314 L
s
.59404 .35552 m
.6436 .41266 L
.61237 .43594 L
.59404 .35552 L
s
.61237 .43594 m
.64982 .49504 L
.6436 .41266 L
.61237 .43594 L
s
.6436 .41266 m
.68423 .4768 L
.64982 .49504 L
.6436 .41266 L
s
.64982 .49504 m
.6768 .55782 L
.68423 .4768 L
.64982 .49504 L
s
.68423 .4768 m
.71377 .54558 L
.6768 .55782 L
.68423 .4768 L
s
.6768 .55782 m
.69118 .62065 L
.71377 .54558 L
.6768 .55782 L
s
.71377 .54558 m
.72985 .61593 L
.69118 .62065 L
.71377 .54558 L
s
.69118 .62065 m
.69144 .67916 L
.72985 .61593 L
.69118 .62065 L
s
.72985 .61593 m
.73007 .68412 L
.69144 .67916 L
.72985 .61593 L
s
.18262 .20617 m
.26198 .20895 L
.18226 .15181 L
.18262 .20617 L
s
.18226 .15181 m
.26647 .15477 L
.26198 .20895 L
.18226 .15181 L
s
.26198 .20895 m
.3371 .21946 L
.26647 .15477 L
.26198 .20895 L
s
.26647 .15477 m
.34791 .16619 L
.3371 .21946 L
.26647 .15477 L
s
.3371 .21946 m
.40819 .23892 L
.34791 .16619 L
.3371 .21946 L
s
.34791 .16619 m
.42616 .18761 L
.40819 .23892 L
.34791 .16619 L
s
.40819 .23892 m
.47512 .26802 L
.42616 .18761 L
.40819 .23892 L
s
.42616 .18761 m
.50043 .2199 L
.47512 .26802 L
.42616 .18761 L
s
.47512 .26802 m
.5374 .30699 L
.50043 .2199 L
.47512 .26802 L
s
.50043 .2199 m
.5696 .26319 L
.5374 .30699 L
.50043 .2199 L
s
.5374 .30699 m
.59404 .35552 L
.5696 .26319 L
.5374 .30699 L
s
.5696 .26319 m
.63236 .31696 L
.59404 .35552 L
.5696 .26319 L
s
.59404 .35552 m
.6436 .41266 L
.63236 .31696 L
.59404 .35552 L
s
.63236 .31696 m
.68719 .38018 L
.6436 .41266 L
.63236 .31696 L
s
.6436 .41266 m
.68423 .4768 L
.68719 .38018 L
.6436 .41266 L
s
.68719 .38018 m
.73226 .45134 L
.68423 .4768 L
.68719 .38018 L
s
.68423 .4768 m
.71377 .54558 L
.73226 .45134 L
.68423 .4768 L
s
.73226 .45134 m
.76538 .5285 L
.71377 .54558 L
.73226 .45134 L
s
.71377 .54558 m
.72985 .61593 L
.76538 .5285 L
.71377 .54558 L
s
.76538 .5285 m
.78381 .60935 L
.72985 .61593 L
.76538 .5285 L
s
.72985 .61593 m
.73007 .68412 L
.78381 .60935 L
.72985 .61593 L
s
.78381 .60935 m
.78399 .69103 L
.73007 .68412 L
.78381 .60935 L
s
.18226 .15181 m
.26647 .15477 L
.18202 .11696 L
.18226 .15181 L
s
.18202 .11696 m
.26935 .12004 L
.26647 .15477 L
.18202 .11696 L
s
.26647 .15477 m
.34791 .16619 L
.26935 .12004 L
.26647 .15477 L
s
.26935 .12004 m
.35483 .13203 L
.34791 .16619 L
.26935 .12004 L
s
.34791 .16619 m
.42616 .18761 L
.35483 .13203 L
.34791 .16619 L
s
.35483 .13203 m
.43768 .15472 L
.42616 .18761 L
.35483 .13203 L
s
.42616 .18761 m
.50043 .2199 L
.43768 .15472 L
.42616 .18761 L
s
.43768 .15472 m
.51665 .18906 L
.50043 .2199 L
.43768 .15472 L
s
.50043 .2199 m
.5696 .26319 L
.51665 .18906 L
.50043 .2199 L
s
.51665 .18906 m
.59024 .23511 L
.5696 .26319 L
.51665 .18906 L
s
.5696 .26319 m
.63236 .31696 L
.59024 .23511 L
.5696 .26319 L
s
.59024 .23511 m
.65693 .29225 L
.63236 .31696 L
.59024 .23511 L
s
.63236 .31696 m
.68719 .38018 L
.65693 .29225 L
.63236 .31696 L
s
.65693 .29225 m
.71513 .35936 L
.68719 .38018 L
.65693 .29225 L
s
.68719 .38018 m
.73226 .45134 L
.71513 .35936 L
.68719 .38018 L
s
.71513 .35936 m
.76305 .43502 L
.73226 .45134 L
.71513 .35936 L
s
.73226 .45134 m
.76538 .5285 L
.76305 .43502 L
.73226 .45134 L
s
.76305 .43502 m
.79847 .51755 L
.76538 .5285 L
.76305 .43502 L
s
.76538 .5285 m
.78381 .60935 L
.79847 .51755 L
.76538 .5285 L
s
.79847 .51755 m
.8184 .60513 L
.78381 .60935 L
.79847 .51755 L
s
.78381 .60935 m
.78399 .69103 L
.8184 .60513 L
.78381 .60935 L
s
.8184 .60513 m
.81856 .69546 L
.78399 .69103 L
.8184 .60513 L
s
.18202 .11696 m
.26935 .12004 L
.18207 .12401 L
.18202 .11696 L
s
.18207 .12401 m
.26877 .12707 L
.26935 .12004 L
.18207 .12401 L
s
.26935 .12004 m
.35483 .13203 L
.26877 .12707 L
.26935 .12004 L
s
.26877 .12707 m
.35343 .13894 L
.35483 .13203 L
.26877 .12707 L
s
.35483 .13203 m
.43768 .15472 L
.35343 .13894 L
.35483 .13203 L
s
.35343 .13894 m
.43535 .16138 L
.43768 .15472 L
.35343 .13894 L
s
.43768 .15472 m
.51665 .18906 L
.43535 .16138 L
.43768 .15472 L
s
.43535 .16138 m
.51337 .1953 L
.51665 .18906 L
.43535 .16138 L
s
.51665 .18906 m
.59024 .23511 L
.51337 .1953 L
.51665 .18906 L
s
.51337 .1953 m
.58606 .24079 L
.59024 .23511 L
.51337 .1953 L
s
.59024 .23511 m
.65693 .29225 L
.58606 .24079 L
.59024 .23511 L
s
.58606 .24079 m
.65196 .29724 L
.65693 .29225 L
.58606 .24079 L
s
.65693 .29225 m
.71513 .35936 L
.65196 .29724 L
.65693 .29225 L
s
.65196 .29724 m
.70948 .36357 L
.71513 .35936 L
.65196 .29724 L
s
.71513 .35936 m
.76305 .43502 L
.70948 .36357 L
.71513 .35936 L
s
.70948 .36357 m
.75682 .43832 L
.76305 .43502 L
.70948 .36357 L
s
.76305 .43502 m
.79847 .51755 L
.75682 .43832 L
.76305 .43502 L
s
.75682 .43832 m
.79178 .51977 L
.79847 .51755 L
.75682 .43832 L
s
.79847 .51755 m
.8184 .60513 L
.79178 .51977 L
.79847 .51755 L
s
.79178 .51977 m
.8114 .60598 L
.8184 .60513 L
.79178 .51977 L
s
.8184 .60513 m
.81856 .69546 L
.8114 .60598 L
.8184 .60513 L
s
.8114 .60598 m
.81157 .69457 L
.81856 .69546 L
.8114 .60598 L
s
.18207 .12401 m
.26877 .12707 L
.18237 .16842 L
.18207 .12401 L
s
.18237 .16842 m
.2651 .17133 L
.26877 .12707 L
.18237 .16842 L
s
.26877 .12707 m
.35343 .13894 L
.2651 .17133 L
.26877 .12707 L
s
.2651 .17133 m
.3446 .18247 L
.35343 .13894 L
.2651 .17133 L
s
.35343 .13894 m
.43535 .16138 L
.3446 .18247 L
.35343 .13894 L
s
.3446 .18247 m
.42067 .2033 L
.43535 .16138 L
.3446 .18247 L
s
.43535 .16138 m
.51337 .1953 L
.42067 .2033 L
.43535 .16138 L
s
.42067 .2033 m
.49269 .23461 L
.51337 .1953 L
.42067 .2033 L
s
.51337 .1953 m
.58606 .24079 L
.49269 .23461 L
.51337 .1953 L
s
.49269 .23461 m
.55976 .27658 L
.58606 .24079 L
.49269 .23461 L
s
.58606 .24079 m
.65196 .29724 L
.55976 .27658 L
.58606 .24079 L
s
.55976 .27658 m
.62065 .32875 L
.65196 .29724 L
.55976 .27658 L
s
.65196 .29724 m
.70948 .36357 L
.62065 .32875 L
.65196 .29724 L
s
.62065 .32875 m
.67386 .39011 L
.70948 .36357 L
.62065 .32875 L
s
.70948 .36357 m
.75682 .43832 L
.67386 .39011 L
.70948 .36357 L
s
.67386 .39011 m
.71758 .45912 L
.75682 .43832 L
.67386 .39011 L
s
.75682 .43832 m
.79178 .51977 L
.71758 .45912 L
.75682 .43832 L
s
.71758 .45912 m
.74961 .53372 L
.79178 .51977 L
.71758 .45912 L
s
.79178 .51977 m
.8114 .60598 L
.74961 .53372 L
.79178 .51977 L
s
.74961 .53372 m
.76731 .61136 L
.8114 .60598 L
.74961 .53372 L
s
.8114 .60598 m
.81157 .69457 L
.76731 .61136 L
.8114 .60598 L
s
.76731 .61136 m
.76751 .68892 L
.81157 .69457 L
.76731 .61136 L
s
.18237 .16842 m
.2651 .17133 L
.18273 .22168 L
.18237 .16842 L
s
.18273 .22168 m
.26069 .22441 L
.2651 .17133 L
.18273 .22168 L
s
.2651 .17133 m
.3446 .18247 L
.26069 .22441 L
.2651 .17133 L
s
.26069 .22441 m
.33402 .23467 L
.3446 .18247 L
.26069 .22441 L
s
.3446 .18247 m
.42067 .2033 L
.33402 .23467 L
.3446 .18247 L
s
.33402 .23467 m
.40306 .25356 L
.42067 .2033 L
.33402 .23467 L
s
.42067 .2033 m
.49269 .23461 L
.40306 .25356 L
.42067 .2033 L
s
.40306 .25356 m
.46791 .28174 L
.49269 .23461 L
.40306 .25356 L
s
.49269 .23461 m
.55976 .27658 L
.46791 .28174 L
.49269 .23461 L
s
.46791 .28174 m
.52821 .31949 L
.55976 .27658 L
.46791 .28174 L
s
.55976 .27658 m
.62065 .32875 L
.52821 .31949 L
.55976 .27658 L
s
.52821 .31949 m
.5831 .36652 L
.62065 .32875 L
.52821 .31949 L
s
.62065 .32875 m
.67386 .39011 L
.5831 .36652 L
.62065 .32875 L
s
.5831 .36652 m
.63116 .42193 L
.67386 .39011 L
.5831 .36652 L
s
.67386 .39011 m
.71758 .45912 L
.63116 .42193 L
.67386 .39011 L
s
.63116 .42193 m
.67053 .48407 L
.71758 .45912 L
.63116 .42193 L
s
.71758 .45912 m
.74961 .53372 L
.67053 .48407 L
.71758 .45912 L
s
.67053 .48407 m
.69905 .55046 L
.74961 .53372 L
.67053 .48407 L
s
.74961 .53372 m
.76731 .61136 L
.69905 .55046 L
.74961 .53372 L
s
.69905 .55046 m
.71445 .61781 L
.76731 .61136 L
.69905 .55046 L
s
.76731 .61136 m
.76751 .68892 L
.71445 .61781 L
.76731 .61136 L
s
.71445 .61781 m
.71469 .68214 L
.76751 .68892 L
.71445 .61781 L
s
.56386 .33319 m
.55503 .3435 L
.54805 .35165 L
.54339 .35709 L
.54137 .35945 L
.54212 .35857 L
.5456 .3545 L
.55157 .34754 L
.55962 .33814 L
.5692 .32695 L
.57967 .31474 L
.59029 .30233 L
.60037 .29057 L
.60919 .28027 L
.61618 .27212 L
.62084 .26668 L
.62286 .26432 L
.6221 .2652 L
.61862 .26926 L
.61265 .27623 L
.6046 .28563 L
.59502 .29682 L
.58456 .30903 L
.57393 .32144 L
.56386 .33319 L
.56386 .33319 L
.57393 .32144 L
.58456 .30903 L
.59502 .29682 L
.6046 .28563 L
.61265 .27623 L
.61862 .26926 L
.6221 .2652 L
.62286 .26432 L
.62084 .26668 L
.61618 .27212 L
.60919 .28027 L
.60037 .29057 L
.59029 .30233 L
.57967 .31474 L
.5692 .32695 L
.55962 .33814 L
.55157 .34754 L
.5456 .3545 L
.54212 .35857 L
.54137 .35945 L
.54339 .35709 L
.54805 .35165 L
.55503 .3435 L
.56386 .33319 L
Mistroke
.56386 .33319 L
Mfstroke
.20455 .15419 m
.21929 .1545 L
.23394 .15503 L
.24851 .1558 L
.263 .15681 L
.2774 .15808 L
.29172 .15961 L
.30594 .16142 L
.32008 .16352 L
.33413 .1659 L
.34808 .16858 L
.36193 .17157 L
.37569 .17487 L
.38934 .17849 L
.40288 .18243 L
.41631 .1867 L
.42962 .19129 L
.44281 .19622 L
.45587 .20148 L
.46879 .20708 L
.48158 .21302 L
.49422 .21929 L
.50671 .22589 L
.51904 .23283 L
.53121 .24011 L
.54321 .24771 L
.55502 .25564 L
.56666 .2639 L
.5781 .27248 L
.58934 .28137 L
.60037 .29057 L
.61118 .30008 L
.62177 .30989 L
.63213 .32 L
.64225 .33039 L
.65211 .34106 L
.66172 .352 L
.67106 .36321 L
.68012 .37467 L
.68889 .38638 L
.69736 .39833 L
.70551 .41051 L
.71335 .42291 L
.72086 .43551 L
.72802 .44831 L
.73482 .4613 L
.74125 .47446 L
.74729 .48778 L
.75294 .50125 L
.75817 .51487 L
Mistroke
.76298 .5286 L
.76734 .54245 L
.77124 .55639 L
.77467 .57042 L
.7776 .58452 L
.78001 .59867 L
.78189 .61285 L
.78322 .62706 L
.78396 .64127 L
.78411 .65546 L
.78364 .66962 L
.78364 .66962 L
.78411 .65546 L
.78396 .64127 L
.78322 .62706 L
.78189 .61285 L
.78001 .59867 L
.7776 .58452 L
.77467 .57042 L
.77124 .55639 L
.76734 .54245 L
.76298 .5286 L
.75817 .51487 L
.75294 .50125 L
.74729 .48778 L
.74125 .47446 L
.73482 .4613 L
.72802 .44831 L
.72086 .43551 L
.71335 .42291 L
.70551 .41051 L
.69736 .39833 L
.68889 .38638 L
.68012 .37467 L
.67106 .36321 L
.66172 .352 L
.65211 .34106 L
.64225 .33039 L
.63213 .32 L
.62177 .30989 L
.61118 .30008 L
.60037 .29057 L
.58934 .28137 L
.5781 .27248 L
.56666 .2639 L
.55502 .25564 L
.54321 .24771 L
.53121 .24011 L
.51904 .23283 L
.50671 .22589 L
Mistroke
.49422 .21929 L
.48158 .21302 L
.46879 .20708 L
.45587 .20148 L
.44281 .19622 L
.42962 .19129 L
.41631 .1867 L
.40288 .18243 L
.38934 .17849 L
.37569 .17487 L
.36193 .17157 L
.34808 .16858 L
.33413 .1659 L
.32008 .16352 L
.30594 .16142 L
.29172 .15961 L
.2774 .15808 L
.263 .15681 L
.24851 .1558 L
.23394 .15503 L
.21929 .1545 L
.20455 .15419 L
.20455 .15419 L
Mfstroke
.72761 .66646 m
.71406 .6657 L
.70334 .6651 L
.69619 .66469 L
.69309 .66452 L
.69425 .66459 L
.69959 .66489 L
.70875 .6654 L
.72111 .6661 L
.73581 .66692 L
.75187 .66783 L
.76818 .66875 L
.78364 .66962 L
.79719 .67038 L
.8079 .67098 L
.81505 .67138 L
.81815 .67156 L
.817 .67149 L
.81165 .67119 L
.80249 .67068 L
.79014 .66998 L
.77543 .66915 L
.75938 .66825 L
.74306 .66733 L
.72761 .66646 L
.72761 .66646 L
.728 .65483 L
.72787 .64305 L
.72725 .63116 L
.72613 .61916 L
.72453 .60709 L
.72246 .59496 L
.71993 .5828 L
.71696 .57062 L
.71355 .55845 L
.70973 .54631 L
.70549 .53421 L
.70087 .52218 L
.69586 .51023 L
.69048 .49838 L
.68474 .48664 L
.67867 .47503 L
.67225 .46357 L
.66552 .45226 L
.65849 .44113 L
.65115 .43018 L
.64353 .41943 L
.63564 .40889 L
.62748 .39857 L
.61907 .38848 L
Mistroke
.61042 .37862 L
.60154 .36902 L
.59243 .35966 L
.58311 .35057 L
.57358 .34174 L
.56386 .33319 L
.55394 .32492 L
.54385 .31694 L
.53358 .30924 L
.52314 .30183 L
.51254 .29471 L
.50179 .2879 L
.49088 .28138 L
.47983 .27515 L
.46863 .26923 L
.4573 .26361 L
.44583 .25829 L
.43423 .25327 L
.4225 .24854 L
.41064 .24411 L
.39866 .23997 L
.38655 .23612 L
.37431 .23256 L
.36195 .22929 L
.34947 .22629 L
.33687 .22357 L
.32414 .22112 L
.31128 .21894 L
.2983 .21702 L
.28519 .21535 L
.27196 .21394 L
.25859 .21276 L
.24509 .21181 L
.23146 .2111 L
.21769 .2106 L
.20378 .2103 L
.20378 .2103 L
.20399 .19483 L
.20421 .17849 L
.20443 .16241 L
.20464 .14768 L
.2048 .13531 L
.20493 .12613 L
.205 .12078 L
.20502 .11962 L
.20498 .12273 L
.20488 .12989 L
.20473 .14062 L
.20455 .15419 L
.20433 .16967 L
Mistroke
.20411 .18601 L
.20389 .20209 L
.20369 .21682 L
.20352 .22919 L
.2034 .23836 L
.20332 .24371 L
.20331 .24487 L
.20335 .24177 L
.20345 .2346 L
.20359 .22387 L
.20378 .2103 L
.20378 .2103 L
.21769 .2106 L
.23146 .2111 L
.24509 .21181 L
.25859 .21276 L
.27196 .21394 L
.28519 .21535 L
.2983 .21702 L
.31128 .21894 L
.32414 .22112 L
.33687 .22357 L
.34947 .22629 L
.36195 .22929 L
.37431 .23256 L
.38655 .23612 L
.39866 .23997 L
.41064 .24411 L
.4225 .24854 L
.43423 .25327 L
.44583 .25829 L
.4573 .26361 L
.46863 .26923 L
.47983 .27515 L
.49088 .28138 L
.50179 .2879 L
.51254 .29471 L
.52314 .30183 L
.53358 .30924 L
.54385 .31694 L
.55394 .32492 L
.56386 .33319 L
.57358 .34174 L
.58311 .35057 L
.59243 .35966 L
.60154 .36902 L
.61042 .37862 L
.61907 .38848 L
.62748 .39857 L
.63564 .40889 L
Mistroke
.64353 .41943 L
.65115 .43018 L
.65849 .44113 L
.66552 .45226 L
.67225 .46357 L
.67867 .47503 L
.68474 .48664 L
.69048 .49838 L
.69586 .51023 L
.70087 .52218 L
.70549 .53421 L
.70973 .54631 L
.71355 .55845 L
.71696 .57062 L
.71993 .5828 L
.72246 .59496 L
.72453 .60709 L
.72613 .61916 L
.72725 .63116 L
.72787 .64305 L
.728 .65483 L
.72761 .66646 L
Mfstroke
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .18254 m
.20416 .18254 L
s
% Start of user PostScript
0 0 1.1362 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20416 .18254 Mdot
.039 .916 .04 r
.5 Mabswid
.20416 .18254 m
.46791 .18254 L
s
% Start of user PostScript
1.1362 0 2.79781 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.46791 .18254 Mdot
.039 .916 .04 r
.5 Mabswid
.46791 .18254 m
.60785 .27832 L
s
% Start of user PostScript
2.79781 0 3.67947 0.60343 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.60785 .27832 Mdot
.039 .916 .04 r
.5 Mabswid
.60785 .27832 m
.70547 .36 L
s
% Start of user PostScript
3.67947 0.60343 4.29447 1.11799 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70547 .36 Mdot
.039 .916 .04 r
.5 Mabswid
.70547 .36 m
.77877 .66934 L
s
% Start of user PostScript
4.29447 1.11799 4.75624 3.06685 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.77877 .66934 Mdot
.039 .916 .04 r
.5 Mabswid
.77877 .66934 m
.85147 .97619 L
s
% Start of user PostScript
4.75624 3.06685 5.21429 5. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.85147 .97619 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0Z0?ooo`l00000eP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`0Z0?ooo`80000000<0oooo0000000000000P3oool0
0`000000oooo0?ooo`040?oooa400000aP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0Z0?ooo`l000002P3oool2000000040?ooo`00000000000?ooo`P00000_P3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0Z0?ooo`8000001@3oool30000
00D0oooo8000002f0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02000000/0oooo100000040?oooaH0
0000/03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool2000000L0oooo0P0000030?ooo`030000
003oool0oooo00@0oooo0P0000040?ooo`P000000`3oool600000:d0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00T0oooo1`0000020?ooo`@00000Z@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool3
000000H0oooo0P0000090?ooo`800000203oool500000080oooo1@0000020?ooo`<00000YP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool2000000040?ooo`0000000000000000@0oooo0P00000;
0?ooo`800000103oool2000000<0oooo0P0000050?ooo`X00000X`3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool3000000H0oooo0P0000020?ooo`8000003@3oool4000000D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0000000:000009l0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0:P3oool>000000T0oooo0`00000=0?ooo`@000001P3oool00`000000
oooo0?ooo`060?ooo`8000000`3oool300000080oooo1@00002L0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo02X0oooo0P0000000`3oool000000?ooo`020?oooaL00000
1P3oool3000000@0oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0`3oool3000000@0oooo0`00002I0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool01000000?0?ooo`l000001`3oool00`000000oooo0?oo
o`02000000/0oooo00<000000?ooo`3oool01@3oool3000000040?ooo`00000000000?ooo`800000
U`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00@000004@3oool010000000oooo0?ooo`0000020?ooo`<0000000<0oooo000000000000
20000000103oool0000000000000000=0?ooo`030000003oool0oooo00H0oooo1@0000020?ooo`<0
0000U03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0Z0?ooo`@00000
0`3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo0?ooo`800000303oool8000000`0
oooo0P0000000`3oool000000000000300000080oooo00<000000?ooo`0000000`0000020?ooo`80
0000TP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0Z0?ooo`h00000
2P3oool5000000030?ooo`000000oooo00l0oooo200000070?ooo`@000001P3oool2000000<0oooo
1@0000000`3oool000000000002@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?oooa000000
00<0oooo0000003oool03`3oool2000000030?ooo`000000000000T00000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001`00002=0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02T0oooo0`09jPX50?ooo`040000003o
ool0oooo0?ooo`8000002@3oool2000000030?ooo`000000oooo00<0oooo1`00000:0?ooo`800000
00@0oooo0000003oool0oooo2@0000050?ooo`8000000`3oool00`000000oooo0?ooo`0300WZ2P04
0?ooo`000000oooo0?ooo`80000000<0oooo0000000000000`00002;0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo02X0oooo1P09jPX00`3oool00000000000040?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000070?ooo`040000003oool0oooo
0?ooo`L000000`3oool6000000H0oooo1`0000030?ooo`040000003oool00000000000<0oooo1P09
jPX5000000030?ooo`000000000000800000R@3oool00`000000oooo0?ooo`050?ooo`001P3ooomo
00WZ2P0300000009jPX02NX:0080oooo0P0000020?ooo`@00000QP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`0Z0?ooo`D02NX:0P3oool00`000000oooo0?ooo`060?oo
o`<000001@3oool2000000T0oooo0P0000070?ooo`80000000@0oooo0000003oool0oooo1000000=
0?ooo`H000000`3oool500WZ2P050?ooo`000000oooo0?ooo`09jPX00`3oool2000000<0oooo1000
00230?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02T0oooo0P09jPX0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool0103oool3
000000d0oooo1@00000200WZ2PH0oooo00<000000?ooo`3oool00P09jPX30?ooo`<000000P3oool3
00000880oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool010000000oooo0000000000040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0100000090?ooo`040000003oool000000?ooo`<000001`3o
ool01@000000oooo0?ooo`3oool02NX:00D0oooo100000000`3oool000000?ooo`200?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`8000001P3oool01@000000oooo0?ooo`3oool0000000d0oooo
0P0000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool4000000D0oooo
00@000000?ooo`3oool000000P3oool3000000H0oooo00@000000?ooo`3oool0oooo0P09jPX80000
00030?ooo`000000000007l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0:P3oool2000000D0oooo00<000000?ooo`3oool00P0000090?ooo`80000000<0oooo0000003o
ool02P3oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo0`0000000`3oool00000000000020?ooo`030000003oool0oooo00d0
00000P3oool00`09jPX0oooo0?ooo`020?ooo`040000003oool0000000000080oooo0P00001m0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02X0oooo700000060?ooo`80
00001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool8000000D0oooo0`0000030?ooo`030000003oool0oooo0080oooo0P09jPX00`3oool0
00000?ooo`020?ooo`<000000P3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo02X0oooo8P0000080?ooo`050000003oool0oooo0?ooo`00
00002`3oool00`000000oooo0?ooo`040?ooo`<0000000<0oooo0000003oool0100000080?ooo`<0
00000P3oool00`000000oooo0?ooo`030?ooo`0300WZ2P000000oooo00<0oooo100000000`3oool0
00000000001j0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`0000004P0000001@3oool000000000003oool000000080oooo2@0000050?ooo`03
0000003oool0000000d0oooo00<000000?ooo`3oool00`0000030?ooo`800000103oool2000000T0
oooo0`0000000`3oool000000?ooo`030?ooo`0300000009jPX02NX:00@0oooo00<000000?ooo`00
00000P0000000`3oool000000000001h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0100000090?ooo`8000000`3oool;000000<0oooo
1`000000103oool0000000000000000<0?ooo`<000001P3oool00`000000oooo0?ooo`050?ooo`80
00002@3oool400000080oooo0P0000020?ooo`0300WZ2P3oool0oooo0080oooo00<000000?ooo`00
00000`0000000`3oool000000?ooo`1f0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo02/0oooo0`0000030?ooo`030000003oool0oooo00D0oooo0P0000060?ooo`800000
00<0oooo0000000000000P0000030?ooo`P000000P3oool5000000P0oooo0`0000000`3oool00000
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000P0000090?ooo`@00000
103oool200WZ2P80oooo00@000000?ooo`3oool0oooo1P00001e0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo02X0oooo3`0000080?ooo`<00000103oool00`000000oooo
0?ooo`080?ooo`H0000000<0oooo0000000000000P0000020?ooo`8000001@3oool00`000000oooo
0?ooo`030?ooo`800000203oool010000000oooo0?ooo`3oool2000000T0oooo0P0000060?ooo`04
00WZ2P3oool0oooo000000@0oooo00<000000?ooo`0000000P00001d0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo02X0oooo0P0000050?ooo`030000003oool0oooo0080
000000<0oooo0000000000003@0000030?ooo`030000003oool0oooo00@0oooo0`0000040?ooo``0
00001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool2000000L0oooo00@000000?ooo`00000000001@3oool200WZ2P030?ooo`000000oooo
00<0oooo0P000000103oool0000000000000001b0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool00`3oool300000080oooo0P0000090?oo
o`8000000`3oool:000000H0oooo0P0000020?ooo`<0000000<0oooo0000000000001`0000020?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`040?ooo`<000000`3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00@0oooo00<02NX:0?ooo`0000001@3oool0
0`000000oooo0?ooo`0300000700oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`020?ooo`8000001P3oool2000000L0oooo00<000000?oo
o`3oool01`3oool900000080oooo100000000`3oool000000?ooo`040?ooo`X0000000<0oooo0000
000000002`3oool00`000000oooo0?ooo`060?ooo`@0000000<0oooo0000003oool00P3oool20000
00D0oooo00<02NX:0000003oool01@3oool200000080oooo0P00001_0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P0000000`3oool0
00000?ooo`070?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`<000000P3oool2000000D0
oooo1@0000030?ooo`030000003oool0oooo00H0oooo2@00000;0?ooo`030000003oool0oooo00D0
oooo2`0000000`3oool00000000000040?ooo`802NX:1`3oool2000000040?ooo`00000000000000
06d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0:`3oool3000000<0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?oo
o`<000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D00000203oool:0000
00X0oooo00<000000?ooo`000000100000030?ooo`050000003oool000000?ooo`0000000`3oool9
0000000400WZ2P0000000000000000D0oooo0`0000000`3oool000000?ooo`1[0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo02X0oooo3@0000060?ooo`8000000P3oool4
000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`@0000000<0oooo
0000000000000P0000050?ooo`80000000<0oooo0000000000000P0000050?ooo`D000001`3oool0
10000000oooo0?ooo`3oool2000000L0oooo0P0000030?ooo`0400000009jPX02NX:0?ooo`T00000
00<0oooo0000003oool0JP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`0Z0?oooa/00000303oool2000000<0oooo00<000000?ooo`3oool01P3oool6000000H0oooo1000
00020?ooo`H00000103oool00`000000oooo0?ooo`040?ooo`8000001@3oool2000000H0oooo0`00
00020?ooo`030000003oool02NX:00D0oooo0P0000001@3oool000000?ooo`3oool0000006X0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=`3ooolE000000L0oooo00<0
00000?ooo`0000001@3oool4000000030?ooo`000000oooo00<0oooo100000020?ooo`030000003o
ool0000000T000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`0000001P3oool300000080oooo00@000000?ooo`09jPX02NX:0P3oool2000000<0oooo
0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo04L0oooo30000000103oool000000000003oool4000000H0oooo00<000000?ooo`3oool0
1@3oool400000080oooo00@000000?ooo`3oool0oooo1P0000030?ooo`030000003oool0oooo0080
oooo0P0000070?ooo`040000003oool00000000000H0oooo0`0000001`3oool000000?ooo`3oool0
2NX:0?ooo`000000103oool3000000030?ooo`000000000006L0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0D@3oool7000000X0oooo00<000000?ooo`3oool01@3oool5
000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00`0000020?ooo`050000003oool0
oooo0?ooo`000000203oool01@000000oooo0?ooo`3oool0000000L0oooo0`0000030?ooo`802NX:
00<0oooo00WZ2P3oool00P3oool300000080oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1D0?ooo`8000000P3oool4000000L0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`8000001@3oool3000000030?ooo`00
00000000008000000P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo0?ooo`800000
1`3oool2000000040?ooo`000000oooo0?ooo`<02NX:0P3oool00`000000oooo0000000200000003
0?ooo`000000oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
F`3oool5000000@0oooo00<000000?ooo`3oool00P3oool2000000H0oooo0P0000060?ooo`P00000
2P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0`0000030?ooo`<02NX:
0P3oool00`000000oooo0?ooo`04000006@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0GP3oool500000080oooo00D000000?ooo`3oool0oooo000000080?ooo`@00000
0`3oool8000000/0oooo00<000000?ooo`3oool00`3oool2000000D0oooo0P000000103oool00000
0?ooo`3oool400WZ2P030?ooo`000000oooo0080oooo1000001S0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0640oooo1P0000020?ooo`030000003oool0oooo0080oooo
2`0000040?ooo`<0000000<0oooo0000003oool02@3oool00`000000oooo0?ooo`050?ooo`800000
0`3oool3000000030?ooo`09jPX02NX:00D02NX:00@0oooo0000003oool0oooo0P0000000`3oool0
00000000001R0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo06@0oooo
2P0000050?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0000000<00000
203oool00`000000oooo0?ooo`070?ooo`030000003oool000000080oooo100000000`3oool02NX:
00WZ2P0300WZ2P030000003oool000000080oooo00<000000?ooo`0000000P00001P0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo06L0oooo1@0000080?ooo`030000003o
ool0oooo00<0oooo0`0000001`3oool000000?ooo`000000oooo0000003oool00P0000040?oooa00
000000@0oooo0000003oool0oooo0P0000040?ooo`0300000009jPX02NX:00@0oooo00<000000?oo
o`3oool00P00001O0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo06X0
oooo1@0000060?ooo`030000003oool0oooo00@0oooo3P0000030?ooo`030000003oool0oooo00L0
oooo200000000`3oool00000000000020?ooo`80000000<0oooo00WZ2P3oool00`3oool200000003
0?ooo`000000000005h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
K@3oool4000000D0oooo00<000000?ooo`3oool00`3oool2000000040?ooo`000000oooo000000<0
oooo100000050?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0P0000030?oo
o`@0000000H0oooo000000000000oooo00000009jPX50?ooo`040000003oool00000000005d0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0K`3oool4000000@0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000000@0oooo100000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000000D0oooo1`0000000`09jPX0oooo
0?ooo`030?ooo`040000003oool0oooo000005`0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0LP3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo0`0000030?ooo`030000003oool0oooo0080oooo
0P0000060?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`80000000<02NX:0000003oool0
0`3oool010000000oooo00000000001K0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo07D0oooo100000020?ooo`030000003oool0oooo00D0oooo0P0000050?ooo`@00000
00<0oooo0000003oool00`3oool00`000000oooo0?ooo`050?ooo`<000000`3oool010000000oooo
0000000000030?ooo`030000003oool02NX:00P00000F`3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`1g0?ooo`<0000000<0oooo0000003oool01P3oool010000000oooo
0000000000050?ooo`@000000`3oool00`000000oooo0?ooo`060?ooo`060000003oool0oooo0000
003oool000000`3oool3000000040?ooo`000000oooo0?ooo`802NX:0`3oool2000000030?ooo`00
0000oooo05T0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0N@3oool?
000000D0oooo1`0000090?ooo`040000003oool0oooo000000D0oooo0`0000000`3oool000000?oo
o`020?ooo`0300WZ2P3oool0000000D00000F@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1i0?ooo`80000000<0oooo0000003oool01`3oool00`000000oooo0000000;
000000X0oooo00<000000?ooo`0000000P0000060?ooo`<00000103oool01009jPX000000?ooo`3o
ool2000000030?ooo`000000oooo05L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0O@3oool2000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`@000002@3oool300000080oooo00<000000?ooo`3oool0103oool300000080oooo0P000000
1009jPX0oooo0?ooo`3oool2000000030?ooo`000000oooo05H0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0O`3oool2000000D0oooo00<000000?ooo`3oool00P3oool2
000000<0oooo1@0000090?ooo`030000003oool0oooo0080oooo0P0000050?ooo`80000000<0oooo
0000000000000P3oool01009jPX0oooo0?ooo`3oool2000000030?ooo`000000oooo05D0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P03oool2000000@0oooo00<00000
0?ooo`3oool0103oool01@000000oooo000000000000oooo00@000001`3oool2000000H0oooo00<0
00000?ooo`3oool00`3oool3000000@0oooo00<02NX:0?ooo`3oool00`0000000`3oool000000?oo
o`1D0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0880oooo0P000003
0?ooo`030000003oool0oooo00<0oooo1`0000000`3oool00000000000050?ooo`030000003oool0
000000L0oooo00<000000?ooo`3oool00P3oool2000000H0oooo0P09jPX00`3oool0000000000002
000005D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P`3oool20000
0080oooo00<000000?ooo`3oool00`3oool2000000050?ooo`000000oooo0000003oool02@000000
0`3oool000000?ooo`070?ooo`040000003oool0oooo0?ooo`<000001`3oool01009jPX000000000
003oool2000005@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q03o
ool3000000030?ooo`000000oooo00<0oooo00P000000?ooo`3oool0oooo0000003oool000000?oo
o`<0000000<0oooo0000000000000P3oool900000080oooo0`000000103oool000000?ooo`000007
0?ooo`0400WZ2P3oool000000?ooo`800000D`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`<000000`3oool2000000@0oooo0P0000030?ooo`@00000103oool0
0`000000oooo0?ooo`040?ooo`D0000000D0oooo0000003oool0oooo000000070?ooo`0400WZ2P3o
ool000000?ooo`800000DP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`270?ooo`<0000000<0oooo0000000000001P3oool00`000000oooo0?ooo`020?ooo`@000000`3o
ool00`000000oooo0?ooo`060?ooo`80000000@0oooo00000000000000000P3oool00`000000oooo
0?ooo`040?ooo`0500000009jPX0oooo0000003oool00P00001A0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08T0oooo100000070?ooo`040000003oool0oooo0?ooo`80
000000H0oooo00000000000000000?ooo`0000070?ooo`040000003oool0oooo00000080oooo0`00
00000`3oool000000?ooo`040?ooo`060000003oool02NX:0?ooo`0000002NX:0P00001@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08T0oooo2@0000020?ooo`800000
00/0oooo0000003oool0oooo0000003oool000000?ooo`000000oooo000000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000000P3oool3000000D0oooo00<000000?ooo`09jPX00P09
jPX00`3oool000000?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08`0oooo0P0000040?ooo`H000000`3oool3000000030?ooo`000000000000@0oooo00<00000
0?ooo`3oool0103oool2000000@0oooo0`0000030?ooo`040000003oool0oooo0?ooo`802NX:00<0
oooo0000003oool0CP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2=
0?ooo`8000001P3oool00`000000oooo00000004000000050?ooo`00000000000?ooo`0000000`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`00
00000`3oool02NX:00WZ2P0300WZ2P030?ooo`000000oooo04d0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0SP3oool2000000@0oooo0P0000030?ooo`030000003oool0
oooo00P000002@3oool2000000@0oooo0P0000030?ooo`8000000P3oool400WZ2P030?ooo`000000
oooo04`0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0S`3oool20000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`@000002P3oool0
0`000000oooo000000040?ooo`8000000`3oool4000000030?ooo`09jPX02NX:0080oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2A0?oo
o`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`00000:0?oo
o`040000003oool0oooo000000@0oooo0P0000020?ooo`040000003oool0oooo0?ooo`80000000@0
2NX:000000000000oooo0P00001:0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0980oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`00
00000`3oool000000?ooo`080?ooo`050000003oool0oooo0?ooo`000000103oool200000080oooo
00<000000?ooo`3oool00P3oool20000000400WZ2P0000000000000004X0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0T`3oool200000080oooo00<000000?ooo`3oool0
0`3oool3000000050?ooo`00000000000?ooo`000000203oool01@000000oooo0?ooo`3oool00000
00D0oooo00@000000?ooo`3oool000001P3oool01009jPX000000?ooo`00001:0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo09@0oooo0P0000000`3oool000000?ooo`04
0?ooo`@0000000D0oooo000000000000oooo000000080?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo000000050?ooo`0400000009jPX000000?ooo`800000B@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool6000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool000000080oooo0`0000001P3oool02NX:000000000000oooo0000
04P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0U`3oool200000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D00000103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P0000000`3oool00000000000030?oo
o`0300WZ2P3oool0000000800000B03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`2H0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000`3oool010000000
oooo0000003oool5000000H0oooo00<000000?ooo`3oool00P3oool4000000@0oooo00H02NX:0?oo
o`00000000000?ooo`0000170?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo09P0oooo0`0000060?ooo`8000000`3oool2000000030?ooo`000000oooo00<0oooo1@000003
0?ooo`040000003oool0oooo0?ooo`<000001@3oool01P09jPX0oooo0?ooo`000000oooo000004L0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0V03oool6000000@0oooo
0P0000030?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`D0000000D0oooo000000000000
oooo000000060?ooo`0600WZ2P3oool000000000003oool00000AP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`2J0?ooo`040000003oool0oooo0?ooo`<000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool3
00000080oooo0P0000050?ooo`0300WZ2P3oool000000080000000<0oooo0000003oool0A03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo
00<0oooo100000040?ooo`030000003oool000000080oooo00<000000?ooo`3oool01@3oool30000
00030?ooo`000000000000<00000103oool00`09jPX0oooo0?ooo`04000004D0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`040?ooo`@0
00000`3oool01@000000oooo0000003oool0000000H0oooo0P0000020?ooo`060000003oool0oooo
0000003oool00000103oool02009jPX0oooo0?ooo`000000oooo0000003oool00000A03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00@0
oooo0P0000002P3oool00000000000000000oooo0000003oool000000?ooo`0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000000`0000030?ooo`0500WZ2P3oool0oooo0000003o
ool00P0000000`3oool000000?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo09d0oooo0P0000050?ooo`030000003oool0000000<0oooo0`0000000`3oool00000
000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool2000000<0oooo
00<02NX:0?ooo`0000000P3oool3000004<0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0WP3oool2000000@0oooo00@000000?ooo`3oool00000103oool4000000030?oo
o`000000000000P0oooo0P0000030?ooo`8000000P3oool00`09jPX0oooo000000030?ooo`<00000
@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2O0?ooo`8000000`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo1000000:0?ooo`800000103oool30000000400WZ
2P3oool0oooo00000080oooo0`0000120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0:00oooo0P0000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
oooo1000000;0?ooo`030000003oool0oooo0080oooo0P0000001@3oool02NX:0000003oool00000
00<0oooo0`0000110?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:40
oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@00000:0?ooo`80
0000103oool010000000oooo0?ooo`09jPX2000000@0oooo0`0000100?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0:80oooo0P0000000`3oool000000?ooo`040?ooo`<0
000000D0oooo000000000000oooo000000090?ooo`800000103oool2000000030?ooo`09jPX0oooo
008000000`3oool00`000000oooo000000100?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0:80oooo00@000000?ooo`0000000000103oool4000000030?ooo`000000oooo
008000002@3oool00`000000oooo000000040?ooo`060000003oool02NX:0?ooo`000000oooo0P00
00020?ooo`<00000?`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2S
0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool000000?ooo`04000000030?ooo`00
0000oooo00L0oooo00<000000?ooo`000000103oool20000000400WZ2P3oool0oooo00000080oooo
0P0000000`3oool000000000000o0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0:@0oooo0`0000000`3oool000000?ooo`030?ooo`040000003oool000000?ooo`<00000
1`3oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000000`09jPX0oooo000000040?ooo`80
000000<0oooo0000003oool0?@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`2U0?ooo`@000001@3oool2000000030?ooo`000000oooo008000001P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00@0000000WZ2P3oool000001@3oool5000003`0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0YP3oool2000000030?oo
o`000000000000<0oooo00@000000?ooo`000000oooo0P000000103oool000000000000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0100000002NX:0?ooo`000006
0?ooo`@00000?03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2V0?oo
o`030000003oool000000080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`<000000P3oool2
000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool00P3oool00`09jPX0000000000004
0?ooo`H00000?03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2W0?oo
o`8000000`3oool200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`<00000103oool0
0`000000oooo0?ooo`020?ooo`0500000009jPX0oooo0000003oool00P0000040?ooo`800000?03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`800000103oool3
000000@0oooo00<000000?ooo`0000000`3oool010000000oooo0000000000030?ooo`030000003o
ool0oooo0080oooo00@02NX:00000000000000001P3oool00`000000oooo0000000k0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`0000001@3o
ool2000000@0oooo0P0000030?ooo`040000003oool0oooo0?ooo`8000000P3oool01@000000oooo
0?ooo`3oool02NX:008000001`3oool3000003/0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0Z@3oool2000000D0oooo00<000000?ooo`0000000`3oool300000080oooo
00<000000?ooo`3oool00`3oool3000000040?ooo`000000000000WZ2P8000001`3oool200000003
0?ooo`000000oooo03T0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
ZP3oool2000000@0oooo00<000000?ooo`0000000P0000001`3oool000000000003oool000000?oo
o`0000001`3oool3000000030?ooo`09jPX00000008000001P3oool4000003X0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0ZP3oool2000000@0oooo00D000000?ooo`3o
ool000000?ooo`05000000030?ooo`000000oooo00@0oooo1P000000103oool02NX:000000000006
0?ooo`040000003oool00000000003X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0Z`3oool2000000<0oooo00@000000?ooo`3oool000000`3oool5000000<0oooo0`00
00030?ooo`040000003oool0000000WZ2P8000001P3oool00`000000oooo00000002000003T0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0[03oool200000080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool000000080000000@0oooo000000000000
00001@3oool01@000000oooo0?ooo`09jPX0oooo008000001@3oool00`000000oooo0?ooo`020000
03T0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0[03oool200000080
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`000000oooo00@00000203oool00`00
0000oooo00WZ2P03000000D0oooo00<000000?ooo`3oool00`00000h0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0:d0oooo0P0000000`3oool000000?ooo`030?ooo`04
0000003oool0oooo0?ooo`@000002@3oool01@000000oooo00000009jPX0oooo00800000103oool0
0`000000oooo0?ooo`03000003P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0[@3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040000
00X0oooo00@000000?ooo`09jPX0oooo0P0000040?ooo`040000003oool0oooo0?ooo`<00000=`3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2^0?ooo`80000000<0oooo
0000003oool00`3oool3000000030?ooo`0000000000008000002@3oool00`000000oooo00WZ2P02
0?ooo`800000103oool01P000000oooo0?ooo`000000oooo000003L0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0[`3oool300000080oooo100000000`3oool000000?oo
o`03000000T0oooo00<000000?ooo`09jPX00`3oool2000000<0oooo00@000000?ooo`3oool0oooo
0`00000f0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:l0oooo1P00
00030?ooo`030000003oool0000000<000002@3oool2000000060?ooo`09jPX0oooo0?ooo`000000
oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0000003H0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0/03oool3000000D0oooo00<000000?ooo`3oool0
100000070?ooo`050000003oool000000?ooo`09jPX00`3oool00`000000oooo0?ooo`02000000<0
oooo00@000000?ooo`0000000000=@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`2`0?ooo`@00000103oool00`000000oooo0?ooo`04000000L0oooo00D000000?ooo`3o
ool0000000WZ2P030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0000000e
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0;40oooo0P0000000`3o
ool000000?ooo`030?ooo`8000000P3oool3000000H0oooo00D000000?ooo`3oool0000000WZ2P04
0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0000000e0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0;80oooo00@000000?ooo`3oool000000`3oool2
00000080oooo1@0000040?ooo`060000003oool0oooo0?ooo`0000002NX:0`3oool01@000000oooo
0?ooo`000000oooo008000000P3oool00`000000oooo0000000d0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0;80oooo0P0000020?ooo`8000000P3oool010000000oooo
0?ooo`3oool200000080oooo0P0000020?ooo`060000003oool0oooo0?ooo`0000002NX:0`3oool0
10000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`000000=03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000`3oool3000000<0oooo0P0000050?ooo`0300WZ2P3oool0oooo0080oooo00<0
00000?ooo`000000103oool01@000000oooo0000003oool0000003<0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`030?ooo`<000000P3o
ool3000000@0oooo0P0000040?ooo`0300WZ2P3oool0oooo0080oooo00<000000?ooo`0000001@3o
ool2000000030?ooo`000000oooo0380oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0/`3oool2000000D0oooo0P0000030?ooo`<000000`3oool00`000000oooo00000004
0?ooo`0400WZ2P3oool0oooo0?ooo`<000001P3oool400000380oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`030?ooo`<000000`3oool2
000000<0oooo00<000000?ooo`3oool00P0000020?ooo`0400WZ2P3oool0oooo0?ooo`<00000103o
ool600000380oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0]03oool2
000000@0oooo00@000000?ooo`00000000000P3oool200000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo00WZ2P040?ooo`80000000<0oooo0000000000000`000000103oool000000?oo
o`00000b0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0;D0oooo00<0
00000?ooo`3oool00P3oool01P000000oooo0000003oool000000?ooo`<0000000<0oooo0000003o
ool01@3oool00`0000002NX:000000030?ooo`D00000103oool010000000oooo00000000000a0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0;D0oooo0P0000030?ooo`05
0000003oool0oooo0000003oool0100000000`3oool000000?ooo`060?ooo`0300WZ2P0000000000
00D000001`3oool00`000000oooo0000000a0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0;H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
0?ooo`@000001P3oool20000000400WZ2P00000000000?ooo`800000203oool00`000000oooo0000
000a0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0;H0oooo0P000002
0?ooo`050000003oool0oooo0?ooo`0000000P3oool4000000<0oooo100000000`3oool02NX:0000
00020?ooo`<000001`3oool00`000000oooo0000000a0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`3o
ool6000000D0oooo00L02NX:000000000000oooo0000003oool0000000L0oooo0`00000a0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`05000000L0oooo00@02NX:0?ooo`00000000000P3oool00`000000
oooo0?ooo`050?ooo`80000000<0oooo0000003oool0;`3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`2g0?ooo`<00000103oool7000000T0oooo00H02NX:000000000000
00000?ooo`0000060?ooo`050000003oool000000?ooo`000000<03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`2h0?ooo`80000000<0oooo000000000000200000090?oo
o`0400WZ2P000000oooo0?ooo`<000001@3oool01@000000oooo0000003oool000000300oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0^03oool500000080oooo00<00000
0?ooo`3oool0100000080?ooo`0300WZ2P000000oooo0080oooo0P0000050?ooo`030000003oool0
000000800000<03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2h0?oo
o`<000001@3oool00`000000oooo00000003000000P0oooo00<02NX:0000003oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000800000<03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`2i0?ooo`8000001@3oool00`000000oooo00000003000000P0
oooo00<0000000WZ2P0000000`3oool00`000000oooo0?ooo`030?ooo`060000003oool000000000
003oool00000;`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2i0?oo
o`<00000103oool200000080oooo0P0000080?ooo`0300000009jPX0000000<0oooo0P0000030?oo
o`040000003oool0oooo0?ooo`<00000;`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2j0?ooo`030000003oool0000000<0oooo0P0000020?ooo`<000001P3oool01000
0000oooo00WZ2P0000040?ooo`8000000P3oool010000000oooo0?ooo`3oool3000002l0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0^P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00@000001@3oool010000000oooo00WZ2P0000040?ooo`050000
003oool000000?ooo`0000000`3oool3000002l0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0^P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00`0000000`3oool000000?ooo`030?ooo`050000003oool0oooo00WZ2P0000000`3oool00`00
0000oooo0?ooo`02000000<0oooo00<000000?ooo`000000;`3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo0080oooo0`0000030?ooo`80
00000P3oool2000000030?ooo`000000oooo0080oooo00<02NX:0000003oool00P3oool200000080
oooo00H000000?ooo`3oool0oooo0000003oool2000002h0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0^P3oool2000000@0oooo0P0000030?ooo`<000000`3oool20000
00<0oooo00<02NX:0000003oool00P3oool2000000030?ooo`000000000000@0oooo0`00000^0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3o
ool00P3oool300000080oooo0`0000030?ooo`8000000`3oool00`09jPX000000?ooo`030?ooo`05
0000003oool000000?ooo`0000000`3oool3000002h0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0
oooo0P0000030?ooo`030000003oool000000080oooo00<02NX:0?ooo`0000000`3oool00`000000
oooo000000020?ooo`060000003oool0oooo0000003oool00000;P3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`2k0?ooo`050000003oool0oooo0?ooo`0000000P3oool2
00000080oooo0P0000030?ooo`040000003oool0oooo00000080oooo00<02NX:0000003oool00P3o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000;P3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2k0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0000003oool3000000030?ooo`000000oooo00<0oooo00@000000?ooo`09
jPX000000`3oool00`000000oooo000000040?ooo`80000000<0oooo000000000000;@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2l0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`0000000`0000000`3oool000000?ooo`040?ooo`0300000009jPX00000
00<0oooo0P0000060?ooo`80000000<0oooo0000003oool0;03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool0100000070?ooo`0300WZ2P000000oooo0080oooo0P0000040?ooo`L00000;03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool0100000080?ooo`0300WZ2P000000000000L000000`3oool4000002`0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0_03oool00`000000oooo0000
00040?ooo`050000003oool0oooo0000003oool00P0000020?ooo`H0000000D02NX:000000000000
00000?ooo`02000000H0oooo0`00000]0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0;`0oooo00<000000?ooo`000000103oool<000000<0oooo00@02NX:0000003oool0
oooo0P0000070?ooo`<00000;@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`2l0?ooo`<0000000<0oooo000000000000200000080?ooo`0600WZ2P00000000000000003o
ool000001`3oool3000002d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0_03oool4000000@0oooo00<000000?ooo`3oool00`0000090?ooo`0500WZ2P00000000000?oo
o`0000001`3oool00`000000oooo0000000]0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0;d0oooo00<000000?ooo`3oool0103oool6000000T0oooo00D02NX:00000000
0000oooo000000070?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0_@3oool2000000D0oooo00<000000?ooo`0000000`0000090?ooo`05
00WZ2P3oool000000?ooo`0000001`3oool3000002d0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0_@3oool00`000000oooo000000040?ooo`80000000@0oooo00000000
000000002@3oool00`09jPX0oooo0?ooo`02000000H0oooo1000000]0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`000000103oool200000004
0?ooo`0000000000000000P0oooo0P0000001009jPX0oooo0000000000060?ooo`@00000;@3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2m0?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00`0000070?ooo`070000003oool0000000WZ2P3oool02NX:
000000060?ooo`@00000;@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`2m0?ooo`060000003oool0oooo0?ooo`000000oooo0P0000020?ooo`<000001`3oool01`000000
2NX:00WZ2P09jPX0oooo00WZ2P0000001@3oool00`000000oooo00000002000002d0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0_@3oool01P000000oooo0?ooo`3oool0
00000?ooo`8000000P3oool4000000D0oooo00<000000?ooo`09jPX01009jPX2000000@0oooo00<0
00000?ooo`0000000P00000]0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0;d0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000020?ooo`@00000103oool0
10000000oooo0?ooo`3oool400WZ2P8000000`3oool00`000000oooo0?ooo`03000002d0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`02
0?ooo`<000000P3oool3000000050?ooo`000000oooo0?ooo`000000103oool400WZ2P030?ooo`00
000000000080oooo00<000000?ooo`3oool00`00000]0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0;d0oooo00H000000?ooo`3oool0oooo0000003oool200000080oooo
0`0000020?ooo`030000003oool0000000@0oooo00D0000000WZ2P09jPX02NX:0?ooo`0200000080
oooo00<000000?ooo`3oool00`00000]0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0;d0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`03000000<0
oooo00<000000?ooo`3oool00`3oool01`0000002NX:00WZ2P09jPX0oooo0000003oool00P000003
0?ooo`<00000;@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2m0?oo
o`T0000000@0oooo00000000000000000P3oool2000000D0oooo00L000000?ooo`09jPX02NX:0?oo
o`000000oooo008000000`3oool3000002d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0_@3oool00`000000oooo000000030?oooa80000000@02NX:0000000000000000
0P3oool010000000oooo0?ooo`3oool3000002d0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0_@3oool00`000000oooo000000040?ooo`040000003oool000000?ooo`80
000000<0oooo0000003oool00P3oool010000000oooo0?ooo`3oool30000000300WZ2P0000000000
00T00000;@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2m0?ooo`80
00001@3oool00`000000oooo0?ooo`04000000D0oooo00@000000?ooo`3oool000000P3oool01`09
jPX0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000]0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0;`0oooo1@0000030?ooo`030000003oool0
oooo00@000001@3oool010000000oooo0?ooo`0000020?ooo`0700WZ2P3oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0_03oool300000080oooo2@0000070?ooo`030000003oool0000000<0oooo
00<02NX:0000000000000`3oool01@000000oooo0000003oool0000002d0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0``3oool2000000030?ooo`000000000000P00000
0P3oool2000000<0oooo00<02NX:0000000000000`3oool01@000000oooo0000003oool0000002d0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0b03oool2000000<0oooo
2P0000000`09jPX00000000000040?ooo`80000000<0oooo0000003oool0;03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3B0?ooo`80000000@0oooo0000000000002NX:
2P00000]0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0=P0oooo00<0
2NX:0?ooo`3oool00P3oool6000002`0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0f03oool00`09jPX0oooo0?ooo`060?ooo`800000;03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3H0?ooo`0300WZ2P3oool0oooo03@0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0f03oool00`09jPX0oooo0?ooo`0d0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0=T0oooo00<02NX:0?ooo`3oool0
<`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3I0?ooo`0300WZ2P3o
ool0oooo03<0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0f@3oool0
0`09jPX0oooo0?ooo`0c0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0=T0oooo00<02NX:0?ooo`3oool0<`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3I0?ooo`0300WZ2P3oool0oooo03<0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0fP3oool00`09jPX0oooo0?ooo`0b0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0=X0oooo00<02NX:0?ooo`3oool0<P3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3J0?ooo`0300WZ2P3oool0oooo0380oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0fP3oool00`09jPX0oooo0?ooo`0b0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0=/0oooo00<02NX:0?ooo`3o
ool0<@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3K0?ooo`0300WZ
2P3oool0oooo0340oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0f`3o
ool00`09jPX0oooo0?ooo`0a0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0=/0oooo00<02NX:0?ooo`3oool0<@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3L0?ooo`0300WZ2P3oool0oooo0300oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0g03oool00`09jPX0oooo0?ooo`0`0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0=`0oooo00<02NX:0?ooo`3oool0<03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3L0?ooo`0300WZ2P3oool0oooo0300oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0g@3oool00`09jPX0oooo0?ooo`0_
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0=d0oooo00<02NX:0?oo
o`3oool0;`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3M0?ooo`03
00WZ2P3oool0oooo02l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
g@3oool00`09jPX0oooo0?ooo`0_0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0=h0oooo00<02NX:0?ooo`3oool0;P3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3N0?ooo`0300WZ2P3oool0oooo02h0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0gP3oool00`09jPX0oooo0?ooo`0^0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0=h0oooo00<02NX:0?ooo`3oool0;P3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3N0?ooo`0300WZ2P3oool0oooo02h0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0g`3oool00`09jPX0oooo0?oo
o`0]0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0=l0oooo00<02NX:
0?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3O0?oo
o`0300WZ2P3oool0oooo02d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0g`3oool00`09jPX0oooo0?ooo`0]0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0>00oooo00<02NX:0?ooo`3oool0;03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3P0?ooo`0300WZ2P3oool0oooo02`0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0h03oool00`09jPX0oooo0?ooo`0/0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0>00oooo00<02NX:0?ooo`3oool0;03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3Q0?ooo`0300WZ2P3oool0oooo02/0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0h@3oool00`09jPX0oooo
0?ooo`0[0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0>40oooo00<0
2NX:0?ooo`3oool0:`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3Q
0?ooo`0300WZ2P3oool0oooo02/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0hP3oool00`09jPX0oooo0?ooo`0Z0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0>80oooo00<02NX:0?ooo`3oool0:P3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3R0?ooo`0300WZ2P3oool0oooo02X0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0hP3oool00`09jPX0oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0><0oooo00<02NX:0?ooo`3oool0:@3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3S0?ooo`0300WZ2P3oool0oooo
02T0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0h`3oool00`09jPX0
oooo0?ooo`0Y0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0><0oooo
00<02NX:0?ooo`3oool0:@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3S0?ooo`0300WZ2P3oool0oooo02T0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0i03oool00`09jPX0oooo0?ooo`0X0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0>@0oooo00<02NX:0?ooo`3oool0:03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3T0?ooo`0300WZ2P3oool0oooo02P0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0i03oool00`09jPX0oooo0?ooo`0X0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0>D0oooo00<02NX:0?ooo`3oool09`3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3U0?ooo`0300WZ2P3oool0
oooo02L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0i@3oool00`09
jPX0oooo0?ooo`0W0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0>D0
oooo00<02NX:0?ooo`3oool09`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3V0?ooo`0300WZ2P3oool0oooo02H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0iP3oool00`09jPX0oooo0?ooo`0V0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0>H0oooo00<02NX:0?ooo`3oool09P3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3V0?ooo`0300WZ2P3oool0oooo02H0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0i`3oool00`09jPX0oooo0?ooo`0U0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0>L0oooo00<02NX:0?ooo`3oool0
9@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3W0?ooo`0300WZ2P3o
ool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0i`3oool0
0`09jPX0oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0>P0oooo00<02NX:0?ooo`3oool0903oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3X0?ooo`0300WZ2P3oool0oooo02@0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0j03oool00`09jPX0oooo0?ooo`0T0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0>P0oooo00<02NX:0?ooo`3oool0903oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3X0?ooo`0300WZ2P3oool0oooo02@0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0j@3oool00`09jPX0oooo00WZ2P0S0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0>L0oooo00D02NX:0?ooo`09
jPX0oooo00WZ2P0S0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0>L0
oooo1@09jPXS0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0>P0oooo
1009jPXS0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0>P0oooo1009
jPXS0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0>T0oooo0`09jPXS
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0>T0oooo0`09jPXS0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0>X0oooo0P09jPXS0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`800000j`3oool2000002<0oooo00<000000?ooo`3oool0
1@3oool000H0ooooo`00000D000000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.150032, -1.15003, 0.0219515, \
0.0219515}},
  CellTags->"CustomFiber"],

Cell[BoxData[
    \(9.933333333332484`\ Second\)], "Output",
  CellTags->"CustomFiber"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Scripted Moves", "Subsection",
  CellTags->"Scripted Moves"],

Cell[CellGroupData[{

Cell["\<\
sys = \
DrawSystem[{LineOfRays[30],Move[PlanoConvexLens[100,50,10],50],Boundary[200]},\
PlotType->TopView]\
\>", "Input",
  CellTags->"Scripted Moves"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.5 0.0047619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.29249 .38095 m
.30952 .38095 L
.30952 .42063 L
.275 .42063 L
.29249 .38095 L
F
.275 .42063 m
.30952 .42063 L
.30952 .46032 L
.26511 .46032 L
.275 .42063 L
F
.26511 .46032 m
.30952 .46032 L
.30952 .5 L
.2619 .5 L
.26511 .46032 L
F
.2619 .5 m
.30952 .5 L
.30952 .53968 L
.26511 .53968 L
.2619 .5 L
F
.26511 .53968 m
.30952 .53968 L
.30952 .57937 L
.275 .57937 L
.26511 .53968 L
F
.275 .57937 m
.30952 .57937 L
.30952 .61905 L
.29249 .61905 L
.275 .57937 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.29249 .38095 m
.275 .42063 L
.26511 .46032 L
.2619 .5 L
.26511 .53968 L
.275 .57937 L
.29249 .61905 L
.30952 .61905 L
.30952 .57937 L
.30952 .53968 L
.30952 .5 L
.30952 .46032 L
.30952 .42063 L
.30952 .38095 L
.29249 .38095 L
s
.5 g
.29249 .5 m
.30952 .5 L
.30952 .5 L
.275 .5 L
.29249 .5 L
F
.275 .5 m
.30952 .5 L
.30952 .5 L
.26511 .5 L
.275 .5 L
F
.26511 .5 m
.30952 .5 L
.30952 .5 L
.2619 .5 L
.26511 .5 L
F
.2619 .5 m
.30952 .5 L
.30952 .5 L
.26511 .5 L
.2619 .5 L
F
.26511 .5 m
.30952 .5 L
.30952 .5 L
.275 .5 L
.26511 .5 L
F
.275 .5 m
.30952 .5 L
.30952 .5 L
.29249 .5 L
.275 .5 L
F
0 g
.29249 .5 m
.275 .5 L
.26511 .5 L
.2619 .5 L
.26511 .5 L
.275 .5 L
.29249 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.29249 .5 L
s
.29249 .61905 m
.30952 .61905 L
.30952 .61499 L
.29249 .61499 L
.29249 .61905 L
s
.29249 .61499 m
.30952 .61499 L
.30952 .6031 L
.29249 .6031 L
.29249 .61499 L
s
.29249 .6031 m
.30952 .6031 L
.30952 .58418 L
.29249 .58418 L
.29249 .6031 L
s
.29249 .58418 m
.30952 .58418 L
.30952 .55952 L
.29249 .55952 L
.29249 .58418 L
s
.29249 .55952 m
.30952 .55952 L
.30952 .53081 L
.29249 .53081 L
.29249 .55952 L
s
.29249 .53081 m
.30952 .53081 L
.30952 .5 L
.29249 .5 L
.29249 .53081 L
s
.29249 .5 m
.30952 .5 L
.30952 .46919 L
.29249 .46919 L
.29249 .5 L
s
.29249 .46919 m
.30952 .46919 L
.30952 .44048 L
.29249 .44048 L
.29249 .46919 L
s
.29249 .44048 m
.30952 .44048 L
.30952 .41582 L
.29249 .41582 L
.29249 .44048 L
s
.29249 .41582 m
.30952 .41582 L
.30952 .3969 L
.29249 .3969 L
.29249 .41582 L
s
.29249 .3969 m
.30952 .3969 L
.30952 .38501 L
.29249 .38501 L
.29249 .3969 L
s
.29249 .38501 m
.30952 .38501 L
.30952 .38095 L
.29249 .38095 L
.29249 .38501 L
s
.29249 .38095 m
.30952 .38095 L
.30952 .38501 L
.29249 .38501 L
.29249 .38095 L
s
.29249 .38501 m
.30952 .38501 L
.30952 .3969 L
.29249 .3969 L
.29249 .38501 L
s
.29249 .3969 m
.30952 .3969 L
.30952 .41582 L
.29249 .41582 L
.29249 .3969 L
s
.29249 .41582 m
.30952 .41582 L
.30952 .44048 L
.29249 .44048 L
.29249 .41582 L
s
.29249 .44048 m
.30952 .44048 L
.30952 .46919 L
.29249 .46919 L
.29249 .44048 L
s
.29249 .46919 m
.30952 .46919 L
.30952 .5 L
.29249 .5 L
.29249 .46919 L
s
.29249 .5 m
.30952 .5 L
.30952 .53081 L
.29249 .53081 L
.29249 .5 L
s
.29249 .53081 m
.30952 .53081 L
.30952 .55952 L
.29249 .55952 L
.29249 .53081 L
s
.29249 .55952 m
.30952 .55952 L
.30952 .58418 L
.29249 .58418 L
.29249 .55952 L
s
.29249 .58418 m
.30952 .58418 L
.30952 .6031 L
.29249 .6031 L
.29249 .58418 L
s
.29249 .6031 m
.30952 .6031 L
.30952 .61499 L
.29249 .61499 L
.29249 .6031 L
s
.29249 .61499 m
.30952 .61499 L
.30952 .61905 L
.29249 .61905 L
.29249 .61499 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .42857 m
.27246 .42857 L
s
% Start of user PostScript
0 -15. 52.2161 -15. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.27246 .42857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.2619 .5 L
s
% Start of user PostScript
0 0 50. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.2619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .57143 m
.27246 .57143 L
s
% Start of user PostScript
0 15. 52.2161 15. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.27246 .57143 Mdot
.039 .916 .04 r
.5 Mabswid
.27246 .42857 m
.30952 .43236 L
s
0 0 0 r
2 Mabswid
.30952 .43236 Mdot
.039 .916 .04 r
.5 Mabswid
.2619 .5 m
.30952 .5 L
s
0 0 0 r
2 Mabswid
.30952 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.27246 .57143 m
.30952 .56764 L
s
0 0 0 r
2 Mabswid
.30952 .56764 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .43236 m
.97619 .53664 L
s
% Start of user PostScript
60. -14.2042 200. 7.6947 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .53664 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .5 m
.97619 .5 L
s
% Start of user PostScript
60. 0 200. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .56764 m
.97619 .46336 L
s
% Start of user PostScript
60. 14.2042 200. -7.6947 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .46336 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0BP3oool600000;l0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0BP3oool600000;l0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0B@3oool2000000@0Ogmo00<000000?ooo`3oool0_@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`190?ooo`800000101oOgl00`000000oooo
0?ooo`2m0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04P0oooo00<0
000007moO`0000001@00002o0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo04P0oooo00<0000007moO`000000101oOgl00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo04L0oooo00@0000007moO`1oOgl00000101oOgl0
0`000000oooo0?ooo`2m0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
04L0oooo00@0000007moO`1oOgl00000101oOgl00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo04L0oooo00@0000007moO`1oOgl00000101oOgl0
0`000000oooo0?ooo`2m0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
04H0oooo00D0000007moO`1oOgl0Ogmo0000000407moO`030000003oool0oooo0;d0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0AP3oool010000000Ogmo07moO`1oOgl6
00000;l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0?@3oool300WZ
2PD0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo
0;d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0?P3oool600WZ2P03
0?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`2m0?ooo`03
0000003oool0oooo00D0oooo00060?ooodL02NX:00<0000000WZ2P09jPX00P09jPX00`1oOgl00000
07moO`0307moO`030000003oool0oooo0;d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0?P3oool500WZ2P030?ooo`000000000000<0Ogmo1@09jPX00`1oOgl000000000
002n0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03d0oooo0P09jPX5
0?ooo`030000001oOgl0Ogmo00<0Ogmo00@0000007moO`1oOgl0Ogmo1@09jPZl0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo04@0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0207moO`040000003oool0oooo0?ooo`L02NX:]@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`140?ooo`030000001oOgl0Ogmo00<0Ogmo1P00000:
0?ooo`H02NX:[`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`140?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0>0?oo
o`H02NX:Z@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`140?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0D0?ooo`L0
2NX:XP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`140?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0K0?ooo`H02NX:
W03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`130?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0Q0?ooo`L02NX:U@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`130?ooo`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0X0?ooo`H02NX:S`3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`130?ooo`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0^0?ooo`H02NX:P03oool800WZ
2P8000001`3oool000H0oooo00<000000?ooo`3oool0@`3oool00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0=03oool700WZ2WP0oooo2@09jPX2000000L0
oooo00060?ooo`030000003oool0oooo04<0oooo00<0000007moO`1oOgl0101oOgl6000003d0oooo
1P09jPY/0?ooo`H02NX:103oool300WZ2P<0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0@`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo0080Ogmo00<0
00000?ooo`3oool0@@3oool700WZ2Ul0oooo1P09jPX90?ooo`802NX:1@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`130?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00P1oOgl00`000000oooo0?ooo`180?ooo`H02NX:DP3oool700WZ2Ph0oooo00<02NX:
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`130?oo
o`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`1>0?oo
o`H02NX:AP3oool600WZ2Qd0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0@P3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3o
ool0E03oool700WZ2SP0oooo1`09jPXS0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0480oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0207moO`030000
003oool0oooo05/0oooo1P09jPX/0?ooo`H02NX::P3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`120?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00P1o
Ogl00`000000oooo0?ooo`1Q0?ooo`L02NX:7`3oool600WZ2S00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0>P3oool300WZ2PD0oooo00<0000007moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0207moO`030000003oool0oooo06P0oooo1P09jPXB0?ooo`L02NX:;P3oool3
00WZ2PD0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0>`3oool600WZ
2P8000001`1oOgl00`000000Ogmo07moO`0207moO`800000K`3oool600WZ2PH0oooo1P09jPXf0?oo
o`H02NX:0P0000070?ooo`001P3ooom400WZ2P0300000009jPX02NX:0<X02NX:0P0000070?ooo`00
1P3oool00`000000oooo0?ooo`0k0?ooo`D02NX:0P3oool00`000000Ogmo07moO`0507moO`030000
001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0K@3oool600WZ2PP0oooo1P09jPXe0?ooo`D02NX:
0P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0j0?ooo`802NX:1P3o
ool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0I`3o
ool600WZ2Q@0oooo1`09jPX]0?ooo`802NX:1P3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`120?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00P1oOgl0
0`000000oooo0?ooo`1P0?ooo`L02NX:8@3oool600WZ2Rl0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0@P3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo
0080Ogmo00<000000?ooo`3oool0FP3oool600WZ2Rh0oooo1P09jPXY0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0480oooo00<0000007moO`1oOgl01@1oOgl00`000000
Ogmo07moO`0207moO`030000003oool0oooo05<0oooo1`09jPXj0?ooo`L02NX:8P3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`130?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`1=0?ooo`H02NX:B03oool600WZ2Q`0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0@`3oool00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0A`3oool600WZ2U@0oooo1`09
jPX=0?ooo`802NX:1P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`13
0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`10
0?ooo`L02NX:H@3oool600WZ2PL0oooo1009jPX40?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo04<0oooo00<0000007moO`1oOgl0101oOgl6000003`0oooo1P09jPY^0?oo
o`H02NX:0P3oool500WZ2P80oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0@`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3o
ool0<`3oool700WZ2WX0oooo2009jPX2000000L0oooo00060?ooo`030000003oool0oooo04<0oooo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo02d0oooo
1P09jPZ10?ooo`P02NX:0P0000070?ooo`001P3oool00`000000oooo0?ooo`130?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0W0?ooo`H02NX:T03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`130?ooo`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0P0?ooo`L02NX:UP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`130?ooo`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0J0?ooo`H02NX:W@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`140?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0C0?ooo`L02NX:X`3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`140?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0=0?ooo`H02NX:ZP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`140?ooo`030000001oOgl0Ogmo00<0Ogmo1P00
00090?ooo`H02NX:/03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0m
0?ooo`<02NX:103oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<00000
0?ooo`3oool01`09jPZf0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
03h0oooo1P09jPX00`000000Ogmo07moO`0307moO`P02NX:_@3oool00`000000oooo0?ooo`050?oo
o`001P3ooom700WZ2P0300000009jPX02NX:00<02NX:00<0000007moO`1oOgl00P1oOgl200000;h0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0?P3oool500WZ2P030?oo
o`000000000000@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`2m0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03d0oooo0P09jPX60?ooo`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`2m0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo04D0oooo00<0000007moO`1oOgl00P1oOgl0
0`000000Ogmo07moO`0207moO`030000003oool0oooo0;d0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0A@3oool00`000000Ogmo07moO`0207moO`H00000_`3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`160?ooo`050000001oOgl0Ogmo07mo
O`000000101oOgl00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo04H0oooo00D0000007moO`1oOgl0Ogmo0000000407moO`030000003oool0oooo
0;d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0A`3oool010000000
Ogmo07moO`00000407moO`030000003oool0oooo0;d0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0A`3oool010000000Ogmo07moO`00000407moO`030000003oool0oooo
0;d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0B03oool00`000000
Ogmo0000000407moO`030000003oool0oooo0;d0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0B03oool00`000000Ogmo0000000500000;l0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0B03oool00`000000Ogmo0000000407moO`030000003o
ool0oooo0;d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0B@3oool2
000000@0Ogmo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`190?ooo`L00000_`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`1:0?ooo`H00000_`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`800000o`3ooolA0?ooo`030000003oool0oooo00D0oooo0006
0?ooool00000500000070?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00105, -105.001, 0.731715, \
0.731715}},
  CellTags->"Scripted Moves"],

Cell[BoxData[
    TagBox[\(DrawSystem[{LineOfRays[30], 
          Move[PlanoConvexLens[100, 50, 10], 50.`], 
          Boundary[{0, \(-100\), \(-100\)}, {200, 100, 100}]}, 
        PlotType \[Rule] TopView]\),
      HoldForm]], "Print",
  CellTags->"Scripted Moves"],

Cell[BoxData[
    \("-9 ray/surface intersections-"\)], "Output",
  CellTags->"Scripted Moves"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[sys,PlotType->TopView,Move->{{56.463, 4.02444}, \
{84.9999, 5.48787}}]\
\>", "Input",
  CellTags->"Scripted Moves"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.5 0.0047619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.45915 .40709 m
.47619 .40709 L
.47619 .44677 L
.44167 .44677 L
.45915 .40709 L
F
.44167 .44677 m
.47619 .44677 L
.47619 .48645 L
.43178 .48645 L
.44167 .44677 L
F
.43178 .48645 m
.47619 .48645 L
.47619 .52613 L
.42857 .52613 L
.43178 .48645 L
F
.42857 .52613 m
.47619 .52613 L
.47619 .56582 L
.43178 .56582 L
.42857 .52613 L
F
.43178 .56582 m
.47619 .56582 L
.47619 .6055 L
.44167 .6055 L
.43178 .56582 L
F
.44167 .6055 m
.47619 .6055 L
.47619 .64518 L
.45915 .64518 L
.44167 .6055 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.45915 .40709 m
.44167 .44677 L
.43178 .48645 L
.42857 .52613 L
.43178 .56582 L
.44167 .6055 L
.45915 .64518 L
.47619 .64518 L
.47619 .6055 L
.47619 .56582 L
.47619 .52613 L
.47619 .48645 L
.47619 .44677 L
.47619 .40709 L
.45915 .40709 L
s
.5 g
.45915 .52613 m
.47619 .52613 L
.47619 .52613 L
.44167 .52613 L
.45915 .52613 L
F
.44167 .52613 m
.47619 .52613 L
.47619 .52613 L
.43178 .52613 L
.44167 .52613 L
F
.43178 .52613 m
.47619 .52613 L
.47619 .52613 L
.42857 .52613 L
.43178 .52613 L
F
.42857 .52613 m
.47619 .52613 L
.47619 .52613 L
.43178 .52613 L
.42857 .52613 L
F
.43178 .52613 m
.47619 .52613 L
.47619 .52613 L
.44167 .52613 L
.43178 .52613 L
F
.44167 .52613 m
.47619 .52613 L
.47619 .52613 L
.45915 .52613 L
.44167 .52613 L
F
0 g
.45915 .52613 m
.44167 .52613 L
.43178 .52613 L
.42857 .52613 L
.43178 .52613 L
.44167 .52613 L
.45915 .52613 L
.47619 .52613 L
.47619 .52613 L
.47619 .52613 L
.47619 .52613 L
.47619 .52613 L
.47619 .52613 L
.47619 .52613 L
.45915 .52613 L
s
.45915 .64518 m
.47619 .64518 L
.47619 .64112 L
.45915 .64112 L
.45915 .64518 L
s
.45915 .64112 m
.47619 .64112 L
.47619 .62923 L
.45915 .62923 L
.45915 .64112 L
s
.45915 .62923 m
.47619 .62923 L
.47619 .61031 L
.45915 .61031 L
.45915 .62923 L
s
.45915 .61031 m
.47619 .61031 L
.47619 .58566 L
.45915 .58566 L
.45915 .61031 L
s
.45915 .58566 m
.47619 .58566 L
.47619 .55695 L
.45915 .55695 L
.45915 .58566 L
s
.45915 .55695 m
.47619 .55695 L
.47619 .52613 L
.45915 .52613 L
.45915 .55695 L
s
.45915 .52613 m
.47619 .52613 L
.47619 .49532 L
.45915 .49532 L
.45915 .52613 L
s
.45915 .49532 m
.47619 .49532 L
.47619 .46661 L
.45915 .46661 L
.45915 .49532 L
s
.45915 .46661 m
.47619 .46661 L
.47619 .44195 L
.45915 .44195 L
.45915 .46661 L
s
.45915 .44195 m
.47619 .44195 L
.47619 .42304 L
.45915 .42304 L
.45915 .44195 L
s
.45915 .42304 m
.47619 .42304 L
.47619 .41114 L
.45915 .41114 L
.45915 .42304 L
s
.45915 .41114 m
.47619 .41114 L
.47619 .40709 L
.45915 .40709 L
.45915 .41114 L
s
.45915 .40709 m
.47619 .40709 L
.47619 .41114 L
.45915 .41114 L
.45915 .40709 L
s
.45915 .41114 m
.47619 .41114 L
.47619 .42304 L
.45915 .42304 L
.45915 .41114 L
s
.45915 .42304 m
.47619 .42304 L
.47619 .44195 L
.45915 .44195 L
.45915 .42304 L
s
.45915 .44195 m
.47619 .44195 L
.47619 .46661 L
.45915 .46661 L
.45915 .44195 L
s
.45915 .46661 m
.47619 .46661 L
.47619 .49532 L
.45915 .49532 L
.45915 .46661 L
s
.45915 .49532 m
.47619 .49532 L
.47619 .52613 L
.45915 .52613 L
.45915 .49532 L
s
.45915 .52613 m
.47619 .52613 L
.47619 .55695 L
.45915 .55695 L
.45915 .52613 L
s
.45915 .55695 m
.47619 .55695 L
.47619 .58566 L
.45915 .58566 L
.45915 .55695 L
s
.45915 .58566 m
.47619 .58566 L
.47619 .61031 L
.45915 .61031 L
.45915 .58566 L
s
.45915 .61031 m
.47619 .61031 L
.47619 .62923 L
.45915 .62923 L
.45915 .61031 L
s
.45915 .62923 m
.47619 .62923 L
.47619 .64112 L
.45915 .64112 L
.45915 .62923 L
s
.45915 .64112 m
.47619 .64112 L
.47619 .64518 L
.45915 .64518 L
.45915 .64112 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .42857 m
.44866 .42857 L
s
% Start of user PostScript
0 -15. 89.2176 -15. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.44866 .42857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.42996 .5 L
s
% Start of user PostScript
0 0 85.2911 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.42996 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .57143 m
.43276 .57143 L
s
% Start of user PostScript
0 15. 85.8796 15. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.43276 .57143 Mdot
.039 .916 .04 r
.5 Mabswid
.44866 .42857 m
.47619 .43254 L
s
0 0 0 r
2 Mabswid
.47619 .43254 Mdot
.039 .916 .04 r
.5 Mabswid
.42996 .5 m
.47619 .50168 L
s
0 0 0 r
2 Mabswid
.47619 .50168 Mdot
.039 .916 .04 r
.5 Mabswid
.43276 .57143 m
.47619 .56867 L
s
0 0 0 r
2 Mabswid
.47619 .56867 Mdot
.039 .916 .04 r
.5 Mabswid
.47619 .43254 m
.97619 .5435 L
s
% Start of user PostScript
95. -14.167 200. 9.13591 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .5435 Mdot
.039 .916 .04 r
.5 Mabswid
.47619 .50168 m
.97619 .5293 L
s
% Start of user PostScript
95. 0.352705 200. 6.15367 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .5293 Mdot
.039 .916 .04 r
.5 Mabswid
.47619 .56867 m
.97619 .52028 L
s
% Start of user PostScript
95. 14.4206 200. 4.25862 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .52028 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo07X0oooo1P00002?0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo07X0oooo1P00002?0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo07T0oooo0P00000407moO`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0N@3oool2000000@0Ogmo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1_0?oo
o`<02NX:1`3oool2000000@0Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`1`0?ooo`H02NX:0P3oool00`000000Ogmo00000005000008l0
oooo00<000000?ooo`3oool01@3oool000H0ooooO@09jPX00`000000Ogmo07moO`0207moO`030000
003oool0oooo08d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0L03o
ool500WZ2P80oooo0P0000000`1oOgl02NX:00WZ2P0200WZ2P0307moO`000000000008h0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0K`3oool200WZ2PH0oooo00@00000
07moO`1oOgl000000`1oOgl400WZ2Xd0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0MP3oool01@000000Ogmo07moO`1oOgl0000000@0Ogmo00<000000?ooo`3oool01@09
jPZ80?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07H0oooo00@00000
07moO`1oOgl0Ogmo1P0000070?ooo`D02NX:P`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1f0?ooo`050000001oOgl0Ogmo07moO`000000101oOgl00`000000oooo0?oo
o`0:0?ooo`@02NX:O`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1e
0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0>
0?ooo`D02NX:NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1e0?oo
o`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0C0?oo
o`D02NX:M@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1e0?ooo`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0H0?ooo`@0
2NX:L@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1d0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0L0?ooo`D02NX:
K03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1d0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0Q0?ooo`@02NX:J03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1d0?ooo`030000001oOgl0
Ogmo00<0Ogmo1P00000W0?ooo`D02NX:H`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`1c0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`00
0000oooo0?ooo`0Z0?ooo`D02NX:GP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`1c0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000
oooo0?ooo`0_0?ooo`@02NX:FP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`1c0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo
0?ooo`0c0?ooo`D02NX:E@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`1c0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?oo
o`0h0?ooo`D02NX:D03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1b
0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0m
0?ooo`@02NX:C03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1b0?oo
o`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`110?oo
o`D02NX:A`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1b0?ooo`03
0000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`160?ooo`D0
2NX:@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1Z0?ooo`<02NX:
1@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0
B`3oool400WZ2Sh0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0J`3o
ool600WZ2P8000001`1oOgl600000540oooo1@09jPXi0?ooo`030000003oool0oooo00D0oooo0006
0?ooog@02NX:00<0000000WZ2P09jPX05@09jPY=0?ooo`D02NX:=03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`1[0?ooo`D02NX:0P3oool00`000000Ogmo07moO`0507mo
O`030000001oOgl0Ogmo0080Ogmo0P0000080?oooa802NX:@03oool400WZ2S00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0JP3oool200WZ2PH0oooo00<0000007moO`1o
Ogl01@1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo01T0oooo4P09jPXb0?ooo`D0
2NX::`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1b0?ooo`030000
001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0[0?oooa802NX:
9@3oool500WZ2RH0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0LP3o
ool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0?@3o
oolB00WZ2QP0oooo1009jPXR0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0780oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0207moO`030000003oool0
oooo04l0oooo4P09jPX:0?ooo`D02NX:503oool600WZ2P80oooo0P0000070?ooo`001P3oool00`00
0000oooo0?ooo`1b0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00P1oOgl00`00
0000oooo0?ooo`1Q0?oooa<02NX:4@3oool700WZ2P8000001`3oool000H0oooo00<000000?ooo`3o
ool0LP3oool>000007D0oooo6@09jPX00`3oool000000?ooo`060?ooo`001P3oool00`000000oooo
0?ooo`1b0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo
0?ooo`1c0?ooo`/02NX:1`3oool700WZ2P8000001`3oool000H0oooo00<000000?ooo`3oool0LP3o
ool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0J@3o
ool:00WZ2P/0oooo1009jPX30?ooo`H02NX:00<0oooo0000000000001`3oool000H0oooo00<00000
0?ooo`3oool0LP3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080Ogmo00<00000
0?ooo`3oool0G`3oool:00WZ2QT0oooo2009jPX30?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0780oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0207mo
O`030000003oool0oooo05@0oooo2`09jPXW0?ooo`L02NX:00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0LP3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080
Ogmo00<000000?ooo`3oool0BP3oool:00WZ2S40oooo1`09jPX2000000L0oooo00060?ooo`030000
003oool0oooo0780oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0207moO`030000
003oool0oooo0400oooo2P09jPXj0?ooo`D02NX:0`3oool2000000L0oooo00060?ooo`030000003o
ool0oooo0780oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0207moO`030000003o
ool0oooo03H0oooo2P09jPY=0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0780oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0207moO`030000003oool0
oooo02/0oooo2`09jPYG0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0780oooo00<0000007moO`1oOgl01@1oOgl6000002<0oooo2P09jPYR0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0780oooo00<0000007moO`1oOgl01@1oOgl00`000000
Ogmo07moO`0207moO`030000003oool0oooo01L0oooo2P09jPY/0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo06/0oooo0`09jPX40?ooo`030000001oOgl0Ogmo00D0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0<0?ooo`/02NX:MP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1/0?ooo`H02NX:00<0000007moO`1oOgl01@1o
Ogl00`000000Ogmo07moO`0207moO`8000000`3oool:00WZ2X40oooo00<000000?ooo`3oool01@3o
ool000H0ooooM@09jPX00`0000002NX:00WZ2P0?00WZ2X/0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0K03oool500WZ2P030?ooo`000000000000H0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo06/0oooo0P09jPX60?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00P1oOgl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo07<0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0207moO`030000
003oool0oooo08d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0L`3o
ool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1d0?ooo`030000001oOgl0
Ogmo00<0Ogmo1P00002?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
07@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo
08d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0M03oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1d0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo07D0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07mo
O`0207moO`030000003oool0oooo08d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0M@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0080Ogmo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1e0?oo
o`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07H0oooo00@0000007moO`1o
Ogl0Ogmo1P00002?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07H0
oooo00D0000007moO`1oOgl0Ogmo0000000407moO`030000003oool0oooo08d0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0MP3oool01@000000Ogmo07moO`1oOgl00000
00@0Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`1g0?ooo`040000001oOgl0Ogmo000000@0Ogmo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1g0?ooo`040000001oOgl0Ogmo0000
00@0Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`1h0?ooo`030000001oOgl0000000D00000S`3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`1h0?ooo`030000001oOgl0000000@0Ogmo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1i0?ooo`800000101o
Ogl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo07T0oooo1`00002?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
07T0oooo0P00000407moO`030000003oool0oooo08d0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0NP3oool6000008l0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo0P00003o0?oooa40oooo00<000000?oo
o`3oool01@3oool000H0ooooo`00000D000000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00105, -105.001, 0.731715, \
0.731715}},
  CellTags->"Scripted Moves"],

Cell[BoxData[
    TagBox[\(DrawSystem[{LineOfRays[30], 
          Move[PlanoConvexLens[100, 50, 10], {85.`, 5.488`}], 
          Boundary[{0, \(-100\), \(-100\)}, {200, 100, 100}]}, 
        PlotType \[Rule] TopView]\),
      HoldForm]], "Print",
  CellTags->"Scripted Moves"],

Cell[BoxData[
    \("-9 ray/surface intersections-"\)], "Output",
  CellTags->"Scripted Moves"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[sys,PlotType->TopView,Move->{{56.463, 4.02444}, \
{84.9999, 5.48787}, {131.83, 26.7076}}]\
\>", "Input",
  CellTags->"Scripted Moves"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.5 0.0047619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.50556 .43032 m
.52108 .43735 L
.5047 .4735 L
.47326 .45925 L
.50556 .43032 L
F
.47326 .45925 m
.5047 .4735 L
.48832 .50964 L
.44787 .49131 L
.47326 .45925 L
F
.44787 .49131 m
.48832 .50964 L
.47195 .54579 L
.42857 .52613 L
.44787 .49131 L
F
.42857 .52613 m
.47195 .54579 L
.45557 .58193 L
.41512 .5636 L
.42857 .52613 L
F
.41512 .5636 m
.45557 .58193 L
.43919 .61808 L
.40775 .60383 L
.41512 .5636 L
F
.40775 .60383 m
.43919 .61808 L
.42281 .65422 L
.40729 .64719 L
.40775 .60383 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.50556 .43032 m
.47326 .45925 L
.44787 .49131 L
.42857 .52613 L
.41512 .5636 L
.40775 .60383 L
.40729 .64719 L
.42281 .65422 L
.43919 .61808 L
.45557 .58193 L
.47195 .54579 L
.48832 .50964 L
.5047 .4735 L
.52108 .43735 L
.50556 .43032 L
s
.5 g
.45643 .53875 m
.47195 .54579 L
.47195 .54579 L
.4405 .53154 L
.45643 .53875 L
F
.4405 .53154 m
.47195 .54579 L
.47195 .54579 L
.43149 .52746 L
.4405 .53154 L
F
.43149 .52746 m
.47195 .54579 L
.47195 .54579 L
.42857 .52613 L
.43149 .52746 L
F
.42857 .52613 m
.47195 .54579 L
.47195 .54579 L
.43149 .52746 L
.42857 .52613 L
F
.43149 .52746 m
.47195 .54579 L
.47195 .54579 L
.4405 .53154 L
.43149 .52746 L
F
.4405 .53154 m
.47195 .54579 L
.47195 .54579 L
.45643 .53875 L
.4405 .53154 L
F
0 g
.45643 .53875 m
.4405 .53154 L
.43149 .52746 L
.42857 .52613 L
.43149 .52746 L
.4405 .53154 L
.45643 .53875 L
.47195 .54579 L
.47195 .54579 L
.47195 .54579 L
.47195 .54579 L
.47195 .54579 L
.47195 .54579 L
.47195 .54579 L
.45643 .53875 L
s
.40729 .64719 m
.42281 .65422 L
.42449 .65053 L
.40897 .6435 L
.40729 .64719 L
s
.40897 .6435 m
.42449 .65053 L
.42939 .63969 L
.41388 .63266 L
.40897 .6435 L
s
.41388 .63266 m
.42939 .63969 L
.4372 .62246 L
.42168 .61543 L
.41388 .63266 L
s
.42168 .61543 m
.4372 .62246 L
.44738 .6 L
.43186 .59297 L
.42168 .61543 L
s
.43186 .59297 m
.44738 .6 L
.45923 .57385 L
.44371 .56682 L
.43186 .59297 L
s
.44371 .56682 m
.45923 .57385 L
.47195 .54579 L
.45643 .53875 L
.44371 .56682 L
s
.45643 .53875 m
.47195 .54579 L
.48466 .51772 L
.46914 .51069 L
.45643 .53875 L
s
.46914 .51069 m
.48466 .51772 L
.49651 .49157 L
.48099 .48454 L
.46914 .51069 L
s
.48099 .48454 m
.49651 .49157 L
.50669 .46911 L
.49117 .46208 L
.48099 .48454 L
s
.49117 .46208 m
.50669 .46911 L
.5145 .45188 L
.49898 .44485 L
.49117 .46208 L
s
.49898 .44485 m
.5145 .45188 L
.51941 .44105 L
.50389 .43401 L
.49898 .44485 L
s
.50389 .43401 m
.51941 .44105 L
.52108 .43735 L
.50556 .43032 L
.50389 .43401 L
s
.50556 .43032 m
.52108 .43735 L
.51941 .44105 L
.50389 .43401 L
.50556 .43032 L
s
.50389 .43401 m
.51941 .44105 L
.5145 .45188 L
.49898 .44485 L
.50389 .43401 L
s
.49898 .44485 m
.5145 .45188 L
.50669 .46911 L
.49117 .46208 L
.49898 .44485 L
s
.49117 .46208 m
.50669 .46911 L
.49651 .49157 L
.48099 .48454 L
.49117 .46208 L
s
.48099 .48454 m
.49651 .49157 L
.48466 .51772 L
.46914 .51069 L
.48099 .48454 L
s
.46914 .51069 m
.48466 .51772 L
.47195 .54579 L
.45643 .53875 L
.46914 .51069 L
s
.45643 .53875 m
.47195 .54579 L
.45923 .57385 L
.44371 .56682 L
.45643 .53875 L
s
.44371 .56682 m
.45923 .57385 L
.44738 .6 L
.43186 .59297 L
.44371 .56682 L
s
.43186 .59297 m
.44738 .6 L
.4372 .62246 L
.42168 .61543 L
.43186 .59297 L
s
.42168 .61543 m
.4372 .62246 L
.42939 .63969 L
.41388 .63266 L
.42168 .61543 L
s
.41388 .63266 m
.42939 .63969 L
.42449 .65053 L
.40897 .6435 L
.41388 .63266 L
s
.40897 .6435 m
.42449 .65053 L
.42281 .65422 L
.40729 .64719 L
.40897 .6435 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .42857 m
.02381 .42857 L
s
0 0 0 r
2 Mabswid
.02381 .42857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.44235 .5 L
s
% Start of user PostScript
0 0 87.8941 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.44235 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .57143 m
.41314 .57143 L
s
% Start of user PostScript
0 15. 81.7586 15. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.41314 .57143 Mdot
.039 .916 .04 r
.5 Mabswid
.44235 .5 m
.48852 .50921 L
s
0 0 0 r
2 Mabswid
.48852 .50921 Mdot
.039 .916 .04 r
.5 Mabswid
.41314 .57143 m
.45867 .57507 L
s
0 0 0 r
2 Mabswid
.45867 .57507 Mdot
.039 .916 .04 r
.5 Mabswid
.48852 .50921 m
.97619 .54534 L
s
% Start of user PostScript
97.5892 1.93376 200. 9.52219 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .54534 Mdot
.039 .916 .04 r
.5 Mabswid
.45867 .57507 m
.97619 .5152 L
s
% Start of user PostScript
91.3217 15.7656 200. 3.19234 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .5152 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`800000o`3ooolA0?ooo`030000003oool0oooo00D0oooo
00060?ooo`800000R03oool3000008D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool30000000307moO`000000000008<0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Q@3oool010000000Ogmo0000001oOgl400000880oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q03oool00`000000Ogmo0000000507mo
O`030000003oool0oooo0800oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0PP3oool200000080Ogmo0P00000307moO`800000PP3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`210?ooo`030000001oOgl0Ogmo0080Ogmo00H0000007moO`000000
000007moO`0000230?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0800
oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo0880
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0O`3oool00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1n0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`230?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo07h0oooo00<0000007moO`1oOgl00P1oOgl2000000@0Ogmo00<00000
0?ooo`3oool0P`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1m0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`000000100000250?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo07`0oooo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0207moO`030000003oool0oooo08@0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0O03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo
0P0000260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07/0oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo08D0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0NP3oool00`000000Ogmo07moO`05
07moO`040000001oOgl0Ogmo07moO`800000Q`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1i0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00P1oOgl0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
07T0oooo00<0000007moO`1oOgl01@1oOgl2000000<0Ogmo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1h0?ooo`030000001oOgl0Ogmo00H0
Ogmo00<0000007moO`0000000`0000280?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo06d0oooo0`09jPX70?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl0
0P1oOgl00`000000oooo0?ooo`270?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo06h0oooo1P09jPX0103oool0000000000000000807moO`030000001oOgl0Ogmo0080Ogmo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`050?ooo`001P3ooomk00WZ2PL0Ogmo00<0
000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`280?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo06h0oooo1@09jPX30?ooo`030000001oOgl02NX:00@02NX:00<0Ogmo
0000001oOgl0101oOgl00`000000oooo0?ooo`280?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo06d0oooo0P09jPX60?ooo`030000001oOgl0Ogmo00D0Ogmo1@09jPX30000
08X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0M03oool00`000000
Ogmo07moO`0607moO`8000000`1oOgl00`0000002NX:00WZ2P0600WZ2W/0oooo1P09jPX30?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07@0oooo00<0000007moO`1oOgl0
1P1oOgl00`000000Ogmo000000020000000307moO`000000oooo00H0oooo3P09jPY_0?ooo`H02NX:
0P0000070?ooo`001P3oool00`000000oooo0?ooo`1c0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0D0?ooo`h02NX:G03oool;00WZ2P8000001`3o
ool000H0oooo00<000000?ooo`3oool0L`3oool00`000000Ogmo07moO`0607moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool08P3oool>00WZ2TD0oooo2@09jPX50?ooo`<02NX:103oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1b0?ooo`030000001oOgl0Ogmo
00H0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0a0?ooo`h02NX:;`3oool800WZ
2Pd0oooo00<02NX:0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`1b0?ooo`<000001P1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03l0
oooo3P09jPXI0?ooo`P02NX:7@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`1a0?ooo`040000001oOgl0Ogmo07moO`8000000`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo04h0oooo3P09jPX20?ooo`T02NX:9@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`1a0?ooo`030000001oOgl0Ogmo00<0Ogmo0P0000000`1oOgl00000
07moO`0407moO`030000003oool0oooo05H0oooo5009jPXJ0?ooo`802NX:1P3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1a0?ooo`030000001oOgl0Ogmo00D0Ogmo0P00
000407moO`030000003oool0oooo04l0oooo2009jPXD0?ooo`h02NX:303oool500WZ2P<0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`06
07moO`030000001oOgl000000080000000<0Ogmo0000003oool0B03oool800WZ2RX0oooo5009jPX0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0o0?ooo`T02NX:?`3oool600WZ
2P8000001`3oool000H0oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0507moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=`3oool800WZ2TL0oooo1009jPX30?ooo`80
00001`3oool000H0oooo00<000000?ooo`3oool0K`3oool00`000000Ogmo07moO`0607moO`030000
001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0<03oool800WZ2UL0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0K`3oool00`000000Ogmo07moO`0507moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool800WZ2Ul0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0K`3oool00`000000Ogmo07moO`0507moO`030000001oOgl0
Ogmo0080Ogmo00<000000?ooo`3oool0803oool900WZ2VL0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0I@3oool300WZ2PH0oooo00<0000007moO`1oOgl01P1oOgl00`00
0000Ogmo07moO`0207moO`030000003oool0oooo01P0oooo2009jPY`0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo06H0oooo1P09jPX20?ooo`030000001oOgl0Ogmo00D0
Ogmo0P00000307moO`030000003oool0oooo0140oooo2009jPYh0?ooo`030000003oool0oooo00D0
oooo00060?ooog@02NX:1@1oOgl01P000000Ogmo000000000000Ogmo000000X0oooo2@09jPZ00?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo06H0oooo1@09jPX20?ooo`80
00000P1oOgl700WZ2P80Ogmo0P0000020?ooo`P02NX:R@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`1U0?ooo`802NX:1P3oool00`000000Ogmo07moO`0507moO`030000
001oOgl0Ogmo00H02NX:T@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`1]0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl2000009@0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0K@3oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`1]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo06d0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`03
0000003oool0oooo09@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
K@3oool00`000000Ogmo07moO`0207moO`800000101oOgl00`000000oooo0?ooo`2D0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo06`0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo000000020000000307moO`000000oooo09D0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0K03oool00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`1/0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`2E0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo06`0
oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo09H0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0K03oool01@000000Ogmo
07moO`1oOgl0000000D0Ogmo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`1/0?ooo`040000001oOgl0Ogmo07moO`8000000`1oOgl2000009P0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0K03oool01P000000Ogmo
07moO`1oOgl0000007moO`80000000<0Ogmo0000003oool0V03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`1/0?ooo`040000001oOgl0Ogmo000000@0Ogmo0P00002I0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo06`0oooo00<0000007moO`00
00001@1oOgl00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo06/0oooo00@0000007moO`1oOgl00000101oOgl2000009X0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0J`3oool010000000Ogmo00000000000407moO`03
0000003oool0oooo09T0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
J`3oool010000000Ogmo0000001oOgl30000000307moO`000000oooo09X0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0J`3oool2000000D0Ogmo00<000000?ooo`3oool0
VP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1[0?ooo`<00000101o
Ogl00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo06/0oooo0P0000001@1oOgl000000000001oOgl0000009d0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0K@3oool5000009d0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool200000?l0oooo4@3oool00`000000oooo0?ooo`050?ooo`001P3ooooo000001@000001`3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00105, -105.001, 0.731715, \
0.731715}},
  CellTags->"Scripted Moves"],

Cell[BoxData[
    TagBox[\(DrawSystem[{LineOfRays[30], 
          Move[PlanoConvexLens[100, 50, 10], {85.`, 5.4879999999999995`}, 
            24.376000000000005`], 
          Boundary[{0, \(-100\), \(-100\)}, {200, 100, 100}]}, 
        PlotType \[Rule] TopView]\),
      HoldForm]], "Print",
  CellTags->"Scripted Moves"],

Cell[BoxData[
    \("-7 ray/surface intersections-"\)], "Output",
  CellTags->"Scripted Moves"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[sys,PlotType->TopView,Copy->{{56.463, 4.02444}, \
{84.9999, 5.48787}}]\
\>", "Input",
  CellTags->"Scripted Moves"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.5 0.0047619 [
[.45238 .36899 -6 -4.5 ]
[.45238 .36899 6 4.5 ]
[.28571 .34286 -6 -4.5 ]
[.28571 .34286 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.29249 .38095 m
.30952 .38095 L
.30952 .42063 L
.275 .42063 L
.29249 .38095 L
F
.275 .42063 m
.30952 .42063 L
.30952 .46032 L
.26511 .46032 L
.275 .42063 L
F
.26511 .46032 m
.30952 .46032 L
.30952 .5 L
.2619 .5 L
.26511 .46032 L
F
.2619 .5 m
.30952 .5 L
.30952 .53968 L
.26511 .53968 L
.2619 .5 L
F
.26511 .53968 m
.30952 .53968 L
.30952 .57937 L
.275 .57937 L
.26511 .53968 L
F
.275 .57937 m
.30952 .57937 L
.30952 .61905 L
.29249 .61905 L
.275 .57937 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.29249 .38095 m
.275 .42063 L
.26511 .46032 L
.2619 .5 L
.26511 .53968 L
.275 .57937 L
.29249 .61905 L
.30952 .61905 L
.30952 .57937 L
.30952 .53968 L
.30952 .5 L
.30952 .46032 L
.30952 .42063 L
.30952 .38095 L
.29249 .38095 L
s
.5 g
.29249 .5 m
.30952 .5 L
.30952 .5 L
.275 .5 L
.29249 .5 L
F
.275 .5 m
.30952 .5 L
.30952 .5 L
.26511 .5 L
.275 .5 L
F
.26511 .5 m
.30952 .5 L
.30952 .5 L
.2619 .5 L
.26511 .5 L
F
.2619 .5 m
.30952 .5 L
.30952 .5 L
.26511 .5 L
.2619 .5 L
F
.26511 .5 m
.30952 .5 L
.30952 .5 L
.275 .5 L
.26511 .5 L
F
.275 .5 m
.30952 .5 L
.30952 .5 L
.29249 .5 L
.275 .5 L
F
0 g
.29249 .5 m
.275 .5 L
.26511 .5 L
.2619 .5 L
.26511 .5 L
.275 .5 L
.29249 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.29249 .5 L
s
.29249 .61905 m
.30952 .61905 L
.30952 .61499 L
.29249 .61499 L
.29249 .61905 L
s
.29249 .61499 m
.30952 .61499 L
.30952 .6031 L
.29249 .6031 L
.29249 .61499 L
s
.29249 .6031 m
.30952 .6031 L
.30952 .58418 L
.29249 .58418 L
.29249 .6031 L
s
.29249 .58418 m
.30952 .58418 L
.30952 .55952 L
.29249 .55952 L
.29249 .58418 L
s
.29249 .55952 m
.30952 .55952 L
.30952 .53081 L
.29249 .53081 L
.29249 .55952 L
s
.29249 .53081 m
.30952 .53081 L
.30952 .5 L
.29249 .5 L
.29249 .53081 L
s
.29249 .5 m
.30952 .5 L
.30952 .46919 L
.29249 .46919 L
.29249 .5 L
s
.29249 .46919 m
.30952 .46919 L
.30952 .44048 L
.29249 .44048 L
.29249 .46919 L
s
.29249 .44048 m
.30952 .44048 L
.30952 .41582 L
.29249 .41582 L
.29249 .44048 L
s
.29249 .41582 m
.30952 .41582 L
.30952 .3969 L
.29249 .3969 L
.29249 .41582 L
s
.29249 .3969 m
.30952 .3969 L
.30952 .38501 L
.29249 .38501 L
.29249 .3969 L
s
.29249 .38501 m
.30952 .38501 L
.30952 .38095 L
.29249 .38095 L
.29249 .38501 L
s
.29249 .38095 m
.30952 .38095 L
.30952 .38501 L
.29249 .38501 L
.29249 .38095 L
s
.29249 .38501 m
.30952 .38501 L
.30952 .3969 L
.29249 .3969 L
.29249 .38501 L
s
.29249 .3969 m
.30952 .3969 L
.30952 .41582 L
.29249 .41582 L
.29249 .3969 L
s
.29249 .41582 m
.30952 .41582 L
.30952 .44048 L
.29249 .44048 L
.29249 .41582 L
s
.29249 .44048 m
.30952 .44048 L
.30952 .46919 L
.29249 .46919 L
.29249 .44048 L
s
.29249 .46919 m
.30952 .46919 L
.30952 .5 L
.29249 .5 L
.29249 .46919 L
s
.29249 .5 m
.30952 .5 L
.30952 .53081 L
.29249 .53081 L
.29249 .5 L
s
.29249 .53081 m
.30952 .53081 L
.30952 .55952 L
.29249 .55952 L
.29249 .53081 L
s
.29249 .55952 m
.30952 .55952 L
.30952 .58418 L
.29249 .58418 L
.29249 .55952 L
s
.29249 .58418 m
.30952 .58418 L
.30952 .6031 L
.29249 .6031 L
.29249 .58418 L
s
.29249 .6031 m
.30952 .6031 L
.30952 .61499 L
.29249 .61499 L
.29249 .6031 L
s
.29249 .61499 m
.30952 .61499 L
.30952 .61905 L
.29249 .61905 L
.29249 .61499 L
s
.5 g
.45915 .40709 m
.47619 .40709 L
.47619 .44677 L
.44167 .44677 L
.45915 .40709 L
F
.44167 .44677 m
.47619 .44677 L
.47619 .48645 L
.43178 .48645 L
.44167 .44677 L
F
.43178 .48645 m
.47619 .48645 L
.47619 .52613 L
.42857 .52613 L
.43178 .48645 L
F
.42857 .52613 m
.47619 .52613 L
.47619 .56582 L
.43178 .56582 L
.42857 .52613 L
F
.43178 .56582 m
.47619 .56582 L
.47619 .6055 L
.44167 .6055 L
.43178 .56582 L
F
.44167 .6055 m
.47619 .6055 L
.47619 .64518 L
.45915 .64518 L
.44167 .6055 L
F
0 g
.45915 .40709 m
.44167 .44677 L
.43178 .48645 L
.42857 .52613 L
.43178 .56582 L
.44167 .6055 L
.45915 .64518 L
.47619 .64518 L
.47619 .6055 L
.47619 .56582 L
.47619 .52613 L
.47619 .48645 L
.47619 .44677 L
.47619 .40709 L
.45915 .40709 L
s
.5 g
.45915 .52613 m
.47619 .52613 L
.47619 .52613 L
.44167 .52613 L
.45915 .52613 L
F
.44167 .52613 m
.47619 .52613 L
.47619 .52613 L
.43178 .52613 L
.44167 .52613 L
F
.43178 .52613 m
.47619 .52613 L
.47619 .52613 L
.42857 .52613 L
.43178 .52613 L
F
.42857 .52613 m
.47619 .52613 L
.47619 .52613 L
.43178 .52613 L
.42857 .52613 L
F
.43178 .52613 m
.47619 .52613 L
.47619 .52613 L
.44167 .52613 L
.43178 .52613 L
F
.44167 .52613 m
.47619 .52613 L
.47619 .52613 L
.45915 .52613 L
.44167 .52613 L
F
0 g
.45915 .52613 m
.44167 .52613 L
.43178 .52613 L
.42857 .52613 L
.43178 .52613 L
.44167 .52613 L
.45915 .52613 L
.47619 .52613 L
.47619 .52613 L
.47619 .52613 L
.47619 .52613 L
.47619 .52613 L
.47619 .52613 L
.47619 .52613 L
.45915 .52613 L
s
.45915 .64518 m
.47619 .64518 L
.47619 .64112 L
.45915 .64112 L
.45915 .64518 L
s
.45915 .64112 m
.47619 .64112 L
.47619 .62923 L
.45915 .62923 L
.45915 .64112 L
s
.45915 .62923 m
.47619 .62923 L
.47619 .61031 L
.45915 .61031 L
.45915 .62923 L
s
.45915 .61031 m
.47619 .61031 L
.47619 .58566 L
.45915 .58566 L
.45915 .61031 L
s
.45915 .58566 m
.47619 .58566 L
.47619 .55695 L
.45915 .55695 L
.45915 .58566 L
s
.45915 .55695 m
.47619 .55695 L
.47619 .52613 L
.45915 .52613 L
.45915 .55695 L
s
.45915 .52613 m
.47619 .52613 L
.47619 .49532 L
.45915 .49532 L
.45915 .52613 L
s
.45915 .49532 m
.47619 .49532 L
.47619 .46661 L
.45915 .46661 L
.45915 .49532 L
s
.45915 .46661 m
.47619 .46661 L
.47619 .44195 L
.45915 .44195 L
.45915 .46661 L
s
.45915 .44195 m
.47619 .44195 L
.47619 .42304 L
.45915 .42304 L
.45915 .44195 L
s
.45915 .42304 m
.47619 .42304 L
.47619 .41114 L
.45915 .41114 L
.45915 .42304 L
s
.45915 .41114 m
.47619 .41114 L
.47619 .40709 L
.45915 .40709 L
.45915 .41114 L
s
.45915 .40709 m
.47619 .40709 L
.47619 .41114 L
.45915 .41114 L
.45915 .40709 L
s
.45915 .41114 m
.47619 .41114 L
.47619 .42304 L
.45915 .42304 L
.45915 .41114 L
s
.45915 .42304 m
.47619 .42304 L
.47619 .44195 L
.45915 .44195 L
.45915 .42304 L
s
.45915 .44195 m
.47619 .44195 L
.47619 .46661 L
.45915 .46661 L
.45915 .44195 L
s
.45915 .46661 m
.47619 .46661 L
.47619 .49532 L
.45915 .49532 L
.45915 .46661 L
s
.45915 .49532 m
.47619 .49532 L
.47619 .52613 L
.45915 .52613 L
.45915 .49532 L
s
.45915 .52613 m
.47619 .52613 L
.47619 .55695 L
.45915 .55695 L
.45915 .52613 L
s
.45915 .55695 m
.47619 .55695 L
.47619 .58566 L
.45915 .58566 L
.45915 .55695 L
s
.45915 .58566 m
.47619 .58566 L
.47619 .61031 L
.45915 .61031 L
.45915 .58566 L
s
.45915 .61031 m
.47619 .61031 L
.47619 .62923 L
.45915 .62923 L
.45915 .61031 L
s
.45915 .62923 m
.47619 .62923 L
.47619 .64112 L
.45915 .64112 L
.45915 .62923 L
s
.45915 .64112 m
.47619 .64112 L
.47619 .64518 L
.45915 .64518 L
.45915 .64112 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .42857 m
.27246 .42857 L
s
% Start of user PostScript
0 -15. 52.2161 -15. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.27246 .42857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.2619 .5 L
s
% Start of user PostScript
0 0 50. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.2619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .57143 m
.27246 .57143 L
s
% Start of user PostScript
0 15. 52.2161 15. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.27246 .57143 Mdot
.039 .916 .04 r
.5 Mabswid
.27246 .42857 m
.30952 .43236 L
s
0 0 0 r
2 Mabswid
.30952 .43236 Mdot
.039 .916 .04 r
.5 Mabswid
.2619 .5 m
.30952 .5 L
s
0 0 0 r
2 Mabswid
.30952 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.27246 .57143 m
.30952 .56764 L
s
0 0 0 r
2 Mabswid
.30952 .56764 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .43236 m
.43973 .45273 L
s
% Start of user PostScript
60. -14.2042 87.3434 -9.92712 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.43973 .45273 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .5 m
.42996 .5 L
s
% Start of user PostScript
60. 0 85.2911 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.42996 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .56764 m
.42962 .54885 L
s
% Start of user PostScript
60. 14.2042 85.2199 10.2593 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.42962 .54885 Mdot
.039 .916 .04 r
.5 Mabswid
.43973 .45273 m
.47619 .46033 L
s
0 0 0 r
2 Mabswid
.47619 .46033 Mdot
.039 .916 .04 r
.5 Mabswid
.42996 .5 m
.47619 .50168 L
s
0 0 0 r
2 Mabswid
.47619 .50168 Mdot
.039 .916 .04 r
.5 Mabswid
.42962 .54885 m
.47619 .54259 L
s
0 0 0 r
2 Mabswid
.47619 .54259 Mdot
.039 .916 .04 r
.5 Mabswid
.47619 .46033 m
.97619 .62337 L
s
% Start of user PostScript
95. -8.33142 200. 25.9067 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .62337 Mdot
.039 .916 .04 r
.5 Mabswid
.47619 .50168 m
.97619 .5293 L
s
% Start of user PostScript
95. 0.352705 200. 6.15367 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .5293 Mdot
.039 .916 .04 r
.5 Mabswid
.47619 .54259 m
.97619 .43926 L
s
% Start of user PostScript
95. 8.94491 200. -12.7547 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .43926 Mdot
[(L2)] .45238 .36899 0 0 Mshowa
[(L1)] .28571 .34286 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo04<0oooo1@0000020?ooo`<00000`P3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`140?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
`@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo00<0oooo0P0000330?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo04<0oooo0`0000050?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07<0oooo1@0000000`3oool00000
0000000200000980oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0M03o
ool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000TP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`1:0?ooo`H000008`3oool3000000@0oooo0P00002C0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04X0oooo1P00002o0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04T0oooo0P00000407moO`030000
003oool0oooo0;d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0B@3o
ool2000000@0Ogmo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`180?ooo`030000001oOgl0000000D00000_`3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`180?ooo`030000001oOgl0000000@0Ogmo00<000000?oo
o`3oool0_@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`170?ooo`04
0000001oOgl0Ogmo000000@0Ogmo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`170?ooo`040000001oOgl0Ogmo000000@0Ogmo00<000000?oo
o`3oool0:03oool6000008l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0A`3oool010000000Ogmo07moO`00000407moO`030000003oool0oooo02P0oooo1P00002?0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04H0oooo00D0000007moO`1o
Ogl0Ogmo0000000407moO`030000003oool0oooo02L0oooo0P00000407moO`030000003oool0oooo
08d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0AP3oool010000000
Ogmo07moO`1oOgl6000002T0oooo0P00000407moO`030000003oool0oooo08d0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0?@3oool300WZ2PD0oooo00<0000007moO`1o
Ogl00P1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo02L0oooo0P00000407moO`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
?P3oool600WZ2P030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo
0?ooo`0V0?ooo`030000001oOgl0000000D00000S`3oool00`000000oooo0?ooo`050?ooo`001P3o
oom700WZ2P0300000009jPX02NX:00802NX:00<0Ogmo0000001oOgl00`1oOgl00`000000oooo0?oo
o`0V0?ooo`030000001oOgl0000000@0Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`0n0?ooo`D02NX:00<0oooo0000000000000`1oOgl5
00WZ2P0307moO`000000000002H0oooo00@0000007moO`1oOgl00000101oOgl00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03d0oooo0P09jPX5
0?ooo`030000001oOgl0Ogmo00<0Ogmo00@0000007moO`1oOgl0Ogmo1P09jPXS0?ooo`040000001o
Ogl0Ogmo000000@0Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`140?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1o
Ogl00`000000oooo0?ooo`020?ooo`L02NX:6`3oool01@000000Ogmo07moO`1oOgl0000000@0Ogmo
00<000000?ooo`3oool0Q03oool600WZ2P80oooo0P0000070?ooo`001P3oool00`000000oooo0?oo
o`140?ooo`030000001oOgl0Ogmo00<0Ogmo1P00000;0?ooo`P02NX:2P3oool200WZ2PL0oooo00@0
000007moO`1oOgl0Ogmo1P0000280?ooo`H02NX:0P0000070?ooo`001P3oool00`000000oooo0?oo
o`140?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?oo
o`0A0?ooo`P02NX:0P3oool500WZ2P@0oooo00D0000007moO`1oOgl0Ogmo0000000407moO`030000
003oool0oooo08H0oooo1P09jPX00`3oool000000?ooo`060?ooo`001P3oool00`000000oooo0?oo
o`140?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?oo
o`0I0?ooo`X02NX:00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0207moO`030000003o
ool0oooo0840oooo2009jPX40?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo04@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000003oool0
oooo01`0oooo1P09jPX0100000002NX:00WZ2P09jPX207moO`030000001oOgl0Ogmo0080Ogmo00<0
00000?ooo`3oool0O03oool500WZ2P@0oooo00<02NX:0?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`130?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00P1oOgl00`000000oooo0?ooo`0J0?ooo`D02NX:0`3oool200000080Ogmo0`09jPX4
07moO`030000003oool0oooo07L0oooo1@09jPXA0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo04<0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0207mo
O`030000003oool0oooo0280oooo00<0000007moO`1oOgl00`1oOgl01@0000002NX:00WZ2P09jPX0
Ogmo00800000L`3oool500WZ2QH0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0@`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo0080Ogmo00<000000?oo
o`3oool08P3oool00`000000Ogmo07moO`0307moO`040000001oOgl0Ogmo07moO`@02NX:K@3oool5
00WZ2Q/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0@`3oool00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool08P3oool00`00
0000Ogmo07moO`0307moO`H000000P3oool300WZ2VD0oooo1@09jPXP0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo04<0oooo00<0000007moO`1oOgl0101oOgl6000002<0
oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo00<0
oooo0`09jPYM0?ooo`D02NX:9@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`130?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo
0?ooo`0Q0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo
0?ooo`060?ooo`<02NX:E@3oool500WZ2RX0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0@`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo0080Ogmo00<0
00000?ooo`3oool08@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo0080Ogmo00<0
00000?ooo`3oool02@3oool300WZ2Td0oooo1@09jPX_0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo04<0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`02
07moO`030000003oool0oooo0240oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`02
07moO`030000003oool0oooo00`0oooo0`09jPY50?ooo`D02NX:=03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`120?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000oooo0?ooo`0P0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000oooo0?ooo`0?0?ooo`<02NX:?@3oool500WZ2ST0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0@P3oool00`000000Ogmo07moO`0507moO`03
0000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0803oool00`000000Ogmo07moO`0507moO`03
0000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool04P3oool300WZ2SD0oooo1@09jPXn0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0480oooo00<0000007moO`1oOgl0
1@1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo0200oooo00<0000007moO`1oOgl0
1@1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo01D0oooo1009jPX/0?ooo`D02NX:
@`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0j0?ooo`<02NX:1@3o
ool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0603o
ool300WZ2PD0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0207moO`030000003o
ool0oooo01T0oooo0`09jPXT0?ooo`D02NX:B03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`0k0?ooo`H02NX:0P00000707moO`030000001oOgl0Ogmo0080Ogmo0P00000J
0?ooo`H02NX:0P00000707moO`H000007P3oool300WZ2Q`0oooo1@09jPY=0?ooo`030000003oool0
oooo00D0oooo00060?oood@02NX:00<0000000WZ2P09jPX0;@09jPX00`0000002NX:00WZ2P0E00WZ
2QP0oooo0`09jPXD0?ooo`D02NX:DP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`0k0?ooo`D02NX:0P3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080
Ogmo00<000000?ooo`3oool06@3oool500WZ2P80oooo00<0000007moO`1oOgl01@1oOgl00`000000
Ogmo07moO`0207moO`800000203ooolB00WZ2PT0oooo0`09jPX<0?ooo`D02NX:E`3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0j0?ooo`802NX:1P3oool00`000000Ogmo
07moO`0507moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0603oool200WZ2PH0oooo
00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo01T0oooo
4P09jPX00`3oool02NX:00WZ2P0300WZ2U`0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0@P3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080Ogmo00<0
00000?ooo`3oool0803oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080Ogmo00<0
00000?ooo`3oool09`3ooolF00WZ2U00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0@P3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080Ogmo00<00000
0?ooo`3oool0803oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080Ogmo00<00000
0?ooo`3oool08P3oool500WZ2P@0oooo1009jPX>0?oooa802NX:?P3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`120?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000oooo0?ooo`0P0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000oooo0?ooo`0M0?ooo`D02NX:3@3oool300WZ2Qd0oooo4P09jPX/0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04<0oooo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo0200oooo00<0000007moO`1o
Ogl01@1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo01P0oooo1@09jPXE0?ooo`<0
2NX:;03ooolB00WZ2Q80oooo0`09jPX50?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo04<0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0207moO`030000
003oool0oooo0200oooo3P00000E0?ooo`D02NX:7@3oool300WZ2S/0oooo4P09jPX00`3oool02NX:
00WZ2P0400WZ2P030?ooo`000000oooo00H0oooo00060?ooo`030000003oool0oooo04<0oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo0200oooo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo00h0oooo1@09
jPXU0?ooo`<02NX:BP3oool700WZ2P8000001`3oool000H0oooo00<000000?ooo`3oool0@`3oool0
0`000000Ogmo07moO`0407moO`H000008P3oool00`000000Ogmo07moO`0507moO`030000001oOgl0
Ogmo0080Ogmo00<000000?ooo`3oool02@3oool500WZ2Rd0oooo0`09jPY80?ooo`D02NX:00<0oooo
0000000000001`3oool000H0oooo00<000000?ooo`3oool0@`3oool00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0803oool00`000000Ogmo07moO`0507mo
O`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0103oool500WZ2SD0oooo0`09jPY40?oo
o`802NX:1P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`130?ooo`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0P0?ooo`03
0000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo00WZ2P0400WZ2Sd0
oooo0`09jPY90?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04<0oooo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo0200oooo
00<0000007moO`1oOgl01@1oOgl00`000000Ogmo00WZ2P0400WZ2TD0oooo1009jPY50?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04<0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0207moO`030000003oool0oooo01P0oooo1@09jPX30?ooo`030000001o
Ogl0Ogmo00L02NX:0`1oOgl2000004T0oooo0`09jPY20?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo04<0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`02
07moO`030000003oool0oooo01T0oooo1P09jPX0100000002NX:00WZ2P09jPX507moO`030000001o
Ogl0Ogmo0080Ogmo00<000000?ooo`3oool0B`3oool300WZ2Sl0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0A03oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo0080Ogmo00<000000?ooo`3oool05P3oool900WZ2P8000001`1oOgl00`000000Ogmo07moO`02
07moO`030000003oool0oooo04h0oooo0`09jPXl0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo04@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207mo
O`030000003oool0oooo00l0oooo1`09jPX30?ooo`<02NX:103oool00`000000Ogmo07moO`0507mo
O`H00000D`3oool300WZ2ST0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0A03oool00`000000Ogmo07moO`0307moO`H000002P3oool700WZ2PT0oooo00<02NX:0?ooo`3o
ool01@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3o
ool0E03oool300WZ2SH0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
?@3oool300WZ2P@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`040000
003oool0oooo0?ooo`L02NX:603oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080
Ogmo00<000000?ooo`3oool0E`3oool300WZ2S<0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0?P3oool600WZ2P030000001oOgl0Ogmo00<0Ogmo2@09jPXO0?ooo`030000
001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`1J0?ooo`<02NX:
<03oool00`000000oooo0?ooo`050?ooo`001P3ooom700WZ2P0300000009jPX02NX:00<02NX:00<0
000007moO`1oOgl00P1oOgl200000240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07mo
O`0207moO`030000003oool0oooo05d0oooo1009jPX/0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo03h0oooo1@09jPX00`3oool000000000000407moO`030000001oOgl0
Ogmo0080Ogmo00<000000?ooo`3oool0803oool00`000000Ogmo07moO`0507moO`030000001oOgl0
Ogmo0080Ogmo00<000000?ooo`3oool0H@3oool300WZ2RT0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0?@3oool200WZ2PH0oooo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0207moO`030000003oool0oooo0240oooo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0207moO`030000003oool0oooo06@0oooo0`09jPXV0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo04D0oooo00<0000007moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0207moO`030000003oool0oooo0240oooo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0207moO`030000003oool0oooo06L0oooo0`09jPXS0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo04D0oooo00<0000007moO`1oOgl00P1oOgl6000002<0oooo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo06X0oooo
0`09jPXP0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04H0oooo00D0
000007moO`1oOgl0Ogmo0000000407moO`030000003oool0oooo0280oooo00<0000007moO`1oOgl0
0`1oOgl6000006l0oooo0`09jPXM0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo04H0oooo00D0000007moO`1oOgl0Ogmo0000000407moO`030000003oool0oooo0280oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo0700oooo
0`09jPXJ0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04L0oooo00@0
000007moO`1oOgl00000101oOgl00`000000oooo0?ooo`0R0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`1c0?ooo`@02NX:5P3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`170?ooo`040000001oOgl0Ogmo000000@0Ogmo
00<000000?ooo`3oool08P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo
00<000000?ooo`3oool0M`3oool300WZ2Q<0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0B03oool00`000000Ogmo0000000407moO`030000003oool0oooo02<0oooo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo07X0oooo0`09
jPX@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04P0oooo00<00000
07moO`0000001@00000U0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00P1oOgl0
0`000000oooo0?ooo`1m0?ooo`<02NX:3@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`180?ooo`030000001oOgl0000000@0Ogmo00<000000?ooo`3oool08`3oool00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0P03oool300WZ
2P<0oooo0P09jPX50?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04T0
oooo0P00000407moO`030000003oool0oooo02@0oooo00@0000007moO`1oOgl0Ogmo1P0000250?oo
o`L02NX:0`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`190?ooo`L0
00009P3oool01@000000Ogmo07moO`1oOgl0000000@0Ogmo00<000000?ooo`3oool0QP3oool500WZ
2P80oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0BP3oool6000002H0
oooo00D0000007moO`1oOgl0Ogmo0000000407moO`030000003oool0oooo08H0oooo1`09jPX00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1g0?ooo`040000001oOgl0Ogmo0000
00@0Ogmo00<000000?ooo`3oool0Q03oool800WZ2P8000001`3oool000H0oooo00<000000?ooo`3o
ool0M`3oool010000000Ogmo07moO`00000407moO`030000003oool0oooo08`0oooo0P0000070?oo
o`001P3oool00`000000oooo0?ooo`1h0?ooo`030000001oOgl0000000D00000S`3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1h0?ooo`030000001oOgl0000000@0Ogmo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`1i0?ooo`800000101oOgl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo07T0oooo1`00002?0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo07T0oooo0P00000407moO`030000003oool0oooo08d0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0NP3oool6000008l0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo0P00003o0?oo
oa40oooo00<000000?ooo`3oool01@3oool000H0ooooo`00000D000000L0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00105, -105.001, 0.731715, \
0.731715}},
  CellTags->"Scripted Moves"],

Cell[BoxData[
    TagBox[\(DrawSystem[{LineOfRays[30], 
          Move[PlanoConvexLens[100, 50, 10], 50.`], 
          Move[PlanoConvexLens[100, 50, 10], {85.`, 5.488`}], 
          Boundary[{0, \(-100\), \(-100\)}, {200, 100, 100}]}, 
        PlotType \[Rule] TopView]\),
      HoldForm]], "Print",
  CellTags->"Scripted Moves"],

Cell[BoxData[
    \("-15 ray/surface intersections-"\)], "Output",
  CellTags->"Scripted Moves"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{939, 693},
WindowMargins->{{1, Automatic}, {Automatic, 7}},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CustomPrism"->{
    Cell[1776, 53, 86, 1, 46, "Subsection",
      CellTags->"CustomPrism"],
    Cell[1865, 56, 415, 13, 60, "Text",
      CellTags->"CustomPrism"],
    Cell[2283, 71, 65, 1, 39, "Input",
      CellTags->"CustomPrism"],
    Cell[2351, 74, 76, 1, 39, "Input",
      CellTags->"CustomPrism"],
    Cell[2452, 79, 56, 1, 39, "Input",
      CellTags->"CustomPrism"],
    Cell[2511, 82, 451, 7, 94, "Print",
      CellTags->"CustomPrism"],
    Cell[2999, 94, 85, 1, 39, "Input",
      CellTags->"CustomPrism"],
    Cell[3087, 97, 64229, 1347, 308, 10833, 683, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"CustomPrism"],
    Cell[67353, 1449, 99, 1, 39, "Input",
      CellTags->"CustomPrism"],
    Cell[67455, 1452, 314, 9, 38, "Output",
      CellTags->"CustomPrism"],
    Cell[67806, 1466, 123, 4, 39, "Input",
      CellTags->"CustomPrism"],
    Cell[67932, 1472, 100, 3, 38, "Output",
      CellTags->"CustomPrism"],
    Cell[68069, 1480, 259, 11, 159, "Input",
      CellTags->"CustomPrism"],
    Cell[68331, 1493, 197078, 3825, 497, 23634, 1679, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"CustomPrism"],
    Cell[265446, 5323, 214, 9, 129, "Input",
      CellTags->"CustomPrism"],
    Cell[265663, 5334, 242454, 6725, 571, 75951, 4664, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"CustomPrism"],
    Cell[508154, 12064, 82, 1, 39, "Input",
      CellTags->"CustomPrism"],
    Cell[508239, 12067, 335732, 6852, 502, 37864, 3169, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"CustomPrism"],
    Cell[844008, 18924, 89, 1, 39, "Input",
      CellTags->"CustomPrism"],
    Cell[844100, 18927, 345953, 11940, 386, 155644, 9586, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"CustomPrism"]},
  "CustomFiber"->{
    Cell[1190102, 30873, 111, 2, 30, "Subsection",
      CellTags->"CustomFiber"],
    Cell[1190238, 30879, 56, 1, 39, "Input",
      CellTags->"CustomFiber"],
    Cell[1190297, 30882, 974, 14, 169, "Print",
      CellTags->{"Info3251466833-6576689", "CustomFiber"}],
    Cell[1191308, 30901, 62, 1, 39, "Input",
      CellTags->"CustomFiber"],
    Cell[1191373, 30904, 737, 10, 154, "Print",
      CellTags->{"Info3251466841-4933577", "CustomFiber"}],
    Cell[1192125, 30917, 286, 8, 99, "Input",
      CellTags->"CustomFiber"],
    Cell[1192436, 30929, 170, 5, 39, "Input",
      CellTags->"CustomFiber"],
    Cell[1192609, 30936, 33056, 913, 308, 6984, 586, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"CustomFiber"],
    Cell[1225668, 31851, 788, 15, 70, "Output",
      CellTags->"CustomFiber"],
    Cell[1226493, 31871, 160, 4, 54, "Input",
      CellTags->"CustomFiber"],
    Cell[1226656, 31877, 78779, 2561, 308, 29780, 1951, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"CustomFiber"],
    Cell[1305438, 34440, 87, 2, 38, "Output",
      CellTags->"CustomFiber"]},
  "Info3251466833-6576689"->{
    Cell[1190297, 30882, 974, 14, 169, "Print",
      CellTags->{"Info3251466833-6576689", "CustomFiber"}]},
  "Info3251466841-4933577"->{
    Cell[1191373, 30904, 737, 10, 154, "Print",
      CellTags->{"Info3251466841-4933577", "CustomFiber"}]},
  "Scripted Moves"->{
    Cell[1305574, 34448, 66, 1, 30, "Subsection",
      CellTags->"Scripted Moves"],
    Cell[1305665, 34453, 161, 5, 27, "Input",
      CellTags->"Scripted Moves"],
    Cell[1305829, 34460, 30866, 772, 296, 6234, 462, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Scripted Moves"],
    Cell[1336698, 35234, 266, 6, 37, "Print",
      CellTags->"Scripted Moves"],
    Cell[1336967, 35242, 95, 2, 26, "Output",
      CellTags->"Scripted Moves"],
    Cell[1337099, 35249, 136, 4, 27, "Input",
      CellTags->"Scripted Moves"],
    Cell[1337238, 35255, 30980, 769, 296, 6571, 462, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Scripted Moves"],
    Cell[1368221, 36026, 276, 6, 37, "Print",
      CellTags->"Scripted Moves"],
    Cell[1368500, 36034, 95, 2, 26, "Output",
      CellTags->"Scripted Moves"],
    Cell[1368632, 36041, 155, 4, 42, "Input",
      CellTags->"Scripted Moves"],
    Cell[1368790, 36047, 30213, 743, 296, 6168, 440, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Scripted Moves"],
    Cell[1399006, 36792, 323, 7, 37, "Print",
      CellTags->"Scripted Moves"],
    Cell[1399332, 36801, 95, 2, 26, "Output",
      CellTags->"Scripted Moves"],
    Cell[1399464, 36808, 136, 4, 27, "Input",
      CellTags->"Scripted Moves"],
    Cell[1399603, 36814, 40807, 1155, 296, 10707, 777, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Scripted Moves"],
    Cell[1440413, 37971, 329, 7, 37, "Print",
      CellTags->"Scripted Moves"],
    Cell[1440745, 37980, 96, 2, 26, "Output",
      CellTags->"Scripted Moves"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CustomPrism", 1441654, 38005},
  {"CustomFiber", 1443512, 38053},
  {"Info3251466833-6576689", 1444655, 38080},
  {"Info3251466841-4933577", 1444794, 38083},
  {"Scripted Moves", 1444925, 38086}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 86, 1, 46, "Subsection",
  CellTags->"CustomPrism"],
Cell[1865, 56, 415, 13, 60, "Text",
  CellTags->"CustomPrism"],
Cell[2283, 71, 65, 1, 39, "Input",
  CellTags->"CustomPrism"],
Cell[2351, 74, 76, 1, 39, "Input",
  CellTags->"CustomPrism"],

Cell[CellGroupData[{
Cell[2452, 79, 56, 1, 39, "Input",
  CellTags->"CustomPrism"],
Cell[2511, 82, 451, 7, 94, "Print",
  CellTags->"CustomPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2999, 94, 85, 1, 39, "Input",
  CellTags->"CustomPrism"],
Cell[3087, 97, 64229, 1347, 308, 10833, 683, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"CustomPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67353, 1449, 99, 1, 39, "Input",
  CellTags->"CustomPrism"],
Cell[67455, 1452, 314, 9, 38, "Output",
  CellTags->"CustomPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67806, 1466, 123, 4, 39, "Input",
  CellTags->"CustomPrism"],
Cell[67932, 1472, 100, 3, 38, "Output",
  CellTags->"CustomPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68069, 1480, 259, 11, 159, "Input",
  CellTags->"CustomPrism"],
Cell[68331, 1493, 197078, 3825, 497, 23634, 1679, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"CustomPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[265446, 5323, 214, 9, 129, "Input",
  CellTags->"CustomPrism"],
Cell[265663, 5334, 242454, 6725, 571, 75951, 4664, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"CustomPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[508154, 12064, 82, 1, 39, "Input",
  CellTags->"CustomPrism"],
Cell[508239, 12067, 335732, 6852, 502, 37864, 3169, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"CustomPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[844008, 18924, 89, 1, 39, "Input",
  CellTags->"CustomPrism"],
Cell[844100, 18927, 345953, 11940, 386, 155644, 9586, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"CustomPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1190102, 30873, 111, 2, 30, "Subsection",
  CellTags->"CustomFiber"],

Cell[CellGroupData[{
Cell[1190238, 30879, 56, 1, 39, "Input",
  CellTags->"CustomFiber"],
Cell[1190297, 30882, 974, 14, 169, "Print",
  CellTags->{"Info3251466833-6576689", "CustomFiber"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[1191308, 30901, 62, 1, 39, "Input",
  CellTags->"CustomFiber"],
Cell[1191373, 30904, 737, 10, 154, "Print",
  CellTags->{"Info3251466841-4933577", "CustomFiber"}]
}, Open  ]],
Cell[1192125, 30917, 286, 8, 99, "Input",
  CellTags->"CustomFiber"],

Cell[CellGroupData[{
Cell[1192436, 30929, 170, 5, 39, "Input",
  CellTags->"CustomFiber"],
Cell[1192609, 30936, 33056, 913, 308, 6984, 586, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"CustomFiber"],
Cell[1225668, 31851, 788, 15, 70, "Output",
  CellTags->"CustomFiber"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1226493, 31871, 160, 4, 54, "Input",
  CellTags->"CustomFiber"],
Cell[1226656, 31877, 78779, 2561, 308, 29780, 1951, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"CustomFiber"],
Cell[1305438, 34440, 87, 2, 38, "Output",
  CellTags->"CustomFiber"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1305574, 34448, 66, 1, 30, "Subsection",
  CellTags->"Scripted Moves"],

Cell[CellGroupData[{
Cell[1305665, 34453, 161, 5, 27, "Input",
  CellTags->"Scripted Moves"],
Cell[1305829, 34460, 30866, 772, 296, 6234, 462, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"Scripted Moves"],
Cell[1336698, 35234, 266, 6, 37, "Print",
  CellTags->"Scripted Moves"],
Cell[1336967, 35242, 95, 2, 26, "Output",
  CellTags->"Scripted Moves"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1337099, 35249, 136, 4, 27, "Input",
  CellTags->"Scripted Moves"],
Cell[1337238, 35255, 30980, 769, 296, 6571, 462, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"Scripted Moves"],
Cell[1368221, 36026, 276, 6, 37, "Print",
  CellTags->"Scripted Moves"],
Cell[1368500, 36034, 95, 2, 26, "Output",
  CellTags->"Scripted Moves"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1368632, 36041, 155, 4, 42, "Input",
  CellTags->"Scripted Moves"],
Cell[1368790, 36047, 30213, 743, 296, 6168, 440, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"Scripted Moves"],
Cell[1399006, 36792, 323, 7, 37, "Print",
  CellTags->"Scripted Moves"],
Cell[1399332, 36801, 95, 2, 26, "Output",
  CellTags->"Scripted Moves"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1399464, 36808, 136, 4, 27, "Input",
  CellTags->"Scripted Moves"],
Cell[1399603, 36814, 40807, 1155, 296, 10707, 777, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"Scripted Moves"],
Cell[1440413, 37971, 329, 7, 37, "Print",
  CellTags->"Scripted Moves"],
Cell[1440745, 37980, 96, 2, 26, "Output",
  CellTags->"Scripted Moves"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

