(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    826563,      13764]
NotebookOptionsPosition[    825554,      13724]
NotebookOutlinePosition[    826171,      13749]
CellTagsIndexPosition[    826083,      13744]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["CustomGrid\n", "Subtitle"],
 "\n",
 StyleBox["CustomGrid can model many types of distributed calculations \nin \
bulk media:including gain and absorption for lasers.\[NonBreakingSpace] \n\
CustomGrid can also be used to measure intensity distributions on optical \
surfaces and  pixelated sensors such as CCD arrays \nas well as non-linear \
optical behaviors om bulk media such as frequency doublers.This simple \
example\nuses this new functionality to model absorption through a slab \
crystal in one dimension, \nwhere the light enters the slab on the left side \
that is then reflected off a mirror on the right side of the slab. \nBelow  \
is an interactive model that allows you to dynamically change the absorption \
constant for the material and then \n observe the absorption profile in the \
slab. ", "Text"],
 "\n\n\n?CustomGrid"
}], "Input",
 CellChangeTimes->{{3.5986212312846613`*^9, 3.598621231456112*^9}, {
  3.614737846579417*^9, 3.614738070044798*^9}, {3.614738106389058*^9, 
  3.614738140786085*^9}},
 FormatType->"TextForm"],

Cell[BoxData[
 StyleBox["\<\"CustomGrid[component, gridparameter, gridboundary, options] is \
a generic building block that models gain, absorption, or custom-defined \
actions at a surface or inside a volume within the ray-trace calculation.\\n \
\\nThe gridparameter is a user-defined variable name. When the option \
EmbedGridData->False is used, CustomGrid incorporates the gridparameter \
variable name as an input variable of the RayTraceFunction and numeric data \
points must be provided at the start of the ray-trace operation either \
through SymbolicValues setting or given directly to the RayTraceFunction. \
When the option EmbedGridData->True is used, the gridparameter data is \
embedded within the ray-trace function calculation along with the \
SymbolicValues setting for gridparameter variable and is not provided as an \
input parameter.\\n \\nThe gridboundary parameter specifies the dimensions of \
a rectangular bounding box that encloses the gridspace. The gridboundary \
parameter accepts the same types of patterns as the Boundary function.\\n \
\\nDuring a CustomGrid calculation, there are three internal function calls \
that can be invoked: GridFunction, ReportedFunction, and \
CustomDisplayFunction. CustomGrid uses the GridFunction setting to apply a \
custom-defined interaction between the gridparameter data and the traced rays \
that pass through a particular grid voxel in space. ReportedFunction is used \
to apply a final tranformation on the gridparameter data at the end of the \
ray-trace calculation. Finally, CustomDisplayFunction is an external \
tranformation passed to ManipulateSystem for rendering of the gridparameter \
data.\\n \\nSee also: GridFunction, EmbedGridData, GridOrder, GridDimensions, \
CustomDisplayFunction, ReportedFunction, and GridCoordinateOffset.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.614710349385501*^9},
 CellTags->"Info3614692349-3788911"]
}, Open  ]],

Cell[CellGroupData[{

Cell["?GridFunction", "Input",
 CellChangeTimes->{{3.598621236070503*^9, 3.598621236266115*^9}}],

Cell[BoxData[
 StyleBox["\<\"GridFunction -> function provides a function that determines \
the gain, absorption, and other custom behaviors for each element within a \
predefined grid space within an optical component during a ray-trace \
calculation.\\n \\nThe input parameter to the gain function is given 10 \
parameters although not all parameters need be employed by the function. For \
three-dimensional grid functions, the first three parameters are indices to \
the affected gain grid element. For two-dimensional grid functions, the first \
two parameters are indices to the affected gain grid element. For \
one-dimensional grid functions, the first parameter is an index to the \
affected gain grid element. The next parameter is the distance of the ray \
traversing across the gird element. The remaining 6 parameters are the \
starting and ending coordinates of the ray that passes through a given grid \
element volume. In addition, the gain function may also reference any number \
of internal ray-parameters such as RayStart, RayEnd, Intensity, RayLength, \
WaveLength, and Polarization. The grid function may change any ray parameter \
as well as the gridparameter name originally specified with the CustomGrid \
function. Any changed Ray parameter element such as Intensity or the \
gridparameter parameter will be used for the subsequent ray-gain grid \
interactions.\\n \\nSee also: CustomGrid, EmbedGridData, GridOrder, \
GridDimensions, CustomDisplayFunction, ReportedFunction, and \
GridCoordinateOffset.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.614710349825076*^9},
 CellTags->"Info3614692349-3788911"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
gainslab = CustomGrid[SlabPrism[10], griddata, 9, \
SymbolicValues->{griddata->{{Table[0.,{20}]}},absorp->0.1},
\tGridFunction->Function[griddata[[#3,#2,#1]]=griddata[[#3,#2,#1]]+Intensity*\
Exp[-#4/absorp]; Intensity = Intensity*(1.-Exp[-#4/absorp])], 
\t\tEmbedGridData->True, ReportedFunction->Hold[Reverse[griddata[[1,1]]]]]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.597237958709096*^9, 3.597237996842471*^9}, {
   3.597238330810791*^9, 3.597238335507229*^9}, {3.597238688536249*^9, 
   3.597238707368928*^9}, {3.597239042671205*^9, 3.597239076850318*^9}, {
   3.597239171591176*^9, 3.597239180812758*^9}, {3.5973441527811117`*^9, 
   3.5973442199616823`*^9}, {3.597381816363407*^9, 3.597381881967244*^9}, 
   3.5973823970689163`*^9, {3.59738363048591*^9, 3.597383634595129*^9}, {
   3.5973843277122107`*^9, 3.59738434308495*^9}, {3.597411462492382*^9, 
   3.597411467491835*^9}, {3.597457999497156*^9, 3.597458018967382*^9}, {
   3.597632038733914*^9, 3.597632058548106*^9}, {3.597632217099813*^9, 
   3.597632251225375*^9}, {3.597633026177422*^9, 3.597633037359619*^9}, {
   3.597634057038965*^9, 3.5976340779855013`*^9}, {3.5976354605428457`*^9, 
   3.597635517602868*^9}, 3.597935028617187*^9, {3.5979350824619427`*^9, 
   3.597935114386157*^9}, 3.597935437634905*^9, {3.5979372170759993`*^9, 
   3.597937221426099*^9}, {3.5979437424467907`*^9, 3.597943742789399*^9}, {
   3.597949982146311*^9, 3.597949991221162*^9}, {3.598018682495386*^9, 
   3.598018685071406*^9}, {3.5983586945572042`*^9, 3.5983587019643383`*^9}, {
   3.5986167063493357`*^9, 3.598616708300345*^9}, {3.598616749468322*^9, 
   3.598616781307159*^9}, {3.598616822165442*^9, 3.598616905136224*^9}, {
   3.59861694510306*^9, 3.5986170016457233`*^9}, {3.598617139222601*^9, 
   3.598617172014608*^9}, {3.598617685355007*^9, 3.598617707574271*^9}, {
   3.598617770991014*^9, 3.598617773188614*^9}, {3.5986178250202436`*^9, 
   3.598617990576351*^9}, {3.598618023555862*^9, 3.5986180278039827`*^9}, {
   3.598618096492874*^9, 3.598618104916382*^9}, {3.598618152205185*^9, 
   3.598618265855753*^9}, {3.598618297071982*^9, 3.5986183010146933`*^9}, {
   3.598618331216523*^9, 3.598618331831071*^9}, {3.5986183899972353`*^9, 
   3.598618421563044*^9}, {3.5986185009868507`*^9, 3.5986185068896914`*^9}, {
   3.598618653682613*^9, 3.59861868614471*^9}, {3.598618738921391*^9, 
   3.598618743985243*^9}, 3.5986188285199137`*^9, {3.598618866776342*^9, 
   3.598618867838866*^9}, {3.5986190004339447`*^9, 3.598619028792245*^9}, {
   3.598619362025923*^9, 3.598619365008605*^9}, {3.5986197342580957`*^9, 
   3.598619747121016*^9}, {3.598619955573572*^9, 3.598619962068234*^9}, 
   3.598620032682416*^9, {3.598620156507202*^9, 3.598620164738914*^9}, 
   3.598621062515483*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"CustomGrid", "[", 
     RowBox[{
      RowBox[{"SlabPrism", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "5"}], ",", 
          RowBox[{"-", "5"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"10", ",", "5", ",", "5"}], "}"}]}], "]"}], ",", "griddata", 
      ",", "9", ",", 
      RowBox[{"SymbolicValues", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"absorp", "\[Rule]", "0.1`"}], "}"}]}], ",", 
      RowBox[{"GridFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"griddata", "\[LeftDoubleBracket]", 
             RowBox[{"#3", ",", "#2", ",", "#1"}], "\[RightDoubleBracket]"}], 
            "=", 
            RowBox[{
             RowBox[{"griddata", "\[LeftDoubleBracket]", 
              RowBox[{"#3", ",", "#2", ",", "#1"}], "\[RightDoubleBracket]"}],
              "+", 
             RowBox[{"Intensity", " ", 
              RowBox[{"Exp", "[", 
               RowBox[{"-", 
                FractionBox["#4", "absorp"]}], "]"}]}]}]}], ";", 
           RowBox[{"Intensity", "=", 
            RowBox[{"Intensity", " ", 
             RowBox[{"(", 
              RowBox[{"1.`", "\[VeryThinSpace]", "-", 
               RowBox[{"Exp", "[", 
                RowBox[{"-", 
                 FractionBox["#4", "absorp"]}], "]"}]}], ")"}]}]}]}], ")"}], 
         "&"}], ")"}]}], ",", 
      RowBox[{"EmbedGridData", "\[Rule]", "True"}], ",", 
      RowBox[{"ReportedFunction", "\[Rule]", 
       RowBox[{"Hold", "[", 
        RowBox[{"Reverse", "[", 
         RowBox[{"griddata", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "]"}], 
        "]"}]}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.598619757020926*^9, 3.598619834012817*^9, 
  3.598619964750908*^9, 3.598620165995583*^9, 3.61471035043613*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ManipulateSystem[{Move[SingleRay[],0,0],Resonate[{Move[gainslab,5],Move[\
Mirror[{10,10}],16,5]}],Boundary[20]},
\t{DynamicFrame[OpticalSystem->{Move[LineOfRays[3,NumberOfRays->11],0,0],\
Resonate[{Move[SlabPrism[10],5],Move[Mirror[{10,10}],16,5]}],Boundary[20]},\
PlotType->TopView],DynamicFrame[PlotType->ListPlot,PlotLabel->\"Absorption\",\
DataRange->{0,10},
\tPlotRange->{0,All},AspectRatio->0.6]},ArrangeSystem->False]\
\>", "Input",
 CellChangeTimes->{{3.59861907189555*^9, 3.59861907603083*^9}, {
   3.5986192376173153`*^9, 3.598619243843154*^9}, {3.598619323601527*^9, 
   3.598619326269944*^9}, {3.5986195567035427`*^9, 3.598619644024191*^9}, {
   3.598619848748253*^9, 3.5986198511948767`*^9}, {3.5986200267348623`*^9, 
   3.598620132315246*^9}, {3.598620263843527*^9, 3.598620286210291*^9}, {
   3.5986205657846117`*^9, 3.598620683654751*^9}, {3.598620715446212*^9, 
   3.598620768892735*^9}, 3.598620803614503*^9, 3.5986208399808807`*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`absorp$$ = 0.1, $CellContext`maxabsorp$$ = 
    0.2, $CellContext`minabsorp$$ = 
    0.001, $CellContext`staticpolygons11176182014718171235803560$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
      
      "]]}, $CellContext`staticpolygons12176182014718171235804694$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4tYzsw378w0cWnn7A1reCB+QusoY8j3GwGHW
A0XnvFkCB9bdTS+L9zJwiE3PzN4wgeuA87OzM46bw9QzH7j+zni3vqqBQxxY
/tf+nO8z704XMnBIAvNf7WcAAwMHBijQFDzjcuGWvkMURN4+SGlG54KtMP4v
+2rjlHMFE/QdmiHmOyxxMRB2zIbJczmcDf0TLuim7zAT4j6Hb2kn5jxU0Ie5
H4MPUw/1D9w8qH8cYPZB/eMAcw/UP/Yw90L9Y4/un2yof6H+2Q8LD6h/9jtB
wwvqH3h4Qv0DD2+ofw6gxwc6HwCMJ7VM
      
      "]]}, $CellContext`staticpolygons13176182014718171235805802$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
      "]]}, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`absorp$$], 0.1}, 0.001, 0.2}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {
      Hold[
       Style[
        Grid[{{"absorp", 
           InputField[
            Dynamic[$CellContext`minabsorp$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable1593176182014718171241473529; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ], {
             Dynamic[$CellContext`minabsorp$$], 
             Dynamic[$CellContext`maxabsorp$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxabsorp$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable1593176182014718171241473529; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{"absorp"}, {$CellContext`absorp$$}}], 
           Optica`Optica`SymbolicRanges -> Map[ToExpression[
               Part[#, 1]] -> {
               Part[#, 2], 
               Part[#, 3]}& , 
             Select[
              
              Transpose[{{
                "absorp"}, {$CellContext`minabsorp$$}, \
{$CellContext`maxabsorp$$}}], NumberQ[
               Part[#, 2]]& ]]}; 
        Optica`Optica`$OpticalSystemScript = 
         "{SingleRay[], Resonate[{CustomGrid[Move[SlabPrism[{0, -5, -5}, {10, \
5, 5}], 5.], griddata, 9, SymbolicValues -> {absorp -> 0.1}, GridFunction -> \
((griddata[[#3,#2,#1]] = griddata[[#3,#2,#1]] + Intensity*Exp[-(#4/absorp)]; \
Intensity = Intensity*(1. - Exp[-(#4/absorp)])) & ), EmbedGridData -> True, \
ReportedFunction -> Hold[Reverse[griddata[[1,1]]]]], Move[Mirror[{10, 10}], \
16., 4.999999999999999]}], Boundary[{0, -10, -10}, {20, 10, 10}]}"; Print[
          InputForm[
           StringJoin["{SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "absorp"}, {$CellContext`absorp$$}}]], ", SymbolicRanges -> ", 
            
            ToString[
             Map[StringJoin[
               Part[#, 1], "->", 
               ToString[{
                 Part[#, 2], 
                 Part[#, 3]}, InputForm]]& , 
              Select[
               
               Transpose[{{
                 "absorp"}, {$CellContext`minabsorp$$}, \
{$CellContext`maxabsorp$$}}], NumberQ[
                Part[#, 2]]& ]]], "}"]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`staticpolygons11176182014718171235803560$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
         "]]}}}, {{
       Hold[$CellContext`staticpolygons12176182014718171235804694$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4tYzsw378w0cWnn7A1reCB+QusoY8j3GwGHW
A0XnvFkCB9bdTS+L9zJwiE3PzN4wgeuA87OzM46bw9QzH7j+zni3vqqBQxxY
/tf+nO8z704XMnBIAvNf7WcAAwMHBijQFDzjcuGWvkMURN4+SGlG54KtMP4v
+2rjlHMFE/QdmiHmOyxxMRB2zIbJczmcDf0TLuim7zAT4j6Hb2kn5jxU0Ie5
H4MPUw/1D9w8qH8cYPZB/eMAcw/UP/Yw90L9Y4/un2yof6H+2Q8LD6h/9jtB
wwvqH3h4Qv0DD2+ofw6gxwc6HwCMJ7VM
         "]]}}}, {{
       Hold[$CellContext`staticpolygons13176182014718171235805802$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
         "]]}}}}, Typeset`size$$ = {
    816., {433.625, 439.375}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`absorp$8827$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`absorp$$ = 0.1, $CellContext`maxabsorp$$ = 
        0.2, $CellContext`minabsorp$$ = 
        0.001, $CellContext`staticpolygons11176182014718171235803560$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
           
           "]]}, $CellContext`staticpolygons12176182014718171235804694$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4tYzsw378w0cWnn7A1reCB+QusoY8j3GwGHW
A0XnvFkCB9bdTS+L9zJwiE3PzN4wgeuA87OzM46bw9QzH7j+zni3vqqBQxxY
/tf+nO8z704XMnBIAvNf7WcAAwMHBijQFDzjcuGWvkMURN4+SGlG54KtMP4v
+2rjlHMFE/QdmiHmOyxxMRB2zIbJczmcDf0TLuim7zAT4j6Hb2kn5jxU0Ie5
H4MPUw/1D9w8qH8cYPZB/eMAcw/UP/Yw90L9Y4/un2yof6H+2Q8LD6h/9jtB
wwvqH3h4Qv0DD2+ofw6gxwc6HwCMJ7VM
           
           "]]}, $CellContext`staticpolygons13176182014718171235805802$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
           "]]}}, 
      "ControllerVariables" :> {
        Hold[$CellContext`absorp$$, $CellContext`absorp$8827$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         TabView[{"TopView" -> Show[{
              Graphics[{{
                 Opacity[
                 0.8], $CellContext`staticpolygons11176182014718171235803560$$\
, $CellContext`staticpolygons12176182014718171235804694$$, \
$CellContext`staticpolygons13176182014718171235805802$$, 
                 Opacity[1], 
                 RGBColor[
                 0.038747429704798886`, 0.9161617552424038, 
                  0.039847212269181365`], 
                 AbsoluteThickness[Medium], 
                 Line[
                  Dynamic[
                   Refresh[
                    Map[{
                    Part[#, {1, 2}], 
                    Part[#, {4, 5}]}& , 
                    Select[
                    $CellContext`raytracefunction1176182014718171235807134[], 
                    And[Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]], 
                    TrackedSymbols :> {}], SynchronousUpdating -> 
                   False]]}}]}, {
             PlotLabel -> "TopView", ImageSize -> 800, AspectRatio -> 
              Automatic}], "Absorption" -> Dynamic[
             ListPlot[
              
              Apply[$CellContext`rayfunction2176182014718171241466160, \
{$CellContext`absorp$$}], {
              PlotLabel -> "Absorption", DataRange -> {0, 10}, 
               PlotRange -> {0, All}, AspectRatio -> 0.6, Frame -> True, Axes -> 
               True, Mesh -> False, ImageSize -> 800, Joined -> True}], 
             SynchronousUpdating -> True]}, 1], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`absorp$$, 0.1}, 0.001, 0.2, 
         ControlType -> None}, {{$CellContext`minabsorp$$, 0.001}, 
         ControlType -> None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> 
         None}, 
        Style[
         Grid[{{"absorp", 
            InputField[
             Dynamic[$CellContext`minabsorp$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable1593176182014718171241473529; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ], {
              Dynamic[$CellContext`minabsorp$$], 
              Dynamic[$CellContext`maxabsorp$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxabsorp$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable1593176182014718171241473529; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ]}}]], {{$CellContext`minabsorp$$, 0.001}, 
         ControlType -> None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> 
         None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{"absorp"}, {$CellContext`absorp$$}}], 
            Optica`Optica`SymbolicRanges -> Map[ToExpression[
                Part[#, 1]] -> {
                Part[#, 2], 
                Part[#, 3]}& , 
              Select[
               
               Transpose[{{
                 "absorp"}, {$CellContext`minabsorp$$}, \
{$CellContext`maxabsorp$$}}], NumberQ[
                Part[#, 2]]& ]]}; 
         Optica`Optica`$OpticalSystemScript = 
          "{SingleRay[], Resonate[{CustomGrid[Move[SlabPrism[{0, -5, -5}, \
{10, 5, 5}], 5.], griddata, 9, SymbolicValues -> {absorp -> 0.1}, \
GridFunction -> ((griddata[[#3,#2,#1]] = griddata[[#3,#2,#1]] + \
Intensity*Exp[-(#4/absorp)]; Intensity = Intensity*(1. - Exp[-(#4/absorp)])) \
& ), EmbedGridData -> True, ReportedFunction -> \
Hold[Reverse[griddata[[1,1]]]]], Move[Mirror[{10, 10}], 16., \
4.999999999999999]}], Boundary[{0, -10, -10}, {20, 10, 10}]}"; Print[
           InputForm[
            StringJoin["{SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "absorp"}, {$CellContext`absorp$$}}]], ", SymbolicRanges -> ", 
             ToString[
              Map[StringJoin[
                Part[#, 1], "->", 
                ToString[{
                  Part[#, 2], 
                  Part[#, 3]}, InputForm]]& , 
               Select[
                
                Transpose[{{
                  "absorp"}, {$CellContext`minabsorp$$}, \
{$CellContext`maxabsorp$$}}], NumberQ[
                 Part[#, 2]]& ]]], "}"]]], ImageSize -> 
         Automatic], \
{{$CellContext`staticpolygons11176182014718171235803560$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
            "]]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons12176182014718171235804694$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4tYzsw378w0cWnn7A1reCB+QusoY8j3GwGHW
A0XnvFkCB9bdTS+L9zJwiE3PzN4wgeuA87OzM46bw9QzH7j+zni3vqqBQxxY
/tf+nO8z704XMnBIAvNf7WcAAwMHBijQFDzjcuGWvkMURN4+SGlG54KtMP4v
+2rjlHMFE/QdmiHmOyxxMRB2zIbJczmcDf0TLuim7zAT4j6Hb2kn5jxU0Ie5
H4MPUw/1D9w8qH8cYPZB/eMAcw/UP/Yw90L9Y4/un2yof6H+2Q8LD6h/9jtB
wwvqH3h4Qv0DD2+ofw6gxwc6HwCMJ7VM
            "]]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons13176182014718171235805802$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
            "]]}}, ControlType -> 
         None}}, "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1}, SynchronousInitialization -> False, 
        SynchronousUpdating -> False, 
        BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{861., {495., 500.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`raytracefunction1176182014718171235807134 = 
       With[{$CellContext`compileoptionsetting = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{}, 
          
          Module[{$CellContext`activeregion, \
$CellContext`allcreatedamplitudes, $CellContext`allcreatedrays, \
$CellContext`allowzeroraylength, $CellContext`alternateindex, \
$CellContext`amplitude, $CellContext`axismagnitude, $CellContext`axismatrix, \
$CellContext`clonedata, $CellContext`clonegenerationnumber, \
$CellContext`cloneinput, $CellContext`clonenumber, \
$CellContext`cloneposition, $CellContext`clonereportedrays, \
$CellContext`clonerotation, $CellContext`clonescale, \
$CellContext`clonescalevector, $CellContext`clonesorthistogram, \
$CellContext`clonetraceinput, $CellContext`clonetraceoutput, \
$CellContext`closestdistances, $CellContext`closestposition, \
$CellContext`closestpositions, $CellContext`closestraylength, \
$CellContext`completedray, $CellContext`componentnumber, \
$CellContext`cosangle, $CellContext`crossmatrix, \
$CellContext`deflecteddummyrayspresent, $CellContext`deflectedlocalrays, \
$CellContext`deflectedrays, $CellContext`deflectedrayspresent, \
$CellContext`dummymatrix, $CellContext`dummymatrixlist, \
$CellContext`dummyvector, $CellContext`frontid, $CellContext`generationlimit, \
$CellContext`generationnumber, $CellContext`holeintersections, \
$CellContext`holeQ, $CellContext`holeQlist, $CellContext`hor, \
$CellContext`index, $CellContext`index1, $CellContext`index2, \
$CellContext`inrays, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`intersectionnumber, $CellContext`intersections, \
$CellContext`intersectionslist, $CellContext`intersectionspresent, \
$CellContext`localdummyoutrayspresent, $CellContext`localoutrays, \
$CellContext`localoutrayspresent, $CellContext`magnitude, \
$CellContext`maxclonegenerationnumber, $CellContext`maximumposition, \
$CellContext`minimumraylength, $CellContext`minresonateraylength, \
$CellContext`n12, $CellContext`newcomponentnumber, \
$CellContext`newdeflectedrays, $CellContext`newdistance, \
$CellContext`newsurfaceid, $CellContext`newsurfacenumber, \
$CellContext`nonintersectingrays, $CellContext`normalizedpolarization, \
$CellContext`oldgenerationnumber, $CellContext`opticallength, \
$CellContext`originalray, $CellContext`originalraytilt, \
$CellContext`originalrotation, $CellContext`originalsurfnorm, \
$CellContext`outrays, $CellContext`parallelamplitude, $CellContext`PAxis, \
$CellContext`perpendicularamplitude, $CellContext`phaseshift, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3, \
$CellContext`previoustilt, $CellContext`propagate, \
$CellContext`propagatedrays, $CellContext`r1, $CellContext`r2, \
$CellContext`r3, $CellContext`r4, $CellContext`r5, $CellContext`r6, \
$CellContext`r7, $CellContext`r8, $CellContext`r9, $CellContext`ray1, \
$CellContext`ray2, $CellContext`ray3, $CellContext`LocRayL, \
$CellContext`rayslot, $CellContext`raysreported, $CellContext`raytiltx, \
$CellContext`raytiltz, $CellContext`reporteddummyrayspresent, \
$CellContext`reportedlocalrays, $CellContext`reportedrays, \
$CellContext`reportedrayspresent, $CellContext`resonateintersections, \
$CellContext`resonatenumber, $CellContext`resonateraylength, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`rotationaxis, $CellContext`rsx, $CellContext`LocRSx, \
$CellContext`rsy, $CellContext`LocRSy, $CellContext`rsz, $CellContext`LocRSz, 
            Optica`Optica`RTx, $CellContext`LocRTy, $CellContext`LocRTz, \
$CellContext`rx, $CellContext`rxhlp, $CellContext`ry, $CellContext`ryhlp, \
$CellContext`rz, $CellContext`rzhlp, $CellContext`LocSCx, \
$CellContext`LocSCy, $CellContext`sid, $CellContext`sinangle, \
$CellContext`sno1, $CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`surfaceid, $CellContext`surfacenumber, \
$CellContext`surfacerotationmatrix, $CellContext`surfacetranslationvector, \
$CellContext`surfnorm, $CellContext`symr1, $CellContext`symr2, \
$CellContext`symr3, $CellContext`symr4, $CellContext`symr5, \
$CellContext`symr6, $CellContext`symr7, $CellContext`symr8, \
$CellContext`symr9, $CellContext`tempclonedata, \
$CellContext`terminatedeflection, $CellContext`thresholdintensity, \
$CellContext`tiltmagnitude, $CellContext`transmatrix, $CellContext`LocTV1, \
$CellContext`LocTV10, $CellContext`LocTV2, $CellContext`LocTV3, \
$CellContext`LocTV4, $CellContext`LocTV5, $CellContext`LocTV6, \
$CellContext`LocTV7, $CellContext`LocTV8, $CellContext`LocTV9, \
$CellContext`u, $CellContext`unfilteredintersections, $CellContext`unit, \
$CellContext`uu, $CellContext`ver, $CellContext`wavelength, \
$CellContext`XAxis, $CellContext`xunit, $CellContext`YAxis, \
$CellContext`yunit, $CellContext`ZAxis, $CellContext`zunit}, $CellContext`rsx = 
            1.; $CellContext`rsy = 1.; $CellContext`rsz = 
            1.; $CellContext`rex = 1.; $CellContext`rey = 
            1.; $CellContext`rez = 1.; $CellContext`r1 = 1.; $CellContext`r2 = 
            1.; $CellContext`r3 = 1.; $CellContext`r4 = 1.; $CellContext`r5 = 
            1.; $CellContext`r6 = 1.; $CellContext`r7 = 1.; $CellContext`r8 = 
            1.; $CellContext`r9 = 1.; $CellContext`symr1 = 
            1.; $CellContext`symr2 = 1.; $CellContext`symr3 = 
            1.; $CellContext`symr4 = 1.; $CellContext`symr5 = 
            1.; $CellContext`symr6 = 1.; $CellContext`symr7 = 
            1.; $CellContext`symr8 = 1.; $CellContext`symr9 = 
            1.; $CellContext`rx = 1.; $CellContext`ry = 1.; $CellContext`rz = 
            1.; $CellContext`xunit = 1.; $CellContext`yunit = 
            1.; $CellContext`zunit = 1.; $CellContext`ray1 = 
            1.; $CellContext`ray2 = 1.; $CellContext`ray3 = 
            1.; $CellContext`LocRSx = 1.; $CellContext`LocRSy = 
            1.; $CellContext`LocRSz = 1.; 
           Optica`Optica`RTx = 1.; $CellContext`LocRTy = 
            1.; $CellContext`LocRTz = 1.; $CellContext`LocRayL = 
            1.; $CellContext`LocSCx = 1.; $CellContext`LocSCy = 
            1.; $CellContext`opticallength = 1.; $CellContext`phaseshift = 
            0.; $CellContext`wavelength = 1.; $CellContext`intensity = 
            1.; $CellContext`intensityscale = 
            1.; $CellContext`componentnumber = -1.; \
$CellContext`surfacenumber = -1.; $CellContext`surfaceid = -1.; \
$CellContext`generationnumber = 1.; $CellContext`intersectionnumber = 
            1.; $CellContext`generationlimit = 
            200.; $CellContext`thresholdintensity = 
            1.; $CellContext`tiltmagnitude = 1.; $CellContext`pol1 = 
            1.; $CellContext`pol2 = 1.; $CellContext`pol3 = 
            1.; $CellContext`sid = 1.; $CellContext`sno1 = 
            1.; $CellContext`sno2 = 1.; $CellContext`sno3 = 
            1.; $CellContext`sno4 = 1.; $CellContext`rayslot = 
            1.; $CellContext`index = 1.; $CellContext`activeregion = 
            1.; $CellContext`frontid = 1.; $CellContext`index1 = 
            1.; $CellContext`index2 = 1.; $CellContext`magnitude = 
            1.; $CellContext`LocTV1 = 1.; $CellContext`LocTV2 = 
            1.; $CellContext`LocTV3 = 1.; $CellContext`LocTV4 = 
            1.; $CellContext`LocTV5 = 1.; $CellContext`LocTV6 = 
            1.; $CellContext`LocTV7 = 1.; $CellContext`LocTV8 = 
            1.; $CellContext`LocTV9 = 1.; $CellContext`LocTV10 = 
            1.; $CellContext`cloneposition = {0., 0., 
             0.}; $CellContext`clonerotation = {{
             1.}}; $CellContext`clonedata = {{1.}}; $CellContext`clonenumber = 
            1; $CellContext`clonescale = 1.; $CellContext`newdistance = 
            1.; $CellContext`closestdistances = {
             1.}; $CellContext`closestposition = 
            0; $CellContext`closestraylength = 
            1.; $CellContext`maximumposition = 
            1; $CellContext`closestpositions = {
             0}; $CellContext`cloneinput = {
             1.}; $CellContext`clonetraceinput = {{
             1.}}; $CellContext`clonetraceoutput = {{
             1.}}; $CellContext`tempclonedata = {{
             1.}}; $CellContext`clonegenerationnumber = 
            1.; $CellContext`maxclonegenerationnumber = 
            1.; $CellContext`clonescalevector = {
             1.}; $CellContext`clonesorthistogram = {
             1}; $CellContext`surfacerotationmatrix = {{1., 0., 0.}, {0., 1., 
             0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector = {0., 
             0., 0.}; $CellContext`oldgenerationnumber = 
            1.; $CellContext`intersections = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections = {{-1., 0., 
             0.}}; $CellContext`intersectionslist = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist = {
             0}; $CellContext`holeintersections = {{-1., 0., 
             0.}}; $CellContext`minimumraylength = 
            0.0001; $CellContext`originalray = {
             1.}; $CellContext`completedray = {
             1.}; $CellContext`reportedrayspresent = 
            False; $CellContext`propagate = 
            True; $CellContext`originalraytilt = {
             1.}; $CellContext`allowzeroraylength = 
            True; $CellContext`deflecteddummyrayspresent = 
            False; $CellContext`reporteddummyrayspresent = 
            False; $CellContext`localoutrayspresent = 
            False; $CellContext`localdummyoutrayspresent = 
            False; $CellContext`deflectedrayspresent = 
            False; $CellContext`intersectionspresent = 
            False; $CellContext`raysreported = 
            False; $CellContext`terminatedeflection = 
            False; $CellContext`allcreatedrays = {{
             1.}}; $CellContext`propagatedrays = {{
             1.}}; $CellContext`deflectedrays = {{
             1.}}; $CellContext`newdeflectedrays = {{
             1.}}; $CellContext`reportedrays = {{
             1.}}; $CellContext`clonereportedrays = {{
             1.}}; $CellContext`nonintersectingrays = {{
             1.}}; $CellContext`inrays = {{1.}}; $CellContext`outrays = {{
             1.}}; $CellContext`reportedlocalrays = {{
             1.}}; $CellContext`deflectedlocalrays = {{
             1.}}; $CellContext`localoutrays = {{
             1.}}; $CellContext`resonatenumber = 
            0; $CellContext`resonateraylength = 
            1.; $CellContext`minresonateraylength = 
            1.; $CellContext`resonateintersections = {{-1., 0., 
             0.}}; $CellContext`dummyvector = {
             1.}; $CellContext`dummymatrix = {{
             1.}}; $CellContext`dummymatrixlist = {{{
             1.}}}; $CellContext`newcomponentnumber = -1.; \
$CellContext`newsurfacenumber = -1.; $CellContext`newsurfaceid = -1.; \
$CellContext`holeQ = False; $CellContext`rxhlp = 1.; $CellContext`ryhlp = 
            1.; $CellContext`rzhlp = 
            1.; $CellContext`surfnorm = {{
             1.}}; $CellContext`originalsurfnorm = {{
             1.}}; $CellContext`XAxis = {1., 0., 0.}; $CellContext`YAxis = {
             1., 0., 0.}; $CellContext`ZAxis = {1., 0., 
             0.}; $CellContext`PAxis = {1., 0., 
             0.}; $CellContext`normalizedpolarization = {1., 
             1.}; $CellContext`amplitude = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude = 
            1. + 0. I; $CellContext`parallelamplitude = 
            1. + 0. I; $CellContext`raytiltz = 1.; $CellContext`raytiltx = 
            1.; $CellContext`n12 = 1.; $CellContext`alternateindex = 
            1.; $CellContext`transmatrix = {{{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}}; $CellContext`u = {{1., 0., 0.}, {0., 1., 0.}, {0., 0.,
              1.}}; $CellContext`uu = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`unit = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`originalrotation = {{1., 0., 0.}, {0., 1., 
             0.}, {0., 0., 1.}}; $CellContext`axismatrix = {{1., 0., 0.}, {0.,
              1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`axismagnitude = 
            1.; $CellContext`cosangle = 1.; $CellContext`sinangle = 
            1.; $CellContext`previoustilt = {1., 0., 0.}; $CellContext`hor = 
            1. + 0. I; $CellContext`ver = 
            0. + 0. I; $CellContext`propagatedrays = CompressedData["
1:eJxTTMoPSmViYGDgBmJ1BnTwYz+GEFbxD/bY1REvv0BK/64K20OoukgHN/HY
kouu2+H6nigFd0kx4jKHkPlQYLnfAYWG61ND4xPvbnQRYzD4jBFu2MWHargx
QGk1ND7x7kYXOQMGbzDCDbv4UA03DiithsYn3t3oIkbgdPUYI9ywiw/VcBOA
0mpofOLdjS5iAA6fyxjhhl18qIabCJRWQ+MT727s4htsiBMfquEmAaXV0PjE
uxtdxAKSrogUH6rhJgOl1dD4xLsbXQQSPo+JFB+q4aYApdXQ+MS7G13kAqTe
JFJ8qIabEpRWQ+MT7250ERNIO41I8aEabipQWg2NT7y70UWYwOQPIsWHarip
4aCJdzeMBQCg9Sat
             "]; $CellContext`propagatedrays = 
            Map[({$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, $CellContext`r1, \
$CellContext`r2, $CellContext`r3, $CellContext`r4, $CellContext`r5, \
$CellContext`r6, $CellContext`r7, $CellContext`r8, $CellContext`r9, \
$CellContext`wavelength, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`ray1, $CellContext`index, $CellContext`opticallength, \
$CellContext`phaseshift, $CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid, $CellContext`ray2, \
$CellContext`ray3, $CellContext`sid, $CellContext`frontid, $CellContext`sno1, \
$CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`rayslot, $CellContext`oldgenerationnumber, \
$CellContext`intersectionnumber, $CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = #; $CellContext`componentnumber = 
               1.; $CellContext`frontid = 
               1.; {$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, $CellContext`r1, \
$CellContext`r2, $CellContext`r3, $CellContext`r4, $CellContext`r5, \
$CellContext`r6, $CellContext`r7, $CellContext`r8, $CellContext`r9, \
$CellContext`wavelength, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`ray1, $CellContext`index, $CellContext`opticallength, \
$CellContext`phaseshift, $CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid, $CellContext`ray2, \
$CellContext`ray3, $CellContext`sid, $CellContext`frontid, $CellContext`sno1, \
$CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`rayslot, $CellContext`generationnumber, \
$CellContext`intersectionnumber, $CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3})& , $CellContext`propagatedrays]; \
$CellContext`thresholdintensity = 1.; $CellContext`generationlimit = 
            200.; $CellContext`reportedrays = {{$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}; \
$CellContext`generationnumber = 
            0.; ($CellContext`inrays = $CellContext`propagatedrays; \
$CellContext`outrays = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent = 
             True; $CellContext`reportedrayspresent = 
             False; $CellContext`propagate = True; While[
              And[$CellContext`deflectedrayspresent, $CellContext`propagate], 
              AddTo[$CellContext`generationnumber, 
                1.]; ($CellContext`deflecteddummyrayspresent = 
                False; $CellContext`deflectedrayspresent = 
                False; $CellContext`reportedrayspresent = 
                False; $CellContext`reporteddummyrayspresent = 
                True; $CellContext`localdummyoutrayspresent = 
                False; $CellContext`localoutrayspresent = 
                False; {$CellContext`deflectedlocalrays, \
$CellContext`localoutrays, $CellContext`reportedlocalrays} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; If[
                    
                    And[$CellContext`intensity > \
$CellContext`thresholdintensity, $CellContext`generationnumber < \
$CellContext`generationlimit], ($CellContext`resonatenumber = 
                    0; $CellContext`resonateraylength = 
                    9.87654321*^8; $CellContext`resonateintersections = {{-1.,
                     0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength], \
$CellContext`resonateraylength = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections = #; \
$CellContext`resonatenumber = 
                    First[#2], $CellContext`resonatenumber]& , \
$CellContext`intersectionslist = {{{-1., 0., 0.}}}; $CellContext`holeQlist = {
                    0}; ({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`index1 = $CellContext`index; $CellContext`xunit = \
$CellContext`r1; $CellContext`yunit = $CellContext`r2; $CellContext`zunit = \
$CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = -5. + \
$CellContext`rex; $CellContext`ry = $CellContext`rey; $CellContext`rz = \
$CellContext`rez; $CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = Block[{Compile`$65}, 
                    If[Chop[$CellContext`xunit] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$65 = $CellContext`xunit^(-1); {-($CellContext`rx 
                    Compile`$65), $CellContext`ry - ($CellContext`rx \
$CellContext`yunit) 
                    Compile`$65, $CellContext`rz - ($CellContext`rx \
$CellContext`zunit) Compile`$65}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections, {-1., 0., 
                    0.}]; $CellContext`holeQ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid - 8018.] == 0., N[
                    Chop[$CellContext`ray1]] < 
                    0.0001]], $CellContext`generationnumber == 
                    1.], $CellContext`minresonateraylength = 
                    0., $CellContext`minresonateraylength = 0.0001]; 
                    Block[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy}, $CellContext`LocRayL = 1.; $CellContext`LocSCx = 
                    1.; $CellContext`LocSCy = 1.; $CellContext`dummymatrix = 
                    Union[
                    
                    Select[$CellContext`intersections, \
({$CellContext`LocRayL, $CellContext`LocSCx, $CellContext`LocSCy} = #; 
                    Or[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL]] >= \
$CellContext`minresonateraylength])& ]]; $CellContext`intersections = \
$CellContext`dummymatrix]; $CellContext`unfilteredintersections = \
$CellContext`intersections; 
                    If[Length[$CellContext`intersections] > 
                    1, $CellContext`dummymatrix = 
                    Take[$CellContext`intersections, {
                    2}]; $CellContext`intersections = \
$CellContext`dummymatrix; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist, \
$CellContext`intersections]; If[$CellContext`holeQ, 
                    AppendTo[$CellContext`holeQlist, 1], 
                    
                    AppendTo[$CellContext`holeQlist, 
                    0]]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`index1 = $CellContext`index; $CellContext`xunit = \
-$CellContext`r1; $CellContext`yunit = -$CellContext`r2; $CellContext`zunit = \
$CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = -(-15. + \
$CellContext`rex); $CellContext`ry = -$CellContext`rey; $CellContext`rz = \
$CellContext`rez; $CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = Block[{Compile`$69}, 
                    If[Chop[$CellContext`xunit] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$69 = $CellContext`xunit^(-1); {-($CellContext`rx 
                    Compile`$69), $CellContext`ry - ($CellContext`rx \
$CellContext`yunit) 
                    Compile`$69, $CellContext`rz - ($CellContext`rx \
$CellContext`zunit) Compile`$69}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections, {-1., 0., 
                    0.}]; $CellContext`holeQ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid - 8046.] == 0., N[
                    Chop[$CellContext`ray1]] < 
                    0.0001]], $CellContext`generationnumber == 
                    1.], $CellContext`minresonateraylength = 
                    0., $CellContext`minresonateraylength = 0.0001]; 
                    Block[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy}, $CellContext`LocRayL = 1.; $CellContext`LocSCx = 
                    1.; $CellContext`LocSCy = 1.; $CellContext`dummymatrix = 
                    Union[
                    
                    Select[$CellContext`intersections, \
({$CellContext`LocRayL, $CellContext`LocSCx, $CellContext`LocSCy} = #; 
                    Or[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL]] >= \
$CellContext`minresonateraylength])& ]]; $CellContext`intersections = \
$CellContext`dummymatrix]; $CellContext`unfilteredintersections = \
$CellContext`intersections; 
                    If[Length[$CellContext`intersections] > 
                    1, $CellContext`dummymatrix = 
                    Take[$CellContext`intersections, {
                    2}]; $CellContext`intersections = \
$CellContext`dummymatrix; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist, \
$CellContext`intersections]; If[$CellContext`holeQ, 
                    AppendTo[$CellContext`holeQlist, 1], 
                    
                    AppendTo[$CellContext`holeQlist, 
                    0]]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`index1 = $CellContext`index; $CellContext`xunit = \
$CellContext`r2; $CellContext`yunit = -$CellContext`r1; $CellContext`zunit = \
$CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = 
                    5. + $CellContext`rey; $CellContext`ry = -(-10. + \
$CellContext`rex); $CellContext`rz = $CellContext`rez; $CellContext`rx = 
                    Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = Block[{Compile`$74}, 
                    If[Chop[$CellContext`xunit] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$74 = $CellContext`xunit^(-1); {-($CellContext`rx 
                    Compile`$74), $CellContext`ry - ($CellContext`rx \
$CellContext`yunit) 
                    Compile`$74, $CellContext`rz - ($CellContext`rx \
$CellContext`zunit) Compile`$74}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections, {-1., 0., 
                    0.}]; $CellContext`holeQ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid - 8130.] == 0., N[
                    Chop[$CellContext`ray1]] < 
                    0.0001]], $CellContext`generationnumber == 
                    1.], $CellContext`minresonateraylength = 
                    0., $CellContext`minresonateraylength = 0.0001]; 
                    Block[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy}, $CellContext`LocRayL = 1.; $CellContext`LocSCx = 
                    1.; $CellContext`LocSCy = 1.; $CellContext`dummymatrix = 
                    Union[
                    
                    Select[$CellContext`intersections, \
({$CellContext`LocRayL, $CellContext`LocSCx, $CellContext`LocSCy} = #; 
                    Or[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL]] >= \
$CellContext`minresonateraylength])& ]]; $CellContext`intersections = \
$CellContext`dummymatrix]; $CellContext`unfilteredintersections = \
$CellContext`intersections; 
                    If[Length[$CellContext`intersections] > 
                    1, $CellContext`dummymatrix = 
                    Take[$CellContext`intersections, {
                    2}]; $CellContext`intersections = \
$CellContext`dummymatrix; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist, \
$CellContext`intersections]; If[$CellContext`holeQ, 
                    AppendTo[$CellContext`holeQlist, 1], 
                    
                    AppendTo[$CellContext`holeQlist, 
                    0]]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`index1 = $CellContext`index; $CellContext`xunit = \
-$CellContext`r2; $CellContext`yunit = $CellContext`r1; $CellContext`zunit = \
$CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = -(-5. + \
$CellContext`rey); $CellContext`ry = -10. + $CellContext`rex; $CellContext`rz = \
$CellContext`rez; $CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = Block[{Compile`$75}, 
                    If[Chop[$CellContext`xunit] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$75 = $CellContext`xunit^(-1); {-($CellContext`rx 
                    Compile`$75), $CellContext`ry - ($CellContext`rx \
$CellContext`yunit) 
                    Compile`$75, $CellContext`rz - ($CellContext`rx \
$CellContext`zunit) Compile`$75}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections, {-1., 0., 
                    0.}]; $CellContext`holeQ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid - 8158.] == 0., N[
                    Chop[$CellContext`ray1]] < 
                    0.0001]], $CellContext`generationnumber == 
                    1.], $CellContext`minresonateraylength = 
                    0., $CellContext`minresonateraylength = 0.0001]; 
                    Block[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy}, $CellContext`LocRayL = 1.; $CellContext`LocSCx = 
                    1.; $CellContext`LocSCy = 1.; $CellContext`dummymatrix = 
                    Union[
                    
                    Select[$CellContext`intersections, \
({$CellContext`LocRayL, $CellContext`LocSCx, $CellContext`LocSCy} = #; 
                    Or[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL]] >= \
$CellContext`minresonateraylength])& ]]; $CellContext`intersections = \
$CellContext`dummymatrix]; $CellContext`unfilteredintersections = \
$CellContext`intersections; 
                    If[Length[$CellContext`intersections] > 
                    1, $CellContext`dummymatrix = 
                    Take[$CellContext`intersections, {
                    2}]; $CellContext`intersections = \
$CellContext`dummymatrix; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist, \
$CellContext`intersections]; If[$CellContext`holeQ, 
                    AppendTo[$CellContext`holeQlist, 1], 
                    
                    AppendTo[$CellContext`holeQlist, 
                    0]]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`index1 = $CellContext`index; $CellContext`xunit = \
$CellContext`r3; $CellContext`yunit = $CellContext`r2; $CellContext`zunit = \
-$CellContext`r1; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = 
                    5. + $CellContext`rez; $CellContext`ry = $CellContext`rey; \
$CellContext`rz = -(-10. + $CellContext`rex); $CellContext`rx = 
                    Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = Block[{Compile`$72}, 
                    If[Chop[$CellContext`xunit] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$72 = $CellContext`xunit^(-1); {-($CellContext`rx 
                    Compile`$72), $CellContext`ry - ($CellContext`rx \
$CellContext`yunit) 
                    Compile`$72, $CellContext`rz - ($CellContext`rx \
$CellContext`zunit) Compile`$72}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections, {-1., 0., 
                    0.}]; $CellContext`holeQ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid - 8102.] == 0., N[
                    Chop[$CellContext`ray1]] < 
                    0.0001]], $CellContext`generationnumber == 
                    1.], $CellContext`minresonateraylength = 
                    0., $CellContext`minresonateraylength = 0.0001]; 
                    
                    Block[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy}, $CellContext`LocRayL = 1.; $CellContext`LocSCx = 
                    1.; $CellContext`LocSCy = 1.; $CellContext`dummymatrix = 
                    Union[
                    
                    Select[$CellContext`intersections, \
({$CellContext`LocRayL, $CellContext`LocSCx, $CellContext`LocSCy} = #; 
                    Or[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL]] >= \
$CellContext`minresonateraylength])& ]]; $CellContext`intersections = \
$CellContext`dummymatrix]; $CellContext`unfilteredintersections = \
$CellContext`intersections; 
                    If[Length[$CellContext`intersections] > 
                    1, $CellContext`dummymatrix = 
                    Take[$CellContext`intersections, {
                    2}]; $CellContext`intersections = \
$CellContext`dummymatrix; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist, \
$CellContext`intersections]; If[$CellContext`holeQ, 
                    AppendTo[$CellContext`holeQlist, 1], 
                    
                    AppendTo[$CellContext`holeQlist, 
                    0]]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`index1 = $CellContext`index; $CellContext`xunit = \
-$CellContext`r3; $CellContext`yunit = -$CellContext`r2; $CellContext`zunit = \
-$CellContext`r1; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = -(-5. + \
$CellContext`rez); $CellContext`ry = -$CellContext`rey; $CellContext`rz = \
-(-10. + $CellContext`rex); $CellContext`rx = 
                    Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = Block[{Compile`$70}, 
                    If[Chop[$CellContext`xunit] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$70 = $CellContext`xunit^(-1); {-($CellContext`rx 
                    Compile`$70), $CellContext`ry - ($CellContext`rx \
$CellContext`yunit) 
                    Compile`$70, $CellContext`rz - ($CellContext`rx \
$CellContext`zunit) Compile`$70}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections, {-1., 0., 
                    0.}]; $CellContext`holeQ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid - 8074.] == 0., N[
                    Chop[$CellContext`ray1]] < 
                    0.0001]], $CellContext`generationnumber == 
                    1.], $CellContext`minresonateraylength = 
                    0., $CellContext`minresonateraylength = 0.0001]; 
                    Block[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy}, $CellContext`LocRayL = 1.; $CellContext`LocSCx = 
                    1.; $CellContext`LocSCy = 1.; $CellContext`dummymatrix = 
                    Union[
                    
                    Select[$CellContext`intersections, \
({$CellContext`LocRayL, $CellContext`LocSCx, $CellContext`LocSCy} = #; 
                    Or[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL]] >= \
$CellContext`minresonateraylength])& ]]; $CellContext`intersections = \
$CellContext`dummymatrix]; $CellContext`unfilteredintersections = \
$CellContext`intersections; 
                    If[Length[$CellContext`intersections] > 
                    1, $CellContext`dummymatrix = 
                    Take[$CellContext`intersections, {
                    2}]; $CellContext`intersections = \
$CellContext`dummymatrix; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist, \
$CellContext`intersections]; If[$CellContext`holeQ, 
                    AppendTo[$CellContext`holeQlist, 1], 
                    
                    AppendTo[$CellContext`holeQlist, 
                    0]]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`index1 = $CellContext`index; $CellContext`xunit = 
                    0.9961946980917455 $CellContext`r1 + 
                    0.08715574274765817 $CellContext`r2; $CellContext`yunit = \
(-0.08715574274765817) $CellContext`r1 + 
                    0.9961946980917455 $CellContext`r2; $CellContext`zunit = \
$CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = 
                    0.9961946980917455 (-16. + $CellContext`rex) + 
                    0.08715574274765817 $CellContext`rey; $CellContext`ry = \
(-0.08715574274765817) (-16. + $CellContext`rex) + 
                    0.9961946980917455 $CellContext`rey; $CellContext`rz = \
$CellContext`rez; $CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = Block[{Compile`$76}, 
                    If[Chop[$CellContext`xunit] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                    Part[#, 3] <= 5.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$76 = $CellContext`xunit^(-1); {-($CellContext`rx 
                    Compile`$76), $CellContext`ry - ($CellContext`rx \
$CellContext`yunit) 
                    Compile`$76, $CellContext`rz - ($CellContext`rx \
$CellContext`zunit) Compile`$76}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections, {-1., 0., 
                    0.}]; $CellContext`holeQ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid - 8210.] == 0., N[
                    Chop[$CellContext`ray1]] < 
                    0.0001]], $CellContext`generationnumber == 
                    1.], $CellContext`minresonateraylength = 
                    0., $CellContext`minresonateraylength = 0.0001]; 
                    Block[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy}, $CellContext`LocRayL = 1.; $CellContext`LocSCx = 
                    1.; $CellContext`LocSCy = 1.; $CellContext`dummymatrix = 
                    Union[
                    
                    Select[$CellContext`intersections, \
({$CellContext`LocRayL, $CellContext`LocSCx, $CellContext`LocSCy} = #; 
                    Or[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL]] >= \
$CellContext`minresonateraylength])& ]]; $CellContext`intersections = \
$CellContext`dummymatrix]; $CellContext`unfilteredintersections = \
$CellContext`intersections; 
                    If[Length[$CellContext`intersections] > 
                    1, $CellContext`dummymatrix = 
                    Take[$CellContext`intersections, {
                    2}]; $CellContext`intersections = \
$CellContext`dummymatrix; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist, \
$CellContext`intersections]; If[$CellContext`holeQ, 
                    AppendTo[$CellContext`holeQlist, 1], 
                    
                    AppendTo[$CellContext`holeQlist, 
                    0]]); $CellContext`holeQlist = 
                    Drop[$CellContext`holeQlist, 1]; 
                    Drop[$CellContext`intersectionslist, 1]]); 
                    Which[$CellContext`resonatenumber == 
                    1, {$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, $CellContext`r1, \
$CellContext`r2, $CellContext`r3, $CellContext`r4, $CellContext`r5, \
$CellContext`r6, $CellContext`r7, $CellContext`r8, $CellContext`r9, \
$CellContext`wavelength, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`ray1, $CellContext`index, $CellContext`opticallength, \
$CellContext`phaseshift, $CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid, $CellContext`ray2, \
$CellContext`ray3, $CellContext`sid, $CellContext`frontid, $CellContext`sno1, \
$CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`rayslot, $CellContext`oldgenerationnumber, \
$CellContext`intersectionnumber, $CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = #; $CellContext`index1 = $CellContext`index; \
$CellContext`xunit = $CellContext`r1; $CellContext`yunit = $CellContext`r2; \
$CellContext`zunit = $CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = -5. + \
$CellContext`rex; $CellContext`ry = $CellContext`rey; $CellContext`rz = \
$CellContext`rez; $CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = \
$CellContext`resonateintersections; $CellContext`holeQ = 
                    Part[$CellContext`holeQlist, $CellContext`resonatenumber] == 
                    1; {$CellContext`newcomponentnumber, \
$CellContext`newsurfacenumber, $CellContext`newsurfaceid} = {1., 1., 
                    8018.}; {$CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid} = {1., 1., 
                    8018.}; {$CellContext`ray1, $CellContext`ray2, \
$CellContext`ray3} = Part[$CellContext`intersections, 
                    1]; $CellContext`rsx = $CellContext`rex; $CellContext`rsy = \
$CellContext`rey; $CellContext`rsz = $CellContext`rez; $CellContext`rxhlp = \
$CellContext`rx + $CellContext`ray1 $CellContext`xunit; $CellContext`ryhlp = \
$CellContext`ry + $CellContext`ray1 $CellContext`yunit; $CellContext`rzhlp = \
$CellContext`rz + $CellContext`ray1 $CellContext`zunit; $CellContext`rex = 
                    5. + $CellContext`rxhlp; $CellContext`rey = \
$CellContext`ryhlp; $CellContext`rez = $CellContext`rzhlp; $CellContext`rex = 
                    Chop[$CellContext`rex]; $CellContext`rey = 
                    Chop[$CellContext`rey]; $CellContext`rez = 
                    Chop[$CellContext`rez]; $CellContext`intersectionnumber = \
$CellContext`intersectionnumber + 
                    1.; $CellContext`opticallength = \
$CellContext`opticallength + $CellContext`ray1 $CellContext`index1; \
$CellContext`completedray = {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`reportedrayspresent = True; $CellContext`intersectionspresent = 
                    True; $CellContext`deflectedrayspresent = 
                    True; $CellContext`localdummyoutrayspresent = 
                    True; ($CellContext`surfnorm = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix = 
                    Map[#& , $CellContext`surfnorm]; $CellContext`surfnorm = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix]; \
$CellContext`surfacerotationmatrix = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector = {
                    5., 0, 0}; $CellContext`activeregion = 
                    1.; $CellContext`completedray = {$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`componentnumber = $CellContext`newcomponentnumber; \
$CellContext`surfacenumber = $CellContext`newsurfacenumber; \
$CellContext`surfaceid = $CellContext`newsurfaceid; $CellContext`originalray = \
{$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, $CellContext`rex, \
$CellContext`rey, $CellContext`rez, $CellContext`r1, $CellContext`r2, \
$CellContext`r3, $CellContext`r4, $CellContext`r5, $CellContext`r6, \
$CellContext`r7, $CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; $CellContext`ZAxis = 
                    First[$CellContext`surfnorm] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm], {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]]; $CellContext`raytiltz = 
                    Dot[$CellContext`ZAxis, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; $CellContext`raytiltx = 
                    1 - $CellContext`raytiltz^2; 
                    If[$CellContext`raytiltx < 
                    2.220446049250313*^-16, $CellContext`raytiltx = 
                    0., $CellContext`raytiltx = 
                    Sqrt[$CellContext`raytiltx]]; $CellContext`XAxis = \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} - $CellContext`ZAxis \
$CellContext`raytiltz; If[
                    Abs[$CellContext`raytiltx] < 1.*^-7, $CellContext`XAxis = 
                    Part[$CellContext`surfnorm, 
                    2], $CellContext`XAxis = \
$CellContext`XAxis/$CellContext`raytiltx]; $CellContext`YAxis = {-(
                    Part[$CellContext`ZAxis, 3] Part[$CellContext`XAxis, 2]) + 
                    Part[$CellContext`ZAxis, 2] Part[$CellContext`XAxis, 3], 
                    Part[$CellContext`ZAxis, 3] Part[$CellContext`XAxis, 1] - 
                    Part[$CellContext`ZAxis, 1] 
                    Part[$CellContext`XAxis, 3], -(
                    Part[$CellContext`ZAxis, 2] Part[$CellContext`XAxis, 1]) + 
                    Part[$CellContext`ZAxis, 1] 
                    Part[$CellContext`XAxis, 
                    2]}; $CellContext`YAxis = $CellContext`YAxis/Sqrt[
                    
                    Dot[$CellContext`YAxis, $CellContext`YAxis]]; \
$CellContext`PAxis = $CellContext`ZAxis 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
$CellContext`XAxis] - $CellContext`XAxis 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
$CellContext`ZAxis]; $CellContext`PAxis = $CellContext`PAxis/Sqrt[
                    
                    Dot[$CellContext`PAxis, $CellContext`PAxis]]; \
$CellContext`normalizedpolarization = 
                    Part[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, {1, 
                    2}]; $CellContext`normalizedpolarization = \
$CellContext`normalizedpolarization/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization, \
$CellContext`normalizedpolarization]]; $CellContext`allcreatedamplitudes = {{
                    0. I, 0. I, 0. I}}; 
                    If[$CellContext`intensity < 0., $CellContext`intensity = 
                    0., 1.]; $CellContext`amplitude = 
                    Sqrt[$CellContext`intensity] (
                    Part[$CellContext`normalizedpolarization, 
                    1] {$CellContext`r4, $CellContext`r5, $CellContext`r6} + (
                    Part[$CellContext`normalizedpolarization, 
                    2] {$CellContext`r7, $CellContext`r8, $CellContext`r9}) 
                    Exp[(I $CellContext`pol3) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude = 
                    Dot[$CellContext`amplitude, $CellContext`YAxis]; \
$CellContext`parallelamplitude = 
                    Dot[$CellContext`amplitude, $CellContext`PAxis]; 
                    If[$CellContext`activeregion Part[
                    
                    Dot[$CellContext`surfacerotationmatrix, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}], 1] > 
                    0, $CellContext`index2 = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]; \
$CellContext`index1 = $CellContext`index; 
                    If[Abs[$CellContext`index2 - $CellContext`index1] < 
                    0.01, $CellContext`alternateindex = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]; 
                    If[Abs[$CellContext`alternateindex - $CellContext`index1] > 
                    Abs[$CellContext`index2 - $CellContext`index1], \
$CellContext`index1 = $CellContext`index2; $CellContext`index2 = \
$CellContext`alternateindex, $CellContext`index1 = \
$CellContext`alternateindex], $CellContext`index1 = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]], \
$CellContext`index2 = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]; \
$CellContext`index1 = $CellContext`index; 
                    If[Abs[$CellContext`index2 - $CellContext`index1] < 
                    0.01, $CellContext`alternateindex = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]; 
                    If[Abs[$CellContext`alternateindex - $CellContext`index1] > 
                    Abs[$CellContext`index2 - $CellContext`index1], \
$CellContext`index1 = $CellContext`index2; $CellContext`index2 = \
$CellContext`alternateindex, $CellContext`index1 = \
$CellContext`alternateindex], $CellContext`index1 = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]]]; \
$CellContext`n12 = $CellContext`index1/$CellContext`index2; \
$CellContext`index = $CellContext`index2; 
                    If[1 - $CellContext`n12^2 $CellContext`raytiltx^2 >= 
                    0., $CellContext`dummyvector = $CellContext`n12 \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} + $CellContext`ZAxis \
(-($CellContext`n12 $CellContext`raytiltz) + 
                    Sqrt[1 - $CellContext`n12^2 $CellContext`raytiltx^2]); \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} = \
$CellContext`dummyvector; 1., 
                    If[Dot[{$CellContext`r1, $CellContext`r2, \
$CellContext`r3}, 
                    Part[$CellContext`surfnorm, 1]] > 
                    0, $CellContext`phaseshift = $CellContext`phaseshift + 
                    0.5, 1.]; $CellContext`index2 = $CellContext`index1; \
$CellContext`index = $CellContext`index1; $CellContext`dummyvector = \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} - (2 $CellContext`ZAxis) 
                    Dot[$CellContext`ZAxis, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; {$CellContext`r1, $CellContext`r2, \
$CellContext`r3} = $CellContext`dummyvector; $CellContext`dummyvector = \
{$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} + {0, 
                    0, -180}; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector; 
                    1.]; $CellContext`allcreatedrays = {{$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}; \
$CellContext`originalrotation = Partition[
                    Take[$CellContext`originalray, {7, 15}], 
                    3]; $CellContext`previoustilt = 
                    Part[$CellContext`originalrotation, 
                    1]; $CellContext`transmatrix = 
                    MapIndexed[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`rotationaxis = 
                    Cross[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; $CellContext`axismagnitude = Sqrt[
                    
                    Dot[$CellContext`rotationaxis, \
$CellContext`rotationaxis]]; 
                    If[Chop[$CellContext`axismagnitude] != 
                    N[0], $CellContext`rotationaxis = \
$CellContext`rotationaxis/$CellContext`axismagnitude; $CellContext`axismatrix = 
                    Map[# $CellContext`rotationaxis& , \
$CellContext`rotationaxis]; $CellContext`crossmatrix = {{
                    0., -Part[$CellContext`rotationaxis, 3], 
                    Part[$CellContext`rotationaxis, 2]}, {
                    Part[$CellContext`rotationaxis, 3], 0., -
                    Part[$CellContext`rotationaxis, 1]}, {-
                    Part[$CellContext`rotationaxis, 2], 
                    Part[$CellContext`rotationaxis, 1], 
                    0.}}; $CellContext`cosangle = 
                    Dot[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; 
                    If[1. - $CellContext`cosangle < 
                    2.220446049250313*^-16, $CellContext`cosangle = 
                    1., $CellContext`cosangle = $CellContext`cosangle]; \
$CellContext`sinangle = 1 - $CellContext`cosangle^2; 
                    If[$CellContext`sinangle < 
                    2.220446049250313*^-16, $CellContext`sinangle = 
                    0., $CellContext`sinangle = 
                    Sqrt[$CellContext`sinangle]]; $CellContext`axismatrix + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix) $CellContext`cosangle + \
$CellContext`crossmatrix $CellContext`sinangle, {{$CellContext`r1, \
$CellContext`r2, $CellContext`r3}, {$CellContext`r4, $CellContext`r5, \
$CellContext`r6}, {$CellContext`r7, $CellContext`r8, $CellContext`r9}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0., 
                    0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays]; \
$CellContext`allcreatedrays = 
                    MapIndexed[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
{{$CellContext`r1, $CellContext`r2, $CellContext`r3}, {$CellContext`r4, \
$CellContext`r5, $CellContext`r6}, {$CellContext`r7, $CellContext`r8, \
$CellContext`r9}} = Function[$CellContext`mm, 
                    Map[
                    Dot[$CellContext`mm, #]& , $CellContext`originalrotation]][
                    Part[$CellContext`transmatrix, 
                    First[#2]]]; $CellContext`tiltmagnitude = 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
{$CellContext`r1, $CellContext`r2, $CellContext`r3}]; 
                    If[Abs[$CellContext`tiltmagnitude - 1.] > 
                    1.*^-6, $CellContext`dummyvector = {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}/
                    Sqrt[$CellContext`tiltmagnitude]; {$CellContext`r1, \
$CellContext`r2, $CellContext`r3} = $CellContext`dummyvector; \
$CellContext`dummymatrix = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1, $CellContext`r2, \
$CellContext`r3}, {$CellContext`r4, $CellContext`r5, $CellContext`r6}, \
{$CellContext`r7, $CellContext`r8, $CellContext`r9}}]; {{$CellContext`r1, \
$CellContext`r2, $CellContext`r3}, {$CellContext`r4, $CellContext`r5, \
$CellContext`r6}, {$CellContext`r7, $CellContext`r8, $CellContext`r9}} = \
$CellContext`dummymatrix; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude = 
                    Part[$CellContext`allcreatedamplitudes, 
                    First[#2]]; $CellContext`hor = 
                    Dot[{$CellContext`r4, $CellContext`r5, $CellContext`r6}, \
$CellContext`amplitude]; $CellContext`ver = 
                    Dot[{$CellContext`r7, $CellContext`r8, $CellContext`r9}, \
$CellContext`amplitude]; If[
                    Or[
                    Abs[$CellContext`hor] > 0., Abs[$CellContext`ver] > 
                    0.], {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = {
                    Abs[$CellContext`hor], 
                    Abs[$CellContext`ver], 
                    0.}; $CellContext`dummyvector = {$CellContext`pol1, \
$CellContext`pol2, $CellContext`pol3}/Sqrt[
                    
                    Dot[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}]]; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector; $CellContext`dummyvector = 
                    ReplacePart[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, (If[$CellContext`ver == 0., 0., 
                    Arg[$CellContext`ver]] - If[$CellContext`hor == 0., 0., 
                    Arg[$CellContext`hor]])/Degree, 
                    3]; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector]; 1., 
                    1.]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3})& , \
$CellContext`allcreatedrays]); {$CellContext`allcreatedrays, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray}}, \
$CellContext`resonatenumber == 
                    2, {$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, $CellContext`r1, \
$CellContext`r2, $CellContext`r3, $CellContext`r4, $CellContext`r5, \
$CellContext`r6, $CellContext`r7, $CellContext`r8, $CellContext`r9, \
$CellContext`wavelength, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`ray1, $CellContext`index, $CellContext`opticallength, \
$CellContext`phaseshift, $CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid, $CellContext`ray2, \
$CellContext`ray3, $CellContext`sid, $CellContext`frontid, $CellContext`sno1, \
$CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`rayslot, $CellContext`oldgenerationnumber, \
$CellContext`intersectionnumber, $CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = #; $CellContext`index1 = $CellContext`index; \
$CellContext`xunit = -$CellContext`r1; $CellContext`yunit = -$CellContext`r2; \
$CellContext`zunit = $CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = -(-15. + \
$CellContext`rex); $CellContext`ry = -$CellContext`rey; $CellContext`rz = \
$CellContext`rez; $CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = \
$CellContext`resonateintersections; $CellContext`holeQ = 
                    Part[$CellContext`holeQlist, $CellContext`resonatenumber] == 
                    1; {$CellContext`newcomponentnumber, \
$CellContext`newsurfacenumber, $CellContext`newsurfaceid} = {1., 2., 
                    8046.}; {$CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid} = {1., 2., 
                    8046.}; {$CellContext`ray1, $CellContext`ray2, \
$CellContext`ray3} = Part[$CellContext`intersections, 
                    1]; $CellContext`rsx = $CellContext`rex; $CellContext`rsy = \
$CellContext`rey; $CellContext`rsz = $CellContext`rez; $CellContext`rxhlp = \
$CellContext`rx + $CellContext`ray1 $CellContext`xunit; $CellContext`ryhlp = \
$CellContext`ry + $CellContext`ray1 $CellContext`yunit; $CellContext`rzhlp = \
$CellContext`rz + $CellContext`ray1 $CellContext`zunit; $CellContext`rex = 
                    15. - 1. $CellContext`rxhlp; $CellContext`rey = \
-$CellContext`ryhlp; $CellContext`rez = $CellContext`rzhlp; $CellContext`rex = 
                    Chop[$CellContext`rex]; $CellContext`rey = 
                    Chop[$CellContext`rey]; $CellContext`rez = 
                    Chop[$CellContext`rez]; $CellContext`intersectionnumber = \
$CellContext`intersectionnumber + 
                    1.; $CellContext`opticallength = \
$CellContext`opticallength + $CellContext`ray1 $CellContext`index1; \
$CellContext`completedray = {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`reportedrayspresent = True; $CellContext`intersectionspresent = 
                    True; $CellContext`deflectedrayspresent = 
                    True; $CellContext`localdummyoutrayspresent = 
                    True; ($CellContext`surfnorm = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm]; $CellContext`surfnorm = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix]; \
$CellContext`surfacerotationmatrix = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector = {
                    15., 0, 0}; $CellContext`activeregion = 
                    1.; $CellContext`completedray = {$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`componentnumber = $CellContext`newcomponentnumber; \
$CellContext`surfacenumber = $CellContext`newsurfacenumber; \
$CellContext`surfaceid = $CellContext`newsurfaceid; $CellContext`originalray = \
{$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, $CellContext`rex, \
$CellContext`rey, $CellContext`rez, $CellContext`r1, $CellContext`r2, \
$CellContext`r3, $CellContext`r4, $CellContext`r5, $CellContext`r6, \
$CellContext`r7, $CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; $CellContext`ZAxis = 
                    First[$CellContext`surfnorm] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm], {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]]; $CellContext`raytiltz = 
                    Dot[$CellContext`ZAxis, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; $CellContext`raytiltx = 
                    1 - $CellContext`raytiltz^2; 
                    If[$CellContext`raytiltx < 
                    2.220446049250313*^-16, $CellContext`raytiltx = 
                    0., $CellContext`raytiltx = 
                    Sqrt[$CellContext`raytiltx]]; $CellContext`XAxis = \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} - $CellContext`ZAxis \
$CellContext`raytiltz; If[
                    Abs[$CellContext`raytiltx] < 1.*^-7, $CellContext`XAxis = 
                    Part[$CellContext`surfnorm, 
                    2], $CellContext`XAxis = \
$CellContext`XAxis/$CellContext`raytiltx]; $CellContext`YAxis = {-(
                    Part[$CellContext`ZAxis, 3] Part[$CellContext`XAxis, 2]) + 
                    Part[$CellContext`ZAxis, 2] Part[$CellContext`XAxis, 3], 
                    Part[$CellContext`ZAxis, 3] Part[$CellContext`XAxis, 1] - 
                    Part[$CellContext`ZAxis, 1] 
                    Part[$CellContext`XAxis, 3], -(
                    Part[$CellContext`ZAxis, 2] Part[$CellContext`XAxis, 1]) + 
                    Part[$CellContext`ZAxis, 1] 
                    Part[$CellContext`XAxis, 
                    2]}; $CellContext`YAxis = $CellContext`YAxis/Sqrt[
                    
                    Dot[$CellContext`YAxis, $CellContext`YAxis]]; \
$CellContext`PAxis = $CellContext`ZAxis 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
$CellContext`XAxis] - $CellContext`XAxis 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
$CellContext`ZAxis]; $CellContext`PAxis = $CellContext`PAxis/Sqrt[
                    
                    Dot[$CellContext`PAxis, $CellContext`PAxis]]; \
$CellContext`normalizedpolarization = 
                    Part[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, {1, 
                    2}]; $CellContext`normalizedpolarization = \
$CellContext`normalizedpolarization/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization, \
$CellContext`normalizedpolarization]]; $CellContext`allcreatedamplitudes = {{
                    0. I, 0. I, 0. I}}; 
                    If[$CellContext`intensity < 0., $CellContext`intensity = 
                    0., 1.]; $CellContext`amplitude = 
                    Sqrt[$CellContext`intensity] (
                    Part[$CellContext`normalizedpolarization, 
                    1] {$CellContext`r4, $CellContext`r5, $CellContext`r6} + (
                    Part[$CellContext`normalizedpolarization, 
                    2] {$CellContext`r7, $CellContext`r8, $CellContext`r9}) 
                    Exp[(I $CellContext`pol3) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude = 
                    Dot[$CellContext`amplitude, $CellContext`YAxis]; \
$CellContext`parallelamplitude = 
                    Dot[$CellContext`amplitude, $CellContext`PAxis]; 
                    If[$CellContext`activeregion Part[
                    
                    Dot[$CellContext`surfacerotationmatrix, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}], 1] > 
                    0, $CellContext`index2 = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]; \
$CellContext`index1 = $CellContext`index; 
                    If[Abs[$CellContext`index2 - $CellContext`index1] < 
                    0.01, $CellContext`alternateindex = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]; 
                    If[Abs[$CellContext`alternateindex - $CellContext`index1] > 
                    Abs[$CellContext`index2 - $CellContext`index1], \
$CellContext`index1 = $CellContext`index2; $CellContext`index2 = \
$CellContext`alternateindex, $CellContext`index1 = \
$CellContext`alternateindex], $CellContext`index1 = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]], \
$CellContext`index2 = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]; \
$CellContext`index1 = $CellContext`index; 
                    If[Abs[$CellContext`index2 - $CellContext`index1] < 
                    0.01, $CellContext`alternateindex = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]; 
                    If[Abs[$CellContext`alternateindex - $CellContext`index1] > 
                    Abs[$CellContext`index2 - $CellContext`index1], \
$CellContext`index1 = $CellContext`index2; $CellContext`index2 = \
$CellContext`alternateindex, $CellContext`index1 = \
$CellContext`alternateindex], $CellContext`index1 = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]]]; \
$CellContext`n12 = $CellContext`index1/$CellContext`index2; \
$CellContext`index = $CellContext`index2; 
                    If[1 - $CellContext`n12^2 $CellContext`raytiltx^2 >= 
                    0., $CellContext`dummyvector = $CellContext`n12 \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} + $CellContext`ZAxis \
(-($CellContext`n12 $CellContext`raytiltz) + 
                    Sqrt[1 - $CellContext`n12^2 $CellContext`raytiltx^2]); \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} = \
$CellContext`dummyvector; 1., 
                    If[Dot[{$CellContext`r1, $CellContext`r2, \
$CellContext`r3}, 
                    Part[$CellContext`surfnorm, 1]] > 
                    0, $CellContext`phaseshift = $CellContext`phaseshift + 
                    0.5, 
                    1.]; $CellContext`index2 = $CellContext`index1; \
$CellContext`index = $CellContext`index1; $CellContext`dummyvector = \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} - (2 $CellContext`ZAxis) 
                    Dot[$CellContext`ZAxis, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; {$CellContext`r1, $CellContext`r2, \
$CellContext`r3} = $CellContext`dummyvector; $CellContext`dummyvector = \
{$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} + {0, 
                    0, -180}; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector; 
                    1.]; $CellContext`allcreatedrays = {{$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}; \
$CellContext`originalrotation = Partition[
                    Take[$CellContext`originalray, {7, 15}], 
                    3]; $CellContext`previoustilt = 
                    Part[$CellContext`originalrotation, 
                    1]; $CellContext`transmatrix = 
                    MapIndexed[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`rotationaxis = 
                    Cross[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; $CellContext`axismagnitude = Sqrt[
                    
                    Dot[$CellContext`rotationaxis, \
$CellContext`rotationaxis]]; 
                    If[Chop[$CellContext`axismagnitude] != 
                    N[0], $CellContext`rotationaxis = \
$CellContext`rotationaxis/$CellContext`axismagnitude; $CellContext`axismatrix = 
                    Map[# $CellContext`rotationaxis& , \
$CellContext`rotationaxis]; $CellContext`crossmatrix = {{
                    0., -Part[$CellContext`rotationaxis, 3], 
                    Part[$CellContext`rotationaxis, 2]}, {
                    Part[$CellContext`rotationaxis, 3], 0., -
                    Part[$CellContext`rotationaxis, 1]}, {-
                    Part[$CellContext`rotationaxis, 2], 
                    Part[$CellContext`rotationaxis, 1], 
                    0.}}; $CellContext`cosangle = 
                    Dot[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; 
                    If[1. - $CellContext`cosangle < 
                    2.220446049250313*^-16, $CellContext`cosangle = 
                    1., $CellContext`cosangle = $CellContext`cosangle]; \
$CellContext`sinangle = 1 - $CellContext`cosangle^2; 
                    If[$CellContext`sinangle < 
                    2.220446049250313*^-16, $CellContext`sinangle = 
                    0., $CellContext`sinangle = 
                    Sqrt[$CellContext`sinangle]]; $CellContext`axismatrix + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix) $CellContext`cosangle + \
$CellContext`crossmatrix $CellContext`sinangle, {{$CellContext`r1, \
$CellContext`r2, $CellContext`r3}, {$CellContext`r4, $CellContext`r5, \
$CellContext`r6}, {$CellContext`r7, $CellContext`r8, $CellContext`r9}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0., 
                    0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays]; \
$CellContext`allcreatedrays = 
                    MapIndexed[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
{{$CellContext`r1, $CellContext`r2, $CellContext`r3}, {$CellContext`r4, \
$CellContext`r5, $CellContext`r6}, {$CellContext`r7, $CellContext`r8, \
$CellContext`r9}} = Function[$CellContext`mm, 
                    Map[
                    Dot[$CellContext`mm, #]& , $CellContext`originalrotation]][
                    Part[$CellContext`transmatrix, 
                    First[#2]]]; $CellContext`tiltmagnitude = 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
{$CellContext`r1, $CellContext`r2, $CellContext`r3}]; 
                    If[Abs[$CellContext`tiltmagnitude - 1.] > 
                    1.*^-6, $CellContext`dummyvector = {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}/
                    Sqrt[$CellContext`tiltmagnitude]; {$CellContext`r1, \
$CellContext`r2, $CellContext`r3} = $CellContext`dummyvector; \
$CellContext`dummymatrix = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1, $CellContext`r2, \
$CellContext`r3}, {$CellContext`r4, $CellContext`r5, $CellContext`r6}, \
{$CellContext`r7, $CellContext`r8, $CellContext`r9}}]; {{$CellContext`r1, \
$CellContext`r2, $CellContext`r3}, {$CellContext`r4, $CellContext`r5, \
$CellContext`r6}, {$CellContext`r7, $CellContext`r8, $CellContext`r9}} = \
$CellContext`dummymatrix; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude = 
                    Part[$CellContext`allcreatedamplitudes, 
                    First[#2]]; $CellContext`hor = 
                    Dot[{$CellContext`r4, $CellContext`r5, $CellContext`r6}, \
$CellContext`amplitude]; $CellContext`ver = 
                    Dot[{$CellContext`r7, $CellContext`r8, $CellContext`r9}, \
$CellContext`amplitude]; If[
                    Or[
                    Abs[$CellContext`hor] > 0., Abs[$CellContext`ver] > 
                    0.], {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = {
                    Abs[$CellContext`hor], 
                    Abs[$CellContext`ver], 
                    0.}; $CellContext`dummyvector = {$CellContext`pol1, \
$CellContext`pol2, $CellContext`pol3}/Sqrt[
                    
                    Dot[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}]]; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector; $CellContext`dummyvector = 
                    ReplacePart[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, (If[$CellContext`ver == 0., 0., 
                    Arg[$CellContext`ver]] - If[$CellContext`hor == 0., 0., 
                    Arg[$CellContext`hor]])/Degree, 
                    3]; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector]; 1., 
                    1.]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3})& , \
$CellContext`allcreatedrays]); {$CellContext`allcreatedrays, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray}}, \
$CellContext`resonatenumber == 
                    3, {$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, $CellContext`r1, \
$CellContext`r2, $CellContext`r3, $CellContext`r4, $CellContext`r5, \
$CellContext`r6, $CellContext`r7, $CellContext`r8, $CellContext`r9, \
$CellContext`wavelength, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`ray1, $CellContext`index, $CellContext`opticallength, \
$CellContext`phaseshift, $CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid, $CellContext`ray2, \
$CellContext`ray3, $CellContext`sid, $CellContext`frontid, $CellContext`sno1, \
$CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`rayslot, $CellContext`oldgenerationnumber, \
$CellContext`intersectionnumber, $CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = #; $CellContext`index1 = $CellContext`index; \
$CellContext`xunit = $CellContext`r2; $CellContext`yunit = -$CellContext`r1; \
$CellContext`zunit = $CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = 
                    5. + $CellContext`rey; $CellContext`ry = -(-10. + \
$CellContext`rex); $CellContext`rz = $CellContext`rez; $CellContext`rx = 
                    Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = \
$CellContext`resonateintersections; $CellContext`holeQ = 
                    Part[$CellContext`holeQlist, $CellContext`resonatenumber] == 
                    1; {$CellContext`newcomponentnumber, \
$CellContext`newsurfacenumber, $CellContext`newsurfaceid} = {1., 3., 
                    8130.}; {$CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid} = {1., 3., 
                    8130.}; {$CellContext`ray1, $CellContext`ray2, \
$CellContext`ray3} = Part[$CellContext`intersections, 
                    1]; $CellContext`rsx = $CellContext`rex; $CellContext`rsy = \
$CellContext`rey; $CellContext`rsz = $CellContext`rez; $CellContext`rxhlp = \
$CellContext`rx + $CellContext`ray1 $CellContext`xunit; $CellContext`ryhlp = \
$CellContext`ry + $CellContext`ray1 $CellContext`yunit; $CellContext`rzhlp = \
$CellContext`rz + $CellContext`ray1 $CellContext`zunit; $CellContext`rex = 
                    10. - 1. $CellContext`ryhlp; $CellContext`rey = -5. + \
$CellContext`rxhlp; $CellContext`rez = $CellContext`rzhlp; $CellContext`rex = 
                    Chop[$CellContext`rex]; $CellContext`rey = 
                    Chop[$CellContext`rey]; $CellContext`rez = 
                    Chop[$CellContext`rez]; $CellContext`intersectionnumber = \
$CellContext`intersectionnumber + 
                    1.; $CellContext`opticallength = \
$CellContext`opticallength + $CellContext`ray1 $CellContext`index1; \
$CellContext`completedray = {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`reportedrayspresent = True; $CellContext`intersectionspresent = 
                    True; $CellContext`deflectedrayspresent = 
                    True; $CellContext`localdummyoutrayspresent = 
                    True; ($CellContext`surfnorm = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm]; $CellContext`surfnorm = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix]; \
$CellContext`surfacerotationmatrix = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector = {
                    10., -5., 0}; $CellContext`activeregion = 
                    1.; $CellContext`completedray = {$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`componentnumber = $CellContext`newcomponentnumber; \
$CellContext`surfacenumber = $CellContext`newsurfacenumber; \
$CellContext`surfaceid = $CellContext`newsurfaceid; $CellContext`originalray = \
{$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, $CellContext`rex, \
$CellContext`rey, $CellContext`rez, $CellContext`r1, $CellContext`r2, \
$CellContext`r3, $CellContext`r4, $CellContext`r5, $CellContext`r6, \
$CellContext`r7, $CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; $CellContext`ZAxis = 
                    First[$CellContext`surfnorm] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm], {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]]; $CellContext`raytiltz = 
                    
                    Dot[$CellContext`ZAxis, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; $CellContext`raytiltx = 
                    1 - $CellContext`raytiltz^2; 
                    If[$CellContext`raytiltx < 
                    2.220446049250313*^-16, $CellContext`raytiltx = 
                    0., $CellContext`raytiltx = 
                    Sqrt[$CellContext`raytiltx]]; $CellContext`XAxis = \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} - $CellContext`ZAxis \
$CellContext`raytiltz; If[
                    Abs[$CellContext`raytiltx] < 1.*^-7, $CellContext`XAxis = 
                    Part[$CellContext`surfnorm, 
                    2], $CellContext`XAxis = \
$CellContext`XAxis/$CellContext`raytiltx]; $CellContext`YAxis = {-(
                    Part[$CellContext`ZAxis, 3] Part[$CellContext`XAxis, 2]) + 
                    Part[$CellContext`ZAxis, 2] Part[$CellContext`XAxis, 3], 
                    Part[$CellContext`ZAxis, 3] Part[$CellContext`XAxis, 1] - 
                    Part[$CellContext`ZAxis, 1] 
                    Part[$CellContext`XAxis, 3], -(
                    Part[$CellContext`ZAxis, 2] Part[$CellContext`XAxis, 1]) + 
                    Part[$CellContext`ZAxis, 1] 
                    Part[$CellContext`XAxis, 
                    2]}; $CellContext`YAxis = $CellContext`YAxis/Sqrt[
                    
                    Dot[$CellContext`YAxis, $CellContext`YAxis]]; \
$CellContext`PAxis = $CellContext`ZAxis 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
$CellContext`XAxis] - $CellContext`XAxis 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
$CellContext`ZAxis]; $CellContext`PAxis = $CellContext`PAxis/Sqrt[
                    
                    Dot[$CellContext`PAxis, $CellContext`PAxis]]; \
$CellContext`normalizedpolarization = 
                    Part[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, {1, 
                    2}]; $CellContext`normalizedpolarization = \
$CellContext`normalizedpolarization/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization, \
$CellContext`normalizedpolarization]]; $CellContext`allcreatedamplitudes = {{
                    0. I, 0. I, 0. I}}; 
                    If[$CellContext`intensity < 0., $CellContext`intensity = 
                    0., 1.]; $CellContext`amplitude = 
                    Sqrt[$CellContext`intensity] (
                    Part[$CellContext`normalizedpolarization, 
                    1] {$CellContext`r4, $CellContext`r5, $CellContext`r6} + (
                    Part[$CellContext`normalizedpolarization, 
                    2] {$CellContext`r7, $CellContext`r8, $CellContext`r9}) 
                    Exp[(I $CellContext`pol3) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude = 
                    Dot[$CellContext`amplitude, $CellContext`YAxis]; \
$CellContext`parallelamplitude = 
                    Dot[$CellContext`amplitude, $CellContext`PAxis]; 
                    If[$CellContext`activeregion Part[
                    
                    Dot[$CellContext`surfacerotationmatrix, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}], 1] > 
                    0, $CellContext`index2 = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]; \
$CellContext`index1 = $CellContext`index; 
                    If[Abs[$CellContext`index2 - $CellContext`index1] < 
                    0.01, $CellContext`alternateindex = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]; 
                    If[Abs[$CellContext`alternateindex - $CellContext`index1] > 
                    Abs[$CellContext`index2 - $CellContext`index1], \
$CellContext`index1 = $CellContext`index2; $CellContext`index2 = \
$CellContext`alternateindex, $CellContext`index1 = \
$CellContext`alternateindex], $CellContext`index1 = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]], \
$CellContext`index2 = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]; \
$CellContext`index1 = $CellContext`index; 
                    If[Abs[$CellContext`index2 - $CellContext`index1] < 
                    0.01, $CellContext`alternateindex = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]; 
                    If[Abs[$CellContext`alternateindex - $CellContext`index1] > 
                    Abs[$CellContext`index2 - $CellContext`index1], \
$CellContext`index1 = $CellContext`index2; $CellContext`index2 = \
$CellContext`alternateindex, $CellContext`index1 = \
$CellContext`alternateindex], $CellContext`index1 = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]]]; \
$CellContext`n12 = $CellContext`index1/$CellContext`index2; \
$CellContext`index = $CellContext`index2; 
                    If[1 - $CellContext`n12^2 $CellContext`raytiltx^2 >= 
                    0., $CellContext`dummyvector = $CellContext`n12 \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} + $CellContext`ZAxis \
(-($CellContext`n12 $CellContext`raytiltz) + 
                    Sqrt[1 - $CellContext`n12^2 $CellContext`raytiltx^2]); \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} = \
$CellContext`dummyvector; 1., 
                    If[Dot[{$CellContext`r1, $CellContext`r2, \
$CellContext`r3}, 
                    Part[$CellContext`surfnorm, 1]] > 
                    0, $CellContext`phaseshift = $CellContext`phaseshift + 
                    0.5, 1.]; $CellContext`index2 = $CellContext`index1; \
$CellContext`index = $CellContext`index1; $CellContext`dummyvector = \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} - (2 $CellContext`ZAxis) 
                    
                    Dot[$CellContext`ZAxis, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; {$CellContext`r1, $CellContext`r2, \
$CellContext`r3} = $CellContext`dummyvector; $CellContext`dummyvector = \
{$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} + {0, 
                    0, -180}; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector; 
                    1.]; $CellContext`allcreatedrays = {{$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}; \
$CellContext`originalrotation = Partition[
                    Take[$CellContext`originalray, {7, 15}], 
                    3]; $CellContext`previoustilt = 
                    Part[$CellContext`originalrotation, 
                    1]; $CellContext`transmatrix = 
                    MapIndexed[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`rotationaxis = 
                    Cross[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; $CellContext`axismagnitude = Sqrt[
                    
                    Dot[$CellContext`rotationaxis, \
$CellContext`rotationaxis]]; 
                    If[Chop[$CellContext`axismagnitude] != 
                    N[0], $CellContext`rotationaxis = \
$CellContext`rotationaxis/$CellContext`axismagnitude; $CellContext`axismatrix = 
                    Map[# $CellContext`rotationaxis& , \
$CellContext`rotationaxis]; $CellContext`crossmatrix = {{
                    0., -Part[$CellContext`rotationaxis, 3], 
                    Part[$CellContext`rotationaxis, 2]}, {
                    Part[$CellContext`rotationaxis, 3], 0., -
                    Part[$CellContext`rotationaxis, 1]}, {-
                    Part[$CellContext`rotationaxis, 2], 
                    Part[$CellContext`rotationaxis, 1], 
                    0.}}; $CellContext`cosangle = 
                    Dot[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; 
                    If[1. - $CellContext`cosangle < 
                    2.220446049250313*^-16, $CellContext`cosangle = 
                    1., $CellContext`cosangle = $CellContext`cosangle]; \
$CellContext`sinangle = 1 - $CellContext`cosangle^2; 
                    If[$CellContext`sinangle < 
                    2.220446049250313*^-16, $CellContext`sinangle = 
                    0., $CellContext`sinangle = 
                    Sqrt[$CellContext`sinangle]]; $CellContext`axismatrix + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix) $CellContext`cosangle + \
$CellContext`crossmatrix $CellContext`sinangle, {{$CellContext`r1, \
$CellContext`r2, $CellContext`r3}, {$CellContext`r4, $CellContext`r5, \
$CellContext`r6}, {$CellContext`r7, $CellContext`r8, $CellContext`r9}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0., 
                    0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays]; \
$CellContext`allcreatedrays = 
                    MapIndexed[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
{{$CellContext`r1, $CellContext`r2, $CellContext`r3}, {$CellContext`r4, \
$CellContext`r5, $CellContext`r6}, {$CellContext`r7, $CellContext`r8, \
$CellContext`r9}} = Function[$CellContext`mm, 
                    Map[
                    Dot[$CellContext`mm, #]& , $CellContext`originalrotation]][
                    Part[$CellContext`transmatrix, 
                    First[#2]]]; $CellContext`tiltmagnitude = 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
{$CellContext`r1, $CellContext`r2, $CellContext`r3}]; 
                    If[Abs[$CellContext`tiltmagnitude - 1.] > 
                    1.*^-6, $CellContext`dummyvector = {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}/
                    Sqrt[$CellContext`tiltmagnitude]; {$CellContext`r1, \
$CellContext`r2, $CellContext`r3} = $CellContext`dummyvector; \
$CellContext`dummymatrix = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1, $CellContext`r2, \
$CellContext`r3}, {$CellContext`r4, $CellContext`r5, $CellContext`r6}, \
{$CellContext`r7, $CellContext`r8, $CellContext`r9}}]; {{$CellContext`r1, \
$CellContext`r2, $CellContext`r3}, {$CellContext`r4, $CellContext`r5, \
$CellContext`r6}, {$CellContext`r7, $CellContext`r8, $CellContext`r9}} = \
$CellContext`dummymatrix; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude = 
                    Part[$CellContext`allcreatedamplitudes, 
                    First[#2]]; $CellContext`hor = 
                    Dot[{$CellContext`r4, $CellContext`r5, $CellContext`r6}, \
$CellContext`amplitude]; $CellContext`ver = 
                    Dot[{$CellContext`r7, $CellContext`r8, $CellContext`r9}, \
$CellContext`amplitude]; If[
                    Or[
                    Abs[$CellContext`hor] > 0., Abs[$CellContext`ver] > 
                    0.], {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = {
                    Abs[$CellContext`hor], 
                    Abs[$CellContext`ver], 
                    0.}; $CellContext`dummyvector = {$CellContext`pol1, \
$CellContext`pol2, $CellContext`pol3}/Sqrt[
                    
                    Dot[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}]]; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector; $CellContext`dummyvector = 
                    ReplacePart[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, (If[$CellContext`ver == 0., 0., 
                    Arg[$CellContext`ver]] - If[$CellContext`hor == 0., 0., 
                    Arg[$CellContext`hor]])/Degree, 
                    3]; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector]; 1., 
                    1.]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3})& , \
$CellContext`allcreatedrays]); {$CellContext`allcreatedrays, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray}}, \
$CellContext`resonatenumber == 
                    4, {$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, $CellContext`r1, \
$CellContext`r2, $CellContext`r3, $CellContext`r4, $CellContext`r5, \
$CellContext`r6, $CellContext`r7, $CellContext`r8, $CellContext`r9, \
$CellContext`wavelength, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`ray1, $CellContext`index, $CellContext`opticallength, \
$CellContext`phaseshift, $CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid, $CellContext`ray2, \
$CellContext`ray3, $CellContext`sid, $CellContext`frontid, $CellContext`sno1, \
$CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`rayslot, $CellContext`oldgenerationnumber, \
$CellContext`intersectionnumber, $CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = #; $CellContext`index1 = $CellContext`index; \
$CellContext`xunit = -$CellContext`r2; $CellContext`yunit = $CellContext`r1; \
$CellContext`zunit = $CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = -(-5. + \
$CellContext`rey); $CellContext`ry = -10. + $CellContext`rex; $CellContext`rz = \
$CellContext`rez; $CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = \
$CellContext`resonateintersections; $CellContext`holeQ = 
                    Part[$CellContext`holeQlist, $CellContext`resonatenumber] == 
                    1; {$CellContext`newcomponentnumber, \
$CellContext`newsurfacenumber, $CellContext`newsurfaceid} = {1., 4., 
                    8158.}; {$CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid} = {1., 4., 
                    8158.}; {$CellContext`ray1, $CellContext`ray2, \
$CellContext`ray3} = Part[$CellContext`intersections, 
                    1]; $CellContext`rsx = $CellContext`rex; $CellContext`rsy = \
$CellContext`rey; $CellContext`rsz = $CellContext`rez; $CellContext`rxhlp = \
$CellContext`rx + $CellContext`ray1 $CellContext`xunit; $CellContext`ryhlp = \
$CellContext`ry + $CellContext`ray1 $CellContext`yunit; $CellContext`rzhlp = \
$CellContext`rz + $CellContext`ray1 $CellContext`zunit; $CellContext`rex = 
                    10. + $CellContext`ryhlp; $CellContext`rey = 
                    5. - 1. $CellContext`rxhlp; $CellContext`rez = \
$CellContext`rzhlp; $CellContext`rex = 
                    Chop[$CellContext`rex]; $CellContext`rey = 
                    Chop[$CellContext`rey]; $CellContext`rez = 
                    Chop[$CellContext`rez]; $CellContext`intersectionnumber = \
$CellContext`intersectionnumber + 
                    1.; $CellContext`opticallength = \
$CellContext`opticallength + $CellContext`ray1 $CellContext`index1; \
$CellContext`completedray = {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`reportedrayspresent = True; $CellContext`intersectionspresent = 
                    True; $CellContext`deflectedrayspresent = 
                    True; $CellContext`localdummyoutrayspresent = 
                    True; ($CellContext`surfnorm = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm]; $CellContext`surfnorm = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix]; \
$CellContext`surfacerotationmatrix = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector = {
                    10., 5., 0}; $CellContext`activeregion = 
                    1.; $CellContext`completedray = {$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`componentnumber = $CellContext`newcomponentnumber; \
$CellContext`surfacenumber = $CellContext`newsurfacenumber; \
$CellContext`surfaceid = $CellContext`newsurfaceid; $CellContext`originalray = \
{$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, $CellContext`rex, \
$CellContext`rey, $CellContext`rez, $CellContext`r1, $CellContext`r2, \
$CellContext`r3, $CellContext`r4, $CellContext`r5, $CellContext`r6, \
$CellContext`r7, $CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; $CellContext`ZAxis = 
                    First[$CellContext`surfnorm] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm], {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]]; $CellContext`raytiltz = 
                    Dot[$CellContext`ZAxis, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; $CellContext`raytiltx = 
                    1 - $CellContext`raytiltz^2; 
                    If[$CellContext`raytiltx < 
                    2.220446049250313*^-16, $CellContext`raytiltx = 
                    0., $CellContext`raytiltx = 
                    Sqrt[$CellContext`raytiltx]]; $CellContext`XAxis = \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} - $CellContext`ZAxis \
$CellContext`raytiltz; If[
                    Abs[$CellContext`raytiltx] < 1.*^-7, $CellContext`XAxis = 
                    Part[$CellContext`surfnorm, 
                    2], $CellContext`XAxis = \
$CellContext`XAxis/$CellContext`raytiltx]; $CellContext`YAxis = {-(
                    Part[$CellContext`ZAxis, 3] Part[$CellContext`XAxis, 2]) + 
                    Part[$CellContext`ZAxis, 2] Part[$CellContext`XAxis, 3], 
                    Part[$CellContext`ZAxis, 3] Part[$CellContext`XAxis, 1] - 
                    Part[$CellContext`ZAxis, 1] 
                    Part[$CellContext`XAxis, 3], -(
                    Part[$CellContext`ZAxis, 2] Part[$CellContext`XAxis, 1]) + 
                    Part[$CellContext`ZAxis, 1] 
                    Part[$CellContext`XAxis, 
                    2]}; $CellContext`YAxis = $CellContext`YAxis/Sqrt[
                    
                    Dot[$CellContext`YAxis, $CellContext`YAxis]]; \
$CellContext`PAxis = $CellContext`ZAxis 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
$CellContext`XAxis] - $CellContext`XAxis 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
$CellContext`ZAxis]; $CellContext`PAxis = $CellContext`PAxis/Sqrt[
                    
                    Dot[$CellContext`PAxis, $CellContext`PAxis]]; \
$CellContext`normalizedpolarization = 
                    Part[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, {1, 
                    2}]; $CellContext`normalizedpolarization = \
$CellContext`normalizedpolarization/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization, \
$CellContext`normalizedpolarization]]; $CellContext`allcreatedamplitudes = {{
                    0. I, 0. I, 0. I}}; 
                    If[$CellContext`intensity < 0., $CellContext`intensity = 
                    0., 1.]; $CellContext`amplitude = 
                    Sqrt[$CellContext`intensity] (
                    Part[$CellContext`normalizedpolarization, 
                    1] {$CellContext`r4, $CellContext`r5, $CellContext`r6} + (
                    Part[$CellContext`normalizedpolarization, 
                    2] {$CellContext`r7, $CellContext`r8, $CellContext`r9}) 
                    Exp[(I $CellContext`pol3) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude = 
                    Dot[$CellContext`amplitude, $CellContext`YAxis]; \
$CellContext`parallelamplitude = 
                    Dot[$CellContext`amplitude, $CellContext`PAxis]; 
                    If[$CellContext`activeregion Part[
                    
                    Dot[$CellContext`surfacerotationmatrix, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}], 1] > 
                    0, $CellContext`index2 = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]; \
$CellContext`index1 = $CellContext`index; 
                    If[Abs[$CellContext`index2 - $CellContext`index1] < 
                    0.01, $CellContext`alternateindex = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]; 
                    If[Abs[$CellContext`alternateindex - $CellContext`index1] > 
                    Abs[$CellContext`index2 - $CellContext`index1], \
$CellContext`index1 = $CellContext`index2; $CellContext`index2 = \
$CellContext`alternateindex, $CellContext`index1 = \
$CellContext`alternateindex], $CellContext`index1 = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]], \
$CellContext`index2 = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]; \
$CellContext`index1 = $CellContext`index; 
                    If[Abs[$CellContext`index2 - $CellContext`index1] < 
                    0.01, $CellContext`alternateindex = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]; 
                    If[Abs[$CellContext`alternateindex - $CellContext`index1] > 
                    Abs[$CellContext`index2 - $CellContext`index1], \
$CellContext`index1 = $CellContext`index2; $CellContext`index2 = \
$CellContext`alternateindex, $CellContext`index1 = \
$CellContext`alternateindex], $CellContext`index1 = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]]]; \
$CellContext`n12 = $CellContext`index1/$CellContext`index2; \
$CellContext`index = $CellContext`index2; 
                    If[1 - $CellContext`n12^2 $CellContext`raytiltx^2 >= 
                    0., $CellContext`dummyvector = $CellContext`n12 \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} + $CellContext`ZAxis \
(-($CellContext`n12 $CellContext`raytiltz) + 
                    Sqrt[1 - $CellContext`n12^2 $CellContext`raytiltx^2]); \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} = \
$CellContext`dummyvector; 1., 
                    If[Dot[{$CellContext`r1, $CellContext`r2, \
$CellContext`r3}, 
                    Part[$CellContext`surfnorm, 1]] > 
                    0, $CellContext`phaseshift = $CellContext`phaseshift + 
                    0.5, 1.]; $CellContext`index2 = $CellContext`index1; \
$CellContext`index = $CellContext`index1; $CellContext`dummyvector = \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} - (2 $CellContext`ZAxis) 
                    Dot[$CellContext`ZAxis, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; {$CellContext`r1, $CellContext`r2, \
$CellContext`r3} = $CellContext`dummyvector; $CellContext`dummyvector = \
{$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} + {0, 
                    0, -180}; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector; 
                    1.]; $CellContext`allcreatedrays = {{$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}; \
$CellContext`originalrotation = Partition[
                    Take[$CellContext`originalray, {7, 15}], 
                    3]; $CellContext`previoustilt = 
                    Part[$CellContext`originalrotation, 
                    1]; $CellContext`transmatrix = 
                    MapIndexed[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`rotationaxis = 
                    Cross[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; $CellContext`axismagnitude = Sqrt[
                    
                    Dot[$CellContext`rotationaxis, \
$CellContext`rotationaxis]]; 
                    If[Chop[$CellContext`axismagnitude] != 
                    N[0], $CellContext`rotationaxis = \
$CellContext`rotationaxis/$CellContext`axismagnitude; $CellContext`axismatrix = 
                    Map[# $CellContext`rotationaxis& , \
$CellContext`rotationaxis]; $CellContext`crossmatrix = {{
                    0., -Part[$CellContext`rotationaxis, 3], 
                    Part[$CellContext`rotationaxis, 2]}, {
                    Part[$CellContext`rotationaxis, 3], 0., -
                    Part[$CellContext`rotationaxis, 1]}, {-
                    Part[$CellContext`rotationaxis, 2], 
                    Part[$CellContext`rotationaxis, 1], 
                    0.}}; $CellContext`cosangle = 
                    Dot[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; 
                    If[1. - $CellContext`cosangle < 
                    2.220446049250313*^-16, $CellContext`cosangle = 
                    1., $CellContext`cosangle = $CellContext`cosangle]; \
$CellContext`sinangle = 1 - $CellContext`cosangle^2; 
                    If[$CellContext`sinangle < 
                    2.220446049250313*^-16, $CellContext`sinangle = 
                    0., $CellContext`sinangle = 
                    Sqrt[$CellContext`sinangle]]; $CellContext`axismatrix + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix) $CellContext`cosangle + \
$CellContext`crossmatrix $CellContext`sinangle, {{$CellContext`r1, \
$CellContext`r2, $CellContext`r3}, {$CellContext`r4, $CellContext`r5, \
$CellContext`r6}, {$CellContext`r7, $CellContext`r8, $CellContext`r9}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0., 
                    0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays]; \
$CellContext`allcreatedrays = 
                    MapIndexed[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
{{$CellContext`r1, $CellContext`r2, $CellContext`r3}, {$CellContext`r4, \
$CellContext`r5, $CellContext`r6}, {$CellContext`r7, $CellContext`r8, \
$CellContext`r9}} = Function[$CellContext`mm, 
                    Map[
                    Dot[$CellContext`mm, #]& , $CellContext`originalrotation]][
                    Part[$CellContext`transmatrix, 
                    First[#2]]]; $CellContext`tiltmagnitude = 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
{$CellContext`r1, $CellContext`r2, $CellContext`r3}]; 
                    If[Abs[$CellContext`tiltmagnitude - 1.] > 
                    1.*^-6, $CellContext`dummyvector = {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}/
                    Sqrt[$CellContext`tiltmagnitude]; {$CellContext`r1, \
$CellContext`r2, $CellContext`r3} = $CellContext`dummyvector; \
$CellContext`dummymatrix = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1, $CellContext`r2, \
$CellContext`r3}, {$CellContext`r4, $CellContext`r5, $CellContext`r6}, \
{$CellContext`r7, $CellContext`r8, $CellContext`r9}}]; {{$CellContext`r1, \
$CellContext`r2, $CellContext`r3}, {$CellContext`r4, $CellContext`r5, \
$CellContext`r6}, {$CellContext`r7, $CellContext`r8, $CellContext`r9}} = \
$CellContext`dummymatrix; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude = 
                    Part[$CellContext`allcreatedamplitudes, 
                    First[#2]]; $CellContext`hor = 
                    Dot[{$CellContext`r4, $CellContext`r5, $CellContext`r6}, \
$CellContext`amplitude]; $CellContext`ver = 
                    Dot[{$CellContext`r7, $CellContext`r8, $CellContext`r9}, \
$CellContext`amplitude]; If[
                    Or[
                    Abs[$CellContext`hor] > 0., Abs[$CellContext`ver] > 
                    0.], {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = {
                    Abs[$CellContext`hor], 
                    Abs[$CellContext`ver], 
                    0.}; $CellContext`dummyvector = {$CellContext`pol1, \
$CellContext`pol2, $CellContext`pol3}/Sqrt[
                    
                    Dot[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}]]; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector; $CellContext`dummyvector = 
                    ReplacePart[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, (If[$CellContext`ver == 0., 0., 
                    Arg[$CellContext`ver]] - If[$CellContext`hor == 0., 0., 
                    Arg[$CellContext`hor]])/Degree, 
                    3]; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector]; 1., 
                    1.]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3})& , \
$CellContext`allcreatedrays]); {$CellContext`allcreatedrays, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray}}, \
$CellContext`resonatenumber == 
                    5, {$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, $CellContext`r1, \
$CellContext`r2, $CellContext`r3, $CellContext`r4, $CellContext`r5, \
$CellContext`r6, $CellContext`r7, $CellContext`r8, $CellContext`r9, \
$CellContext`wavelength, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`ray1, $CellContext`index, $CellContext`opticallength, \
$CellContext`phaseshift, $CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid, $CellContext`ray2, \
$CellContext`ray3, $CellContext`sid, $CellContext`frontid, $CellContext`sno1, \
$CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`rayslot, $CellContext`oldgenerationnumber, \
$CellContext`intersectionnumber, $CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = #; $CellContext`index1 = $CellContext`index; \
$CellContext`xunit = $CellContext`r3; $CellContext`yunit = $CellContext`r2; \
$CellContext`zunit = -$CellContext`r1; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = 
                    5. + $CellContext`rez; $CellContext`ry = $CellContext`rey; \
$CellContext`rz = -(-10. + $CellContext`rex); $CellContext`rx = 
                    Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = \
$CellContext`resonateintersections; $CellContext`holeQ = 
                    Part[$CellContext`holeQlist, $CellContext`resonatenumber] == 
                    1; {$CellContext`newcomponentnumber, \
$CellContext`newsurfacenumber, $CellContext`newsurfaceid} = {1., 5., 
                    8102.}; {$CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid} = {1., 5., 
                    8102.}; {$CellContext`ray1, $CellContext`ray2, \
$CellContext`ray3} = Part[$CellContext`intersections, 
                    1]; $CellContext`rsx = $CellContext`rex; $CellContext`rsy = \
$CellContext`rey; $CellContext`rsz = $CellContext`rez; $CellContext`rxhlp = \
$CellContext`rx + $CellContext`ray1 $CellContext`xunit; $CellContext`ryhlp = \
$CellContext`ry + $CellContext`ray1 $CellContext`yunit; $CellContext`rzhlp = \
$CellContext`rz + $CellContext`ray1 $CellContext`zunit; $CellContext`rex = 
                    10. - 1. $CellContext`rzhlp; $CellContext`rey = \
$CellContext`ryhlp; $CellContext`rez = -5. + $CellContext`rxhlp; \
$CellContext`rex = Chop[$CellContext`rex]; $CellContext`rey = 
                    Chop[$CellContext`rey]; $CellContext`rez = 
                    Chop[$CellContext`rez]; $CellContext`intersectionnumber = \
$CellContext`intersectionnumber + 
                    1.; $CellContext`opticallength = \
$CellContext`opticallength + $CellContext`ray1 $CellContext`index1; \
$CellContext`completedray = {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`reportedrayspresent = True; $CellContext`intersectionspresent = 
                    True; $CellContext`deflectedrayspresent = 
                    True; $CellContext`localdummyoutrayspresent = 
                    True; ($CellContext`surfnorm = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm]; $CellContext`surfnorm = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix]; \
$CellContext`surfacerotationmatrix = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector = {
                    10., 0, -5.}; $CellContext`activeregion = 
                    1.; $CellContext`completedray = {$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`componentnumber = $CellContext`newcomponentnumber; \
$CellContext`surfacenumber = $CellContext`newsurfacenumber; \
$CellContext`surfaceid = $CellContext`newsurfaceid; $CellContext`originalray = \
{$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, $CellContext`rex, \
$CellContext`rey, $CellContext`rez, $CellContext`r1, $CellContext`r2, \
$CellContext`r3, $CellContext`r4, $CellContext`r5, $CellContext`r6, \
$CellContext`r7, $CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; $CellContext`ZAxis = 
                    First[$CellContext`surfnorm] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm], {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]]; $CellContext`raytiltz = 
                    Dot[$CellContext`ZAxis, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; $CellContext`raytiltx = 
                    1 - $CellContext`raytiltz^2; 
                    If[$CellContext`raytiltx < 
                    2.220446049250313*^-16, $CellContext`raytiltx = 
                    0., $CellContext`raytiltx = 
                    Sqrt[$CellContext`raytiltx]]; $CellContext`XAxis = \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} - $CellContext`ZAxis \
$CellContext`raytiltz; If[
                    Abs[$CellContext`raytiltx] < 1.*^-7, $CellContext`XAxis = 
                    Part[$CellContext`surfnorm, 
                    2], $CellContext`XAxis = \
$CellContext`XAxis/$CellContext`raytiltx]; $CellContext`YAxis = {-(
                    Part[$CellContext`ZAxis, 3] Part[$CellContext`XAxis, 2]) + 
                    Part[$CellContext`ZAxis, 2] Part[$CellContext`XAxis, 3], 
                    Part[$CellContext`ZAxis, 3] Part[$CellContext`XAxis, 1] - 
                    Part[$CellContext`ZAxis, 1] 
                    Part[$CellContext`XAxis, 3], -(
                    Part[$CellContext`ZAxis, 2] Part[$CellContext`XAxis, 1]) + 
                    Part[$CellContext`ZAxis, 1] 
                    Part[$CellContext`XAxis, 
                    2]}; $CellContext`YAxis = $CellContext`YAxis/Sqrt[
                    
                    Dot[$CellContext`YAxis, $CellContext`YAxis]]; \
$CellContext`PAxis = $CellContext`ZAxis 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
$CellContext`XAxis] - $CellContext`XAxis 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
$CellContext`ZAxis]; $CellContext`PAxis = $CellContext`PAxis/Sqrt[
                    
                    Dot[$CellContext`PAxis, $CellContext`PAxis]]; \
$CellContext`normalizedpolarization = 
                    Part[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, {1, 
                    2}]; $CellContext`normalizedpolarization = \
$CellContext`normalizedpolarization/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization, \
$CellContext`normalizedpolarization]]; $CellContext`allcreatedamplitudes = {{
                    0. I, 0. I, 0. I}}; 
                    If[$CellContext`intensity < 0., $CellContext`intensity = 
                    0., 1.]; $CellContext`amplitude = 
                    Sqrt[$CellContext`intensity] (
                    Part[$CellContext`normalizedpolarization, 
                    1] {$CellContext`r4, $CellContext`r5, $CellContext`r6} + (
                    Part[$CellContext`normalizedpolarization, 
                    2] {$CellContext`r7, $CellContext`r8, $CellContext`r9}) 
                    Exp[(I $CellContext`pol3) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude = 
                    Dot[$CellContext`amplitude, $CellContext`YAxis]; \
$CellContext`parallelamplitude = 
                    Dot[$CellContext`amplitude, $CellContext`PAxis]; 
                    If[$CellContext`activeregion Part[
                    
                    Dot[$CellContext`surfacerotationmatrix, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}], 1] > 
                    0, $CellContext`index2 = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]; \
$CellContext`index1 = $CellContext`index; 
                    If[Abs[$CellContext`index2 - $CellContext`index1] < 
                    0.01, $CellContext`alternateindex = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]; 
                    If[Abs[$CellContext`alternateindex - $CellContext`index1] > 
                    Abs[$CellContext`index2 - $CellContext`index1], \
$CellContext`index1 = $CellContext`index2; $CellContext`index2 = \
$CellContext`alternateindex, $CellContext`index1 = \
$CellContext`alternateindex], $CellContext`index1 = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]], \
$CellContext`index2 = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]; \
$CellContext`index1 = $CellContext`index; 
                    If[Abs[$CellContext`index2 - $CellContext`index1] < 
                    0.01, $CellContext`alternateindex = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]; 
                    If[Abs[$CellContext`alternateindex - $CellContext`index1] > 
                    Abs[$CellContext`index2 - $CellContext`index1], \
$CellContext`index1 = $CellContext`index2; $CellContext`index2 = \
$CellContext`alternateindex, $CellContext`index1 = \
$CellContext`alternateindex], $CellContext`index1 = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]]]; \
$CellContext`n12 = $CellContext`index1/$CellContext`index2; \
$CellContext`index = $CellContext`index2; 
                    If[1 - $CellContext`n12^2 $CellContext`raytiltx^2 >= 
                    0., $CellContext`dummyvector = $CellContext`n12 \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} + $CellContext`ZAxis \
(-($CellContext`n12 $CellContext`raytiltz) + 
                    Sqrt[1 - $CellContext`n12^2 $CellContext`raytiltx^2]); \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} = \
$CellContext`dummyvector; 1., 
                    If[Dot[{$CellContext`r1, $CellContext`r2, \
$CellContext`r3}, 
                    Part[$CellContext`surfnorm, 1]] > 
                    0, $CellContext`phaseshift = $CellContext`phaseshift + 
                    0.5, 1.]; $CellContext`index2 = $CellContext`index1; \
$CellContext`index = $CellContext`index1; $CellContext`dummyvector = \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} - (2 $CellContext`ZAxis) 
                    Dot[$CellContext`ZAxis, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; {$CellContext`r1, $CellContext`r2, \
$CellContext`r3} = $CellContext`dummyvector; $CellContext`dummyvector = \
{$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} + {0, 
                    0, -180}; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector; 
                    1.]; $CellContext`allcreatedrays = {{$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}; \
$CellContext`originalrotation = Partition[
                    Take[$CellContext`originalray, {7, 15}], 
                    3]; $CellContext`previoustilt = 
                    Part[$CellContext`originalrotation, 
                    1]; $CellContext`transmatrix = 
                    MapIndexed[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`rotationaxis = 
                    Cross[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; $CellContext`axismagnitude = Sqrt[
                    
                    Dot[$CellContext`rotationaxis, \
$CellContext`rotationaxis]]; 
                    If[Chop[$CellContext`axismagnitude] != 
                    N[0], $CellContext`rotationaxis = \
$CellContext`rotationaxis/$CellContext`axismagnitude; $CellContext`axismatrix = 
                    Map[# $CellContext`rotationaxis& , \
$CellContext`rotationaxis]; $CellContext`crossmatrix = {{
                    0., -Part[$CellContext`rotationaxis, 3], 
                    Part[$CellContext`rotationaxis, 2]}, {
                    Part[$CellContext`rotationaxis, 3], 0., -
                    Part[$CellContext`rotationaxis, 1]}, {-
                    Part[$CellContext`rotationaxis, 2], 
                    Part[$CellContext`rotationaxis, 1], 
                    0.}}; $CellContext`cosangle = 
                    Dot[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; 
                    If[1. - $CellContext`cosangle < 
                    2.220446049250313*^-16, $CellContext`cosangle = 
                    1., $CellContext`cosangle = $CellContext`cosangle]; \
$CellContext`sinangle = 1 - $CellContext`cosangle^2; 
                    If[$CellContext`sinangle < 
                    2.220446049250313*^-16, $CellContext`sinangle = 
                    0., $CellContext`sinangle = 
                    Sqrt[$CellContext`sinangle]]; $CellContext`axismatrix + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix) $CellContext`cosangle + \
$CellContext`crossmatrix $CellContext`sinangle, {{$CellContext`r1, \
$CellContext`r2, $CellContext`r3}, {$CellContext`r4, $CellContext`r5, \
$CellContext`r6}, {$CellContext`r7, $CellContext`r8, $CellContext`r9}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0., 
                    0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays]; \
$CellContext`allcreatedrays = 
                    
                    MapIndexed[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
{{$CellContext`r1, $CellContext`r2, $CellContext`r3}, {$CellContext`r4, \
$CellContext`r5, $CellContext`r6}, {$CellContext`r7, $CellContext`r8, \
$CellContext`r9}} = Function[$CellContext`mm, 
                    Map[
                    Dot[$CellContext`mm, #]& , $CellContext`originalrotation]][
                    Part[$CellContext`transmatrix, 
                    First[#2]]]; $CellContext`tiltmagnitude = 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
{$CellContext`r1, $CellContext`r2, $CellContext`r3}]; 
                    If[Abs[$CellContext`tiltmagnitude - 1.] > 
                    1.*^-6, $CellContext`dummyvector = {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}/
                    Sqrt[$CellContext`tiltmagnitude]; {$CellContext`r1, \
$CellContext`r2, $CellContext`r3} = $CellContext`dummyvector; \
$CellContext`dummymatrix = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1, $CellContext`r2, \
$CellContext`r3}, {$CellContext`r4, $CellContext`r5, $CellContext`r6}, \
{$CellContext`r7, $CellContext`r8, $CellContext`r9}}]; {{$CellContext`r1, \
$CellContext`r2, $CellContext`r3}, {$CellContext`r4, $CellContext`r5, \
$CellContext`r6}, {$CellContext`r7, $CellContext`r8, $CellContext`r9}} = \
$CellContext`dummymatrix; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude = 
                    Part[$CellContext`allcreatedamplitudes, 
                    First[#2]]; $CellContext`hor = 
                    Dot[{$CellContext`r4, $CellContext`r5, $CellContext`r6}, \
$CellContext`amplitude]; $CellContext`ver = 
                    Dot[{$CellContext`r7, $CellContext`r8, $CellContext`r9}, \
$CellContext`amplitude]; If[
                    Or[
                    Abs[$CellContext`hor] > 0., Abs[$CellContext`ver] > 
                    0.], {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = {
                    Abs[$CellContext`hor], 
                    Abs[$CellContext`ver], 
                    0.}; $CellContext`dummyvector = {$CellContext`pol1, \
$CellContext`pol2, $CellContext`pol3}/Sqrt[
                    
                    Dot[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}]]; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector; $CellContext`dummyvector = 
                    ReplacePart[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, (If[$CellContext`ver == 0., 0., 
                    Arg[$CellContext`ver]] - If[$CellContext`hor == 0., 0., 
                    Arg[$CellContext`hor]])/Degree, 
                    3]; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector]; 1., 
                    1.]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3})& , \
$CellContext`allcreatedrays]); {$CellContext`allcreatedrays, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray}}, \
$CellContext`resonatenumber == 
                    6, {$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, $CellContext`r1, \
$CellContext`r2, $CellContext`r3, $CellContext`r4, $CellContext`r5, \
$CellContext`r6, $CellContext`r7, $CellContext`r8, $CellContext`r9, \
$CellContext`wavelength, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`ray1, $CellContext`index, $CellContext`opticallength, \
$CellContext`phaseshift, $CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid, $CellContext`ray2, \
$CellContext`ray3, $CellContext`sid, $CellContext`frontid, $CellContext`sno1, \
$CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`rayslot, $CellContext`oldgenerationnumber, \
$CellContext`intersectionnumber, $CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = #; $CellContext`index1 = $CellContext`index; \
$CellContext`xunit = -$CellContext`r3; $CellContext`yunit = -$CellContext`r2; \
$CellContext`zunit = -$CellContext`r1; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = -(-5. + \
$CellContext`rez); $CellContext`ry = -$CellContext`rey; $CellContext`rz = \
-(-10. + $CellContext`rex); $CellContext`rx = 
                    Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = \
$CellContext`resonateintersections; $CellContext`holeQ = 
                    Part[$CellContext`holeQlist, $CellContext`resonatenumber] == 
                    1; {$CellContext`newcomponentnumber, \
$CellContext`newsurfacenumber, $CellContext`newsurfaceid} = {1., 6., 
                    8074.}; {$CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid} = {1., 6., 
                    8074.}; {$CellContext`ray1, $CellContext`ray2, \
$CellContext`ray3} = Part[$CellContext`intersections, 
                    1]; $CellContext`rsx = $CellContext`rex; $CellContext`rsy = \
$CellContext`rey; $CellContext`rsz = $CellContext`rez; $CellContext`rxhlp = \
$CellContext`rx + $CellContext`ray1 $CellContext`xunit; $CellContext`ryhlp = \
$CellContext`ry + $CellContext`ray1 $CellContext`yunit; $CellContext`rzhlp = \
$CellContext`rz + $CellContext`ray1 $CellContext`zunit; $CellContext`rex = 
                    10. - 1. $CellContext`rzhlp; $CellContext`rey = \
-$CellContext`ryhlp; $CellContext`rez = 
                    5. - 1. $CellContext`rxhlp; $CellContext`rex = 
                    Chop[$CellContext`rex]; $CellContext`rey = 
                    Chop[$CellContext`rey]; $CellContext`rez = 
                    Chop[$CellContext`rez]; $CellContext`intersectionnumber = \
$CellContext`intersectionnumber + 
                    1.; $CellContext`opticallength = \
$CellContext`opticallength + $CellContext`ray1 $CellContext`index1; \
$CellContext`completedray = {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`reportedrayspresent = True; $CellContext`intersectionspresent = 
                    True; $CellContext`deflectedrayspresent = 
                    True; $CellContext`localdummyoutrayspresent = 
                    True; ($CellContext`surfnorm = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm]; $CellContext`surfnorm = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix]; \
$CellContext`surfacerotationmatrix = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector = {
                    10., 0, 5.}; $CellContext`activeregion = 
                    1.; $CellContext`completedray = {$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`componentnumber = $CellContext`newcomponentnumber; \
$CellContext`surfacenumber = $CellContext`newsurfacenumber; \
$CellContext`surfaceid = $CellContext`newsurfaceid; $CellContext`originalray = \
{$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, $CellContext`rex, \
$CellContext`rey, $CellContext`rez, $CellContext`r1, $CellContext`r2, \
$CellContext`r3, $CellContext`r4, $CellContext`r5, $CellContext`r6, \
$CellContext`r7, $CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; $CellContext`ZAxis = 
                    First[$CellContext`surfnorm] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm], {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]]; $CellContext`raytiltz = 
                    Dot[$CellContext`ZAxis, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; $CellContext`raytiltx = 
                    1 - $CellContext`raytiltz^2; 
                    If[$CellContext`raytiltx < 
                    2.220446049250313*^-16, $CellContext`raytiltx = 
                    0., $CellContext`raytiltx = 
                    Sqrt[$CellContext`raytiltx]]; $CellContext`XAxis = \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} - $CellContext`ZAxis \
$CellContext`raytiltz; If[
                    Abs[$CellContext`raytiltx] < 1.*^-7, $CellContext`XAxis = 
                    Part[$CellContext`surfnorm, 
                    
                    2], $CellContext`XAxis = \
$CellContext`XAxis/$CellContext`raytiltx]; $CellContext`YAxis = {-(
                    Part[$CellContext`ZAxis, 3] Part[$CellContext`XAxis, 2]) + 
                    Part[$CellContext`ZAxis, 2] Part[$CellContext`XAxis, 3], 
                    Part[$CellContext`ZAxis, 3] Part[$CellContext`XAxis, 1] - 
                    Part[$CellContext`ZAxis, 1] 
                    Part[$CellContext`XAxis, 3], -(
                    Part[$CellContext`ZAxis, 2] Part[$CellContext`XAxis, 1]) + 
                    Part[$CellContext`ZAxis, 1] 
                    Part[$CellContext`XAxis, 
                    2]}; $CellContext`YAxis = $CellContext`YAxis/Sqrt[
                    
                    Dot[$CellContext`YAxis, $CellContext`YAxis]]; \
$CellContext`PAxis = $CellContext`ZAxis 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
$CellContext`XAxis] - $CellContext`XAxis 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
$CellContext`ZAxis]; $CellContext`PAxis = $CellContext`PAxis/Sqrt[
                    
                    Dot[$CellContext`PAxis, $CellContext`PAxis]]; \
$CellContext`normalizedpolarization = 
                    Part[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, {1, 
                    2}]; $CellContext`normalizedpolarization = \
$CellContext`normalizedpolarization/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization, \
$CellContext`normalizedpolarization]]; $CellContext`allcreatedamplitudes = {{
                    0. I, 0. I, 0. I}}; 
                    If[$CellContext`intensity < 0., $CellContext`intensity = 
                    0., 1.]; $CellContext`amplitude = 
                    Sqrt[$CellContext`intensity] (
                    Part[$CellContext`normalizedpolarization, 
                    1] {$CellContext`r4, $CellContext`r5, $CellContext`r6} + (
                    Part[$CellContext`normalizedpolarization, 
                    2] {$CellContext`r7, $CellContext`r8, $CellContext`r9}) 
                    Exp[(I $CellContext`pol3) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude = 
                    Dot[$CellContext`amplitude, $CellContext`YAxis]; \
$CellContext`parallelamplitude = 
                    Dot[$CellContext`amplitude, $CellContext`PAxis]; 
                    If[$CellContext`activeregion Part[
                    
                    Dot[$CellContext`surfacerotationmatrix, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}], 1] > 
                    0, $CellContext`index2 = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]; \
$CellContext`index1 = $CellContext`index; 
                    If[Abs[$CellContext`index2 - $CellContext`index1] < 
                    0.01, $CellContext`alternateindex = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]; 
                    If[Abs[$CellContext`alternateindex - $CellContext`index1] > 
                    Abs[$CellContext`index2 - $CellContext`index1], \
$CellContext`index1 = $CellContext`index2; $CellContext`index2 = \
$CellContext`alternateindex, $CellContext`index1 = \
$CellContext`alternateindex], $CellContext`index1 = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]], \
$CellContext`index2 = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength^8]; \
$CellContext`index1 = $CellContext`index; 
                    If[Abs[$CellContext`index2 - $CellContext`index1] < 
                    0.01, $CellContext`alternateindex = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]; 
                    If[Abs[$CellContext`alternateindex - $CellContext`index1] > 
                    Abs[$CellContext`index2 - $CellContext`index1], \
$CellContext`index1 = $CellContext`index2; $CellContext`index2 = \
$CellContext`alternateindex, $CellContext`index1 = \
$CellContext`alternateindex], $CellContext`index1 = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength^2 + 
                    0.010592509/$CellContext`wavelength^2 + 
                    0.00020816965/$CellContext`wavelength^4 - 
                    7.6472538*^-6/$CellContext`wavelength^6 + 
                    4.9240991*^-7/$CellContext`wavelength^8]]]; \
$CellContext`n12 = $CellContext`index1/$CellContext`index2; \
$CellContext`index = $CellContext`index2; 
                    If[1 - $CellContext`n12^2 $CellContext`raytiltx^2 >= 
                    0., $CellContext`dummyvector = $CellContext`n12 \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} + $CellContext`ZAxis \
(-($CellContext`n12 $CellContext`raytiltz) + 
                    Sqrt[1 - $CellContext`n12^2 $CellContext`raytiltx^2]); \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} = \
$CellContext`dummyvector; 1., 
                    If[Dot[{$CellContext`r1, $CellContext`r2, \
$CellContext`r3}, 
                    Part[$CellContext`surfnorm, 1]] > 
                    0, $CellContext`phaseshift = $CellContext`phaseshift + 
                    0.5, 1.]; $CellContext`index2 = $CellContext`index1; \
$CellContext`index = $CellContext`index1; $CellContext`dummyvector = \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} - (2 $CellContext`ZAxis) 
                    Dot[$CellContext`ZAxis, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; {$CellContext`r1, $CellContext`r2, \
$CellContext`r3} = $CellContext`dummyvector; $CellContext`dummyvector = \
{$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} + {0, 
                    0, -180}; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector; 
                    1.]; $CellContext`allcreatedrays = {{$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}; \
$CellContext`originalrotation = Partition[
                    Take[$CellContext`originalray, {7, 15}], 
                    3]; $CellContext`previoustilt = 
                    Part[$CellContext`originalrotation, 
                    1]; $CellContext`transmatrix = 
                    MapIndexed[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`rotationaxis = 
                    Cross[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; $CellContext`axismagnitude = Sqrt[
                    
                    Dot[$CellContext`rotationaxis, \
$CellContext`rotationaxis]]; 
                    If[Chop[$CellContext`axismagnitude] != 
                    N[0], $CellContext`rotationaxis = \
$CellContext`rotationaxis/$CellContext`axismagnitude; $CellContext`axismatrix = 
                    Map[# $CellContext`rotationaxis& , \
$CellContext`rotationaxis]; $CellContext`crossmatrix = {{
                    0., -Part[$CellContext`rotationaxis, 3], 
                    Part[$CellContext`rotationaxis, 2]}, {
                    Part[$CellContext`rotationaxis, 3], 0., -
                    Part[$CellContext`rotationaxis, 1]}, {-
                    Part[$CellContext`rotationaxis, 2], 
                    Part[$CellContext`rotationaxis, 1], 
                    0.}}; $CellContext`cosangle = 
                    Dot[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; 
                    If[1. - $CellContext`cosangle < 
                    2.220446049250313*^-16, $CellContext`cosangle = 
                    1., $CellContext`cosangle = $CellContext`cosangle]; \
$CellContext`sinangle = 1 - $CellContext`cosangle^2; 
                    If[$CellContext`sinangle < 
                    2.220446049250313*^-16, $CellContext`sinangle = 
                    0., $CellContext`sinangle = 
                    Sqrt[$CellContext`sinangle]]; $CellContext`axismatrix + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix) $CellContext`cosangle + \
$CellContext`crossmatrix $CellContext`sinangle, {{$CellContext`r1, \
$CellContext`r2, $CellContext`r3}, {$CellContext`r4, $CellContext`r5, \
$CellContext`r6}, {$CellContext`r7, $CellContext`r8, $CellContext`r9}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0., 
                    0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays]; \
$CellContext`allcreatedrays = 
                    MapIndexed[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
{{$CellContext`r1, $CellContext`r2, $CellContext`r3}, {$CellContext`r4, \
$CellContext`r5, $CellContext`r6}, {$CellContext`r7, $CellContext`r8, \
$CellContext`r9}} = Function[$CellContext`mm, 
                    Map[
                    Dot[$CellContext`mm, #]& , $CellContext`originalrotation]][
                    Part[$CellContext`transmatrix, 
                    First[#2]]]; $CellContext`tiltmagnitude = 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
{$CellContext`r1, $CellContext`r2, $CellContext`r3}]; 
                    If[Abs[$CellContext`tiltmagnitude - 1.] > 
                    1.*^-6, $CellContext`dummyvector = {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}/
                    Sqrt[$CellContext`tiltmagnitude]; {$CellContext`r1, \
$CellContext`r2, $CellContext`r3} = $CellContext`dummyvector; \
$CellContext`dummymatrix = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1, $CellContext`r2, \
$CellContext`r3}, {$CellContext`r4, $CellContext`r5, $CellContext`r6}, \
{$CellContext`r7, $CellContext`r8, $CellContext`r9}}]; {{$CellContext`r1, \
$CellContext`r2, $CellContext`r3}, {$CellContext`r4, $CellContext`r5, \
$CellContext`r6}, {$CellContext`r7, $CellContext`r8, $CellContext`r9}} = \
$CellContext`dummymatrix; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude = 
                    Part[$CellContext`allcreatedamplitudes, 
                    First[#2]]; $CellContext`hor = 
                    Dot[{$CellContext`r4, $CellContext`r5, $CellContext`r6}, \
$CellContext`amplitude]; $CellContext`ver = 
                    Dot[{$CellContext`r7, $CellContext`r8, $CellContext`r9}, \
$CellContext`amplitude]; If[
                    Or[
                    Abs[$CellContext`hor] > 0., Abs[$CellContext`ver] > 
                    0.], {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = {
                    Abs[$CellContext`hor], 
                    Abs[$CellContext`ver], 
                    0.}; $CellContext`dummyvector = {$CellContext`pol1, \
$CellContext`pol2, $CellContext`pol3}/Sqrt[
                    
                    Dot[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}]]; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector; $CellContext`dummyvector = 
                    ReplacePart[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, (If[$CellContext`ver == 0., 0., 
                    Arg[$CellContext`ver]] - If[$CellContext`hor == 0., 0., 
                    Arg[$CellContext`hor]])/Degree, 
                    3]; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector]; 1., 
                    1.]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3})& , \
$CellContext`allcreatedrays]); {$CellContext`allcreatedrays, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray}}, \
$CellContext`resonatenumber == 
                    7, {$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, $CellContext`r1, \
$CellContext`r2, $CellContext`r3, $CellContext`r4, $CellContext`r5, \
$CellContext`r6, $CellContext`r7, $CellContext`r8, $CellContext`r9, \
$CellContext`wavelength, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`ray1, $CellContext`index, $CellContext`opticallength, \
$CellContext`phaseshift, $CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid, $CellContext`ray2, \
$CellContext`ray3, $CellContext`sid, $CellContext`frontid, $CellContext`sno1, \
$CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`rayslot, $CellContext`oldgenerationnumber, \
$CellContext`intersectionnumber, $CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = #; $CellContext`index1 = $CellContext`index; \
$CellContext`xunit = 0.9961946980917455 $CellContext`r1 + 
                    0.08715574274765817 $CellContext`r2; $CellContext`yunit = \
(-0.08715574274765817) $CellContext`r1 + 
                    0.9961946980917455 $CellContext`r2; $CellContext`zunit = \
$CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = 
                    0.9961946980917455 (-16. + $CellContext`rex) + 
                    0.08715574274765817 $CellContext`rey; $CellContext`ry = \
(-0.08715574274765817) (-16. + $CellContext`rex) + 
                    0.9961946980917455 $CellContext`rey; $CellContext`rz = \
$CellContext`rez; $CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = \
$CellContext`resonateintersections; $CellContext`holeQ = 
                    Part[$CellContext`holeQlist, $CellContext`resonatenumber] == 
                    1; {$CellContext`newcomponentnumber, \
$CellContext`newsurfacenumber, $CellContext`newsurfaceid} = {1., 7., 
                    8210.}; {$CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid} = {1., 7., 
                    8210.}; {$CellContext`ray1, $CellContext`ray2, \
$CellContext`ray3} = Part[$CellContext`intersections, 
                    1]; $CellContext`rsx = $CellContext`rex; $CellContext`rsy = \
$CellContext`rey; $CellContext`rsz = $CellContext`rez; $CellContext`rxhlp = \
$CellContext`rx + $CellContext`ray1 $CellContext`xunit; $CellContext`ryhlp = \
$CellContext`ry + $CellContext`ray1 $CellContext`yunit; $CellContext`rzhlp = \
$CellContext`rz + $CellContext`ray1 $CellContext`zunit; $CellContext`rex = 
                    16. + 0.9961946980917455 $CellContext`rxhlp - 
                    0.08715574274765817 $CellContext`ryhlp; $CellContext`rey = 
                    0.08715574274765817 $CellContext`rxhlp + 
                    0.9961946980917455 $CellContext`ryhlp; $CellContext`rez = \
$CellContext`rzhlp; $CellContext`rex = 
                    Chop[$CellContext`rex]; $CellContext`rey = 
                    Chop[$CellContext`rey]; $CellContext`rez = 
                    Chop[$CellContext`rez]; $CellContext`intersectionnumber = \
$CellContext`intersectionnumber + 
                    1.; $CellContext`opticallength = \
$CellContext`opticallength + $CellContext`ray1 $CellContext`index1; \
$CellContext`completedray = {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`reportedrayspresent = True; $CellContext`intersectionspresent = 
                    True; $CellContext`deflectedrayspresent = 
                    True; $CellContext`localdummyoutrayspresent = 
                    True; ($CellContext`surfnorm = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix = 
                    Map[Dot[{{0.9961946980917455, -0.08715574274765817, 0.}, {
                    0.08715574274765817, 0.9961946980917455, 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm]; $CellContext`surfnorm = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix]; \
$CellContext`surfacerotationmatrix = {{0.9961946980917455, 
                    0.08715574274765817, 0.}, {-0.08715574274765817, 
                    0.9961946980917455, 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector = {
                    16., 0, 0}; $CellContext`activeregion = 
                    0.; $CellContext`completedray = {$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`componentnumber = $CellContext`newcomponentnumber; \
$CellContext`surfacenumber = $CellContext`newsurfacenumber; \
$CellContext`surfaceid = $CellContext`newsurfaceid; $CellContext`originalray = \
{$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, $CellContext`rex, \
$CellContext`rey, $CellContext`rez, $CellContext`r1, $CellContext`r2, \
$CellContext`r3, $CellContext`r4, $CellContext`r5, $CellContext`r6, \
$CellContext`r7, $CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; $CellContext`ZAxis = 
                    First[$CellContext`surfnorm] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm], {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]]; $CellContext`raytiltz = 
                    Dot[$CellContext`ZAxis, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; $CellContext`raytiltx = 
                    1 - $CellContext`raytiltz^2; 
                    If[$CellContext`raytiltx < 
                    2.220446049250313*^-16, $CellContext`raytiltx = 
                    0., $CellContext`raytiltx = 
                    Sqrt[$CellContext`raytiltx]]; $CellContext`XAxis = \
{$CellContext`r1, $CellContext`r2, $CellContext`r3} - $CellContext`ZAxis \
$CellContext`raytiltz; If[
                    Abs[$CellContext`raytiltx] < 1.*^-7, $CellContext`XAxis = 
                    Part[$CellContext`surfnorm, 
                    2], $CellContext`XAxis = \
$CellContext`XAxis/$CellContext`raytiltx]; $CellContext`YAxis = {-(
                    Part[$CellContext`ZAxis, 3] Part[$CellContext`XAxis, 2]) + 
                    Part[$CellContext`ZAxis, 2] Part[$CellContext`XAxis, 3], 
                    Part[$CellContext`ZAxis, 3] Part[$CellContext`XAxis, 1] - 
                    Part[$CellContext`ZAxis, 1] 
                    Part[$CellContext`XAxis, 3], -(
                    Part[$CellContext`ZAxis, 2] Part[$CellContext`XAxis, 1]) + 
                    Part[$CellContext`ZAxis, 1] 
                    Part[$CellContext`XAxis, 
                    2]}; $CellContext`YAxis = $CellContext`YAxis/Sqrt[
                    
                    Dot[$CellContext`YAxis, $CellContext`YAxis]]; \
$CellContext`PAxis = $CellContext`ZAxis 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
$CellContext`XAxis] - $CellContext`XAxis 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
$CellContext`ZAxis]; $CellContext`PAxis = $CellContext`PAxis/Sqrt[
                    
                    Dot[$CellContext`PAxis, $CellContext`PAxis]]; \
$CellContext`normalizedpolarization = 
                    Part[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, {1, 
                    2}]; $CellContext`normalizedpolarization = \
$CellContext`normalizedpolarization/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization, \
$CellContext`normalizedpolarization]]; $CellContext`allcreatedamplitudes = {{
                    0. I, 0. I, 0. I}}; 
                    If[$CellContext`intensity < 0., $CellContext`intensity = 
                    0., 1.]; $CellContext`amplitude = 
                    Sqrt[$CellContext`intensity] (
                    Part[$CellContext`normalizedpolarization, 
                    1] {$CellContext`r4, $CellContext`r5, $CellContext`r6} + (
                    Part[$CellContext`normalizedpolarization, 
                    2] {$CellContext`r7, $CellContext`r8, $CellContext`r9}) 
                    Exp[(I $CellContext`pol3) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude = 
                    Dot[$CellContext`amplitude, $CellContext`YAxis]; \
$CellContext`parallelamplitude = 
                    Dot[$CellContext`amplitude, $CellContext`PAxis]; 
                    If[Dot[{$CellContext`r1, $CellContext`r2, \
$CellContext`r3}, 
                    Part[$CellContext`surfnorm, 1]] > 
                    0, $CellContext`phaseshift = $CellContext`phaseshift + 
                    0.5, 1.]; $CellContext`dummyvector = {$CellContext`r1, \
$CellContext`r2, $CellContext`r3} - (2 $CellContext`ZAxis) 
                    Dot[$CellContext`ZAxis, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; {$CellContext`r1, $CellContext`r2, \
$CellContext`r3} = $CellContext`dummyvector; $CellContext`dummyvector = \
{$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} + {0, 
                    0, -180}; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector; $CellContext`allcreatedrays = \
{{$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, $CellContext`rex, \
$CellContext`rey, $CellContext`rez, $CellContext`r1, $CellContext`r2, \
$CellContext`r3, $CellContext`r4, $CellContext`r5, $CellContext`r6, \
$CellContext`r7, $CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}; \
$CellContext`originalrotation = Partition[
                    Take[$CellContext`originalray, {7, 15}], 
                    3]; $CellContext`previoustilt = 
                    Part[$CellContext`originalrotation, 
                    1]; $CellContext`transmatrix = 
                    MapIndexed[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`rotationaxis = 
                    Cross[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; $CellContext`axismagnitude = Sqrt[
                    
                    Dot[$CellContext`rotationaxis, \
$CellContext`rotationaxis]]; 
                    If[Chop[$CellContext`axismagnitude] != 
                    N[0], $CellContext`rotationaxis = \
$CellContext`rotationaxis/$CellContext`axismagnitude; $CellContext`axismatrix = 
                    Map[# $CellContext`rotationaxis& , \
$CellContext`rotationaxis]; $CellContext`crossmatrix = {{
                    0., -Part[$CellContext`rotationaxis, 3], 
                    Part[$CellContext`rotationaxis, 2]}, {
                    Part[$CellContext`rotationaxis, 3], 0., -
                    Part[$CellContext`rotationaxis, 1]}, {-
                    Part[$CellContext`rotationaxis, 2], 
                    Part[$CellContext`rotationaxis, 1], 
                    0.}}; $CellContext`cosangle = 
                    Dot[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]; 
                    If[1. - $CellContext`cosangle < 
                    2.220446049250313*^-16, $CellContext`cosangle = 
                    1., $CellContext`cosangle = $CellContext`cosangle]; \
$CellContext`sinangle = 1 - $CellContext`cosangle^2; 
                    If[$CellContext`sinangle < 
                    2.220446049250313*^-16, $CellContext`sinangle = 
                    0., $CellContext`sinangle = 
                    Sqrt[$CellContext`sinangle]]; $CellContext`axismatrix + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix) $CellContext`cosangle + \
$CellContext`crossmatrix $CellContext`sinangle, {{$CellContext`r1, \
$CellContext`r2, $CellContext`r3}, {$CellContext`r4, $CellContext`r5, \
$CellContext`r6}, {$CellContext`r7, $CellContext`r8, $CellContext`r9}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt, {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0., 
                    0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays]; \
$CellContext`allcreatedrays = 
                    MapIndexed[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
{{$CellContext`r1, $CellContext`r2, $CellContext`r3}, {$CellContext`r4, \
$CellContext`r5, $CellContext`r6}, {$CellContext`r7, $CellContext`r8, \
$CellContext`r9}} = Function[$CellContext`mm, 
                    Map[
                    Dot[$CellContext`mm, #]& , $CellContext`originalrotation]][
                    Part[$CellContext`transmatrix, 
                    First[#2]]]; $CellContext`tiltmagnitude = 
                    Dot[{$CellContext`r1, $CellContext`r2, $CellContext`r3}, \
{$CellContext`r1, $CellContext`r2, $CellContext`r3}]; 
                    If[Abs[$CellContext`tiltmagnitude - 1.] > 
                    1.*^-6, $CellContext`dummyvector = {$CellContext`r1, \
$CellContext`r2, $CellContext`r3}/
                    Sqrt[$CellContext`tiltmagnitude]; {$CellContext`r1, \
$CellContext`r2, $CellContext`r3} = $CellContext`dummyvector; \
$CellContext`dummymatrix = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1, $CellContext`r2, \
$CellContext`r3}, {$CellContext`r4, $CellContext`r5, $CellContext`r6}, \
{$CellContext`r7, $CellContext`r8, $CellContext`r9}}]; {{$CellContext`r1, \
$CellContext`r2, $CellContext`r3}, {$CellContext`r4, $CellContext`r5, \
$CellContext`r6}, {$CellContext`r7, $CellContext`r8, $CellContext`r9}} = \
$CellContext`dummymatrix; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude = 
                    Part[$CellContext`allcreatedamplitudes, 
                    First[#2]]; $CellContext`hor = 
                    Dot[{$CellContext`r4, $CellContext`r5, $CellContext`r6}, \
$CellContext`amplitude]; $CellContext`ver = 
                    Dot[{$CellContext`r7, $CellContext`r8, $CellContext`r9}, \
$CellContext`amplitude]; If[
                    Or[
                    Abs[$CellContext`hor] > 0., Abs[$CellContext`ver] > 
                    0.], {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = {
                    Abs[$CellContext`hor], 
                    Abs[$CellContext`ver], 
                    0.}; $CellContext`dummyvector = {$CellContext`pol1, \
$CellContext`pol2, $CellContext`pol3}/Sqrt[
                    
                    Dot[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}]]; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector; $CellContext`dummyvector = 
                    ReplacePart[{$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3}, (If[$CellContext`ver == 0., 0., 
                    Arg[$CellContext`ver]] - If[$CellContext`hor == 0., 0., 
                    Arg[$CellContext`hor]])/Degree, 
                    3]; {$CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = $CellContext`dummyvector]; 1., 
                    1.]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3})& , \
$CellContext`allcreatedrays]); {$CellContext`allcreatedrays, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray}}, 
                    True, $CellContext`deflecteddummyrayspresent = 
                    True; $CellContext`reporteddummyrayspresent = 
                    True; $CellContext`localoutrayspresent = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent = 
                    True; $CellContext`reporteddummyrayspresent = 
                    True; $CellContext`localdummyoutrayspresent = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays]]]; If[
                 
                 And[$CellContext`deflectedrayspresent, \
$CellContext`deflecteddummyrayspresent], $CellContext`deflectedlocalrays = 
                 Select[$CellContext`deflectedlocalrays, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent, 
                 If[$CellContext`localdummyoutrayspresent, \
$CellContext`localoutrays = 
                    Select[$CellContext`localoutrays, Part[#, 23] > 0.& ]; 1.,
                    1.]; $CellContext`outrays = 
                  Join[$CellContext`outrays, $CellContext`localoutrays]; 1., 
                 1.]; If[
                 
                 And[$CellContext`reportedrayspresent, \
$CellContext`reporteddummyrayspresent], $CellContext`reportedlocalrays = 
                  Select[$CellContext`reportedlocalrays, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent, $CellContext`raysreported = 
                 True; $CellContext`reportedrays = 
                 Join[$CellContext`reportedrays, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays]; 1., 
                1.]; $CellContext`inrays = $CellContext`deflectedlocalrays; \
$CellContext`propagate = $CellContext`generationnumber < \
$CellContext`generationlimit]; $CellContext`propagatedrays = 
             If[Length[$CellContext`outrays] > 1, 
               Drop[$CellContext`outrays, 1], $CellContext`outrays]; If[
              
              And[$CellContext`generationnumber >= \
$CellContext`generationlimit, $CellContext`deflectedrayspresent], \
$CellContext`propagatedrays = 
               Join[$CellContext`propagatedrays, \
$CellContext`deflectedlocalrays]; 1., 
              1.]); ($CellContext`inrays = $CellContext`propagatedrays; \
$CellContext`outrays = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent = 
             True; $CellContext`reportedrayspresent = 
             False; $CellContext`propagate = True; While[
              And[$CellContext`deflectedrayspresent, $CellContext`propagate], 
              AddTo[$CellContext`generationnumber, 
                1.]; ($CellContext`deflecteddummyrayspresent = 
                False; $CellContext`deflectedrayspresent = 
                False; $CellContext`reportedrayspresent = 
                False; $CellContext`reporteddummyrayspresent = 
                True; $CellContext`localdummyoutrayspresent = 
                False; $CellContext`localoutrayspresent = 
                False; {$CellContext`deflectedlocalrays, \
$CellContext`localoutrays, $CellContext`reportedlocalrays} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; If[
                    
                    And[$CellContext`intensity > \
$CellContext`thresholdintensity, $CellContext`generationnumber < \
$CellContext`generationlimit], ($CellContext`resonatenumber = 
                    0; $CellContext`resonateraylength = 
                    9.87654321*^8; $CellContext`resonateintersections = {{-1.,
                     0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength], \
$CellContext`resonateraylength = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections = #; \
$CellContext`resonatenumber = 
                    First[#2], $CellContext`resonatenumber]& , \
$CellContext`intersectionslist = {{{-1., 0., 0.}}}; $CellContext`holeQlist = {
                    0}; ({$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`index1 = $CellContext`index; $CellContext`xunit = \
-$CellContext`r1; $CellContext`yunit = -$CellContext`r2; $CellContext`zunit = \
$CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = -(-20. + \
$CellContext`rex); $CellContext`ry = -$CellContext`rey; $CellContext`rz = \
$CellContext`rez; $CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = Block[{Compile`$79}, 
                    If[Chop[$CellContext`xunit] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$79 = $CellContext`xunit^(-1); {-($CellContext`rx 
                    Compile`$79), $CellContext`ry - ($CellContext`rx \
$CellContext`yunit) 
                    Compile`$79, $CellContext`rz - ($CellContext`rx \
$CellContext`zunit) Compile`$79}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections, {-1., 0., 
                    0.}]; $CellContext`holeQ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid - 8360.] == 0., N[
                    Chop[$CellContext`ray1]] < 
                    0.0001]], $CellContext`generationnumber == 
                    1.], $CellContext`minresonateraylength = 
                    0., $CellContext`minresonateraylength = 0.0001]; 
                    Block[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy}, $CellContext`LocRayL = 1.; $CellContext`LocSCx = 
                    1.; $CellContext`LocSCy = 1.; $CellContext`dummymatrix = 
                    Union[
                    
                    Select[$CellContext`intersections, \
({$CellContext`LocRayL, $CellContext`LocSCx, $CellContext`LocSCy} = #; 
                    Or[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL]] >= \
$CellContext`minresonateraylength])& ]]; $CellContext`intersections = \
$CellContext`dummymatrix]; $CellContext`unfilteredintersections = \
$CellContext`intersections; 
                    If[Length[$CellContext`intersections] > 
                    1, $CellContext`dummymatrix = 
                    Take[$CellContext`intersections, {
                    2}]; $CellContext`intersections = \
$CellContext`dummymatrix; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist, \
$CellContext`intersections]; If[$CellContext`holeQ, 
                    AppendTo[$CellContext`holeQlist, 1], 
                    
                    AppendTo[$CellContext`holeQlist, 
                    0]]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`index1 = $CellContext`index; $CellContext`xunit = \
$CellContext`r2; $CellContext`yunit = -$CellContext`r1; $CellContext`zunit = \
$CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = 
                    10. + $CellContext`rey; $CellContext`ry = -(-10. + \
$CellContext`rex); $CellContext`rz = $CellContext`rez; $CellContext`rx = 
                    Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = Block[{Compile`$81}, 
                    If[Chop[$CellContext`xunit] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$81 = $CellContext`xunit^(-1); {-($CellContext`rx 
                    Compile`$81), $CellContext`ry - ($CellContext`rx \
$CellContext`yunit) 
                    Compile`$81, $CellContext`rz - ($CellContext`rx \
$CellContext`zunit) Compile`$81}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections, {-1., 0., 
                    0.}]; $CellContext`holeQ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid - 8361.] == 0., N[
                    Chop[$CellContext`ray1]] < 
                    0.0001]], $CellContext`generationnumber == 
                    1.], $CellContext`minresonateraylength = 
                    0., $CellContext`minresonateraylength = 0.0001]; 
                    Block[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy}, $CellContext`LocRayL = 1.; $CellContext`LocSCx = 
                    1.; $CellContext`LocSCy = 1.; $CellContext`dummymatrix = 
                    Union[
                    
                    Select[$CellContext`intersections, \
({$CellContext`LocRayL, $CellContext`LocSCx, $CellContext`LocSCy} = #; 
                    Or[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL]] >= \
$CellContext`minresonateraylength])& ]]; $CellContext`intersections = \
$CellContext`dummymatrix]; $CellContext`unfilteredintersections = \
$CellContext`intersections; 
                    If[Length[$CellContext`intersections] > 
                    1, $CellContext`dummymatrix = 
                    Take[$CellContext`intersections, {
                    2}]; $CellContext`intersections = \
$CellContext`dummymatrix; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist, \
$CellContext`intersections]; If[$CellContext`holeQ, 
                    AppendTo[$CellContext`holeQlist, 1], 
                    
                    AppendTo[$CellContext`holeQlist, 
                    0]]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`index1 = $CellContext`index; $CellContext`xunit = \
$CellContext`r1; $CellContext`yunit = $CellContext`r2; $CellContext`zunit = \
$CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = $CellContext`rex; \
$CellContext`ry = $CellContext`rey; $CellContext`rz = $CellContext`rez; \
$CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = Block[{Compile`$79}, 
                    If[Chop[$CellContext`xunit] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$79 = $CellContext`xunit^(-1); {-($CellContext`rx 
                    Compile`$79), $CellContext`ry - ($CellContext`rx \
$CellContext`yunit) 
                    Compile`$79, $CellContext`rz - ($CellContext`rx \
$CellContext`zunit) Compile`$79}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections, {-1., 0., 
                    0.}]; $CellContext`holeQ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid - 8362.] == 0., N[
                    Chop[$CellContext`ray1]] < 
                    0.0001]], $CellContext`generationnumber == 
                    1.], $CellContext`minresonateraylength = 
                    0., $CellContext`minresonateraylength = 0.0001]; 
                    Block[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy}, $CellContext`LocRayL = 1.; $CellContext`LocSCx = 
                    1.; $CellContext`LocSCy = 1.; $CellContext`dummymatrix = 
                    Union[
                    
                    Select[$CellContext`intersections, \
({$CellContext`LocRayL, $CellContext`LocSCx, $CellContext`LocSCy} = #; 
                    Or[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL]] >= \
$CellContext`minresonateraylength])& ]]; $CellContext`intersections = \
$CellContext`dummymatrix]; $CellContext`unfilteredintersections = \
$CellContext`intersections; 
                    If[Length[$CellContext`intersections] > 
                    1, $CellContext`dummymatrix = 
                    Take[$CellContext`intersections, {
                    2}]; $CellContext`intersections = \
$CellContext`dummymatrix; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist, \
$CellContext`intersections]; If[$CellContext`holeQ, 
                    AppendTo[$CellContext`holeQlist, 1], 
                    
                    AppendTo[$CellContext`holeQlist, 
                    0]]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`index1 = $CellContext`index; $CellContext`xunit = \
-$CellContext`r2; $CellContext`yunit = $CellContext`r1; $CellContext`zunit = \
$CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = -(-10. + \
$CellContext`rey); $CellContext`ry = -10. + $CellContext`rex; $CellContext`rz = \
$CellContext`rez; $CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = Block[{Compile`$81}, 
                    If[Chop[$CellContext`xunit] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$81 = $CellContext`xunit^(-1); {-($CellContext`rx 
                    Compile`$81), $CellContext`ry - ($CellContext`rx \
$CellContext`yunit) 
                    Compile`$81, $CellContext`rz - ($CellContext`rx \
$CellContext`zunit) Compile`$81}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections, {-1., 0., 
                    0.}]; $CellContext`holeQ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid - 8363.] == 0., N[
                    Chop[$CellContext`ray1]] < 
                    0.0001]], $CellContext`generationnumber == 
                    1.], $CellContext`minresonateraylength = 
                    0., $CellContext`minresonateraylength = 0.0001]; 
                    Block[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy}, $CellContext`LocRayL = 1.; $CellContext`LocSCx = 
                    1.; $CellContext`LocSCy = 1.; $CellContext`dummymatrix = 
                    Union[
                    
                    Select[$CellContext`intersections, \
({$CellContext`LocRayL, $CellContext`LocSCx, $CellContext`LocSCy} = #; 
                    Or[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL]] >= \
$CellContext`minresonateraylength])& ]]; $CellContext`intersections = \
$CellContext`dummymatrix]; $CellContext`unfilteredintersections = \
$CellContext`intersections; 
                    If[Length[$CellContext`intersections] > 
                    1, $CellContext`dummymatrix = 
                    Take[$CellContext`intersections, {
                    2}]; $CellContext`intersections = \
$CellContext`dummymatrix; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist, \
$CellContext`intersections]; If[$CellContext`holeQ, 
                    AppendTo[$CellContext`holeQlist, 1], 
                    
                    AppendTo[$CellContext`holeQlist, 
                    0]]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`index1 = $CellContext`index; $CellContext`xunit = \
$CellContext`r3; $CellContext`yunit = $CellContext`r2; $CellContext`zunit = \
-$CellContext`r1; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = 
                    10. + $CellContext`rez; $CellContext`ry = \
$CellContext`rey; $CellContext`rz = -(-10. + $CellContext`rex); \
$CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = Block[{Compile`$80}, 
                    If[Chop[$CellContext`xunit] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$80 = $CellContext`xunit^(-1); {-($CellContext`rx 
                    Compile`$80), $CellContext`ry - ($CellContext`rx \
$CellContext`yunit) 
                    Compile`$80, $CellContext`rz - ($CellContext`rx \
$CellContext`zunit) Compile`$80}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections, {-1., 0., 
                    0.}]; $CellContext`holeQ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid - 8364.] == 0., N[
                    Chop[$CellContext`ray1]] < 
                    0.0001]], $CellContext`generationnumber == 
                    1.], $CellContext`minresonateraylength = 
                    0., $CellContext`minresonateraylength = 0.0001]; 
                    Block[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy}, $CellContext`LocRayL = 1.; $CellContext`LocSCx = 
                    1.; $CellContext`LocSCy = 1.; $CellContext`dummymatrix = 
                    Union[
                    
                    Select[$CellContext`intersections, \
({$CellContext`LocRayL, $CellContext`LocSCx, $CellContext`LocSCy} = #; 
                    Or[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL]] >= \
$CellContext`minresonateraylength])& ]]; $CellContext`intersections = \
$CellContext`dummymatrix]; $CellContext`unfilteredintersections = \
$CellContext`intersections; 
                    If[Length[$CellContext`intersections] > 
                    1, $CellContext`dummymatrix = 
                    Take[$CellContext`intersections, {
                    2}]; $CellContext`intersections = \
$CellContext`dummymatrix; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist, \
$CellContext`intersections]; If[$CellContext`holeQ, 
                    AppendTo[$CellContext`holeQlist, 1], 
                    
                    AppendTo[$CellContext`holeQlist, 
                    0]]; {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`oldgenerationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3} = #; \
$CellContext`index1 = $CellContext`index; $CellContext`xunit = \
-$CellContext`r3; $CellContext`yunit = -$CellContext`r2; $CellContext`zunit = \
-$CellContext`r1; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = -(-10. + \
$CellContext`rez); $CellContext`ry = -$CellContext`rey; $CellContext`rz = \
-(-10. + $CellContext`rex); $CellContext`rx = 
                    Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = Block[{Compile`$80}, 
                    If[Chop[$CellContext`xunit] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$80 = $CellContext`xunit^(-1); {-($CellContext`rx 
                    Compile`$80), $CellContext`ry - ($CellContext`rx \
$CellContext`yunit) 
                    Compile`$80, $CellContext`rz - ($CellContext`rx \
$CellContext`zunit) Compile`$80}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections, {-1., 0., 
                    0.}]; $CellContext`holeQ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid - 8365.] == 0., N[
                    Chop[$CellContext`ray1]] < 
                    0.0001]], $CellContext`generationnumber == 
                    1.], $CellContext`minresonateraylength = 
                    0., $CellContext`minresonateraylength = 0.0001]; 
                    Block[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy}, $CellContext`LocRayL = 1.; $CellContext`LocSCx = 
                    1.; $CellContext`LocSCy = 1.; $CellContext`dummymatrix = 
                    Union[
                    
                    Select[$CellContext`intersections, \
({$CellContext`LocRayL, $CellContext`LocSCx, $CellContext`LocSCy} = #; 
                    Or[{$CellContext`LocRayL, $CellContext`LocSCx, \
$CellContext`LocSCy} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL]] >= \
$CellContext`minresonateraylength])& ]]; $CellContext`intersections = \
$CellContext`dummymatrix]; $CellContext`unfilteredintersections = \
$CellContext`intersections; 
                    If[Length[$CellContext`intersections] > 
                    1, $CellContext`dummymatrix = 
                    Take[$CellContext`intersections, {
                    2}]; $CellContext`intersections = \
$CellContext`dummymatrix; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist, \
$CellContext`intersections]; If[$CellContext`holeQ, 
                    AppendTo[$CellContext`holeQlist, 1], 
                    
                    AppendTo[$CellContext`holeQlist, 
                    0]]); $CellContext`holeQlist = 
                    Drop[$CellContext`holeQlist, 1]; 
                    Drop[$CellContext`intersectionslist, 1]]); 
                    Which[$CellContext`resonatenumber == 
                    1, {$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, $CellContext`r1, \
$CellContext`r2, $CellContext`r3, $CellContext`r4, $CellContext`r5, \
$CellContext`r6, $CellContext`r7, $CellContext`r8, $CellContext`r9, \
$CellContext`wavelength, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`ray1, $CellContext`index, $CellContext`opticallength, \
$CellContext`phaseshift, $CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid, $CellContext`ray2, \
$CellContext`ray3, $CellContext`sid, $CellContext`frontid, $CellContext`sno1, \
$CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`rayslot, $CellContext`oldgenerationnumber, \
$CellContext`intersectionnumber, $CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = #; $CellContext`index1 = $CellContext`index; \
$CellContext`xunit = -$CellContext`r1; $CellContext`yunit = -$CellContext`r2; \
$CellContext`zunit = $CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = -(-20. + \
$CellContext`rex); $CellContext`ry = -$CellContext`rey; $CellContext`rz = \
$CellContext`rez; $CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = \
$CellContext`resonateintersections; $CellContext`holeQ = 
                    Part[$CellContext`holeQlist, $CellContext`resonatenumber] == 
                    1; {$CellContext`newcomponentnumber, \
$CellContext`newsurfacenumber, $CellContext`newsurfaceid} = {2., 1., 
                    8360.}; {$CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid} = {2., 1., 
                    8360.}; {$CellContext`ray1, $CellContext`ray2, \
$CellContext`ray3} = Part[$CellContext`intersections, 
                    1]; $CellContext`rsx = $CellContext`rex; $CellContext`rsy = \
$CellContext`rey; $CellContext`rsz = $CellContext`rez; $CellContext`rxhlp = \
$CellContext`rx + $CellContext`ray1 $CellContext`xunit; $CellContext`ryhlp = \
$CellContext`ry + $CellContext`ray1 $CellContext`yunit; $CellContext`rzhlp = \
$CellContext`rz + $CellContext`ray1 $CellContext`zunit; $CellContext`rex = 
                    20. - 1. $CellContext`rxhlp; $CellContext`rey = \
-$CellContext`ryhlp; $CellContext`rez = $CellContext`rzhlp; $CellContext`rex = 
                    Chop[$CellContext`rex]; $CellContext`rey = 
                    Chop[$CellContext`rey]; $CellContext`rez = 
                    Chop[$CellContext`rez]; $CellContext`intersectionnumber = \
$CellContext`intersectionnumber + 
                    1.; $CellContext`opticallength = \
$CellContext`opticallength + $CellContext`ray1 $CellContext`index1; \
$CellContext`completedray = {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`reportedrayspresent = True; $CellContext`intersectionspresent = 
                    True; $CellContext`deflectedrayspresent = 
                    True; $CellContext`localdummyoutrayspresent = 
                    True; ($CellContext`surfnorm = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm]; $CellContext`surfnorm = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix]; \
$CellContext`surfacerotationmatrix = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector = {
                    20., 0, 0}; $CellContext`activeregion = 
                    0.; $CellContext`completedray = {$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`componentnumber = $CellContext`newcomponentnumber; \
$CellContext`surfacenumber = $CellContext`newsurfacenumber; \
$CellContext`surfaceid = $CellContext`newsurfaceid; $CellContext`originalray = \
{$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, $CellContext`rex, \
$CellContext`rey, $CellContext`rez, $CellContext`r1, $CellContext`r2, \
$CellContext`r3, $CellContext`r4, $CellContext`r5, $CellContext`r6, \
$CellContext`r7, $CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`intensity = 
                    0.; $CellContext`allcreatedrays = {{$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}); \
{$CellContext`allcreatedrays, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray}}, \
$CellContext`resonatenumber == 
                    2, {$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, $CellContext`r1, \
$CellContext`r2, $CellContext`r3, $CellContext`r4, $CellContext`r5, \
$CellContext`r6, $CellContext`r7, $CellContext`r8, $CellContext`r9, \
$CellContext`wavelength, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`ray1, $CellContext`index, $CellContext`opticallength, \
$CellContext`phaseshift, $CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid, $CellContext`ray2, \
$CellContext`ray3, $CellContext`sid, $CellContext`frontid, $CellContext`sno1, \
$CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`rayslot, $CellContext`oldgenerationnumber, \
$CellContext`intersectionnumber, $CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = #; $CellContext`index1 = $CellContext`index; \
$CellContext`xunit = $CellContext`r2; $CellContext`yunit = -$CellContext`r1; \
$CellContext`zunit = $CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = 
                    10. + $CellContext`rey; $CellContext`ry = -(-10. + \
$CellContext`rex); $CellContext`rz = $CellContext`rez; $CellContext`rx = 
                    Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = \
$CellContext`resonateintersections; $CellContext`holeQ = 
                    Part[$CellContext`holeQlist, $CellContext`resonatenumber] == 
                    1; {$CellContext`newcomponentnumber, \
$CellContext`newsurfacenumber, $CellContext`newsurfaceid} = {2., 2., 
                    8361.}; {$CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid} = {2., 2., 
                    8361.}; {$CellContext`ray1, $CellContext`ray2, \
$CellContext`ray3} = Part[$CellContext`intersections, 
                    1]; $CellContext`rsx = $CellContext`rex; $CellContext`rsy = \
$CellContext`rey; $CellContext`rsz = $CellContext`rez; $CellContext`rxhlp = \
$CellContext`rx + $CellContext`ray1 $CellContext`xunit; $CellContext`ryhlp = \
$CellContext`ry + $CellContext`ray1 $CellContext`yunit; $CellContext`rzhlp = \
$CellContext`rz + $CellContext`ray1 $CellContext`zunit; $CellContext`rex = 
                    10. - 1. $CellContext`ryhlp; $CellContext`rey = -10. + \
$CellContext`rxhlp; $CellContext`rez = $CellContext`rzhlp; $CellContext`rex = 
                    Chop[$CellContext`rex]; $CellContext`rey = 
                    Chop[$CellContext`rey]; $CellContext`rez = 
                    Chop[$CellContext`rez]; $CellContext`intersectionnumber = \
$CellContext`intersectionnumber + 
                    1.; $CellContext`opticallength = \
$CellContext`opticallength + $CellContext`ray1 $CellContext`index1; \
$CellContext`completedray = {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`reportedrayspresent = True; $CellContext`intersectionspresent = 
                    True; $CellContext`deflectedrayspresent = 
                    True; $CellContext`localdummyoutrayspresent = 
                    True; ($CellContext`surfnorm = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm]; $CellContext`surfnorm = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix]; \
$CellContext`surfacerotationmatrix = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector = {
                    10., -10., 0}; $CellContext`activeregion = 
                    0.; $CellContext`completedray = {$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`componentnumber = $CellContext`newcomponentnumber; \
$CellContext`surfacenumber = $CellContext`newsurfacenumber; \
$CellContext`surfaceid = $CellContext`newsurfaceid; $CellContext`originalray = \
{$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, $CellContext`rex, \
$CellContext`rey, $CellContext`rez, $CellContext`r1, $CellContext`r2, \
$CellContext`r3, $CellContext`r4, $CellContext`r5, $CellContext`r6, \
$CellContext`r7, $CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`intensity = 
                    0.; $CellContext`allcreatedrays = {{$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}); \
{$CellContext`allcreatedrays, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray}}, \
$CellContext`resonatenumber == 
                    3, {$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, $CellContext`r1, \
$CellContext`r2, $CellContext`r3, $CellContext`r4, $CellContext`r5, \
$CellContext`r6, $CellContext`r7, $CellContext`r8, $CellContext`r9, \
$CellContext`wavelength, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`ray1, $CellContext`index, $CellContext`opticallength, \
$CellContext`phaseshift, $CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid, $CellContext`ray2, \
$CellContext`ray3, $CellContext`sid, $CellContext`frontid, $CellContext`sno1, \
$CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`rayslot, $CellContext`oldgenerationnumber, \
$CellContext`intersectionnumber, $CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = #; $CellContext`index1 = $CellContext`index; \
$CellContext`xunit = $CellContext`r1; $CellContext`yunit = $CellContext`r2; \
$CellContext`zunit = $CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = $CellContext`rex; \
$CellContext`ry = $CellContext`rey; $CellContext`rz = $CellContext`rez; \
$CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = \
$CellContext`resonateintersections; $CellContext`holeQ = 
                    Part[$CellContext`holeQlist, $CellContext`resonatenumber] == 
                    1; {$CellContext`newcomponentnumber, \
$CellContext`newsurfacenumber, $CellContext`newsurfaceid} = {2., 3., 
                    8362.}; {$CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid} = {2., 3., 
                    8362.}; {$CellContext`ray1, $CellContext`ray2, \
$CellContext`ray3} = Part[$CellContext`intersections, 
                    1]; $CellContext`rsx = $CellContext`rex; $CellContext`rsy = \
$CellContext`rey; $CellContext`rsz = $CellContext`rez; $CellContext`rxhlp = \
$CellContext`rx + $CellContext`ray1 $CellContext`xunit; $CellContext`ryhlp = \
$CellContext`ry + $CellContext`ray1 $CellContext`yunit; $CellContext`rzhlp = \
$CellContext`rz + $CellContext`ray1 $CellContext`zunit; $CellContext`rex = \
$CellContext`rxhlp; $CellContext`rey = $CellContext`ryhlp; $CellContext`rez = \
$CellContext`rzhlp; $CellContext`rex = 
                    Chop[$CellContext`rex]; $CellContext`rey = 
                    Chop[$CellContext`rey]; $CellContext`rez = 
                    Chop[$CellContext`rez]; $CellContext`intersectionnumber = \
$CellContext`intersectionnumber + 
                    1.; $CellContext`opticallength = \
$CellContext`opticallength + $CellContext`ray1 $CellContext`index1; \
$CellContext`completedray = {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`reportedrayspresent = True; $CellContext`intersectionspresent = 
                    True; $CellContext`deflectedrayspresent = 
                    True; $CellContext`localdummyoutrayspresent = 
                    True; ($CellContext`surfnorm = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix = 
                    Map[#& , $CellContext`surfnorm]; $CellContext`surfnorm = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix]; \
$CellContext`surfacerotationmatrix = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector = {0, 0, 
                    0}; $CellContext`activeregion = 
                    0.; $CellContext`completedray = {$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`componentnumber = $CellContext`newcomponentnumber; \
$CellContext`surfacenumber = $CellContext`newsurfacenumber; \
$CellContext`surfaceid = $CellContext`newsurfaceid; $CellContext`originalray = \
{$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, $CellContext`rex, \
$CellContext`rey, $CellContext`rez, $CellContext`r1, $CellContext`r2, \
$CellContext`r3, $CellContext`r4, $CellContext`r5, $CellContext`r6, \
$CellContext`r7, $CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`intensity = 
                    0.; $CellContext`allcreatedrays = {{$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}); \
{$CellContext`allcreatedrays, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray}}, \
$CellContext`resonatenumber == 
                    4, {$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, $CellContext`r1, \
$CellContext`r2, $CellContext`r3, $CellContext`r4, $CellContext`r5, \
$CellContext`r6, $CellContext`r7, $CellContext`r8, $CellContext`r9, \
$CellContext`wavelength, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`ray1, $CellContext`index, $CellContext`opticallength, \
$CellContext`phaseshift, $CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid, $CellContext`ray2, \
$CellContext`ray3, $CellContext`sid, $CellContext`frontid, $CellContext`sno1, \
$CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`rayslot, $CellContext`oldgenerationnumber, \
$CellContext`intersectionnumber, $CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = #; $CellContext`index1 = $CellContext`index; \
$CellContext`xunit = -$CellContext`r2; $CellContext`yunit = $CellContext`r1; \
$CellContext`zunit = $CellContext`r3; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = -(-10. + \
$CellContext`rey); $CellContext`ry = -10. + $CellContext`rex; $CellContext`rz = \
$CellContext`rez; $CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = \
$CellContext`resonateintersections; $CellContext`holeQ = 
                    Part[$CellContext`holeQlist, $CellContext`resonatenumber] == 
                    1; {$CellContext`newcomponentnumber, \
$CellContext`newsurfacenumber, $CellContext`newsurfaceid} = {2., 4., 
                    8363.}; {$CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid} = {2., 4., 
                    8363.}; {$CellContext`ray1, $CellContext`ray2, \
$CellContext`ray3} = Part[$CellContext`intersections, 
                    1]; $CellContext`rsx = $CellContext`rex; $CellContext`rsy = \
$CellContext`rey; $CellContext`rsz = $CellContext`rez; $CellContext`rxhlp = \
$CellContext`rx + $CellContext`ray1 $CellContext`xunit; $CellContext`ryhlp = \
$CellContext`ry + $CellContext`ray1 $CellContext`yunit; $CellContext`rzhlp = \
$CellContext`rz + $CellContext`ray1 $CellContext`zunit; $CellContext`rex = 
                    10. + $CellContext`ryhlp; $CellContext`rey = 
                    10. - 1. $CellContext`rxhlp; $CellContext`rez = \
$CellContext`rzhlp; $CellContext`rex = 
                    Chop[$CellContext`rex]; $CellContext`rey = 
                    Chop[$CellContext`rey]; $CellContext`rez = 
                    Chop[$CellContext`rez]; $CellContext`intersectionnumber = \
$CellContext`intersectionnumber + 
                    1.; $CellContext`opticallength = \
$CellContext`opticallength + $CellContext`ray1 $CellContext`index1; \
$CellContext`completedray = {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`reportedrayspresent = True; $CellContext`intersectionspresent = 
                    True; $CellContext`deflectedrayspresent = 
                    True; $CellContext`localdummyoutrayspresent = 
                    True; ($CellContext`surfnorm = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm]; $CellContext`surfnorm = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix]; \
$CellContext`surfacerotationmatrix = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector = {
                    10., 10., 0}; $CellContext`activeregion = 
                    0.; $CellContext`completedray = {$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`componentnumber = $CellContext`newcomponentnumber; \
$CellContext`surfacenumber = $CellContext`newsurfacenumber; \
$CellContext`surfaceid = $CellContext`newsurfaceid; $CellContext`originalray = \
{$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, $CellContext`rex, \
$CellContext`rey, $CellContext`rez, $CellContext`r1, $CellContext`r2, \
$CellContext`r3, $CellContext`r4, $CellContext`r5, $CellContext`r6, \
$CellContext`r7, $CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`intensity = 
                    0.; $CellContext`allcreatedrays = {{$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}); \
{$CellContext`allcreatedrays, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray}}, \
$CellContext`resonatenumber == 
                    5, {$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, $CellContext`r1, \
$CellContext`r2, $CellContext`r3, $CellContext`r4, $CellContext`r5, \
$CellContext`r6, $CellContext`r7, $CellContext`r8, $CellContext`r9, \
$CellContext`wavelength, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`ray1, $CellContext`index, $CellContext`opticallength, \
$CellContext`phaseshift, $CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid, $CellContext`ray2, \
$CellContext`ray3, $CellContext`sid, $CellContext`frontid, $CellContext`sno1, \
$CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`rayslot, $CellContext`oldgenerationnumber, \
$CellContext`intersectionnumber, $CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = #; $CellContext`index1 = $CellContext`index; \
$CellContext`xunit = $CellContext`r3; $CellContext`yunit = $CellContext`r2; \
$CellContext`zunit = -$CellContext`r1; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = 
                    10. + $CellContext`rez; $CellContext`ry = \
$CellContext`rey; $CellContext`rz = -(-10. + $CellContext`rex); \
$CellContext`rx = Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = \
$CellContext`resonateintersections; $CellContext`holeQ = 
                    Part[$CellContext`holeQlist, $CellContext`resonatenumber] == 
                    1; {$CellContext`newcomponentnumber, \
$CellContext`newsurfacenumber, $CellContext`newsurfaceid} = {2., 5., 
                    8364.}; {$CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid} = {2., 5., 
                    8364.}; {$CellContext`ray1, $CellContext`ray2, \
$CellContext`ray3} = Part[$CellContext`intersections, 
                    1]; $CellContext`rsx = $CellContext`rex; $CellContext`rsy = \
$CellContext`rey; $CellContext`rsz = $CellContext`rez; $CellContext`rxhlp = \
$CellContext`rx + $CellContext`ray1 $CellContext`xunit; $CellContext`ryhlp = \
$CellContext`ry + $CellContext`ray1 $CellContext`yunit; $CellContext`rzhlp = \
$CellContext`rz + $CellContext`ray1 $CellContext`zunit; $CellContext`rex = 
                    10. - 1. $CellContext`rzhlp; $CellContext`rey = \
$CellContext`ryhlp; $CellContext`rez = -10. + $CellContext`rxhlp; \
$CellContext`rex = Chop[$CellContext`rex]; $CellContext`rey = 
                    Chop[$CellContext`rey]; $CellContext`rez = 
                    Chop[$CellContext`rez]; $CellContext`intersectionnumber = \
$CellContext`intersectionnumber + 
                    1.; $CellContext`opticallength = \
$CellContext`opticallength + $CellContext`ray1 $CellContext`index1; \
$CellContext`completedray = {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`reportedrayspresent = True; $CellContext`intersectionspresent = 
                    True; $CellContext`deflectedrayspresent = 
                    True; $CellContext`localdummyoutrayspresent = 
                    True; ($CellContext`surfnorm = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm]; $CellContext`surfnorm = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix]; \
$CellContext`surfacerotationmatrix = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector = {
                    10., 0, -10.}; $CellContext`activeregion = 
                    0.; $CellContext`completedray = {$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`componentnumber = $CellContext`newcomponentnumber; \
$CellContext`surfacenumber = $CellContext`newsurfacenumber; \
$CellContext`surfaceid = $CellContext`newsurfaceid; $CellContext`originalray = \
{$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, $CellContext`rex, \
$CellContext`rey, $CellContext`rez, $CellContext`r1, $CellContext`r2, \
$CellContext`r3, $CellContext`r4, $CellContext`r5, $CellContext`r6, \
$CellContext`r7, $CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`intensity = 
                    0.; $CellContext`allcreatedrays = {{$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}); \
{$CellContext`allcreatedrays, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray}}, \
$CellContext`resonatenumber == 
                    6, {$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, \
$CellContext`rex, $CellContext`rey, $CellContext`rez, $CellContext`r1, \
$CellContext`r2, $CellContext`r3, $CellContext`r4, $CellContext`r5, \
$CellContext`r6, $CellContext`r7, $CellContext`r8, $CellContext`r9, \
$CellContext`wavelength, $CellContext`intensity, $CellContext`intensityscale, \
$CellContext`ray1, $CellContext`index, $CellContext`opticallength, \
$CellContext`phaseshift, $CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid, $CellContext`ray2, \
$CellContext`ray3, $CellContext`sid, $CellContext`frontid, $CellContext`sno1, \
$CellContext`sno2, $CellContext`sno3, $CellContext`sno4, \
$CellContext`rayslot, $CellContext`oldgenerationnumber, \
$CellContext`intersectionnumber, $CellContext`pol1, $CellContext`pol2, \
$CellContext`pol3} = #; $CellContext`index1 = $CellContext`index; \
$CellContext`xunit = -$CellContext`r3; $CellContext`yunit = -$CellContext`r2; \
$CellContext`zunit = -$CellContext`r1; $CellContext`xunit = 
                    Chop[$CellContext`xunit]; $CellContext`yunit = 
                    Chop[$CellContext`yunit]; $CellContext`zunit = 
                    Chop[$CellContext`zunit]; $CellContext`magnitude = \
($CellContext`xunit^2 + $CellContext`yunit^2 + $CellContext`zunit^2)^(
                    2^(-1)); $CellContext`xunit = \
$CellContext`xunit/$CellContext`magnitude; $CellContext`yunit = \
$CellContext`yunit/$CellContext`magnitude; $CellContext`zunit = \
$CellContext`zunit/$CellContext`magnitude; $CellContext`rx = -(-10. + \
$CellContext`rez); $CellContext`ry = -$CellContext`rey; $CellContext`rz = \
-(-10. + $CellContext`rex); $CellContext`rx = 
                    Chop[$CellContext`rx]; $CellContext`ry = 
                    Chop[$CellContext`ry]; $CellContext`rz = 
                    Chop[$CellContext`rz]; $CellContext`terminatedeflection = 
                    False; $CellContext`intersections = {{-1., 0., 
                    0.}}; $CellContext`intersections = \
$CellContext`resonateintersections; $CellContext`holeQ = 
                    Part[$CellContext`holeQlist, $CellContext`resonatenumber] == 
                    1; {$CellContext`newcomponentnumber, \
$CellContext`newsurfacenumber, $CellContext`newsurfaceid} = {2., 6., 
                    8365.}; {$CellContext`componentnumber, \
$CellContext`surfacenumber, $CellContext`surfaceid} = {2., 6., 
                    8365.}; {$CellContext`ray1, $CellContext`ray2, \
$CellContext`ray3} = Part[$CellContext`intersections, 
                    1]; $CellContext`rsx = $CellContext`rex; $CellContext`rsy = \
$CellContext`rey; $CellContext`rsz = $CellContext`rez; $CellContext`rxhlp = \
$CellContext`rx + $CellContext`ray1 $CellContext`xunit; $CellContext`ryhlp = \
$CellContext`ry + $CellContext`ray1 $CellContext`yunit; $CellContext`rzhlp = \
$CellContext`rz + $CellContext`ray1 $CellContext`zunit; $CellContext`rex = 
                    10. - 1. $CellContext`rzhlp; $CellContext`rey = \
-$CellContext`ryhlp; $CellContext`rez = 
                    10. - 1. $CellContext`rxhlp; $CellContext`rex = 
                    Chop[$CellContext`rex]; $CellContext`rey = 
                    Chop[$CellContext`rey]; $CellContext`rez = 
                    Chop[$CellContext`rez]; $CellContext`intersectionnumber = \
$CellContext`intersectionnumber + 
                    1.; $CellContext`opticallength = \
$CellContext`opticallength + $CellContext`ray1 $CellContext`index1; \
$CellContext`completedray = {$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`reportedrayspresent = True; $CellContext`intersectionspresent = 
                    True; $CellContext`deflectedrayspresent = 
                    True; $CellContext`localdummyoutrayspresent = 
                    True; ($CellContext`surfnorm = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm]; $CellContext`surfnorm = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix]; \
$CellContext`surfacerotationmatrix = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector = {
                    10., 0, 10.}; $CellContext`activeregion = 
                    0.; $CellContext`completedray = {$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`componentnumber = $CellContext`newcomponentnumber; \
$CellContext`surfacenumber = $CellContext`newsurfacenumber; \
$CellContext`surfaceid = $CellContext`newsurfaceid; $CellContext`originalray = \
{$CellContext`rsx, $CellContext`rsy, $CellContext`rsz, $CellContext`rex, \
$CellContext`rey, $CellContext`rez, $CellContext`r1, $CellContext`r2, \
$CellContext`r3, $CellContext`r4, $CellContext`r5, $CellContext`r6, \
$CellContext`r7, $CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}; \
$CellContext`intensity = 
                    0.; $CellContext`allcreatedrays = {{$CellContext`rsx, \
$CellContext`rsy, $CellContext`rsz, $CellContext`rex, $CellContext`rey, \
$CellContext`rez, $CellContext`r1, $CellContext`r2, $CellContext`r3, \
$CellContext`r4, $CellContext`r5, $CellContext`r6, $CellContext`r7, \
$CellContext`r8, $CellContext`r9, $CellContext`wavelength, \
$CellContext`intensity, $CellContext`intensityscale, $CellContext`ray1, \
$CellContext`index, $CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}); \
{$CellContext`allcreatedrays, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray}}, 
                    True, $CellContext`deflecteddummyrayspresent = 
                    True; $CellContext`reporteddummyrayspresent = 
                    True; $CellContext`localoutrayspresent = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx, $CellContext`rsy, \
$CellContext`rsz, $CellContext`rex, $CellContext`rey, $CellContext`rez, \
$CellContext`r1, $CellContext`r2, $CellContext`r3, $CellContext`r4, \
$CellContext`r5, $CellContext`r6, $CellContext`r7, $CellContext`r8, \
$CellContext`r9, $CellContext`wavelength, $CellContext`intensity, \
$CellContext`intensityscale, $CellContext`ray1, $CellContext`index, \
$CellContext`opticallength, $CellContext`phaseshift, \
$CellContext`componentnumber, $CellContext`surfacenumber, \
$CellContext`surfaceid, $CellContext`ray2, $CellContext`ray3, \
$CellContext`sid, $CellContext`frontid, $CellContext`sno1, $CellContext`sno2, \
$CellContext`sno3, $CellContext`sno4, $CellContext`rayslot, \
$CellContext`generationnumber, $CellContext`intersectionnumber, \
$CellContext`pol1, $CellContext`pol2, $CellContext`pol3}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent = 
                    True; $CellContext`reporteddummyrayspresent = 
                    True; $CellContext`localdummyoutrayspresent = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays]]]; If[
                 
                 And[$CellContext`deflectedrayspresent, \
$CellContext`deflecteddummyrayspresent], $CellContext`deflectedlocalrays = 
                 Select[$CellContext`deflectedlocalrays, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent, 
                 If[$CellContext`localdummyoutrayspresent, \
$CellContext`localoutrays = 
                    Select[$CellContext`localoutrays, Part[#, 23] > 0.& ]; 1.,
                    1.]; $CellContext`outrays = 
                  Join[$CellContext`outrays, $CellContext`localoutrays]; 1., 
                 1.]; If[
                 
                 And[$CellContext`reportedrayspresent, \
$CellContext`reporteddummyrayspresent], $CellContext`reportedlocalrays = 
                  Select[$CellContext`reportedlocalrays, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent, $CellContext`raysreported = 
                 True; $CellContext`reportedrays = 
                 Join[$CellContext`reportedrays, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays]; 1., 
                1.]; $CellContext`inrays = $CellContext`deflectedlocalrays; \
$CellContext`propagate = $CellContext`generationnumber < \
$CellContext`generationlimit]; $CellContext`propagatedrays = 
             If[Length[$CellContext`outrays] > 1, 
               Drop[$CellContext`outrays, 1], $CellContext`outrays]; If[
              
              And[$CellContext`generationnumber >= \
$CellContext`generationlimit, $CellContext`deflectedrayspresent], \
$CellContext`propagatedrays = 
               Join[$CellContext`propagatedrays, \
$CellContext`deflectedlocalrays]; 1., 1.]); 
           If[Length[$CellContext`reportedrays] > 
             2, $CellContext`reportedrays = 
             Drop[$CellContext`reportedrays, 2], $CellContext`reportedrays]; 
           Map[{
              Part[#, 1], 
              Part[#, 2], 
              Part[#, 3], 
              Part[#, 4], 
              Part[#, 5], 
              
              Part[#, 6]}& , $CellContext`reportedrays]], \
$CellContext`compileoptionsetting]]; \
$CellContext`rayfunction2176182014718171241466160 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`absorp$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`gcx$, $CellContext`gcy$, \
$CellContext`gcz$, $CellContext`gdimx$, $CellContext`gdimy$, \
$CellContext`gdimz$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`gintercepts$, \
$CellContext`gmaxlength$, $CellContext`gmm$, $CellContext`gnn$, \
$CellContext`goo$, $CellContext`griddata$, $CellContext`grr$, \
$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$, \
$CellContext`grtx$, $CellContext`grty$, $CellContext`grtz$, \
$CellContext`gspacex$, $CellContext`gspacey$, $CellContext`gspacez$, \
$CellContext`gu$, $CellContext`gv$, $CellContext`gw$, $CellContext`gxave$, \
$CellContext`gyave$, $CellContext`gzave$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`listofpositions$, $CellContext`localdummyoutrayspresent$, \
$CellContext`localendingpoint$, $CellContext`localendpos$, \
$CellContext`localindex$, $CellContext`localintensity$, \
$CellContext`localopticallength$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`localpos$, \
$CellContext`localraylength$, $CellContext`localrotation$, \
$CellContext`localstartingpoint$, $CellContext`localstartpos$, \
$CellContext`localtilt$, $CellContext`localtranslation$, \
$CellContext`magnitude$, $CellContext`maxclonegenerationnumber$, \
$CellContext`maximumposition$, $CellContext`minimumraylength$, \
$CellContext`minresonateraylength$, $CellContext`n12$, \
$CellContext`newcomponentnumber$, $CellContext`newdeflectedrays$, \
$CellContext`newdistance$, $CellContext`newpos$, $CellContext`newsurfaceid$, \
$CellContext`newsurfacenumber$, $CellContext`newtilt$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`surfrot$, $CellContext`surftrans$, \
$CellContext`symr1$, $CellContext`symr2$, $CellContext`symr3$, \
$CellContext`symr4$, $CellContext`symr5$, $CellContext`symr6$, \
$CellContext`symr7$, $CellContext`symr8$, $CellContext`symr9$, \
$CellContext`tempclonedata$, $CellContext`terminatedeflection$, \
$CellContext`thresholdintensity$, $CellContext`tiltmagnitude$, \
$CellContext`transmatrix$, $CellContext`LocTV1$, $CellContext`LocTV10$, \
$CellContext`LocTV2$, $CellContext`LocTV3$, $CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$, $CellContext`LocTV7$, \
$CellContext`LocTV8$, $CellContext`LocTV9$, $CellContext`u$, \
$CellContext`unfilteredintersections$, $CellContext`unit$, $CellContext`uu$, \
$CellContext`ver$, $CellContext`wavelength$, $CellContext`XAxis$, \
$CellContext`xunit$, $CellContext`YAxis$, $CellContext`yunit$, \
$CellContext`ZAxis$, $CellContext`zunit$}, $CellContext`rsx$ = 
            1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`griddata$ = {{{0., 0., 0., 0., 0., 0., 0.,
              0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 
             0.}}}; $CellContext`localstartingpoint$ = {0., 0., 
             0.}; $CellContext`localendingpoint$ = {0., 0., 
             0.}; $CellContext`localtilt$ = {1., 0., 
             0.}; $CellContext`surftrans$ = {1., 0., 
             0.}; $CellContext`surfrot$ = {{
             1.}}; $CellContext`listofpositions$ = {{
             1.}}; $CellContext`gintercepts$ = {{
             1.}}; $CellContext`localopticallength$ = 
            0.; $CellContext`localtranslation$ = {1., 0., 
             0.}; $CellContext`localrotation$ = {{
             1.}}; $CellContext`localintensity$ = 
            1.; $CellContext`localindex$ = 1.; $CellContext`gspacex$ = 
            1.; $CellContext`gspacey$ = 1.; $CellContext`gspacez$ = 
            1.; $CellContext`gxave$ = 1.; $CellContext`gyave$ = 
            1.; $CellContext`gzave$ = 1.; $CellContext`localraylength$ = 
            0.; $CellContext`newpos$ = {0., 0., 0.}; $CellContext`newtilt$ = {
             1., 0., 0.}; $CellContext`localpos$ = {0., 0., 
             0.}; $CellContext`localstartpos$ = {0., 0., 
             0.}; $CellContext`localendpos$ = {0., 0., 
             0.}; $CellContext`grsx$ = 1.; $CellContext`grsy$ = 
            1.; $CellContext`grsz$ = 1.; $CellContext`grtx$ = 
            1.; $CellContext`grty$ = 1.; $CellContext`grtz$ = 
            1.; $CellContext`gcx$ = 1.; $CellContext`gcy$ = 
            1.; $CellContext`gcz$ = 1.; $CellContext`gdimx$ = 
            1.; $CellContext`gdimy$ = 1.; $CellContext`gdimz$ = 
            1.; $CellContext`gu$ = 1.; $CellContext`gv$ = 
            1.; $CellContext`gw$ = 1.; $CellContext`gnn$ = 
            1; $CellContext`gmm$ = 1; $CellContext`goo$ = 
            1; $CellContext`grr$ = 1.; $CellContext`gmaxlength$ = 
            1.; $CellContext`propagatedrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BnLBB3tK5RdI6d9VYXsIVRfpgK7viVJwlxQjLnMI
mQ8FDfscUGi4PnLNRcgDAFl4Fk0=
             "]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$} = Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$37}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$37 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$37), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$37, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$37}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 4776.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$38}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$38 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$38), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$38, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$38}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 4804.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$49}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$49 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$49), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$49, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$49}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 4888.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$52}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$52 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$52), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$52, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$52}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 4916.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$43}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$43 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$43), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$43, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$43}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 4860.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$41}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$41 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$41), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$41, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$41}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 4832.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = 0.9961946980917455 $CellContext`r1$ + 
                    0.08715574274765817 $CellContext`r2$; $CellContext`yunit$ = \
(-0.08715574274765817) $CellContext`r1$ + 
                    0.9961946980917455 $CellContext`r2$; $CellContext`zunit$ = \
$CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    0.9961946980917455 (-16. + $CellContext`rex$) + 
                    0.08715574274765817 $CellContext`rey$; $CellContext`ry$ = \
(-0.08715574274765817) (-16. + $CellContext`rex$) + 
                    0.9961946980917455 $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$53}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                    Part[#, 3] <= 5.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$53 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$53), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$53, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$53}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 7834.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    4776.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 1., 
                    4776.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    5., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    4970, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4776, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4804, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4888, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4916, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4860, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[-(#4/$CellContext`absorp$$)]; $CellContext`intensity$ = \
$CellContext`intensity$ (1. - 
                    Exp[-(#4/$CellContext`absorp$$)]))& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    4804.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 2., 
                    4804.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    15. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    15., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    4970, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4776, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4804, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4888, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4916, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4860, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[-(#4/$CellContext`absorp$$)]; $CellContext`intensity$ = \
$CellContext`intensity$ (1. - 
                    Exp[-(#4/$CellContext`absorp$$)]))& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    4888.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 3., 
                    4888.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -5. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    4970, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4776, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4804, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4888, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4916, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4860, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[-(#4/$CellContext`absorp$$)]; $CellContext`intensity$ = \
$CellContext`intensity$ (1. - 
                    Exp[-(#4/$CellContext`absorp$$)]))& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    4916.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 4., 
                    4916.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    4970, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4776, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4804, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4888, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4916, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4860, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[-(#4/$CellContext`absorp$$)]; $CellContext`intensity$ = \
$CellContext`intensity$ (1. - 
                    Exp[-(#4/$CellContext`absorp$$)]))& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    4860.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 5., 
                    4860.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -5. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    4970, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4776, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4804, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4888, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4916, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4860, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[-(#4/$CellContext`absorp$$)]; $CellContext`intensity$ = \
$CellContext`intensity$ (1. - 
                    Exp[-(#4/$CellContext`absorp$$)]))& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    4832.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 6., 
                    4832.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    4970, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4776, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4804, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4888, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4916, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4860, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[-(#4/$CellContext`absorp$$)]; $CellContext`intensity$ = \
$CellContext`intensity$ (1. - 
                    Exp[-(#4/$CellContext`absorp$$)]))& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    7, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = 0.9961946980917455 $CellContext`r1$ + 
                    0.08715574274765817 $CellContext`r2$; $CellContext`yunit$ = \
(-0.08715574274765817) $CellContext`r1$ + 
                    0.9961946980917455 $CellContext`r2$; $CellContext`zunit$ = \
$CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    0.9961946980917455 (-16. + $CellContext`rex$) + 
                    0.08715574274765817 $CellContext`rey$; $CellContext`ry$ = \
(-0.08715574274765817) (-16. + $CellContext`rex$) + 
                    0.9961946980917455 $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 7., 
                    7834.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 7., 
                    7834.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    16. + 0.9961946980917455 $CellContext`rxhlp$ - 
                    0.08715574274765817 $CellContext`ryhlp$; \
$CellContext`rey$ = 0.08715574274765817 $CellContext`rxhlp$ + 
                    0.9961946980917455 $CellContext`ryhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0.9961946980917455, -0.08715574274765817, 0.}, {
                    0.08715574274765817, 0.9961946980917455, 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0.9961946980917455, 
                    0.08715574274765817, 0.}, {-0.08715574274765817, 
                    0.9961946980917455, 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    16., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - (2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGBgAmJGIFZngIEP9gNHN0SY5J89SJx6uHv346AH0B/0podm
uAEAvnFifw==
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]); $CellContext`inrays$ = \
$CellContext`deflectedlocalrays$; $CellContext`propagate$ = \
$CellContext`generationnumber$ < $CellContext`generationlimit$]; \
$CellContext`propagatedrays$ = If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$54}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$54 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$54), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$54, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$54}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 7984.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$59}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$59 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$59), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$59, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$59}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 7985.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$54}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$54 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$54), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$54, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$54}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 7986.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$59}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$59 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$59), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$59, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$59}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 7987.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$55}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$55 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$55), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$55, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$55}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 7988.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$55}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$55 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$55), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$55, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$55}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 7989.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    7984.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 1., 
                    7984.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    7985.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 2., 
                    7985.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -10. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    
                    7986.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 3., 
                    7986.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    7987.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 4., 
                    7987.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 5., 
                    7988.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 5., 
                    7988.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -10. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 6., 
                    7989.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 6., 
                    7989.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
           Reverse[
             
             Part[$CellContext`griddata$, 1, 
              1]]], $CellContext`compileoptionsetting$]]); 
     Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.598620695745722*^9, 3.598620706903715*^9}, {
  3.598620752915114*^9, 3.598620808382793*^9}, {3.598620853822877*^9, 
  3.598620858319643*^9}, {3.598620910216481*^9, 3.59862104256742*^9}, {
  3.59862111681295*^9, 3.5986211448333473`*^9}, {3.614710362572721*^9, 
  3.6147103842846107`*^9}}]
}, Open  ]]
},
WindowSize->{1647, 1094},
WindowMargins->{{18, Automatic}, {Automatic, 48}},
ShowSelection->True,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3614692349-3788911"->{
  Cell[1654, 43, 1936, 27, 249, "Print",
   CellTags->"Info3614692349-3788911"],
  Cell[3726, 78, 1645, 23, 163, "Print",
   CellTags->"Info3614692349-3788911"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3614692349-3788911", 825897, 13736}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 1072, 19, 256, "Input"],
Cell[1654, 43, 1936, 27, 249, "Print",
 CellTags->"Info3614692349-3788911"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3627, 75, 96, 1, 29, "Input"],
Cell[3726, 78, 1645, 23, 163, "Print",
 CellTags->"Info3614692349-3788911"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5408, 106, 2768, 40, 59, "Input"],
Cell[8179, 148, 2032, 54, 109, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10248, 207, 961, 15, 59, "Input"],
Cell[11212, 224, 814326, 13497, 1012, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
