(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     30950,       1719]*)
(*NotebookOutlinePosition[     31647,       1743]*)
(*  CellTagsIndexPosition[     31603,       1739]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Creating a Fiber", "Section"],

Cell["\<\
This notebook shows the construction of a straight fiber from \
scratch. First the cylindrical surfaces are defined.\
\>", "Text"],

Cell["\<\
Clear[fibercylinder];
fibercylinder[radius_, fiberlength_, opts___] := {
\tMove3D[
\t\tCylindricalLensSurface[
\t\t\tradius, {2*radius*Cos[30*Degree], fiberlength}, opts],
\t\t{0, 0, radius}, {0, 0, -1}, 0],
\tMove3D[
\t\tMove3D[
\t\t\tCylindricalLensSurface[
\t\t\t\tradius, {2*radius*Cos[30*Degree], fiberlength}, opts],
\t\t\t{0, 0, radius}, {0, 0, -1}, 0],
\t\t{0, 0, 0}, {1, 0, 0}, 120],
\tMove3D[
\t\tMove3D[
\t\t\tCylindricalLensSurface[
\t\t\t\tradius, {2*radius*Cos[30*Degree], fiberlength}, opts],
\t\t\t{0, 0, radius}, {0, 0, -1}, 0],
\t\t{0, 0, 0}, {1, 0, 0}, 240]
};\
\>", "Input",
  CellLabel->"In[2]:="],

Cell["\<\
Next, the fiber is plugged together. On the left side is a planar \
surface, on the right a spherical. In between are the two cylindrical \
surfaces.\
\>", "Text"],

Cell["\<\
Clear[OpticalFiber];
OpticalFiber[coreradius_, claddingradius_, fiberlength_, lensradius_, \
opts___] :=
Resonate[
\tMove[Flatten[{
\t\tMove[LensSurface[2*claddingradius, opts], {-0.5*fiberlength, 0, 0}],
\t\tfibercylinder[coreradius, fiberlength, opts],
 \t\tfibercylinder[claddingradius, fiberlength, opts],
\t\tMove[SphericalLensSurface[lensradius, 50, opts], 
\t\t\t{0.5*fiberlength-lensradius-Sqrt[lensradius^2-25^2], 0, 0}]
\t}], {0.5*fiberlength, 0, 0}]
];\
\>", "Input",
  CellLabel->"In[60]:="],

Cell["The fiber is ready to be used.", "Text"],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{
  Move[ConeOfRays[20], {10, 0, 0}],
  Move[OpticalFiber[10, 30, 300, -25.1], {60, 0, 0}],
  Boundary[450, GraphicDesign -> Off]
}, 
\tPlotType -> TopView, 
\tShowLabels -> False, 
\tQuickTrace -> False,
\tPlotPoints -> 50
];\
\>", "Input",
  CellLabel->"In[65]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .13636 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0021645 0.0021645 0.0681818 0.0021645 [
[ 0 0 0 0 ]
[ 1 .13636 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.13203 .00325 m
.13203 .00974 L
.13203 .01623 L
.13203 .02273 L
.13203 .02922 L
.13203 .03571 L
.13203 .04221 L
.13203 .0487 L
.13203 .05519 L
.13203 .06169 L
.13203 .06818 L
.13203 .07468 L
.13203 .08117 L
.13203 .08766 L
.13203 .09416 L
.13203 .10065 L
.13203 .10714 L
.13203 .11364 L
.13203 .12013 L
.13203 .12662 L
.13203 .13312 L
.13203 .13312 L
.13203 .12662 L
.13203 .12013 L
.13203 .11364 L
.13203 .10714 L
.13203 .10065 L
.13203 .09416 L
.13203 .08766 L
.13203 .08117 L
.13203 .07468 L
.13203 .06818 L
.13203 .06169 L
.13203 .05519 L
.13203 .0487 L
.13203 .04221 L
.13203 .03571 L
.13203 .02922 L
.13203 .02273 L
.13203 .01623 L
.13203 .00974 L
.13203 .00325 L
.13203 .00325 L
s
.13203 .06818 m
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
.13203 .06818 L
s
.45671 .08693 m
.45671 .08505 L
.45671 .08318 L
.45671 .0813 L
.45671 .07943 L
.45671 .07755 L
.45671 .07568 L
.45671 .07381 L
.45671 .07193 L
.45671 .07006 L
.45671 .06818 L
.45671 .06631 L
.45671 .06443 L
.45671 .06256 L
.45671 .06068 L
.45671 .05881 L
.45671 .05693 L
.45671 .05506 L
.45671 .05319 L
.45671 .05131 L
.45671 .04944 L
.45671 .04944 L
.45671 .05131 L
.45671 .05319 L
.45671 .05506 L
.45671 .05693 L
.45671 .05881 L
.45671 .06068 L
.45671 .06256 L
.45671 .06443 L
.45671 .06631 L
.45671 .06818 L
.45671 .07006 L
.45671 .07193 L
.45671 .07381 L
.45671 .07568 L
.45671 .07755 L
.45671 .07943 L
.45671 .0813 L
.45671 .08318 L
.45671 .08505 L
.45671 .08693 L
.45671 .08693 L
s
.78139 .06818 m
.74892 .06818 L
.71645 .06818 L
.68398 .06818 L
.65152 .06818 L
.61905 .06818 L
.58658 .06818 L
.55411 .06818 L
.52165 .06818 L
.48918 .06818 L
.45671 .06818 L
.42424 .06818 L
.39177 .06818 L
.35931 .06818 L
.32684 .06818 L
.29437 .06818 L
.2619 .06818 L
.22944 .06818 L
.19697 .06818 L
.1645 .06818 L
.13203 .06818 L
.13203 .06818 L
.1645 .06818 L
.19697 .06818 L
.22944 .06818 L
.2619 .06818 L
.29437 .06818 L
.32684 .06818 L
.35931 .06818 L
.39177 .06818 L
.42424 .06818 L
.45671 .06818 L
.48918 .06818 L
.52165 .06818 L
.55411 .06818 L
.58658 .06818 L
.61905 .06818 L
.65152 .06818 L
.68398 .06818 L
.71645 .06818 L
.74892 .06818 L
.78139 .06818 L
.78139 .06818 L
s
.45671 .04944 m
.45671 .048 L
.45671 .04717 L
.45671 .04671 L
.45671 .04654 L
.45671 .0466 L
.45671 .04685 L
.45671 .04727 L
.45671 .04785 L
.45671 .04857 L
.45671 .04944 L
.45671 .05044 L
.45671 .05159 L
.45671 .05289 L
.45671 .05435 L
.45671 .05597 L
.45671 .05779 L
.45671 .05983 L
.45671 .06216 L
.45671 .06487 L
.45671 .06818 L
.45671 .06818 L
.45671 .06487 L
.45671 .06216 L
.45671 .05983 L
.45671 .05779 L
.45671 .05597 L
.45671 .05435 L
.45671 .05289 L
.45671 .05159 L
.45671 .05044 L
.45671 .04944 L
.45671 .04857 L
.45671 .04785 L
.45671 .04727 L
.45671 .04685 L
.45671 .0466 L
.45671 .04654 L
.45671 .04671 L
.45671 .04717 L
.45671 .048 L
.45671 .04944 L
.45671 .04944 L
s
.78139 .04944 m
.74892 .04944 L
.71645 .04944 L
.68398 .04944 L
.65152 .04944 L
.61905 .04944 L
.58658 .04944 L
.55411 .04944 L
.52165 .04944 L
.48918 .04944 L
.45671 .04944 L
.42424 .04944 L
.39177 .04944 L
.35931 .04944 L
.32684 .04944 L
.29437 .04944 L
.2619 .04944 L
.22944 .04944 L
.19697 .04944 L
.1645 .04944 L
.13203 .04944 L
.13203 .04944 L
.1645 .04944 L
.19697 .04944 L
.22944 .04944 L
.2619 .04944 L
.29437 .04944 L
.32684 .04944 L
.35931 .04944 L
.39177 .04944 L
.42424 .04944 L
.45671 .04944 L
.48918 .04944 L
.52165 .04944 L
.55411 .04944 L
.58658 .04944 L
.61905 .04944 L
.65152 .04944 L
.68398 .04944 L
.71645 .04944 L
.74892 .04944 L
.78139 .04944 L
.78139 .04944 L
s
.45671 .06818 m
.45671 .07149 L
.45671 .0742 L
.45671 .07653 L
.45671 .07857 L
.45671 .08039 L
.45671 .08202 L
.45671 .08347 L
.45671 .08477 L
.45671 .08592 L
.45671 .08693 L
.45671 .08779 L
.45671 .08852 L
.45671 .0891 L
.45671 .08952 L
.45671 .08976 L
.45671 .08982 L
.45671 .08965 L
.45671 .0892 L
.45671 .08836 L
.45671 .08693 L
.45671 .08693 L
.45671 .08836 L
.45671 .0892 L
.45671 .08965 L
.45671 .08982 L
.45671 .08976 L
.45671 .08952 L
.45671 .0891 L
.45671 .08852 L
.45671 .08779 L
.45671 .08693 L
.45671 .08592 L
.45671 .08477 L
.45671 .08347 L
.45671 .08202 L
.45671 .08039 L
.45671 .07857 L
.45671 .07653 L
.45671 .0742 L
.45671 .07149 L
.45671 .06818 L
.45671 .06818 L
s
.78139 .08693 m
.74892 .08693 L
.71645 .08693 L
.68398 .08693 L
.65152 .08693 L
.61905 .08693 L
.58658 .08693 L
.55411 .08693 L
.52165 .08693 L
.48918 .08693 L
.45671 .08693 L
.42424 .08693 L
.39177 .08693 L
.35931 .08693 L
.32684 .08693 L
.29437 .08693 L
.2619 .08693 L
.22944 .08693 L
.19697 .08693 L
.1645 .08693 L
.13203 .08693 L
.13203 .08693 L
.1645 .08693 L
.19697 .08693 L
.22944 .08693 L
.2619 .08693 L
.29437 .08693 L
.32684 .08693 L
.35931 .08693 L
.39177 .08693 L
.42424 .08693 L
.45671 .08693 L
.48918 .08693 L
.52165 .08693 L
.55411 .08693 L
.58658 .08693 L
.61905 .08693 L
.65152 .08693 L
.68398 .08693 L
.71645 .08693 L
.74892 .08693 L
.78139 .08693 L
.78139 .08693 L
s
.45671 .12442 m
.45671 .11879 L
.45671 .11317 L
.45671 .10755 L
.45671 .10192 L
.45671 .0963 L
.45671 .09068 L
.45671 .08505 L
.45671 .07943 L
.45671 .07381 L
.45671 .06818 L
.45671 .06256 L
.45671 .05693 L
.45671 .05131 L
.45671 .04569 L
.45671 .04006 L
.45671 .03444 L
.45671 .02882 L
.45671 .02319 L
.45671 .01757 L
.45671 .01195 L
.45671 .01195 L
.45671 .01757 L
.45671 .02319 L
.45671 .02882 L
.45671 .03444 L
.45671 .04006 L
.45671 .04569 L
.45671 .05131 L
.45671 .05693 L
.45671 .06256 L
.45671 .06818 L
.45671 .07381 L
.45671 .07943 L
.45671 .08505 L
.45671 .09068 L
.45671 .0963 L
.45671 .10192 L
.45671 .10755 L
.45671 .11317 L
.45671 .11879 L
.45671 .12442 L
.45671 .12442 L
s
.78139 .06818 m
.74892 .06818 L
.71645 .06818 L
.68398 .06818 L
.65152 .06818 L
.61905 .06818 L
.58658 .06818 L
.55411 .06818 L
.52165 .06818 L
.48918 .06818 L
.45671 .06818 L
.42424 .06818 L
.39177 .06818 L
.35931 .06818 L
.32684 .06818 L
.29437 .06818 L
.2619 .06818 L
.22944 .06818 L
.19697 .06818 L
.1645 .06818 L
.13203 .06818 L
.13203 .06818 L
.1645 .06818 L
.19697 .06818 L
.22944 .06818 L
.2619 .06818 L
.29437 .06818 L
.32684 .06818 L
.35931 .06818 L
.39177 .06818 L
.42424 .06818 L
.45671 .06818 L
.48918 .06818 L
.52165 .06818 L
.55411 .06818 L
.58658 .06818 L
.61905 .06818 L
.65152 .06818 L
.68398 .06818 L
.71645 .06818 L
.74892 .06818 L
.78139 .06818 L
.78139 .06818 L
s
.45671 .01195 m
.45671 .00764 L
.45671 .00514 L
.45671 .00378 L
.45671 .00326 L
.45671 .00343 L
.45671 .00418 L
.45671 .00544 L
.45671 .00717 L
.45671 .00935 L
.45671 .01195 L
.45671 .01497 L
.45671 .01842 L
.45671 .02231 L
.45671 .02668 L
.45671 .03155 L
.45671 .037 L
.45671 .04314 L
.45671 .05012 L
.45671 .05826 L
.45671 .06818 L
.45671 .06818 L
.45671 .05826 L
.45671 .05012 L
.45671 .04314 L
.45671 .037 L
.45671 .03155 L
.45671 .02668 L
.45671 .02231 L
.45671 .01842 L
.45671 .01497 L
.45671 .01195 L
.45671 .00935 L
.45671 .00717 L
.45671 .00544 L
.45671 .00418 L
.45671 .00343 L
.45671 .00326 L
.45671 .00378 L
.45671 .00514 L
.45671 .00764 L
.45671 .01195 L
.45671 .01195 L
s
.78139 .01195 m
.74892 .01195 L
.71645 .01195 L
.68398 .01195 L
.65152 .01195 L
.61905 .01195 L
.58658 .01195 L
.55411 .01195 L
.52165 .01195 L
.48918 .01195 L
.45671 .01195 L
.42424 .01195 L
.39177 .01195 L
.35931 .01195 L
.32684 .01195 L
.29437 .01195 L
.2619 .01195 L
.22944 .01195 L
.19697 .01195 L
.1645 .01195 L
.13203 .01195 L
.13203 .01195 L
.1645 .01195 L
.19697 .01195 L
.22944 .01195 L
.2619 .01195 L
.29437 .01195 L
.32684 .01195 L
.35931 .01195 L
.39177 .01195 L
.42424 .01195 L
.45671 .01195 L
.48918 .01195 L
.52165 .01195 L
.55411 .01195 L
.58658 .01195 L
.61905 .01195 L
.65152 .01195 L
.68398 .01195 L
.71645 .01195 L
.74892 .01195 L
.78139 .01195 L
.78139 .01195 L
s
.45671 .06818 m
.45671 .07811 L
.45671 .08624 L
.45671 .09322 L
.45671 .09936 L
.45671 .10481 L
.45671 .10969 L
.45671 .11405 L
.45671 .11794 L
.45671 .12139 L
.45671 .12442 L
.45671 .12702 L
.45671 .12919 L
.45671 .13092 L
.45671 .13218 L
.45671 .13293 L
.45671 .1331 L
.45671 .13259 L
.45671 .13123 L
.45671 .12872 L
.45671 .12442 L
.45671 .12442 L
.45671 .12872 L
.45671 .13123 L
.45671 .13259 L
.45671 .1331 L
.45671 .13293 L
.45671 .13218 L
.45671 .13092 L
.45671 .12919 L
.45671 .12702 L
.45671 .12442 L
.45671 .12139 L
.45671 .11794 L
.45671 .11405 L
.45671 .10969 L
.45671 .10481 L
.45671 .09936 L
.45671 .09322 L
.45671 .08624 L
.45671 .07811 L
.45671 .06818 L
.45671 .06818 L
s
.78139 .12442 m
.74892 .12442 L
.71645 .12442 L
.68398 .12442 L
.65152 .12442 L
.61905 .12442 L
.58658 .12442 L
.55411 .12442 L
.52165 .12442 L
.48918 .12442 L
.45671 .12442 L
.42424 .12442 L
.39177 .12442 L
.35931 .12442 L
.32684 .12442 L
.29437 .12442 L
.2619 .12442 L
.22944 .12442 L
.19697 .12442 L
.1645 .12442 L
.13203 .12442 L
.13203 .12442 L
.1645 .12442 L
.19697 .12442 L
.22944 .12442 L
.2619 .12442 L
.29437 .12442 L
.32684 .12442 L
.35931 .12442 L
.39177 .12442 L
.42424 .12442 L
.45671 .12442 L
.48918 .12442 L
.52165 .12442 L
.55411 .12442 L
.58658 .12442 L
.61905 .12442 L
.65152 .12442 L
.68398 .12442 L
.71645 .12442 L
.74892 .12442 L
.78139 .12442 L
.78139 .12442 L
s
.78139 .01407 m
.80062 .01948 L
.80937 .02489 L
.81549 .0303 L
.8201 .03571 L
.82365 .04113 L
.82637 .04654 L
.82839 .05195 L
.82978 .05736 L
.8306 .06277 L
.83087 .06818 L
.8306 .07359 L
.82978 .079 L
.82839 .08442 L
.82637 .08983 L
.82365 .09524 L
.8201 .10065 L
.81549 .10606 L
.80937 .11147 L
.80062 .11688 L
.78139 .12229 L
.78139 .12229 L
.80062 .11688 L
.80937 .11147 L
.81549 .10606 L
.8201 .10065 L
.82365 .09524 L
.82637 .08983 L
.82839 .08442 L
.82978 .079 L
.8306 .07359 L
.83087 .06818 L
.8306 .06277 L
.82978 .05736 L
.82839 .05195 L
.82637 .04654 L
.82365 .04113 L
.8201 .03571 L
.81549 .0303 L
.80937 .02489 L
.80062 .01948 L
.78139 .01407 L
.78139 .01407 L
s
.78139 .06818 m
.80062 .06818 L
.80937 .06818 L
.81549 .06818 L
.8201 .06818 L
.82365 .06818 L
.82637 .06818 L
.82839 .06818 L
.82978 .06818 L
.8306 .06818 L
.83087 .06818 L
.8306 .06818 L
.82978 .06818 L
.82839 .06818 L
.82637 .06818 L
.82365 .06818 L
.8201 .06818 L
.81549 .06818 L
.80937 .06818 L
.80062 .06818 L
.78139 .06818 L
.78139 .06818 L
.80062 .06818 L
.80937 .06818 L
.81549 .06818 L
.8201 .06818 L
.82365 .06818 L
.82637 .06818 L
.82839 .06818 L
.82978 .06818 L
.8306 .06818 L
.83087 .06818 L
.8306 .06818 L
.82978 .06818 L
.82839 .06818 L
.82637 .06818 L
.82365 .06818 L
.8201 .06818 L
.81549 .06818 L
.80937 .06818 L
.80062 .06818 L
.78139 .06818 L
.78139 .06818 L
s
.13203 .13312 m
.13203 .13292 L
.13203 .13232 L
.13203 .13132 L
.13203 .12994 L
.13203 .12817 L
.13203 .12604 L
.13203 .12355 L
.13203 .12072 L
.13203 .11756 L
.13203 .1141 L
.13203 .11035 L
.13203 .10635 L
.13203 .10211 L
.13203 .09766 L
.13203 .09303 L
.13203 .08825 L
.13203 .08334 L
.13203 .07834 L
.13203 .07328 L
.13203 .06818 L
.13203 .06309 L
.13203 .05802 L
.13203 .05302 L
.13203 .04812 L
.13203 .04333 L
.13203 .0387 L
.13203 .03425 L
.13203 .03001 L
.13203 .02601 L
.13203 .02227 L
.13203 .0188 L
.13203 .01565 L
.13203 .01282 L
.13203 .01032 L
.13203 .00819 L
.13203 .00642 L
.13203 .00504 L
.13203 .00405 L
.13203 .00345 L
.13203 .00325 L
.13203 .00345 L
.13203 .00405 L
.13203 .00504 L
.13203 .00642 L
.13203 .00819 L
.13203 .01032 L
.13203 .01282 L
.13203 .01565 L
.13203 .0188 L
Mistroke
.13203 .02227 L
.13203 .02601 L
.13203 .03001 L
.13203 .03425 L
.13203 .0387 L
.13203 .04333 L
.13203 .04812 L
.13203 .05302 L
.13203 .05802 L
.13203 .06309 L
.13203 .06818 L
.13203 .07328 L
.13203 .07834 L
.13203 .08334 L
.13203 .08825 L
.13203 .09303 L
.13203 .09766 L
.13203 .10211 L
.13203 .10635 L
.13203 .11035 L
.13203 .1141 L
.13203 .11756 L
.13203 .12072 L
.13203 .12355 L
.13203 .12604 L
.13203 .12817 L
.13203 .12994 L
.13203 .13132 L
.13203 .13232 L
.13203 .13292 L
.13203 .13312 L
Mfstroke
.13203 .08693 m
.13203 .08505 L
.13203 .08318 L
.13203 .0813 L
.13203 .07943 L
.13203 .07755 L
.13203 .07568 L
.13203 .07381 L
.13203 .07193 L
.13203 .07006 L
.13203 .06818 L
.13203 .06631 L
.13203 .06443 L
.13203 .06256 L
.13203 .06068 L
.13203 .05881 L
.13203 .05693 L
.13203 .05506 L
.13203 .05319 L
.13203 .05131 L
.13203 .04944 L
.13203 .04944 L
.1645 .04944 L
.19697 .04944 L
.22944 .04944 L
.2619 .04944 L
.29437 .04944 L
.32684 .04944 L
.35931 .04944 L
.39177 .04944 L
.42424 .04944 L
.45671 .04944 L
.48918 .04944 L
.52165 .04944 L
.55411 .04944 L
.58658 .04944 L
.61905 .04944 L
.65152 .04944 L
.68398 .04944 L
.71645 .04944 L
.74892 .04944 L
.78139 .04944 L
.78139 .04944 L
.78139 .05131 L
.78139 .05319 L
.78139 .05506 L
.78139 .05693 L
.78139 .05881 L
.78139 .06068 L
.78139 .06256 L
Mistroke
.78139 .06443 L
.78139 .06631 L
.78139 .06818 L
.78139 .07006 L
.78139 .07193 L
.78139 .07381 L
.78139 .07568 L
.78139 .07755 L
.78139 .07943 L
.78139 .0813 L
.78139 .08318 L
.78139 .08505 L
.78139 .08693 L
.78139 .08693 L
.74892 .08693 L
.71645 .08693 L
.68398 .08693 L
.65152 .08693 L
.61905 .08693 L
.58658 .08693 L
.55411 .08693 L
.52165 .08693 L
.48918 .08693 L
.45671 .08693 L
.42424 .08693 L
.39177 .08693 L
.35931 .08693 L
.32684 .08693 L
.29437 .08693 L
.2619 .08693 L
.22944 .08693 L
.19697 .08693 L
.1645 .08693 L
.13203 .08693 L
Mfstroke
.13203 .04944 m
.13203 .048 L
.13203 .04717 L
.13203 .04671 L
.13203 .04654 L
.13203 .0466 L
.13203 .04685 L
.13203 .04727 L
.13203 .04785 L
.13203 .04857 L
.13203 .04944 L
.13203 .05044 L
.13203 .05159 L
.13203 .05289 L
.13203 .05435 L
.13203 .05597 L
.13203 .05779 L
.13203 .05983 L
.13203 .06216 L
.13203 .06487 L
.13203 .06818 L
.13203 .06818 L
.1645 .06818 L
.19697 .06818 L
.22944 .06818 L
.2619 .06818 L
.29437 .06818 L
.32684 .06818 L
.35931 .06818 L
.39177 .06818 L
.42424 .06818 L
.45671 .06818 L
.48918 .06818 L
.52165 .06818 L
.55411 .06818 L
.58658 .06818 L
.61905 .06818 L
.65152 .06818 L
.68398 .06818 L
.71645 .06818 L
.74892 .06818 L
.78139 .06818 L
.78139 .06818 L
.78139 .06487 L
.78139 .06216 L
.78139 .05983 L
.78139 .05779 L
.78139 .05597 L
.78139 .05435 L
.78139 .05289 L
Mistroke
.78139 .05159 L
.78139 .05044 L
.78139 .04944 L
.78139 .04857 L
.78139 .04785 L
.78139 .04727 L
.78139 .04685 L
.78139 .0466 L
.78139 .04654 L
.78139 .04671 L
.78139 .04717 L
.78139 .048 L
.78139 .04944 L
.78139 .04944 L
.74892 .04944 L
.71645 .04944 L
.68398 .04944 L
.65152 .04944 L
.61905 .04944 L
.58658 .04944 L
.55411 .04944 L
.52165 .04944 L
.48918 .04944 L
.45671 .04944 L
.42424 .04944 L
.39177 .04944 L
.35931 .04944 L
.32684 .04944 L
.29437 .04944 L
.2619 .04944 L
.22944 .04944 L
.19697 .04944 L
.1645 .04944 L
.13203 .04944 L
Mfstroke
.13203 .06818 m
.13203 .07149 L
.13203 .0742 L
.13203 .07653 L
.13203 .07857 L
.13203 .08039 L
.13203 .08202 L
.13203 .08347 L
.13203 .08477 L
.13203 .08592 L
.13203 .08693 L
.13203 .08779 L
.13203 .08852 L
.13203 .0891 L
.13203 .08952 L
.13203 .08976 L
.13203 .08982 L
.13203 .08965 L
.13203 .0892 L
.13203 .08836 L
.13203 .08693 L
.13203 .08693 L
.1645 .08693 L
.19697 .08693 L
.22944 .08693 L
.2619 .08693 L
.29437 .08693 L
.32684 .08693 L
.35931 .08693 L
.39177 .08693 L
.42424 .08693 L
.45671 .08693 L
.48918 .08693 L
.52165 .08693 L
.55411 .08693 L
.58658 .08693 L
.61905 .08693 L
.65152 .08693 L
.68398 .08693 L
.71645 .08693 L
.74892 .08693 L
.78139 .08693 L
.78139 .08693 L
.78139 .08836 L
.78139 .0892 L
.78139 .08965 L
.78139 .08982 L
.78139 .08976 L
.78139 .08952 L
.78139 .0891 L
Mistroke
.78139 .08852 L
.78139 .08779 L
.78139 .08693 L
.78139 .08592 L
.78139 .08477 L
.78139 .08347 L
.78139 .08202 L
.78139 .08039 L
.78139 .07857 L
.78139 .07653 L
.78139 .0742 L
.78139 .07149 L
.78139 .06818 L
.78139 .06818 L
.74892 .06818 L
.71645 .06818 L
.68398 .06818 L
.65152 .06818 L
.61905 .06818 L
.58658 .06818 L
.55411 .06818 L
.52165 .06818 L
.48918 .06818 L
.45671 .06818 L
.42424 .06818 L
.39177 .06818 L
.35931 .06818 L
.32684 .06818 L
.29437 .06818 L
.2619 .06818 L
.22944 .06818 L
.19697 .06818 L
.1645 .06818 L
.13203 .06818 L
Mfstroke
.13203 .12442 m
.13203 .11879 L
.13203 .11317 L
.13203 .10755 L
.13203 .10192 L
.13203 .0963 L
.13203 .09068 L
.13203 .08505 L
.13203 .07943 L
.13203 .07381 L
.13203 .06818 L
.13203 .06256 L
.13203 .05693 L
.13203 .05131 L
.13203 .04569 L
.13203 .04006 L
.13203 .03444 L
.13203 .02882 L
.13203 .02319 L
.13203 .01757 L
.13203 .01195 L
.13203 .01195 L
.1645 .01195 L
.19697 .01195 L
.22944 .01195 L
.2619 .01195 L
.29437 .01195 L
.32684 .01195 L
.35931 .01195 L
.39177 .01195 L
.42424 .01195 L
.45671 .01195 L
.48918 .01195 L
.52165 .01195 L
.55411 .01195 L
.58658 .01195 L
.61905 .01195 L
.65152 .01195 L
.68398 .01195 L
.71645 .01195 L
.74892 .01195 L
.78139 .01195 L
.78139 .01195 L
.78139 .01757 L
.78139 .02319 L
.78139 .02882 L
.78139 .03444 L
.78139 .04006 L
.78139 .04569 L
.78139 .05131 L
Mistroke
.78139 .05693 L
.78139 .06256 L
.78139 .06818 L
.78139 .07381 L
.78139 .07943 L
.78139 .08505 L
.78139 .09068 L
.78139 .0963 L
.78139 .10192 L
.78139 .10755 L
.78139 .11317 L
.78139 .11879 L
.78139 .12442 L
.78139 .12442 L
.74892 .12442 L
.71645 .12442 L
.68398 .12442 L
.65152 .12442 L
.61905 .12442 L
.58658 .12442 L
.55411 .12442 L
.52165 .12442 L
.48918 .12442 L
.45671 .12442 L
.42424 .12442 L
.39177 .12442 L
.35931 .12442 L
.32684 .12442 L
.29437 .12442 L
.2619 .12442 L
.22944 .12442 L
.19697 .12442 L
.1645 .12442 L
.13203 .12442 L
Mfstroke
.13203 .01195 m
.13203 .00764 L
.13203 .00514 L
.13203 .00378 L
.13203 .00326 L
.13203 .00343 L
.13203 .00418 L
.13203 .00544 L
.13203 .00717 L
.13203 .00935 L
.13203 .01195 L
.13203 .01497 L
.13203 .01842 L
.13203 .02231 L
.13203 .02668 L
.13203 .03155 L
.13203 .037 L
.13203 .04314 L
.13203 .05012 L
.13203 .05826 L
.13203 .06818 L
.13203 .06818 L
.1645 .06818 L
.19697 .06818 L
.22944 .06818 L
.2619 .06818 L
.29437 .06818 L
.32684 .06818 L
.35931 .06818 L
.39177 .06818 L
.42424 .06818 L
.45671 .06818 L
.48918 .06818 L
.52165 .06818 L
.55411 .06818 L
.58658 .06818 L
.61905 .06818 L
.65152 .06818 L
.68398 .06818 L
.71645 .06818 L
.74892 .06818 L
.78139 .06818 L
.78139 .06818 L
.78139 .05826 L
.78139 .05012 L
.78139 .04314 L
.78139 .037 L
.78139 .03155 L
.78139 .02668 L
.78139 .02231 L
Mistroke
.78139 .01842 L
.78139 .01497 L
.78139 .01195 L
.78139 .00935 L
.78139 .00717 L
.78139 .00544 L
.78139 .00418 L
.78139 .00343 L
.78139 .00326 L
.78139 .00378 L
.78139 .00514 L
.78139 .00764 L
.78139 .01195 L
.78139 .01195 L
.74892 .01195 L
.71645 .01195 L
.68398 .01195 L
.65152 .01195 L
.61905 .01195 L
.58658 .01195 L
.55411 .01195 L
.52165 .01195 L
.48918 .01195 L
.45671 .01195 L
.42424 .01195 L
.39177 .01195 L
.35931 .01195 L
.32684 .01195 L
.29437 .01195 L
.2619 .01195 L
.22944 .01195 L
.19697 .01195 L
.1645 .01195 L
.13203 .01195 L
Mfstroke
.13203 .06818 m
.13203 .07811 L
.13203 .08624 L
.13203 .09322 L
.13203 .09936 L
.13203 .10481 L
.13203 .10969 L
.13203 .11405 L
.13203 .11794 L
.13203 .12139 L
.13203 .12442 L
.13203 .12702 L
.13203 .12919 L
.13203 .13092 L
.13203 .13218 L
.13203 .13293 L
.13203 .1331 L
.13203 .13259 L
.13203 .13123 L
.13203 .12872 L
.13203 .12442 L
.13203 .12442 L
.1645 .12442 L
.19697 .12442 L
.22944 .12442 L
.2619 .12442 L
.29437 .12442 L
.32684 .12442 L
.35931 .12442 L
.39177 .12442 L
.42424 .12442 L
.45671 .12442 L
.48918 .12442 L
.52165 .12442 L
.55411 .12442 L
.58658 .12442 L
.61905 .12442 L
.65152 .12442 L
.68398 .12442 L
.71645 .12442 L
.74892 .12442 L
.78139 .12442 L
.78139 .12442 L
.78139 .12872 L
.78139 .13123 L
.78139 .13259 L
.78139 .1331 L
.78139 .13293 L
.78139 .13218 L
.78139 .13092 L
Mistroke
.78139 .12919 L
.78139 .12702 L
.78139 .12442 L
.78139 .12139 L
.78139 .11794 L
.78139 .11405 L
.78139 .10969 L
.78139 .10481 L
.78139 .09936 L
.78139 .09322 L
.78139 .08624 L
.78139 .07811 L
.78139 .06818 L
.78139 .06818 L
.74892 .06818 L
.71645 .06818 L
.68398 .06818 L
.65152 .06818 L
.61905 .06818 L
.58658 .06818 L
.55411 .06818 L
.52165 .06818 L
.48918 .06818 L
.45671 .06818 L
.42424 .06818 L
.39177 .06818 L
.35931 .06818 L
.32684 .06818 L
.29437 .06818 L
.2619 .06818 L
.22944 .06818 L
.19697 .06818 L
.1645 .06818 L
.13203 .06818 L
Mfstroke
.78139 .12229 m
.78139 .12213 L
.78139 .12163 L
.78139 .1208 L
.78139 .11965 L
.78139 .11818 L
.78139 .1164 L
.78139 .11432 L
.78139 .11196 L
.78139 .10933 L
.78139 .10645 L
.78139 .10333 L
.78139 .09999 L
.78139 .09646 L
.78139 .09275 L
.78139 .08889 L
.78139 .0849 L
.78139 .08081 L
.78139 .07665 L
.78139 .07243 L
.78139 .06818 L
.78139 .06394 L
.78139 .05972 L
.78139 .05555 L
.78139 .05146 L
.78139 .04747 L
.78139 .04362 L
.78139 .03991 L
.78139 .03638 L
.78139 .03304 L
.78139 .02992 L
.78139 .02703 L
.78139 .0244 L
.78139 .02204 L
.78139 .01997 L
.78139 .01819 L
.78139 .01672 L
.78139 .01556 L
.78139 .01474 L
.78139 .01424 L
.78139 .01407 L
.78139 .01424 L
.78139 .01474 L
.78139 .01556 L
.78139 .01672 L
.78139 .01819 L
.78139 .01997 L
.78139 .02204 L
.78139 .0244 L
.78139 .02703 L
Mistroke
.78139 .02992 L
.78139 .03304 L
.78139 .03638 L
.78139 .03991 L
.78139 .04362 L
.78139 .04747 L
.78139 .05146 L
.78139 .05555 L
.78139 .05972 L
.78139 .06394 L
.78139 .06818 L
.78139 .07243 L
.78139 .07665 L
.78139 .08081 L
.78139 .0849 L
.78139 .08889 L
.78139 .09275 L
.78139 .09646 L
.78139 .09999 L
.78139 .10333 L
.78139 .10645 L
.78139 .10933 L
.78139 .11196 L
.78139 .11432 L
.78139 .1164 L
.78139 .11818 L
.78139 .11965 L
.78139 .1208 L
.78139 .12163 L
.78139 .12213 L
.78139 .12229 L
Mfstroke
.039 .916 .04 r
.02381 .06818 m
.13203 .08726 L
s
0 0 0 r
2 Mabswid
.13203 .08726 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06818 m
.13203 .05871 L
s
0 0 0 r
2 Mabswid
.13203 .05871 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06818 m
.13203 .05871 L
s
0 0 0 r
2 Mabswid
.13203 .05871 Mdot
.039 .916 .04 r
.5 Mabswid
.13203 .08726 m
.15431 .08983 L
s
0 0 0 r
2 Mabswid
.15431 .08983 Mdot
.039 .916 .04 r
.5 Mabswid
.13203 .05871 m
.15449 .05743 L
s
0 0 0 r
2 Mabswid
.15449 .05743 Mdot
.039 .916 .04 r
.5 Mabswid
.13203 .05871 m
.15449 .05743 L
s
0 0 0 r
2 Mabswid
.15449 .05743 Mdot
.039 .916 .04 r
.5 Mabswid
.15431 .08983 m
.53062 .04654 L
s
0 0 0 r
2 Mabswid
.53062 .04654 Mdot
.039 .916 .04 r
.5 Mabswid
.15449 .05743 m
.53117 .07893 L
s
0 0 0 r
2 Mabswid
.53117 .07893 Mdot
.039 .916 .04 r
.5 Mabswid
.15449 .05743 m
.53117 .07893 L
s
0 0 0 r
2 Mabswid
.53117 .07893 Mdot
.039 .916 .04 r
.5 Mabswid
.53062 .04654 m
.82936 .0809 L
s
0 0 0 r
2 Mabswid
.82936 .0809 Mdot
.039 .916 .04 r
.5 Mabswid
.53117 .07893 m
.82938 .06191 L
s
0 0 0 r
2 Mabswid
.82938 .06191 Mdot
.039 .916 .04 r
.5 Mabswid
.53117 .07893 m
.82938 .06191 L
s
0 0 0 r
2 Mabswid
.82938 .06191 Mdot
.039 .916 .04 r
.5 Mabswid
.82936 .0809 m
.97619 .08835 L
s
0 0 0 r
2 Mabswid
.97619 .08835 Mdot
.039 .916 .04 r
.5 Mabswid
.82938 .06191 m
.97619 .05816 L
s
0 0 0 r
2 Mabswid
.97619 .05816 Mdot
.039 .916 .04 r
.5 Mabswid
.82938 .06191 m
.97619 .05816 L
s
0 0 0 r
2 Mabswid
.97619 .05816 Mdot
0 0 m
1 0 L
1 .13636 L
0 .13636 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[65]:=",
  ImageSize->{288, 39.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00009`P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiNL;2`_ma0?l0FJ6QXDa<o`00`^[ZjW5aLJFUYOoF0=ZU
8000PD1Yh_ooPLk>JHf=A;:b/^;RhVEUIIFEUKZj^_lD0?l/0?m40?mM0?me0?n=0?nU0?o^0?Ko0=ko
0<Ko0:ko09Go06Go04co03Co01co00Co003o303o903o?03oK@3oQ@3oW@3o]P3ocP3oiP3Vo`3>o`2f
o`2Mo`25o`1]o`1Eo`0To`0<o`@0oa`0oc@0od`0ofD0oiD0ojh0olH0omh0ooH0ool0k_l0e_l0__l0
YOl0SOl0MOl0GOl0A?l0;?l05?nn9?nn900000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?md8G@002Qd00<AM7@0F7@00a5dM01HM003
4GAd03md000XM0034GAd05Qd00<AM7@0F7@00a5dM00oM000:7@00a5dM01HM0034GAd05Qd00<AM7@0
?g@002Qd^150M000:7@00a5dM01HM0034GAd05Qd00@AM14A?W@002Qd00<AM7@0F7@00a5dM01HM004
4GAdM0<A>g@002Qd00<AM7@0F7@00a5dM01HM0034GAd00Ad0Q4iM000:7@00a5dM01HM0034GAd05Qd
00<AM7@01G@00a5dM00gM000:7@00a5dM01HM0034GAd05Qd00<AM7@01W@00a5dM00fM000:7@00a5d
M01HM0034GAd05Qd00<AM7@01g@24CId000XM0034GAd05Qd00<AM7@0F7@00a5dM008M0034GAd03Ad
000XM0034GAd05Qd00<AM7@0F7@00a5dM009M0034GAd03=d000XM0034GAd05Qd00<AM7@03W@02AdQ
7A4M8AdQ7@11M0034GAd00Yd00<AM7@0<W@002QdHa498@TA224j4@ad00<AM7@0<W@002Qd00<AM7@0
Eg@02AdQ7B4M8AdQ7@0JM0088AdQ7B4M8AdaM0034GAd00Yd00<AM7@0<W@002Md0Q42M0`Q@g@88@03
M15d02Qd2B4XM0034GAd00]d00<AM7@09G@24@Yd000QM00:8AdQ7B4M8AdQ7@Ad00<AM7@01G@04R4M
8AdQ7B4M8AdQ7B4M8AdQ7BQd00TQ7B4M8AdQ7B402G@00a5dM00`M0087B4M8AdQ7B4PM0034GAd00Yd
0Q4CM00F7B4M8AdQ7B4M8AdQ7B4M8AdQ7B4M4@Yd000AM10Q1g@00a5dM00NM18Q3G@98A9d00<AM7@0
>7@88AQd00<AM7@07b4PM0002G@0224M8AdQ7B4M5g@c4@0A8AdQ7B4M8AdQ7B4M8AdQ7B40FQ406adQ
7B4M8AdQ7B4M8AdQ7B4M8AdQ7B4M8AdQ7@0<4C=d000<M0DQ5g@00a5dM00[M0TQ3G@B8@Ed00<AM7@0
<W@D8@9d2B47M0034GAd00]d00<AM7@0<G@0015d00DQ7B4M8@0BM0034GAd029d00TQ7B4M8AdQ7B40
:7@04QdQ7B4M8AdQ7B4M8AdQ7B4M8A=d01DQ7B4M8AdQ7B4M8AdQ7B4M8AdQ7B407g@0224M8AdQ7B4M
3G@00a5dM00aM0005W@68@ad00<AM7@06W@88CId00<AM7@02W@78@034B4Q00TQ>g@00a4Q8@068@Ad
0Q4cM00077@01AdQ7B4M00Md00<AM7@04G@02AdQ7B4M8AdQ7@0nM0034GAd019d00<AM7@0@g@00a5d
M006M00?8AdQ7B4M8AdQ7B4M8AdQ02Yd000QM0DQ00=d4A402W@98DMd00<AM7@0F7@00a5dM00:M003
4GAd00Qd5B4EM0009W@03AdQ7B4M8AdQ7B4M8Ad0[14<M0034GAd01ed00TQ7B4M8AdQ7B400Q4:M000
:7@00a5dM004M0034GAd055d00<AM7@0F7@00a5dM00:M0034GAd02Md00<AM7@027@002Qd00<AM7@0
F7@00a5dM01HM0034GAd00Ud00<AM7@0<g@002Qd00<AM7@0F7@00a5dM01HM0034GAd00Qd00<AM7@0
=7@002Qd00<AM7@0F7@00a5dM01HM0034GAd00Md00<AM7@0=G@002Qd00<AM7@0F7@00a5dM01HM003
4GAd00Id00<AM7@0=W@002Qd00<AM7@0F7@00a5dM01HM0034GAd00Id00<AM7@0=W@002Qd00<AM7@0
F7@00a5dM01HM0034GAd00Ad0Q4iM000:7@00a5dM01HM0034GAd05Qd00@AM7Ad0a4kM000:7@00a5d
M01HM0034GAd05Qd00@AM14A?W@002Qd^150M000:7@00a5dM01HM0034GAd05Qd00<AM7@0?g@002Qd
00<AM7@0F7@00a5dM01HM0034GAd03md000XM0034GAd05Qd00<AM7@0F7@00a5dM00oM000\
\>"],
  ImageRangeCache->{{{0, 287}, {38.25, 0}} -> {-6.34664, -31.5, 1.64702, 
  1.64702}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1920}, {0, 1174}},
WindowSize->{1026, 967},
WindowMargins->{{86, Automatic}, {Automatic, 45}},
ShowCellTags->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 35, 0, 52, "Section"],
Cell[1814, 55, 140, 3, 24, "Text"],
Cell[1957, 60, 628, 21, 334, "Input"],
Cell[2588, 83, 173, 4, 24, "Text"],
Cell[2764, 89, 513, 14, 198, "Input"],
Cell[3280, 105, 46, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[3351, 109, 287, 12, 181, "Input"],
Cell[3641, 123, 27281, 1592, 46, 23789, 1544, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

