(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    254919,       6614]*)
(*NotebookOutlinePosition[    256282,       6656]*)
(*  CellTagsIndexPosition[    256117,       6648]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "The ",
  StyleBox["DistortionGrid", "Input"],
  " and ",
  StyleBox["FindFocalSurface", "Input"],
  " functions are used to determine the best surface of focus for an imaging \
system. First we examine the ",
  StyleBox["DistortionGrid", "Input"],
  " light source function."
}], "Text"],

Cell[CellGroupData[{

Cell["?DistortionGrid", "Input"],

Cell[BoxData[
    \("DistortionGrid[seed, gridsize, gridpoints] creates a grid of rays to \
display the image distortion of an optical system.\n \nThe grid is \
rectangular in shape, where its dimensions are given by the gridsize \
parameter and the number of points along each grid dimension is specified by \
the gridpoints parameter. Both gridsize and gridpoints parameters may be \
given either as a single numeric value (to create a one-dimensional set of \
points) or as a list of two numeric values (to create a two-dimensional array \
of points).\n \nThe seed parameter is optional and is used to generate more \
elaborate ray patterns. When it is present, it specifies additional light \
sources to be nested with the basic DistortionGrid result. However, when \
DistortionGrid is used in conjunction with FindFocalSurface, the seed \
parameter should be included using a point-source function, such as \
PointOfRays. DistortionGrid calls CustomRays internally and is principally \
used by FindFocalSurface.\n \nSee also FindFocalSurface."\)], "Print",
  CellTags->"Info3257567525-4308219"]
}, Open  ]],

Cell[TextData[{
  "Here are some examples of ",
  StyleBox["DistortionGrid", "Input"],
  " patterns."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[
\t{DistortionGrid[WedgeOfRays[10], 10, 3],
\tMove[Screen[{15,15}],10]}];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2975 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.147952 1.36927 0 1.36927 [
[ 0 0 0 0 ]
[ 1 1.2975 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.2975 L
0 1.2975 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.91356 .51629 m
.9775 1.15706 L
s
.58389 .03441 m
.91356 .51629 L
s
.039 .916 .04 r
.43754 .88173 m
.87536 .72384 L
s
.43754 .88173 m
.89347 .74733 L
s
.43754 .88173 m
.91118 .7703 L
s
0 g
.94303 .81162 m
.89347 .74733 L
s
.94303 .81162 m
.94303 .81162 L
s
.76444 .29832 m
.76444 .29832 L
s
.77063 .39512 m
.76444 .29832 L
s
0 0 0 r
2 Mabswid
.91118 .7703 Mdot
.039 .916 .04 r
.5 Mabswid
.30649 .75833 m
.76338 .57856 L
s
.30649 .75833 m
.78409 .60543 L
s
.30649 .75833 m
.80431 .63165 L
s
0 0 0 r
2 Mabswid
.89347 .74733 Mdot
0 g
.5 Mabswid
.89347 .74733 m
.84061 .67875 L
s
.77717 .49733 m
.77063 .39512 L
s
0 0 0 r
2 Mabswid
.87536 .72384 Mdot
0 g
.5 Mabswid
.84061 .67875 m
.78409 .60543 L
s
.78409 .60543 m
.77717 .49733 L
s
.9775 1.15706 m
.59394 .73634 L
s
0 0 0 r
2 Mabswid
.80431 .63165 Mdot
.039 .916 .04 r
.5 Mabswid
.15744 .618 m
.63457 .41145 L
s
.15744 .618 m
.65849 .44248 L
s
.15744 .618 m
.68179 .47271 L
s
0 0 0 r
2 Mabswid
.78409 .60543 Mdot
0 g
.5 Mabswid
.79142 .71992 m
.78409 .60543 L
s
.78409 .60543 m
.72353 .52687 L
s
0 0 0 r
2 Mabswid
.76338 .57856 Mdot
0 g
.5 Mabswid
.59394 .73634 m
.58389 .03441 L
s
.79919 .84141 m
.79142 .71992 L
s
.72353 .52687 m
.65849 .44248 L
s
0 0 0 r
2 Mabswid
.68179 .47271 Mdot
0 g
.5 Mabswid
.80745 .97054 m
.79919 .84141 L
s
0 0 0 r
2 Mabswid
.65849 .44248 Mdot
0 g
.5 Mabswid
.65849 .44248 m
.58843 .3516 L
s
0 0 0 r
2 Mabswid
.63457 .41145 Mdot
0 g
.5 Mabswid
.80745 .97054 m
.80745 .97054 L
s
.58843 .3516 m
.58843 .3516 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{221.938, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M00017b000`400?l00000o`00003og@3oool0
0=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00840oooo00<000000?ooo`3o
ool0F@3oool00840oooo00<000000?ooo`3oool0F@3oool00840oooo0P00001J0?ooo`00P@3oool0
0`000000oooo0000001I0?ooo`00P@3oool00`000000oooo0000001I0?ooo`00P@3oool010000000
oooo0?ooo`00001H0?ooo`00P@3oool01@000000oooo0?ooo`3oool0000005L0oooo00210?ooo`05
0000003oool0oooo0?ooo`000000E`3oool00840oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1D0?ooo`00P@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05<0oooo
00210?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0D`3oool00840oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1B0?ooo`00P@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0540oooo00210?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0D@3oool00840oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1@0?ooo`00P@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04l0oooo00210?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0C`3oool00840oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`1>0?ooo`00P@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04d0
oooo00210?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0C@3oool00840oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1<0?ooo`00P@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo04/0oooo00210?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0B`3oool00840oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1:0?ooo`00
P@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04T0oooo00210?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0B@3oool00840oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`180?ooo`00P@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
04L0oooo00210?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0AP3oool00840oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`160?ooo`00P@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo04D0oooo00210?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0A03oool00840oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`140?oo
o`00P@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04<0oooo00210?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0@P3oool00840oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`120?ooo`00P@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0440oooo00210?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0@03oool00840
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`100?ooo`00P@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo03l0oooo00220?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0?P3oool00880oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0n
0?ooo`00PP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03d0oooo00220?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0?03oool00880oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0l0?ooo`00PP3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo03/0oooo00220?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0>P3oool0
0880oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0j0?ooo`00PP3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo03T0oooo00220?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0>03oool00880oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0h0?ooo`00PP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03L0oooo00220?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=P3oool00880oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0f0?ooo`00PP3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03D0oooo00220?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0=03o
ool00880oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0d0?ooo`00PP3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo03<0oooo00220?ooo`030000003oool0oooo02<0
oooo0P00000c0?ooo`00PP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0380oooo
00220?ooo`030000003oool0oooo02<0oooo0P00000c0?ooo`00PP3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool000000380oooo00220?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`000000<P3oool00880oooo00<000000?ooo`3oool08`3oool010000000oooo0?ooo`00000a0?oo
o`00PP3oool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`000000<03oool00880
oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000`0?ooo`00PP3oool00`000000
oooo0?ooo`0T0?ooo`050000003oool0oooo0?ooo`000000;`3oool00880oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02`0oooo00220?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0/0?ooo`00PP3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:`3o
ool00880oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo02X0oooo00220?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0Z0?ooo`00PP3oool2000002D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0Y0?ooo`00PP3oool00`000000oooo0000000T0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0:03oool00880oooo00@000000?ooo`3oool000008`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02P0oooo00220?ooo`040000003oool0oooo000002<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?ooo`00PP3oool01@000000oooo0?oo
o`3oool0000002<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0V0?ooo`00PP3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0V0?ooo`00PP3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0U0?ooo`00PP3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0T0?ooo`00PP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0T0?ooo`00PP3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0S0?ooo`00PP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0R0?ooo`00PP3oool00`000000oooo0?ooo`06
0?ooo`8000007@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0240oooo00220?oo
o`030000003oool0oooo00H0oooo0P00000M0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool08@3oool00880oooo00<000000?ooo`3oool00`3oool300WZ2P80oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0200oooo00220?ooo`040000
003oool0oooo0?ooo`802NX:1P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool07`3oool00880oooo00@000000?ooo`09jPX02NX:203oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool07`3oool00840oooo
00<02NX:00000009jPX02`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool07P3oool007l0oooo0P09jPX00`3oool000000?ooo`0<0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0M0?ooo`00O@3oool2
00WZ2P<0oooo00<000000?ooo`3oool02`3oool2000001P0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0M0?ooo`00NP3oool300WZ2PD0oooo00<000000?ooo`3oool0203oool300WZ
2P800000603oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01`0oooo001h0?ooo`80
2NX:203oool00`000000oooo0?ooo`050?ooo`<02NX:1@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool06`3oool007H0oooo0P09jPX:0?ooo`030000
003oool0oooo0080oooo0`09jPX90?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0K0?ooo`00L`3oool300WZ2P`0oooo00<000000?ooo`09jPX00P09
jPX=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0J0?ooo`00L@3oool200WZ2Ph0oooo00<02NX:00000009jPX0403oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06@3oool006l0oooo0P09jPX=0?oo
o`<02NX:00<0oooo0000003oool04@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool06@3oool006`0oooo0`09jPX=0?ooo`802NX:103oool00`000000
oooo0?ooo`0?0?ooo`802NX:0P00000C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0603oool006X0oooo0P09jPX=0?ooo`<02NX:1P3oool00`000000oooo0?ooo`0<0?ooo`<02NX:
0P3oool2000001<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`00I`3o
ool300WZ2P`0oooo0`09jPX90?ooo`030000003oool0oooo00P0oooo1009jPX60?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`00I@3oool2
00WZ2P`0oooo0`09jPX<0?ooo`030000003oool0oooo00@0oooo1009jPX;0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`00H`3oool200WZ
2P/0oooo0`09jPX?0?ooo`040000003oool0oooo0?ooo`<02NX:403oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05@3oool00600oooo0`09jPX:0?oo
o`<02NX:4P3oool0100000002NX:00WZ2P09jPXC0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0E0?ooo`00GP3oool200WZ2P/0oooo0P09jPXA0?oo
o`@02NX:00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0503oool005`0oooo0P09jPX:0?ooo`<02NX:403oool300WZ2P@0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool04`3oool005T0oooo0`09jPX90?ooo`<02NX:3`3oool400WZ2PL0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool04`3oool005L0oooo0P09jPX90?ooo`<02NX:3`3oool300WZ2P/0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool04P3oool005D0oooo0P09jPX80?ooo`<02NX:3P3oool400WZ2Ph0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool04@3oool00580oooo0`09jPX70?ooo`<02NX:3@3oool400WZ2Q80oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool04@3oool00500oooo0P09jPX70?ooo`<02NX:3@3oool300WZ2QH0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool04@3oool004h0oooo0P09jPX70?ooo`802NX:303oool400WZ2QT0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
4@3oool004/0oooo0`09jPX60?ooo`<02NX:2P3oool400WZ2Qd0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04@3o
ool004T0oooo0P09jPX60?ooo`<02NX:2P3oool300WZ2R40oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04@3oool0
04L0oooo0P09jPX50?ooo`<02NX:2@3oool400WZ2R@0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool004@0
oooo0`09jPX40?ooo`<02NX:2@3oool300WZ2RP0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00480oooo
0P09jPX40?ooo`<02NX:203oool400WZ2R/0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool003l0oooo0`09
jPX40?ooo`802NX:1`3oool400WZ2Rl0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool003d0oooo0P09jPX4
0?ooo`<02NX:1P3oool300WZ2S@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool003/0oooo0P09jPX30?oo
o`<02NX:1@3oool400WZ2SL0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool003P0oooo0`09jPX20?ooo`<0
2NX:103oool400WZ2S/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool003H0oooo0P09jPX20?ooo`<02NX:
103oool300WZ2Sl0oooo00<000000?ooo`3oool08P3oool200000080oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0@0?ooo`00=03oool200WZ2P040?ooo`09jPX02NX:00WZ2P<0oooo
1009jPY20?ooo`030000003oool0oooo0240oooo00<02NX:0000000000000`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo0100oooo000a0?ooo`H02NX:0`3oool300WZ2TH0oooo00<0
00000?ooo`3oool07P3oool300WZ2P80oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000
003oool0oooo0100oooo000_0?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool400WZ2TT0oooo00<0
00000?ooo`3oool0703oool200WZ2PH0oooo00@000000?ooo`3oool000007@3oool00`000000oooo
0?ooo`0?0?ooo`00;@3oool900WZ2Td0oooo00<000000?ooo`3oool06@3oool300WZ2PT0oooo00<0
00000?ooo`0000007@3oool00`000000oooo0?ooo`0?0?ooo`00:P3oool800WZ2U40oooo00<00000
0?ooo`3oool05P3oool300WZ2Pd0oooo0P00000M0?ooo`030000003oool0oooo00l0oooo000X0?oo
o`L02NX:E03oool00`000000oooo0?ooo`0D0?ooo`802NX:3`3oool00`09jPX000000000000M0?oo
o`030000003oool0oooo00l0oooo000V0?ooo`D02NX:F03oool00`000000oooo0?ooo`0A0?ooo`<0
2NX:3P3oool300WZ2P030?ooo`000000000001d0oooo00<000000?ooo`3oool03`3oool002<0oooo
1009jPYL0?ooo`030000003oool0oooo00l0oooo0P09jPX>0?ooo`<02NX:1@3oool2000001`0oooo
00<000000?ooo`3oool03`3oool00280oooo0P09jPYO0?ooo`030000003oool0oooo00`0oooo0`09
jPX=0?ooo`<02NX:203oool00`000000oooo0000000K0?ooo`030000003oool0oooo00l0oooo0023
0?ooo`030000003oool0oooo00T0oooo0`09jPX=0?ooo`<02NX:2`3oool00`000000oooo0000000K
0?ooo`030000003oool0oooo00l0oooo00230?ooo`030000003oool0oooo00L0oooo0P09jPX=0?oo
o`<02NX:3P3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo00l0oooo00230?oo
o`030000003oool0oooo00@0oooo0`09jPX<0?ooo`<02NX:4@3oool010000000oooo00WZ2P09jPX2
000001P0oooo00<000000?ooo`3oool03`3oool008<0oooo00<000000?ooo`3oool00P3oool200WZ
2P`0oooo0`09jPXB0?ooo`802NX:00@0000000WZ2P3oool0oooo0P00000I0?ooo`030000003oool0
oooo00h0oooo00230?ooo`030000003oool02NX:00802NX:2P3oool400WZ2Q40oooo1009jPX20?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0>0?oo
o`00PP3oool00`09jPX0000000WZ2P0:0?ooo`<02NX:4@3oool400WZ2PH0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0oooo00200?ooo`802NX:
00<0oooo0000003oool01`3oool300WZ2Q00oooo1009jPX:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`00O@3oool300WZ2P<0oooo00<0
00000?ooo`3oool00`3oool300WZ2Pl0oooo1009jPX>0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`00N`3oool200WZ2PH0oooo00<00000
0?ooo`3oool00`09jPX>0?ooo`@02NX:4P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool03P3oool007P0oooo0`09jPX80?ooo`0300000009jPX02NX:
00h0oooo0`09jPXF0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0>0?ooo`00M@3oool300WZ2PP0oooo0`09jPX00`000000oooo0?ooo`0:0?ooo`@0
2NX:6P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool03P3oool007<0oooo0P09jPX80?ooo`<02NX:0`3oool00`000000oooo0?ooo`060?ooo`@02NX:
7P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
3P3oool00700oooo0`09jPX70?ooo`<02NX:1P3oool00`000000oooo0?ooo`020?ooo`@02NX:8P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3o
ool006h0oooo0P09jPX60?ooo`@02NX:2@3oool00`0000002NX:00WZ2P0200WZ2RH0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo001[0?oo
o`<02NX:1@3oool300WZ2PX0oooo0`09jPX00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`00J@3oool200WZ2PD0
oooo0`09jPX90?ooo`@02NX:0`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`00IP3oool300WZ2P@0oooo
0`09jPX80?ooo`@02NX:1`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`00H`3oool300WZ2P@0oooo0`09
jPX70?ooo`@02NX:2`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`00H@3oool200WZ2P@0oooo0`09jPX6
0?ooo`@02NX:3`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`00GP3oool300WZ2P<0oooo0`09jPX50?oo
o`@02NX:4`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`00G03oool200WZ2P<0oooo0`09jPX40?ooo`@0
2NX:5`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0=0?ooo`00F@3oool300WZ2P030?ooo`09jPX02NX:00802NX:
0`3oool400WZ2Q/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool005H0oooo0`09jPX0103oool02NX:00WZ
2P09jPX30?ooo`@02NX:7`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00l0oooo
0P00000;0?ooo`030000003oool0oooo00d0oooo001D0?ooo`802NX:00@0oooo00WZ2P09jPX02NX:
0`3oool300WZ2R<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0?0?ooo`800000
303oool00`000000oooo0?ooo`0<0?ooo`00D@3oool600WZ2P80oooo1009jPXV0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0303oool300WZ2P030?ooo`000000oooo00/0oooo00<0
00000?ooo`3oool0303oool004l0oooo1@09jPX00`3oool02NX:00WZ2P0200WZ2RX0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`<02NX:1@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00`0oooo001<0?ooo`T02NX:;P3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00H0oooo0`09jPX90?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0303oool004T0oooo2009jPXc0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0103oool200WZ2Pd0oooo0P0000080?ooo`030000003oool0oooo00`0oooo00170?ooo`H02NX:
>03oool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo0?ooo`<02NX:3P3oool00`09jPX0
0000000000080?ooo`030000003oool0oooo00`0oooo00140?ooo`D02NX:?@3oool00`000000oooo
0?ooo`0U0?ooo`0400000009jPX02NX:00WZ2Ph0oooo0`09jPX20?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0303oool004<0oooo0P09jPY20?ooo`030000003oool0oooo0280oooo
0`09jPX00`000000oooo0?ooo`0;0?ooo`<02NX:1P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00`0oooo00280?ooo`030000003oool0oooo01h0oooo0`09jPX30?ooo`030000003o
ool0oooo00L0oooo1009jPX:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303o
ool008T0oooo00<000000?ooo`3oool06`3oool200WZ2PH0oooo00<000000?ooo`3oool0103oool3
00WZ2Pl0oooo0P0000040?ooo`030000003oool0oooo00`0oooo002:0?ooo`030000003oool0oooo
01L0oooo0`09jPX80?ooo`030000003oool0oooo00@02NX:4@3oool00`09jPX00000000000050?oo
o`030000003oool0oooo00/0oooo002;0?ooo`030000003oool0oooo01<0oooo0`09jPX;0?ooo`03
00000009jPX02NX:0140oooo1009jPX20?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02`3oool008`0oooo00<000000?ooo`3oool03`3oool300WZ2P/0oooo0`09jPX00`000000oooo
0?ooo`0<0?ooo`D02NX:1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
002<0?ooo`030000003oool0oooo00d0oooo0P09jPX:0?ooo`@02NX:0`3oool00`000000oooo0?oo
o`080?ooo`@02NX:3@3oool01@000000oooo0?ooo`3oool0000000d0oooo002=0?ooo`030000003o
ool0oooo00T0oooo0`09jPX90?ooo`<02NX:1`3oool00`000000oooo0?ooo`040?ooo`@02NX:4P3o
ool010000000oooo0?ooo`00000=0?ooo`00SP3oool00`000000oooo0?ooo`050?ooo`<02NX:2@3o
ool300WZ2PX0oooo00<000000?ooo`3oool01009jPXF0?ooo`040000003oool0oooo000000d0oooo
002?0?ooo`040000003oool0oooo0?ooo`<02NX:203oool400WZ2P`0oooo00@02NX:00000009jPX0
2NX:6`3oool00`000000oooo0000000=0?ooo`00T03oool00`0000002NX:00WZ2P080?ooo`<02NX:
2`3oool500WZ2P030?ooo`000000oooo01d0oooo0P00000=0?ooo`00SP3oool200WZ2P030?ooo`00
0000oooo00D0oooo0`09jPX:0?ooo`@02NX:1P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00/0oooo002;0?ooo`<02NX:103oool00`000000oooo00WZ2P0300WZ2PT0oooo1009jPX:
0?ooo`030000003oool0oooo01d0oooo0P00000<0?ooo`00R03oool300WZ2PH0oooo0P09jPX00`00
0000oooo0?ooo`070?ooo`@02NX:3`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00X0oooo00250?ooo`<02NX:1@3oool400WZ2P<0oooo00<000000?ooo`3oool00P3oool400WZ2Q<0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`00P`3oool200WZ2PD0oooo
0`09jPX70?ooo`0300WZ2P0000002NX:00802NX:5`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00X0oooo00200?ooo`<02NX:103oool300WZ2PH0oooo1009jPX20?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`00O@3oool3
00WZ2P<0oooo1009jPX50?ooo`@02NX:1P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool02P3oool007X0oooo0`09jPX30?ooo`<02NX:1@3oool400WZ
2P/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00X0oooo001h0?ooo`802NX:0`3oool300WZ2P@0oooo1009jPX@0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`00M@3oool300WZ2P030?oo
o`09jPX02NX:00802NX:0P3oool500WZ2QD0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00X0oooo001b0?ooo`<02NX:00@0oooo00WZ2P09jPX02NX:
0P3oool400WZ2Q/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00X0oooo001_0?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2R00oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0oooo
001/0?ooo`/02NX:9@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool02P3oool006X0oooo2@09jPXZ0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`00I`3oool800WZ2Rl0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo001T0?ooo`H0
2NX:=@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool02@3oool00640oooo1@09jPXi0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`090?ooo`00H03oool200WZ2Sh0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo002Q0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`00XP3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02@3oool00:<0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0
oooo002T0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`090?ooo`00Y@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool02@3oool00:H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00P0oooo002W0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`080?ooo`00Z03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool00:P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00P0oooo002Y0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`080?ooo`00ZP3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool0
0:/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00P0oooo002/0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`080?ooo`00[@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0203oool00:h0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`030000
003oool0oooo00P0oooo002_0?ooo`040000003oool0oooo00000200oooo00<000000?ooo`3oool0
1`3oool00;00oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`070?ooo`00/@3oool2
00000200oooo00<000000?ooo`3oool01`3oool00;80oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`070?ooo`00/P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0
oooo002c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00;@0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`070?ooo`00]@3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00L0oooo002f0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool01`3oool00;L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`00
^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo002i0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool01P3oool00;X0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`060?ooo`00^`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00H0oooo002k0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01P3oool00;`0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`00_@3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00H0oooo002n0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool01P3oool00;l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`060?oo
o`00`03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo00310?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool01@3oool00<80oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`050?ooo`00``3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00D0oooo00340?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00<@0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`00a@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00360?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool01@3oool00<L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`05
0?ooo`00b03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00390?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00<X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`040?ooo`00b`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00@0oooo003<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool0
0<d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`00cP3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo003>0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00<l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`00d03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo003A0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00=80oooo00D000000?ooo`3o
ool0oooo000000060?ooo`00d`3oool01@000000oooo0?ooo`3oool0000000D0oooo003D0?ooo`04
0000003oool0oooo000000D0oooo003E0?ooo`030000003oool0000000D0oooo003F0?ooo`800000
1@3oool00=L0oooo00<000000?ooo`3oool00`3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo
003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0
oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool0
0=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3o
ool00=d0oooo0000\
\>"],
  ImageRangeCache->{{{0, 220.938}, {286.938, 0}} -> {0.108048, -0.000452797, \
0.00330557, 0.00330557}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[
\t{DistortionGrid[PointOfRays[10], {10,10}, {3,3}],
\tMove[Screen[{15,15}],10]}];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2975 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.147952 1.36927 0 1.36927 [
[ 0 0 0 0 ]
[ 1 1.2975 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.2975 L
0 1.2975 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
[ ] 0 setdash
.44229 .68337 m
.88651 .58431 L
s
.44229 .68337 m
.88118 .52563 L
s
.44229 .68337 m
.85788 .51816 L
s
.44229 .68337 m
.88086 .56342 L
s
.44229 .68337 m
.87822 .53409 L
s
.44229 .68337 m
.86663 .5305 L
s
.44229 .68337 m
.87525 .54266 L
s
0 g
.91356 .51629 m
.9775 1.15706 L
s
.58389 .03441 m
.91356 .51629 L
s
.039 .916 .04 r
.43754 .88173 m
.90539 .79174 L
s
.43754 .88173 m
.89946 .72661 L
s
.43754 .88173 m
.87536 .72384 L
s
.43754 .88173 m
.8994 .76946 L
s
.43754 .88173 m
.89647 .73689 L
s
.43754 .88173 m
.88449 .73567 L
s
.43754 .88173 m
.89347 .74733 L
s
0 0 0 r
2 Mabswid
.88118 .52563 Mdot
.87822 .53409 Mdot
.039 .916 .04 r
.5 Mabswid
.31818 .55415 m
.78237 .43913 L
s
.31818 .55415 m
.77838 .37903 L
s
.31818 .55415 m
.75091 .3673 L
s
.31818 .55415 m
.77647 .41705 L
s
.31818 .55415 m
.77451 .38701 L
s
.31818 .55415 m
.76084 .38131 L
s
.31818 .55415 m
.77063 .39512 L
s
0 0 0 r
2 Mabswid
.87525 .54266 Mdot
.88086 .56342 Mdot
.88651 .58431 Mdot
.86663 .5305 Mdot
.85788 .51816 Mdot
0 g
.5 Mabswid
.94303 .81162 m
.89347 .74733 L
s
.94303 .81162 m
.94303 .81162 L
s
.76444 .29832 m
.76444 .29832 L
s
.77063 .39512 m
.76444 .29832 L
s
.039 .916 .04 r
.4323 1.1011 m
.92641 1.02282 L
s
.4323 1.1011 m
.9198 .95012 L
s
.4323 1.1011 m
.89486 .95319 L
s
.4323 1.1011 m
.92006 .99897 L
s
.4323 1.1011 m
.91678 .9626 L
s
.4323 1.1011 m
.90439 .96432 L
s
.4323 1.1011 m
.91376 .97528 L
s
0 0 0 r
2 Mabswid
.89946 .72661 Mdot
.89647 .73689 Mdot
.039 .916 .04 r
.5 Mabswid
.30649 .75833 m
.79654 .65253 L
s
.30649 .75833 m
.79208 .58536 L
s
.30649 .75833 m
.76338 .57856 L
s
.30649 .75833 m
.79028 .6289 L
s
.30649 .75833 m
.78809 .59531 L
s
.30649 .75833 m
.77382 .5921 L
s
.30649 .75833 m
.78409 .60543 L
s
0 0 0 r
2 Mabswid
.77838 .37903 Mdot
.89347 .74733 Mdot
0 g
.5 Mabswid
.89347 .74733 m
.84061 .67875 L
s
0 0 0 r
2 Mabswid
.8994 .76946 Mdot
.90539 .79174 Mdot
.77451 .38701 Mdot
.039 .916 .04 r
.5 Mabswid
.17796 .40815 m
.66363 .2736 L
s
.17796 .40815 m
.66143 .21224 L
s
.17796 .40815 m
.6288 .1951 L
s
.17796 .40815 m
.65748 .2502 L
s
.17796 .40815 m
.65643 .21954 L
s
.17796 .40815 m
.64019 .21116 L
s
.17796 .40815 m
.6514 .22697 L
s
0 0 0 r
2 Mabswid
.88449 .73567 Mdot
.77063 .39512 Mdot
0 g
.5 Mabswid
.77717 .49733 m
.77063 .39512 L
s
0 0 0 r
2 Mabswid
.87536 .72384 Mdot
.77647 .41705 Mdot
.78237 .43913 Mdot
.76084 .38131 Mdot
.75091 .3673 Mdot
0 g
.5 Mabswid
.84061 .67875 m
.78409 .60543 L
s
.78409 .60543 m
.77717 .49733 L
s
0 0 0 r
2 Mabswid
.9198 .95012 Mdot
.91678 .9626 Mdot
0 g
.5 Mabswid
.9775 1.15706 m
.59394 .73634 L
s
.039 .916 .04 r
.29347 .98561 m
.81244 .89206 L
s
.29347 .98561 m
.80742 .8165 L
s
.29347 .98561 m
.7774 .81594 L
s
.29347 .98561 m
.80578 .86665 L
s
.29347 .98561 m
.80332 .82885 L
s
.29347 .98561 m
.78838 .82878 L
s
.29347 .98561 m
.79919 .84141 L
s
0 0 0 r
2 Mabswid
.79208 .58536 Mdot
.91376 .97528 Mdot
.92006 .99897 Mdot
.92641 1.02282 Mdot
.78809 .59531 Mdot
.039 .916 .04 r
.5 Mabswid
.15744 .618 m
.6715 .49262 L
s
.15744 .618 m
.66902 .42349 L
s
.15744 .618 m
.63457 .41145 L
s
.15744 .618 m
.66496 .46746 L
s
.15744 .618 m
.66377 .4329 L
s
.15744 .618 m
.64663 .4271 L
s
.15744 .618 m
.65849 .44248 L
s
0 0 0 r
2 Mabswid
.90439 .96432 Mdot
.66143 .21224 Mdot
.78409 .60543 Mdot
0 g
.5 Mabswid
.79142 .71992 m
.78409 .60543 L
s
.78409 .60543 m
.72353 .52687 L
s
0 0 0 r
2 Mabswid
.89486 .95319 Mdot
.79028 .6289 Mdot
.79654 .65253 Mdot
.65643 .21954 Mdot
.77382 .5921 Mdot
.6514 .22697 Mdot
.76338 .57856 Mdot
.65748 .2502 Mdot
.66363 .2736 Mdot
0 g
.5 Mabswid
.59394 .73634 m
.58389 .03441 L
s
0 0 0 r
2 Mabswid
.64019 .21116 Mdot
.6288 .1951 Mdot
0 g
.5 Mabswid
.79919 .84141 m
.79142 .71992 L
s
.72353 .52687 m
.65849 .44248 L
s
0 0 0 r
2 Mabswid
.80742 .8165 Mdot
.80332 .82885 Mdot
.039 .916 .04 r
.5 Mabswid
.13444 .85331 m
.68041 .74058 L
s
.13444 .85331 m
.67759 .66211 L
s
.13444 .85331 m
.6411 .6567 L
s
.13444 .85331 m
.67342 .71338 L
s
.13444 .85331 m
.67207 .67414 L
s
.13444 .85331 m
.65392 .67167 L
s
.13444 .85331 m
.66651 .68638 L
s
0 0 0 r
2 Mabswid
.66902 .42349 Mdot
.79919 .84141 Mdot
0 g
.5 Mabswid
.80745 .97054 m
.79919 .84141 L
s
0 0 0 r
2 Mabswid
.80578 .86665 Mdot
.81244 .89206 Mdot
.66377 .4329 Mdot
.78838 .82878 Mdot
.65849 .44248 Mdot
0 g
.5 Mabswid
.65849 .44248 m
.58843 .3516 L
s
0 0 0 r
2 Mabswid
.7774 .81594 Mdot
.66496 .46746 Mdot
.6715 .49262 Mdot
.64663 .4271 Mdot
.63457 .41145 Mdot
0 g
.5 Mabswid
.80745 .97054 m
.80745 .97054 L
s
.58843 .3516 m
.58843 .3516 L
s
0 0 0 r
2 Mabswid
.67759 .66211 Mdot
.67207 .67414 Mdot
.66651 .68638 Mdot
.67342 .71338 Mdot
.68041 .74058 Mdot
.65392 .67167 Mdot
.6411 .6567 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{221.938, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M00017b000`400?l00000o`00003og@3oool0
0=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00840oooo00<000000?ooo`3o
ool0F@3oool00840oooo00<000000?ooo`3oool0F@3oool00840oooo0P00001J0?ooo`00P@3oool0
0`000000oooo0000001I0?ooo`00P@3oool00`000000oooo0000001I0?ooo`00P@3oool010000000
oooo0?ooo`00001H0?ooo`00P@3oool01@000000oooo0?ooo`3oool0000005L0oooo00210?ooo`05
0000003oool0oooo0?ooo`000000E`3oool00840oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1D0?ooo`00P@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05<0oooo
00210?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0D`3oool00840oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1B0?ooo`00P@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0540oooo00210?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0D@3oool00840oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1@0?ooo`00P@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04l0oooo00210?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0C`3oool00840oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`1>0?ooo`00P@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04d0
oooo00210?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0C@3oool00840oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1<0?ooo`00P@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo04/0oooo00210?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0B`3oool00840oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1:0?ooo`00
P@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04T0oooo00210?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0B@3oool00840oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`180?ooo`00P@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
04L0oooo00210?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0AP3oool00840oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`160?ooo`00P@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo04D0oooo00210?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0A03oool00840oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`140?oo
o`00P@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04<0oooo00210?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0@P3oool00840oooo00<000000?ooo`3oool01P3o
ool2000000`0oooo00<000000?ooo`3oool0@P3oool00840oooo00<000000?ooo`3oool01@3oool0
0`09jPX000000000000=0?ooo`030000003oool0oooo0440oooo00210?ooo`030000003oool0oooo
00<0oooo0P09jPXA0?ooo`030000003oool0oooo0400oooo00210?ooo`040000003oool0oooo0?oo
o`802NX:4`3oool00`000000oooo0?ooo`100?ooo`00P@3oool010000000oooo00WZ2P09jPX70?oo
o`8000000`3oool2000000P0oooo00<000000?ooo`3oool0?`3oool00840oooo00<02NX:0000003o
ool01P3oool200WZ2P8000000`3oool2000000T0oooo00<000000?ooo`3oool0?P3oool007h0oooo
0`09jPX00`3oool000000?ooo`030?ooo`<02NX:103oool200WZ2P8000002P3oool00`000000oooo
0?ooo`0n0?ooo`00O03oool200WZ2P@0oooo00<000000?ooo`3oool00P09jPX50?ooo`<02NX:0`00
000;0?ooo`030000003oool0oooo03d0oooo001j0?ooo`802NX:1P3oool00`0000002NX:00WZ2P04
0?ooo`@02NX:00@0oooo00WZ2P00000000003@3oool00`000000oooo0?ooo`0l0?ooo`00N03oool2
00WZ2PH0oooo0P09jPX00`000000oooo0?ooo`020?ooo`L02NX:403oool00`000000oooo0?ooo`0l
0?ooo`00MP3oool200WZ2PH0oooo0P09jPX20?ooo`030000003oool02NX:00H02NX:503oool00`00
0000oooo0?ooo`0k0?ooo`00M03oool200WZ2PH0oooo0P09jPX40?ooo`0300000009jPX02NX:00<0
2NX:603oool00`000000oooo0?ooo`0j0?ooo`00LP3oool200WZ2PD0oooo0`09jPX30?ooo`<02NX:
00@0000000WZ2P09jPX02NX:2P3oool2000000h0oooo00<000000?ooo`3oool0>P3oool00700oooo
0P09jPX50?ooo`802NX:103oool500WZ2P030000003oool0oooo00X0oooo00<02NX:000000000000
3`3oool00`000000oooo0?ooo`0i0?ooo`00KP3oool200WZ2PD0oooo0P09jPX30?ooo`L02NX:00<0
oooo0000003oool0203oool300WZ2Q<0oooo00<000000?ooo`3oool0>03oool006/0oooo0`09jPX4
0?ooo`<02NX:0`3oool600WZ2P@0oooo00<000000?ooo`3oool0103oool300WZ2QH0oooo00<00000
0?ooo`3oool0>03oool006T0oooo0P09jPX50?ooo`802NX:0`3oool600WZ2PL0oooo00@000000?oo
o`3oool0oooo0`09jPXJ0?ooo`030000003oool0oooo03L0oooo001W0?ooo`802NX:1@3oool200WZ
2P<0oooo1P09jPX90?ooo`0400000009jPX02NX:00WZ2Qh0oooo00<000000?ooo`3oool0=P3oool0
06D0oooo0P09jPX40?ooo`<02NX:0P3oool600WZ2PX0oooo0P09jPX00`000000oooo0?ooo`0;0?oo
o`802NX:0P00000@0?ooo`030000003oool0oooo03H0oooo001S0?ooo`802NX:103oool200WZ2P<0
oooo1P09jPX90?ooo`<02NX:0P3oool00`000000oooo0?ooo`080?ooo`<02NX:0P3oool200000140
oooo00<000000?ooo`3oool0=@3oool00640oooo0P09jPX40?ooo`802NX:0P3oool600WZ2PT0oooo
0`09jPX50?ooo`030000003oool0oooo00@0oooo1009jPXI0?ooo`030000003oool0oooo03@0oooo
001O0?ooo`802NX:0`3oool300WZ2P80oooo1@09jPX90?ooo`<02NX:203oool010000000oooo0?oo
o`3oool300WZ2Qd0oooo00<000000?ooo`3oool0=03oool005d0oooo0P09jPX30?ooo`802NX:0P3o
ool600WZ2PP0oooo0`09jPX;0?ooo`0400000009jPX02NX:00WZ2R40oooo00<000000?ooo`3oool0
<`3oool005/0oooo0P09jPX30?ooo`802NX:0P3oool500WZ2PP0oooo0`09jPX:0?ooo`@02NX:00<0
00000?ooo`3oool08`3oool2000003<0oooo001H0?ooo`<02NX:0P3oool300WZ2P030?ooo`09jPX0
2NX:00@02NX:1`3oool300WZ2PX0oooo0`09jPX40?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0<P3oool005H0oooo0P09jPX30?ooo`802NX:0P3oool500WZ2PL0oooo0`09jPX90?oo
o`@02NX:1`3oool00`000000oooo0?ooo`0S0?ooo`800000<`3oool005@0oooo0P09jPX30?ooo`80
2NX:00<0oooo00WZ2P09jPX00`09jPX70?ooo`<02NX:2@3oool300WZ2P/0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0000000b0?ooo`00DP3oool200WZ2P<0oooo0P09jPX00`3oool02NX:
00WZ2P0300WZ2PH0oooo0`09jPX80?ooo`@02NX:3P3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool000000380oooo001@0?ooo`802NX:0P3oool300WZ2P030?ooo`09jPX02NX:00802NX:1P3o
ool300WZ2PP0oooo0`09jPXB0?ooo`030000003oool0oooo02<0oooo00@000000?ooo`3oool00000
<@3oool004h0oooo0P09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX00`09jPX50?ooo`<02NX:1`3o
ool400WZ2QD0oooo00<000000?ooo`3oool08`3oool01@000000oooo0?ooo`3oool000000300oooo
001<0?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX02NX:00802NX:1@3oool300WZ2PH0oooo1009
jPXI0?ooo`030000003oool0oooo02@0oooo00@000000?ooo`3oool00000<03oool004X0oooo0P09
jPX00`3oool02NX:00WZ2P0500WZ2PD0oooo0`09jPX60?ooo`<02NX:7@3oool00`000000oooo0?oo
o`0T0?ooo`050000003oool0oooo0?ooo`000000;`3oool004P0oooo0P09jPX0103oool02NX:00WZ
2P3oool400WZ2P@0oooo0`09jPX50?ooo`@02NX:803oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0;03oool004H0oooo0P09jPX00`3oool02NX:00WZ
2P0400WZ2P@0oooo0`09jPX50?ooo`<02NX:903oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0;03oool004<0oooo2P09jPX30?ooo`<02NX:103oool4
00WZ2RL0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02/0oooo00110?ooo`802NX:00<0oooo00WZ2P09jPX01009jPX30?ooo`<02NX:103oool300WZ
2R/0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02X0oooo000o0?ooo`802NX:00<0oooo00WZ2P09jPX00`09jPX30?ooo`<02NX:0`3oool400WZ2Rh0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02X0
oooo000m0?ooo`P02NX:0P3oool300WZ2P80oooo1009jPXb0?ooo`8000009@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo02T0oooo000k0?ooo`L02NX:0P3oool300WZ2P80oooo0`09
jPXf0?ooo`030000003oool000000200oooo0P0000020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0:03oool003T0oooo1`09jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:>@3o
ool010000000oooo0?ooo`00000N0?ooo`0300WZ2P00000000000080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0X0?ooo`00=`3oool600WZ2P050?ooo`09jPX02NX:00WZ2P3oool0
0`09jPXm0?ooo`040000003oool0oooo000001`0oooo0P09jPX50?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool09`3oool003D0oooo1@09jPX00`3oool02NX:00WZ2P0500WZ2T00oooo
00D000000?ooo`3oool0oooo0000000H0?ooo`<02NX:1@3oool2000000040?ooo`00000000000000
00L0oooo00<000000?ooo`3oool09P3oool003<0oooo2`09jPY40?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool04`3oool200WZ2PP0oooo0P0000001009jPX000000000000000070?oo
o`030000003oool0oooo02H0oooo000`0?ooo`/02NX:A`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0100oooo0P09jPX70?ooo`<02NX:0`3oool2000000T0oooo00<000000?ooo`3o
ool09@3oool002h0oooo2@09jPY;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3@3oool300WZ2PL0oooo0`09jPX20?ooo`802NX:0`00000:0?ooo`030000003oool0oooo02@0oooo
000/0?ooo`L02NX:C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo0P09
jPX70?ooo`<02NX:0P3oool300WZ2P80oooo0P00000;0?ooo`030000003oool0oooo02@0oooo000Z
0?ooo`H02NX:DP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P09jPX6
0?ooo`<02NX:0P3oool300WZ2P80oooo0`09jPX00`3oool000000?ooo`0;0?ooo`030000003oool0
oooo02<0oooo000X0?ooo`@02NX:EP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00<0oooo0`09jPX60?ooo`<02NX:0P3oool200WZ2P80oooo0`09jPX40?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool08P3oool002L0oooo0P09jPYI0?ooo`030000003oool0oooo00H0
oooo0P0000020?ooo`802NX:1P3oool300WZ2P80oooo0`09jPX0103oool02NX:00WZ2P09jPX70?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool08@3oool00880oooo00<000000?ooo`3o
ool01P3oool2000000802NX:1P3oool300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX:0?oo
o`<00000303oool00`000000oooo0?ooo`0Q0?ooo`00PP3oool00`000000oooo0?ooo`030?ooo`D0
2NX:00<000000?ooo`3oool00P3oool300WZ2P80oooo0P09jPX0103oool02NX:00WZ2P09jPX<0?oo
o`0400WZ2P0000000000000000d0oooo00<000000?ooo`3oool0803oool00880oooo00@000000?oo
o`3oool0oooo1009jPX40?ooo`0300000009jPX02NX:00802NX:0P00000500WZ2P`0oooo0`09jPX0
0`3oool000000?ooo`0?0?ooo`030000003oool0oooo01l0oooo00220?ooo`030000003oool02NX:
00<02NX:1@3oool00`09jPX000000000000300WZ2P8000000P09jPX<0?ooo`<02NX:103oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo01l0oooo00210?ooo`0300WZ2P0000002NX:0080
2NX:103oool400WZ2P8000000P09jPX20000000300WZ2P3oool0oooo00P0oooo1009jPX70?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool07P3oool007l0oooo0`09jPX00`000000oooo
0?ooo`030?ooo`P02NX:00@0000000WZ2P0000000000203oool300WZ2P/0oooo00@000000?ooo`00
000000003`3oool00`000000oooo0?ooo`0M0?ooo`00O@3oool400WZ2P040?ooo`000000oooo0?oo
o`X02NX:00<0oooo0000000000001P3oool400WZ2Ph0oooo00@0000000WZ2P00000000003`3oool0
0`000000oooo0?ooo`0M0?ooo`00NP3oool500WZ2P<0oooo00<0000000WZ2P09jPX01`09jPX0103o
ool02NX:00WZ2P09jPX2000000<0oooo0`09jPX>0?ooo`@02NX:00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0L0?ooo`00N03oool400WZ2P@0oooo0P09jPX00`0000002NX:00WZ2P0400WZ
2P040?ooo`09jPX02NX:00WZ2PD0oooo00<0000000WZ2P09jPX03@3oool400WZ2PD0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0K0?ooo`00MP3oool400WZ2P<0oooo1@09jPX01@00
00002NX:00WZ2P09jPX0oooo00<02NX:103oool400WZ2P030?ooo`000000oooo00T0oooo1009jPX9
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06`3oool007<0oooo1@09jPX30?oo
o`L02NX:00<000000?ooo`09jPX00P09jPX40?ooo`<02NX:1P3oool00`000000oooo0?ooo`030?oo
o`@02NX:3@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01X0oooo001a0?ooo`@0
2NX:0`3oool:00WZ2P0300000009jPX0oooo00<0oooo0`09jPX70?ooo`<0000000<0oooo00WZ2P09
jPX00P09jPXA0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06@3oool006l0oooo
1009jPX30?ooo`/02NX:00<0oooo0000003oool01009jPX80?ooo`802NX:0P0000000`09jPX00000
0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06@3oool006`0oooo1@09
jPX20?ooo`P02NX:00<0oooo00WZ2P09jPX00`3oool00`09jPX0000000WZ2P090?ooo`@02NX:1@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0603o
ool006X0oooo1@09jPX00`3oool02NX:00WZ2P0600WZ2P040?ooo`09jPX02NX:00WZ2P80oooo0`09
jPX00`3oool000000?ooo`050?ooo`@02NX:2P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool05`3oool006L0oooo1@09jPX20?ooo`L02NX:00D0oooo
00WZ2P09jPX02NX:0?ooo`0400WZ2P@0oooo00<000000?ooo`3oool01@09jPX=0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`00I@3oool2
00WZ2P040?ooo`09jPX02NX:0?ooo`/02NX:00@0oooo00WZ2P09jPX02NX:1`3oool00`09jPX00000
00WZ2P0200WZ2Q80oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01H0oooo001S0?ooo`D02NX:00<0oooo00WZ2P09jPX03009jPX60?ooo`D02NX:00<0
00000?ooo`3oool03P3oool2000000@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01D0oooo001P0?ooo`D02NX:00<0oooo00WZ2P09jPX02`09jPX6
0?ooo`H02NX:0`3oool00`000000oooo0?ooo`0=0?ooo`0300WZ2P000000000000@0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01D0oooo001N0?oo
o`802NX:00@0oooo00WZ2P09jPX0oooo1P09jPX00`3oool02NX:00WZ2P0300WZ2PD0oooo1`09jPX6
0?ooo`030000003oool0oooo00T0oooo1009jPX80?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0D0?ooo`00G03ooolA00WZ2P@0oooo2009jPX90?oo
o`030000003oool0oooo00@0oooo1@09jPX=0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0C0?ooo`00F@3oool@00WZ2P@0oooo1009jPX0103oool0
2NX:00WZ2P09jPX=0?ooo`030000003oool0oooo00@02NX:4`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool04`3oool005L0oooo0P09jPX00`3oool0
2NX:00WZ2P0:00WZ2P<0oooo1009jPX00`3oool02NX:00WZ2P0200WZ2Pl0oooo00@02NX:00000009
jPX02NX:5`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool04P3oool005D0oooo3P09jPX20?ooo`@02NX:0P3oool300WZ2Pl0oooo1009jPX00`3oool0
00000?ooo`0I0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`09jPX0
00000000000:0?ooo`030000003oool0oooo0140oooo001B0?ooo`d02NX:0P3oool400WZ2P<0oooo
0`09jPX>0?ooo`@02NX:1@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool300WZ2P030?ooo`000000000000<0oooo0P0000050?ooo`030000
003oool0oooo0140oooo001@0?ooo`802NX:00<0oooo00WZ2P09jPX03009jPX30?ooo`@02NX:303o
ool500WZ2PT0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo0P09jPX50?ooo`80000000@0oooo00WZ2P00000000001@3oool00`000000oooo
0?ooo`0A0?ooo`00CP3oool>00WZ2PD0oooo0`09jPX<0?ooo`@02NX:3P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool300WZ2PL0oooo0P00
00000`09jPX00000000000060?ooo`030000003oool0oooo0140oooo001;0?ooo`d02NX:1@3oool4
00WZ2P/0oooo1009jPXB0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`802NX:1`3oool300WZ2P<0oooo0P0000060?ooo`030000003oool0
oooo0140oooo00190?ooo`802NX:00<0oooo00WZ2P09jPX01P09jPX60?ooo`<02NX:2`3oool400WZ
2QH0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00<02NX:1P3oool300WZ2P<0oooo0P09jPX2000000L0oooo00<000000?ooo`3oool04@3oool004L0
oooo2P09jPX60?ooo`<02NX:2@3oool500WZ2QX0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`070?ooo`0300000009jPX02NX:00H0oooo0`09jPX30?ooo`<02NX:00@0oooo00WZ2P00
00000000203oool00`000000oooo0?ooo`0@0?ooo`00A03oool:00WZ2PD0oooo1009jPX80?ooo`@0
2NX:7`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo0P09jPX00`000000
oooo0?ooo`040?ooo`<02NX:0P3oool300WZ2P040?ooo`09jPX02NX:00WZ2P/0oooo00<000000?oo
o`3oool0403oool00480oooo0P09jPX00`3oool02NX:00WZ2P0400WZ2PD0oooo0`09jPX80?ooo`@0
2NX:8`3oool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo0?ooo`802NX:0P3oool01000
0000oooo0?ooo`3oool300WZ2P80oooo0`09jPX0103oool02NX:00WZ2P09jPX>0?ooo`030000003o
ool0oooo0100oooo000o0?ooo`T02NX:103oool400WZ2PL0oooo1009jPXW0?ooo`030000003oool0
oooo01l0oooo00@0000000WZ2P09jPX02NX:103oool0100000002NX:00WZ2P09jPX20?ooo`<02NX:
00@0oooo00WZ2P09jPX02NX:4@3oool00`000000oooo0?ooo`0@0?ooo`00?@3oool200WZ2P030?oo
o`09jPX02NX:00@02NX:0`3oool300WZ2PL0oooo1009jPX/0?ooo`030000003oool0oooo01d0oooo
0P09jPX00`000000oooo0?ooo`020?ooo`802NX:00<000000?ooo`3oool00`09jPX0103oool02NX:
00WZ2P09jPX:0?ooo`802NX:0P0000060?ooo`030000003oool0oooo0100oooo000k0?ooo`P02NX:
0`3oool300WZ2PD0oooo1@09jPX`0?ooo`030000003oool0oooo01X0oooo0`09jPX30?ooo`040000
0009jPX02NX:00WZ2P80oooo00@0000000WZ2P09jPX0oooo0`09jPX:0?ooo`<02NX:0P3oool20000
00H0oooo00<000000?ooo`3oool0403oool003P0oooo2009jPX20?ooo`@02NX:103oool400WZ2SD0
oooo00<000000?ooo`3oool0603oool200WZ2PD0oooo0P09jPX00`000000oooo00WZ2P0200WZ2P04
00000009jPX02NX:00WZ2PT0oooo1009jPX=0?ooo`030000003oool0oooo0100oooo000f0?ooo`L0
2NX:0P3oool300WZ2P@0oooo1009jPXi0?ooo`030000003oool0oooo01D0oooo0`09jPX40?ooo`<0
2NX:00<0oooo00WZ2P09jPX00P00000200WZ2P030000003oool0oooo00H0oooo1009jPXA0?ooo`03
0000003oool0oooo0100oooo000d0?ooo`H02NX:00<0oooo00WZ2P09jPX00P09jPX30?ooo`@02NX:
?@3oool00`000000oooo0?ooo`0C0?ooo`802NX:103oool300WZ2P060?ooo`09jPX02NX:00WZ2P3o
ool02NX:0P0000030?ooo`030000003oool0oooo0080oooo0`09jPX>0?ooo`8000001@3oool00`00
0000oooo0?ooo`0@0?ooo`00<@3oool600WZ2P040?ooo`09jPX02NX:00WZ2P80oooo1@09jPY10?oo
o`030000003oool0oooo0100oooo0`09jPX30?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`03
00WZ2P80oooo00@000000?ooo`3oool0oooo0`00000200WZ2Pl0oooo0P09jPX2000000D0oooo00<0
00000?ooo`3oool0403oool002l0oooo1@09jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:AP3o
ool00`000000oooo0?ooo`0>0?ooo`802NX:103oool:00WZ2PH0oooo0P0000001009jPX000000000
0000000<0?ooo`D02NX:2P3oool00`000000oooo0?ooo`0?0?ooo`00;@3oool<00WZ2TX0oooo00<0
00000?ooo`3oool02`3oool300WZ2P<0oooo2`09jPX50?ooo`<02NX:0P0000000`3oool000000000
00090?ooo`@02NX:3`3oool00`000000oooo0?ooo`0?0?ooo`00:P3oool;00WZ2Th0oooo00<00000
0?ooo`3oool02@3oool200WZ2P<0oooo2`09jPX40?ooo`H02NX:00<0oooo00WZ2P09jPX00`000004
0?ooo`D02NX:4`3oool00`000000oooo0?ooo`0?0?ooo`00:03oool900WZ2U80oooo00<000000?oo
o`3oool01`3oool200WZ2P80oooo2`09jPX40?ooo`H02NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09
jPX2000000030?ooo`09jPX02NX:00802NX:603oool00`000000oooo0?ooo`0?0?ooo`009P3oool7
00WZ2UH0oooo00<000000?ooo`3oool0103oool300WZ2P80oooo2`09jPX20?ooo`L02NX:00D0oooo
00WZ2P09jPX02NX:0?ooo`0400WZ2P80000000<02NX:0?ooo`3oool06P3oool00`000000oooo0?oo
o`0?0?ooo`008`3oool500WZ2U/0oooo00<000000?ooo`3oool00P3oool200WZ2P80oooo2009jPX0
0`3oool02NX:00WZ2P020?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09
jPX02NX:00<02NX:0`3oool2000001`0oooo00<000000?ooo`3oool03`3oool00280oooo0P09jPYO
0?ooo`030000003oool02NX:00802NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:00WZ2P05
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0200WZ2PL0oooo00<0
00000?ooo`0000006`3oool00`000000oooo0?ooo`0?0?ooo`00P`3oool00`0000002NX:0?ooo`08
00WZ2P030?ooo`09jPX02NX:00@02NX:0P3oool300WZ2P030?ooo`09jPX02NX:00D02NX:2`3oool0
0`000000oooo0000000K0?ooo`030000003oool0oooo00l0oooo00200?ooo`<02NX:00<0000000WZ
2P09jPX01@09jPX20?ooo`@02NX:0`3oool300WZ2P030?ooo`09jPX02NX:00D02NX:3P3oool40000
01X0oooo00<000000?ooo`3oool03`3oool007h0oooo0P09jPX0103oool02NX:00WZ2P00000400WZ
2P80oooo1009jPX30?ooo`/02NX:403oool01P09jPX00000000000000000oooo000001T0oooo00<0
00000?ooo`3oool03`3oool007/0oooo2009jPX0100000002NX:0?ooo`3oool300WZ2P@0oooo1`09
jPX0103oool02NX:00WZ2P09jPX?0?ooo`@02NX:00<0oooo0000003oool00`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00h0oooo001i0?ooo`T02NX:00<0oooo00000009jPX00`09
jPX30?ooo`/02NX:3P3oool400WZ2PD0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00h0oooo001f0?ooo`P02NX:0P3oool300WZ2P0400000009jPX0
oooo0?ooo`/02NX:3`3oool300WZ2PT0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00h0oooo001d0?ooo`L02NX:00<0oooo00WZ2P09jPX01@09jPX0
0`0000002NX:00WZ2P0900WZ2Ph0oooo1009jPX<0?ooo`040000003oool00000000000<0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`00L@3oool;00WZ2P030?ooo`09jPX0
2NX:00<02NX:00<0oooo00000009jPX01`09jPX00`3oool000000000000:0?ooo`@02NX:403oool0
100000002NX:0000000000030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03P3o
ool006l0oooo2@09jPX00`3oool02NX:00WZ2P0300WZ2P80oooo0`09jPX00`0000002NX:00WZ2P03
00WZ2P<0oooo00<02NX:0000000000001P3oool2000000802NX:3`3oool500WZ2P030000003oool0
oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0>0?ooo`00K03oool?00WZ
2P80oooo1P09jPX00`0000002NX:00WZ2P030?ooo`<02NX:1@3oool400WZ2P800000303oool500WZ
2PD0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00h0oooo001Z0?ooo`h02NX:0P3oool900WZ2P030000003oool0oooo00<02NX:1@3oool600WZ2P/0
oooo1009jPX;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0>0?ooo`00I`3oool:00WZ2P80oooo0P09jPX30?ooo`P02NX:0`3oool00`0000002NX:
00WZ2P040?ooo`D02NX:0P0000020?ooo`8000001@3oool500WZ2Pl0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00h0oooo001U0?ooo`L02NX:103o
ool300WZ2P80oooo2009jPX40?ooo`<02NX:0P3oool400WZ2P030?ooo`09jPX02NX:00802NX:0P00
0000103oool02NX:00000000000500WZ2Q@0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00h0oooo001R0?ooo`H02NX:1P3oool200WZ2P80oooo2009
jPX50?ooo`802NX:00<0oooo00WZ2P0000000P09jPX20?ooo`@02NX:0`3oool600WZ2QT0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo001Q
0?ooo`802NX:203oool300WZ2P030?ooo`09jPX02NX:00D02NX:1P3oool600WZ2P030?ooo`000000
oooo00@02NX:0`3oool400WZ2P040?ooo`09jPX00000000001X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo001Y0?ooo`802NX:00<0oooo
00WZ2P09jPX01@09jPX60?ooo`D02NX:103oool400WZ2P030?ooo`09jPX02NX:00<02NX:0P3oool3
00WZ2P030?ooo`000000000001X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00d0oooo001V0?ooo`X02NX:1`3oool300WZ2PH0oooo0`09jPX00`00
00002NX:00WZ2P0300WZ2P80oooo0`09jPXP0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`00H`3oool300WZ2P030?ooo`09jPX02NX:00@0
2NX:1P3oool400WZ2PH0oooo1@09jPX0103oool02NX:00WZ2P09jPX20?ooo`<02NX:8`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00640
oooo0P09jPX00`3oool02NX:00WZ2P0400WZ2PD0oooo1@09jPX50?ooo`D02NX:0P3oool300WZ2P03
0000003oool02NX:00802NX:9P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool005h0oooo2@09jPX40?ooo`L02NX:0P3oool600WZ2P<0oooo
0`09jPX00`3oool02NX:00WZ2P0200WZ2RT0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00d0oooo001L0?ooo`P02NX:0`3oool400WZ2P050?ooo`09
jPX02NX:00WZ2P3oool02009jPX20?ooo`<02NX:00@0oooo00WZ2P09jPX02NX:0P3oool00`000000
oooo0?ooo`0<0?ooo`802NX:0P00000H0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0=0?ooo`00F@3oool800WZ2P80oooo1009jPX30?ooo`H02NX:
00<0oooo00WZ2P09jPX00P09jPX20?ooo`<02NX:00@0oooo00WZ2P09jPX02NX:1@3oool00`000000
oooo0?ooo`080?ooo`@02NX:0P3oool2000001P0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo001F0?ooo`L02NX:0`3oool300WZ2P<0oooo
1@09jPX30?ooo`@02NX:0P3oool300WZ2P040?ooo`09jPX02NX:00WZ2PP0oooo00<000000?ooo`3o
ool0103oool400WZ2R00oooo00<000000?ooo`3oool03`3oool2000000/0oooo00<000000?ooo`3o
ool03@3oool005@0oooo1P09jPX20?ooo`@02NX:0P3oool500WZ2PD0oooo0`09jPX20?ooo`<02NX:
00@0oooo00WZ2P09jPX02NX:2`3oool010000000oooo0?ooo`3oool300WZ2R@0oooo00<000000?oo
o`3oool03`3oool2000000<0oooo00<02NX:0000000000001P3oool00`000000oooo0?ooo`0<0?oo
o`00D@3oool600WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01P09jPX40?ooo`<0
2NX:0P3oool300WZ2P040?ooo`09jPX02NX:00WZ2Ph0oooo1009jPXW0?ooo`030000003oool0oooo
00`0oooo0`09jPX00`3oool0000000WZ2P0200WZ2P030?ooo`000000000000H0oooo00<000000?oo
o`3oool0303oool004l0oooo3P09jPX20?ooo`<02NX:103oool300WZ2P80oooo1`09jPX=0?ooo`@0
2NX:00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`<02NX:0P3oool300WZ2P80
000000<0oooo0000000000001`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool<00WZ2PD0oooo
0P09jPX40?ooo`<02NX:0P3oool600WZ2Pd0oooo1009jPX40?ooo`030000003oool0oooo00h0oooo
00<02NX:0000000000005`3oool00`000000oooo0?ooo`060?ooo`<02NX:0P3oool600WZ2P800000
00<02NX:0000000000001`3oool00`000000oooo0?ooo`0<0?ooo`00B@3oool:00WZ2PL0oooo0`09
jPX30?ooo`<02NX:0P3oool600WZ2P`0oooo1009jPX90?ooo`030000003oool0oooo00P0oooo1@09
jPX00`3oool000000000000G0?ooo`030000003oool0oooo00@0oooo0P09jPX20?ooo`H02NX:0P3o
ool300WZ2P800000203oool00`000000oooo0?ooo`0<0?ooo`00A`3oool800WZ2PT0oooo0P09jPX3
0?ooo`@02NX:00<0oooo00WZ2P09jPX01009jPX;0?ooo`@02NX:3P3oool00`000000oooo0?ooo`02
0?ooo`D02NX:7`3oool010000000oooo0?ooo`3oool300WZ2P030?ooo`09jPX02NX:00@02NX:0P3o
ool300WZ2P80oooo00<02NX:000000000000203oool00`000000oooo0?ooo`0<0?ooo`00A03oool6
00WZ2P/0oooo0`09jPX20?ooo`@02NX:00<0oooo00WZ2P09jPX01009jPX;0?ooo`<02NX:4P3oool5
00WZ2R@0oooo00D0000000WZ2P09jPX02NX:0?ooo`0600WZ2P80oooo0`09jPX20?ooo`<02NX:0P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00130?ooo`802NX:3@3oool3
00WZ2P<0oooo0`09jPX00`3oool02NX:00WZ2P0400WZ2PX0oooo1009jPX@0?ooo`D02NX:0P3oool0
0`000000oooo0?ooo`0R0?ooo`<02NX:00<0000000WZ2P09jPX01009jPX20?ooo`<02NX:0P3oool3
00WZ2PH0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`00D03oool200WZ
2P<0oooo2@09jPX:0?ooo`@02NX:3`3oool500WZ2PP0oooo00<000000?ooo`3oool07P3oool300WZ
2P040?ooo`09jPX02NX:000000<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P02
00WZ2PX0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`00C@3oool300WZ
2P80oooo2@09jPX90?ooo`@02NX:3`3oool400WZ2Ph0oooo00<000000?ooo`3oool06`3oool200WZ
2P030?ooo`09jPX02NX:00<02NX:00<000000?ooo`09jPX00P09jPX20?ooo`<02NX:3@3oool30000
00D0oooo00<000000?ooo`3oool0303oool004/0oooo0P09jPX20?ooo`T02NX:203oool400WZ2Ph0
oooo1@09jPXC0?ooo`030000003oool0oooo01L0oooo2@09jPX01@3oool02NX:00000009jPX0oooo
00@02NX:3P3oool200WZ2P80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0;0?oo
o`00B03oool300WZ2P030?ooo`09jPX02NX:00L02NX:1`3oool400WZ2Pd0oooo1@09jPXI0?ooo`03
0000003oool0oooo01<0oooo2@09jPX01P3oool02NX:00WZ2P09jPX0oooo000000802NX:3P3oool4
00WZ2PD0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`00A@3oool300WZ
2P030?ooo`09jPX02NX:00L02NX:1P3oool400WZ2P`0oooo1@09jPXO0?ooo`030000003oool0oooo
00l0oooo0`09jPX00`3oool02NX:00WZ2P0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX0
0`000000oooo0?ooo`0:0?ooo`@02NX:2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00/0oooo00130?ooo`802NX:00<0oooo00WZ2P09jPX01P09jPX70?ooo`<02NX:2`3oool500WZ
2R@0oooo00<000000?ooo`3oool03@3oool200WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ
2P09jPX01@09jPX30?ooo`030000003oool0oooo00H0oooo1009jPX?0?ooo`050000003oool0oooo
0?ooo`0000003@3oool00400oooo0`09jPX00`3oool02NX:00WZ2P0500WZ2PH0oooo1009jPX90?oo
o`D02NX::P3oool00`000000oooo0?ooo`090?ooo`l02NX:1`3oool00`000000oooo0?ooo`020?oo
o`@02NX:3`3oool2000000<0oooo00@000000?ooo`3oool000003@3oool003h0oooo0P09jPX00`3o
ool02NX:00WZ2P0500WZ2PD0oooo1009jPX80?ooo`D02NX:<03oool00`000000oooo0?ooo`050?oo
o`/02NX:00@0oooo00WZ2P09jPX02NX:2P3oool00`0000002NX:00WZ2P0200WZ2Q40oooo0P09jPX2
000000<0oooo00@000000?ooo`3oool000003@3oool003/0oooo2P09jPX40?ooo`@02NX:203oool4
00WZ2SH0oooo00@000000?ooo`3oool0oooo3`09jPX90?ooo`@02NX:00<000000?ooo`3oool03P3o
ool500WZ2PP0oooo00<000000?ooo`0000003@3oool003P0oooo2P09jPX30?ooo`@02NX:1`3oool5
00WZ2S/0oooo00<0000000WZ2P09jPX02`09jPX90?ooo`@02NX:103oool00`000000oooo0?ooo`09
0?ooo`D02NX:3P3oool2000000d0oooo000f0?ooo`P02NX:0`3oool400WZ2PH0oooo1@09jPXn0?oo
o`<02NX:00<0000000WZ2P09jPX01`09jPX80?ooo`@02NX:203oool00`000000oooo0?ooo`040?oo
o`D02NX:503oool00`000000oooo0?ooo`0;0?ooo`00<`3oool800WZ2P<0oooo0`09jPX50?ooo`D0
2NX:@03oool700WZ2P0300000009jPX02NX:00<02NX:1`3oool400WZ2PP0oooo0P0000020?ooo`03
0000003oool02NX:00@02NX:6@3oool2000000`0oooo000a0?ooo`L02NX:0P3oool400WZ2P<0oooo
1@09jPY20?ooo`/02NX:00<000000?ooo`3oool01@3oool400WZ2P/0oooo00<02NX:000000000000
0`09jPX3000001d0oooo00<000000?ooo`3oool02P3oool002h0oooo1`09jPX00`3oool02NX:00WZ
2P0200WZ2P80oooo1@09jPY40?ooo``02NX:0`3oool00`000000oooo0?ooo`0400WZ2P/0oooo1@09
jPX20?ooo`<02NX:0`00000M0?ooo`030000003oool0oooo00X0oooo000[0?ooo`/02NX:0P3oool4
00WZ2TL0oooo2P09jPX60?ooo`802NX:00<0000000WZ2P3oool02@3oool600WZ2P<0oooo0`09jPX2
000000030?ooo`000000000001h0oooo00<000000?ooo`3oool02P3oool002T0oooo2@09jPX00`3o
ool02NX:00WZ2P0300WZ2TP0oooo2P09jPX50?ooo`@02NX:0`3oool00`000000oooo0?ooo`030?oo
o`P02NX:0`3oool300WZ2P80oooo00@02NX:0000000000002NX:0P00000N0?ooo`030000003oool0
oooo00X0oooo000V0?ooo`d02NX:BP3oool:00WZ2P@0oooo1009jPX70?ooo`0300000009jPX02NX:
00<02NX:0P3oool300WZ2P<0oooo0`09jPX20?ooo`H02NX:00<0oooo0000003oool07P3oool00`00
0000oooo0?ooo`0:0?ooo`00903oool:00WZ2T`0oooo2@09jPX40?ooo`@02NX:1P3oool600WZ2P04
0000003oool0oooo0?ooo`<02NX:0`3oool300WZ2P80oooo1P09jPX40?ooo`8000007P3oool00`00
0000oooo0?ooo`0:0?ooo`008@3oool800WZ2Tl0oooo2009jPX30?ooo`@02NX:1@3oool500WZ2PL0
oooo0`09jPX30?ooo`<02NX:0P3oool600WZ2PD0oooo0P09jPX2000001h0oooo00<000000?ooo`3o
ool02P3oool001h0oooo1P09jPYA0?ooo`P02NX:0P3oool400WZ2P@0oooo1@09jPX90?ooo`<02NX:
00<0oooo0000003oool00`09jPX00`3oool02NX:00WZ2P0400WZ2PH0oooo0`09jPX20?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool02P3oool001d0oooo0P09jPYC0?ooo`L02NX:0P3o
ool400WZ2P<0oooo1@09jPX;0?ooo`<02NX:0`3oool300WZ2P030?ooo`09jPX02NX:00@02NX:1@3o
ool400WZ2PD0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`00K`3oool<
00WZ2P80oooo1@09jPX>0?ooo`802NX:0`3oool300WZ2P030?ooo`09jPX02NX:00@02NX:103oool4
00WZ2PT0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`00K03oool:00WZ
2P030?ooo`09jPX02NX:00@02NX:403oool300WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P0300WZ
2P030?ooo`000000oooo0080oooo0`09jPX=0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool02P3oool006X0oooo3@09jPXC0?ooo`<02NX:0P3oool900WZ2P@0oooo1009jPX@0?ooo`<0
00007P3oool00`000000oooo0?ooo`090?ooo`00I`3oool;00WZ2QD0oooo0`09jPX00`3oool02NX:
00WZ2P0800WZ2P@0oooo0`09jPX20?ooo`030000003oool0oooo00X0oooo1@09jPX3000001h0oooo
00<000000?ooo`3oool02@3oool006@0oooo2@09jPXG0?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:
0?ooo`0500WZ2P@0oooo1009jPX60?ooo`030000003oool0oooo00D0oooo1009jPX50?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool00640oooo1`09jPXI0?ooo`<02NX:00D0
oooo00WZ2P09jPX02NX:0?ooo`0500WZ2P<0oooo1009jPX:0?ooo`040000003oool0oooo0?ooo`@0
2NX:2P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo001P0?ooo`<02NX:
6`3oool300WZ2P050?ooo`09jPX02NX:00WZ2P3oool01@09jPX30?ooo`<02NX:3@3oool500WZ2Ph0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`00N`3oool300WZ2P030?oo
o`09jPX02NX:00H02NX:0`3oool400WZ2P`0oooo1009jPX30?ooo`030000003oool0oooo00d0oooo
0`00000M0?ooo`030000003oool0oooo00T0oooo001h0?ooo`<02NX:00<0oooo00WZ2P09jPX01P09
jPX20?ooo`@02NX:2`3oool500WZ2PP0oooo00<000000?ooo`3oool02`3oool01009jPX000000000
0000000M0?ooo`030000003oool0oooo00T0oooo001e0?ooo`<02NX:00<0oooo00WZ2P09jPX01P09
jPX20?ooo`<02NX:2`3oool400WZ2Ph0oooo00<000000?ooo`3oool0103oool600WZ2P030?ooo`00
0000oooo01h0oooo00<000000?ooo`3oool02@3oool007<0oooo0P09jPX00`3oool02NX:00WZ2P05
00WZ2P80oooo1009jPX:0?ooo`@02NX:4`3oool00`0000002NX:00WZ2P0300WZ2PL0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`00L03oool:00WZ2P80oooo0`09jPX90?oo
o`D02NX:4P3oool600WZ2P030000003oool0oooo00T0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`090?ooo`00K@3oool:00WZ2P030?ooo`09jPX02NX:00802NX:203oool400WZ2Q40
oooo1P09jPX70?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`080?ooo`00JP3oool>00WZ2PP0oooo1009jPX?0?ooo`H02NX:3P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool006L0oooo2@09
jPX0103oool02NX:00WZ2P09jPX70?ooo`D02NX:3P3oool500WZ2QD0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00P0oooo001T0?ooo`d02NX:1P3o
ool400WZ2Pd0oooo1P09jPXJ0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`080?ooo`00H@3oool<00WZ2PD0oooo1@09jPX;0?ooo`H02NX:8@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool0
05h0oooo3009jPX40?ooo`@02NX:2P3oool600WZ2RP0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00P0oooo001K0?ooo`/02NX:103oool400WZ2PT0
oooo1@09jPX_0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`080?ooo`00F@3oool900WZ2P<0oooo1@09jPX70?ooo`H02NX:=@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0203oool005H0oooo2@09
jPX20?ooo`@02NX:1P3oool600WZ2S`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0E0?ooo`8000001P3oool00`000000oooo0?ooo`080?ooo`00D`3oool800WZ2P030?ooo`09jPX0
2NX:00<02NX:103oool600WZ2T<0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`802NX:0P00
00020?ooo`0300WZ2P000000000000H0oooo00<000000?ooo`3oool0203oool00500oooo1`09jPX0
0`3oool02NX:00WZ2P0200WZ2P@0oooo1@09jPY:0?ooo`040000003oool0oooo000000d0oooo0`09
jPX20?ooo`8000000P09jPX:0?ooo`030000003oool0oooo00L0oooo001=0?ooo`/02NX:0P3oool6
00WZ2U00oooo00<000000?ooo`0000002P3oool300WZ2P<0oooo0`09jPX0103oool0000000000009
jPX2000000L0oooo00<000000?ooo`3oool01`3oool004X0oooo4009jPYG0?ooo`8000001`3oool3
00WZ2P<0oooo0`09jPX20?ooo`802NX:0P0000000`3oool00000000000070?ooo`030000003oool0
oooo00L0oooo00170?ooo`d02NX:GP3oool00`000000oooo0?ooo`020?ooo`<02NX:0P3oool400WZ
2P030?ooo`09jPX02NX:00802NX:3P3oool00`000000oooo0?ooo`070?ooo`00A03oool:00WZ2V@0
oooo00<000000?ooo`09jPX00P09jPX20?ooo`<02NX:0P3oool400WZ2PD0oooo0P09jPX2000000P0
oooo00<000000?ooo`3oool01`3oool00440oooo2009jPYX0?ooo`802NX:00<000000?ooo`3oool0
0`09jPX00`3oool02NX:00WZ2P0200WZ2PD0oooo1009jPX20?ooo`800000203oool00`000000oooo
0?ooo`070?ooo`00@03oool300WZ2V/0oooo0`09jPX01P3oool02NX:00WZ2P0000002NX:0?ooo`@0
2NX:1@3oool300WZ2Q00oooo00<000000?ooo`3oool01`3oool00:/0oooo0`09jPX0103oool02NX:
00WZ2P09jPX20?ooo`0300WZ2P0000002NX:00D0oooo1009jPXC0?ooo`030000003oool0oooo00L0
oooo002X0?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P80oooo00<000000?ooo`09
jPX00`09jPXG0?ooo`030000003oool0oooo00L0oooo002U0?ooo`<02NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0300WZ2P@0oooo0`09jPX00`000000oooo0?ooo`0?0?ooo`0300WZ2P000000000000L0
oooo00<000000?ooo`3oool01`3oool00:40oooo3009jPX30?ooo`@02NX:103oool00`000000oooo
0?ooo`090?ooo`D02NX:00<0oooo000000000000203oool00`000000oooo0?ooo`060?ooo`00WP3o
ool300WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX30?ooo`<02NX:2@3oool00`000000oooo
0?ooo`030?ooo`D02NX:403oool00`000000oooo0?ooo`060?ooo`00V`3oool300WZ2P030?ooo`09
jPX02NX:00D02NX:0`3oool400WZ2Pd0oooo00<0000000WZ2P09jPX00P09jPXE0?ooo`030000003o
ool0oooo00H0oooo002H0?ooo`<02NX:00<0oooo00WZ2P09jPX01@09jPX20?ooo`@02NX:3@3oool5
00WZ2P030000003oool0oooo01H0oooo00<000000?ooo`3oool01P3oool009D0oooo2P09jPX20?oo
o`@02NX:303oool500WZ2PD0oooo00<000000?ooo`3oool03P3oool2000000H0oooo00<000000?oo
o`3oool01P3oool00980oooo2P09jPX00`3oool02NX:00WZ2P0200WZ2P/0oooo1@09jPX;0?ooo`03
0000003oool0oooo00X0oooo0`09jPX2000000H0oooo00<000000?ooo`3oool01P3oool008l0oooo
2@09jPX20?ooo`<02NX:2`3oool400WZ2Q40oooo00<000000?ooo`3oool00P3oool700WZ2P/0oooo
00<000000?ooo`3oool01P3oool008`0oooo2@09jPX00`3oool02NX:00WZ2P0200WZ2PT0oooo1@09
jPXD0?ooo`802NX:00@0000000WZ2P09jPX02NX:4P3oool00`000000oooo0?ooo`060?ooo`00R@3o
ool800WZ2P030?ooo`09jPX02NX:00802NX:203oool500WZ2Q<0oooo1P09jPX30?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool01P3oool008H0oooo3009jPX80?ooo`@02NX:4@3oool7
00WZ2PX0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`00P`3oool700WZ
2P040?ooo`09jPX02NX:00WZ2PL0oooo1@09jPX?0?ooo`H02NX:4P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00D0oooo001o0?ooo``02NX:1@3oool500WZ2Pd0oooo1`09jPXI0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool007`0oooo2`09jPX50?ooo`@0
2NX:303oool600WZ2R40oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`00
N@3oool:00WZ2P@0oooo1@09jPX90?ooo`L02NX::03oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00D0oooo001f0?ooo`T02NX:0`3oool500WZ2PP0oooo1P09jPX_0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01@3oool007<0oooo2009jPX30?ooo`@02NX:1`3oool6
00WZ2SH0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`00L03oool800WZ
2P030?ooo`09jPX02NX:00<02NX:103oool700WZ2Sd0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`050?ooo`00K@3oool<00WZ2P<0oooo1P09jPY50?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool01@3oool006X0oooo2P09jPX00`3oool02NX:00WZ2P0500WZ2T`0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`00I`3oool>00WZ2U@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`00I03oool;00WZ2U/0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`00H@3oool800WZ2V80oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`040?ooo`00G`3oool300WZ2VX0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`040?ooo`00c@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo003>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00<h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`00c`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo003@0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00=40oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`00dP3oool01@000000oooo0?ooo`3oool0000000H0oooo003C0?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00=@0oooo00@000000?ooo`3oool000001@3oool00=D0oooo00<0
00000?ooo`0000001@3oool00=H0oooo0P0000050?ooo`00e`3oool00`000000oooo0?ooo`030?oo
o`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M
0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo
003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0
oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00001\
\>"],
  ImageRangeCache->{{{0, 220.938}, {286.938, 0}} -> {0.108048, -0.000452797, \
0.00330557, 0.00330557}}]
}, Open  ]],

Cell[TextData[{
  "Next we examine ",
  StyleBox["FindFocalSurface", "Input"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["?FindFocalSurface", "Input"],

Cell[BoxData[
    \("FindFocalSurface[opticalsystem] determines the image surface of best \
focus in three-dimensional space for an array of focus points that result \
from the DistortionGrid light source function.\n \nInternally, \
FindFocalSurface calls FindFocusFast to determine the foci positions. If the \
SingleRay -> True option setting is used, then FindFocalSurface returns a \
single ray for each foci position. Otherwise, FindFocalSurface returns a \
cluster of rays for each foci position according to the input source \
function.\n \nSee also DistortionGrid."\)], "Print",
  CellTags->"Info3257567535-1728977"]
}, Open  ]],

Cell["Consider the following optical system:", "Text"],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[{
\tDistortionGrid[PointOfRays[0.25], {10, 10}, {7, 7}],
\tMove[PlanoConvexLens[80, 50,10], 200],
\tBoundary[350, GraphicDesign -> Off]
}, PlotType -> TopView];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14286 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00272109 0.0714286 0.00272109 [
[ 0 0 0 0 ]
[ 1 .14286 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.59082 .0034 m
.59524 .0034 L
.59524 .02608 L
.57753 .02608 L
.59082 .0034 L
F
.57753 .02608 m
.59524 .02608 L
.59524 .04875 L
.57033 .04875 L
.57753 .02608 L
F
.57033 .04875 m
.59524 .04875 L
.59524 .07143 L
.56803 .07143 L
.57033 .04875 L
F
.56803 .07143 m
.59524 .07143 L
.59524 .0941 L
.57033 .0941 L
.56803 .07143 L
F
.57033 .0941 m
.59524 .0941 L
.59524 .11678 L
.57753 .11678 L
.57033 .0941 L
F
.57753 .11678 m
.59524 .11678 L
.59524 .13946 L
.59082 .13946 L
.57753 .11678 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.59082 .0034 m
.57753 .02608 L
.57033 .04875 L
.56803 .07143 L
.57033 .0941 L
.57753 .11678 L
.59082 .13946 L
.59524 .13946 L
.59524 .11678 L
.59524 .0941 L
.59524 .07143 L
.59524 .04875 L
.59524 .02608 L
.59524 .0034 L
.59082 .0034 L
s
.5 g
.59082 .07143 m
.59524 .07143 L
.59524 .07143 L
.57753 .07143 L
.59082 .07143 L
F
.57753 .07143 m
.59524 .07143 L
.59524 .07143 L
.57033 .07143 L
.57753 .07143 L
F
.57033 .07143 m
.59524 .07143 L
.59524 .07143 L
.56803 .07143 L
.57033 .07143 L
F
.56803 .07143 m
.59524 .07143 L
.59524 .07143 L
.57033 .07143 L
.56803 .07143 L
F
.57033 .07143 m
.59524 .07143 L
.59524 .07143 L
.57753 .07143 L
.57033 .07143 L
F
.57753 .07143 m
.59524 .07143 L
.59524 .07143 L
.59082 .07143 L
.57753 .07143 L
F
0 g
.59082 .07143 m
.57753 .07143 L
.57033 .07143 L
.56803 .07143 L
.57033 .07143 L
.57753 .07143 L
.59082 .07143 L
.59524 .07143 L
.59524 .07143 L
.59524 .07143 L
.59524 .07143 L
.59524 .07143 L
.59524 .07143 L
.59524 .07143 L
.59082 .07143 L
s
.59082 .13946 m
.59524 .13946 L
.59524 .13714 L
.59082 .13714 L
.59082 .13946 L
s
.59082 .13714 m
.59524 .13714 L
.59524 .13034 L
.59082 .13034 L
.59082 .13714 L
s
.59082 .13034 m
.59524 .13034 L
.59524 .11953 L
.59082 .11953 L
.59082 .13034 L
s
.59082 .11953 m
.59524 .11953 L
.59524 .10544 L
.59082 .10544 L
.59082 .11953 L
s
.59082 .10544 m
.59524 .10544 L
.59524 .08904 L
.59082 .08904 L
.59082 .10544 L
s
.59082 .08904 m
.59524 .08904 L
.59524 .07143 L
.59082 .07143 L
.59082 .08904 L
s
.59082 .07143 m
.59524 .07143 L
.59524 .05382 L
.59082 .05382 L
.59082 .07143 L
s
.59082 .05382 m
.59524 .05382 L
.59524 .03741 L
.59082 .03741 L
.59082 .05382 L
s
.59082 .03741 m
.59524 .03741 L
.59524 .02333 L
.59082 .02333 L
.59082 .03741 L
s
.59082 .02333 m
.59524 .02333 L
.59524 .01252 L
.59082 .01252 L
.59082 .02333 L
s
.59082 .01252 m
.59524 .01252 L
.59524 .00572 L
.59082 .00572 L
.59082 .01252 L
s
.59082 .00572 m
.59524 .00572 L
.59524 .0034 L
.59082 .0034 L
.59082 .00572 L
s
.59082 .0034 m
.59524 .0034 L
.59524 .00572 L
.59082 .00572 L
.59082 .0034 L
s
.59082 .00572 m
.59524 .00572 L
.59524 .01252 L
.59082 .01252 L
.59082 .00572 L
s
.59082 .01252 m
.59524 .01252 L
.59524 .02333 L
.59082 .02333 L
.59082 .01252 L
s
.59082 .02333 m
.59524 .02333 L
.59524 .03741 L
.59082 .03741 L
.59082 .02333 L
s
.59082 .03741 m
.59524 .03741 L
.59524 .05382 L
.59082 .05382 L
.59082 .03741 L
s
.59082 .05382 m
.59524 .05382 L
.59524 .07143 L
.59082 .07143 L
.59082 .05382 L
s
.59082 .07143 m
.59524 .07143 L
.59524 .08904 L
.59082 .08904 L
.59082 .07143 L
s
.59082 .08904 m
.59524 .08904 L
.59524 .10544 L
.59082 .10544 L
.59082 .08904 L
s
.59082 .10544 m
.59524 .10544 L
.59524 .11953 L
.59082 .11953 L
.59082 .10544 L
s
.59082 .11953 m
.59524 .11953 L
.59524 .13034 L
.59082 .13034 L
.59082 .11953 L
s
.59082 .13034 m
.59524 .13034 L
.59524 .13714 L
.59082 .13714 L
.59082 .13034 L
s
.59082 .13714 m
.59524 .13714 L
.59524 .13946 L
.59082 .13946 L
.59082 .13714 L
s
.039 .916 .04 r
.02381 .05782 m
.56885 .05782 L
s
0 0 0 r
2.5 Mabswid
.56885 .05782 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .05782 m
.56892 .05723 L
s
0 0 0 r
2.5 Mabswid
.56892 .05723 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .05782 m
.56882 .05812 L
s
0 0 0 r
2.5 Mabswid
.56882 .05812 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .05782 m
.56882 .05812 L
s
0 0 0 r
2.5 Mabswid
.56882 .05812 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .05782 m
.569 .05663 L
s
0 0 0 r
2.5 Mabswid
.569 .05663 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .05782 m
.56878 .05842 L
s
0 0 0 r
2.5 Mabswid
.56878 .05842 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .05782 m
.56878 .05842 L
s
0 0 0 r
2.5 Mabswid
.56878 .05842 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06236 m
.56839 .06236 L
s
0 0 0 r
2.5 Mabswid
.56839 .06236 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06236 m
.56844 .06176 L
s
0 0 0 r
2.5 Mabswid
.56844 .06176 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06236 m
.56837 .06266 L
s
0 0 0 r
2.5 Mabswid
.56837 .06266 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06236 m
.56837 .06266 L
s
0 0 0 r
2.5 Mabswid
.56837 .06266 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06236 m
.56849 .06117 L
s
0 0 0 r
2.5 Mabswid
.56849 .06117 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06236 m
.56835 .06295 L
s
0 0 0 r
2.5 Mabswid
.56835 .06295 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06236 m
.56835 .06295 L
s
0 0 0 r
2.5 Mabswid
.56835 .06295 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06689 m
.56812 .06689 L
s
0 0 0 r
2.5 Mabswid
.56812 .06689 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06689 m
.56814 .0663 L
s
0 0 0 r
2.5 Mabswid
.56814 .0663 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06689 m
.56811 .06719 L
s
0 0 0 r
2.5 Mabswid
.56811 .06719 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06689 m
.56811 .06719 L
s
0 0 0 r
2.5 Mabswid
.56811 .06719 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06689 m
.56817 .06571 L
s
0 0 0 r
2.5 Mabswid
.56817 .06571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06689 m
.5681 .06749 L
s
0 0 0 r
2.5 Mabswid
.5681 .06749 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06689 m
.5681 .06749 L
s
0 0 0 r
2.5 Mabswid
.5681 .06749 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .07143 m
.56803 .07143 L
s
0 0 0 r
2.5 Mabswid
.56803 .07143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .07143 m
.56803 .07083 L
s
0 0 0 r
2.5 Mabswid
.56803 .07083 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .07143 m
.56803 .07173 L
s
0 0 0 r
2.5 Mabswid
.56803 .07173 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .07143 m
.56803 .07173 L
s
0 0 0 r
2.5 Mabswid
.56803 .07173 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .07143 m
.56803 .07024 L
s
0 0 0 r
2.5 Mabswid
.56803 .07024 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .07143 m
.56803 .07202 L
s
0 0 0 r
2.5 Mabswid
.56803 .07202 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .07143 m
.56803 .07202 L
s
0 0 0 r
2.5 Mabswid
.56803 .07202 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .07596 m
.56812 .07596 L
s
0 0 0 r
2.5 Mabswid
.56812 .07596 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .07596 m
.5681 .07537 L
s
0 0 0 r
2.5 Mabswid
.5681 .07537 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .07596 m
.56813 .07626 L
s
0 0 0 r
2.5 Mabswid
.56813 .07626 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .07596 m
.56813 .07626 L
s
0 0 0 r
2.5 Mabswid
.56813 .07626 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .07596 m
.56808 .07478 L
s
0 0 0 r
2.5 Mabswid
.56808 .07478 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .07596 m
.56815 .07656 L
s
0 0 0 r
2.5 Mabswid
.56815 .07656 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .07596 m
.56815 .07656 L
s
0 0 0 r
2.5 Mabswid
.56815 .07656 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .0805 m
.56839 .0805 L
s
0 0 0 r
2.5 Mabswid
.56839 .0805 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .0805 m
.56835 .0799 L
s
0 0 0 r
2.5 Mabswid
.56835 .0799 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .0805 m
.56842 .0808 L
s
0 0 0 r
2.5 Mabswid
.56842 .0808 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .0805 m
.56842 .0808 L
s
0 0 0 r
2.5 Mabswid
.56842 .0808 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .0805 m
.5683 .07931 L
s
0 0 0 r
2.5 Mabswid
.5683 .07931 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .0805 m
.56845 .08109 L
s
0 0 0 r
2.5 Mabswid
.56845 .08109 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .0805 m
.56845 .08109 L
s
0 0 0 r
2.5 Mabswid
.56845 .08109 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .08503 m
.56885 .08503 L
s
0 0 0 r
2.5 Mabswid
.56885 .08503 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .08503 m
.56878 .08444 L
s
0 0 0 r
2.5 Mabswid
.56878 .08444 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .08503 m
.56889 .08533 L
s
0 0 0 r
2.5 Mabswid
.56889 .08533 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .08503 m
.56889 .08533 L
s
0 0 0 r
2.5 Mabswid
.56889 .08533 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .08503 m
.56871 .08385 L
s
0 0 0 r
2.5 Mabswid
.56871 .08385 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .08503 m
.56893 .08563 L
s
0 0 0 r
2.5 Mabswid
.56893 .08563 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .08503 m
.56893 .08563 L
s
0 0 0 r
2.5 Mabswid
.56893 .08563 Mdot
.039 .916 .04 r
.5 Mabswid
.56885 .05782 m
.59524 .05892 L
s
0 0 0 r
2.5 Mabswid
.59524 .05892 Mdot
.039 .916 .04 r
.5 Mabswid
.56892 .05723 m
.59524 .05835 L
s
0 0 0 r
2.5 Mabswid
.59524 .05835 Mdot
.039 .916 .04 r
.5 Mabswid
.56882 .05812 m
.59524 .0592 L
s
0 0 0 r
2.5 Mabswid
.59524 .0592 Mdot
.039 .916 .04 r
.5 Mabswid
.56882 .05812 m
.59524 .0592 L
s
0 0 0 r
2.5 Mabswid
.59524 .0592 Mdot
.039 .916 .04 r
.5 Mabswid
.569 .05663 m
.59524 .05778 L
s
0 0 0 r
2.5 Mabswid
.59524 .05778 Mdot
.039 .916 .04 r
.5 Mabswid
.56878 .05842 m
.59524 .05948 L
s
0 0 0 r
2.5 Mabswid
.59524 .05948 Mdot
.039 .916 .04 r
.5 Mabswid
.56878 .05842 m
.59524 .05948 L
s
0 0 0 r
2.5 Mabswid
.59524 .05948 Mdot
.039 .916 .04 r
.5 Mabswid
.56839 .06236 m
.59524 .0631 L
s
0 0 0 r
2.5 Mabswid
.59524 .0631 Mdot
.039 .916 .04 r
.5 Mabswid
.56844 .06176 m
.59524 .06253 L
s
0 0 0 r
2.5 Mabswid
.59524 .06253 Mdot
.039 .916 .04 r
.5 Mabswid
.56837 .06266 m
.59524 .06338 L
s
0 0 0 r
2.5 Mabswid
.59524 .06338 Mdot
.039 .916 .04 r
.5 Mabswid
.56837 .06266 m
.59524 .06338 L
s
0 0 0 r
2.5 Mabswid
.59524 .06338 Mdot
.039 .916 .04 r
.5 Mabswid
.56849 .06117 m
.59524 .06196 L
s
0 0 0 r
2.5 Mabswid
.59524 .06196 Mdot
.039 .916 .04 r
.5 Mabswid
.56835 .06295 m
.59524 .06366 L
s
0 0 0 r
2.5 Mabswid
.59524 .06366 Mdot
.039 .916 .04 r
.5 Mabswid
.56835 .06295 m
.59524 .06366 L
s
0 0 0 r
2.5 Mabswid
.59524 .06366 Mdot
.039 .916 .04 r
.5 Mabswid
.56812 .06689 m
.59524 .06727 L
s
0 0 0 r
2.5 Mabswid
.59524 .06727 Mdot
.039 .916 .04 r
.5 Mabswid
.56814 .0663 m
.59524 .0667 L
s
0 0 0 r
2.5 Mabswid
.59524 .0667 Mdot
.039 .916 .04 r
.5 Mabswid
.56811 .06719 m
.59524 .06755 L
s
0 0 0 r
2.5 Mabswid
.59524 .06755 Mdot
.039 .916 .04 r
.5 Mabswid
.56811 .06719 m
.59524 .06755 L
s
0 0 0 r
2.5 Mabswid
.59524 .06755 Mdot
.039 .916 .04 r
.5 Mabswid
.56817 .06571 m
.59524 .06614 L
s
0 0 0 r
2.5 Mabswid
.59524 .06614 Mdot
.039 .916 .04 r
.5 Mabswid
.5681 .06749 m
.59524 .06783 L
s
0 0 0 r
2.5 Mabswid
.59524 .06783 Mdot
.039 .916 .04 r
.5 Mabswid
.5681 .06749 m
.59524 .06783 L
s
0 0 0 r
2.5 Mabswid
.59524 .06783 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .07143 m
.59524 .07143 L
s
0 0 0 r
2.5 Mabswid
.59524 .07143 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .07083 m
.59524 .07086 L
s
0 0 0 r
2.5 Mabswid
.59524 .07086 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .07173 m
.59524 .07171 L
s
0 0 0 r
2.5 Mabswid
.59524 .07171 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .07173 m
.59524 .07171 L
s
0 0 0 r
2.5 Mabswid
.59524 .07171 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .07024 m
.59524 .0703 L
s
0 0 0 r
2.5 Mabswid
.59524 .0703 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .07202 m
.59524 .07199 L
s
0 0 0 r
2.5 Mabswid
.59524 .07199 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .07202 m
.59524 .07199 L
s
0 0 0 r
2.5 Mabswid
.59524 .07199 Mdot
.039 .916 .04 r
.5 Mabswid
.56812 .07596 m
.59524 .07559 L
s
0 0 0 r
2.5 Mabswid
.59524 .07559 Mdot
.039 .916 .04 r
.5 Mabswid
.5681 .07537 m
.59524 .07503 L
s
0 0 0 r
2.5 Mabswid
.59524 .07503 Mdot
.039 .916 .04 r
.5 Mabswid
.56813 .07626 m
.59524 .07587 L
s
0 0 0 r
2.5 Mabswid
.59524 .07587 Mdot
.039 .916 .04 r
.5 Mabswid
.56813 .07626 m
.59524 .07587 L
s
0 0 0 r
2.5 Mabswid
.59524 .07587 Mdot
.039 .916 .04 r
.5 Mabswid
.56808 .07478 m
.59524 .07446 L
s
0 0 0 r
2.5 Mabswid
.59524 .07446 Mdot
.039 .916 .04 r
.5 Mabswid
.56815 .07656 m
.59524 .07616 L
s
0 0 0 r
2.5 Mabswid
.59524 .07616 Mdot
.039 .916 .04 r
.5 Mabswid
.56815 .07656 m
.59524 .07616 L
s
0 0 0 r
2.5 Mabswid
.59524 .07616 Mdot
.039 .916 .04 r
.5 Mabswid
.56839 .0805 m
.59524 .07976 L
s
0 0 0 r
2.5 Mabswid
.59524 .07976 Mdot
.039 .916 .04 r
.5 Mabswid
.56835 .0799 m
.59524 .07919 L
s
0 0 0 r
2.5 Mabswid
.59524 .07919 Mdot
.039 .916 .04 r
.5 Mabswid
.56842 .0808 m
.59524 .08004 L
s
0 0 0 r
2.5 Mabswid
.59524 .08004 Mdot
.039 .916 .04 r
.5 Mabswid
.56842 .0808 m
.59524 .08004 L
s
0 0 0 r
2.5 Mabswid
.59524 .08004 Mdot
.039 .916 .04 r
.5 Mabswid
.5683 .07931 m
.59524 .07863 L
s
0 0 0 r
2.5 Mabswid
.59524 .07863 Mdot
.039 .916 .04 r
.5 Mabswid
.56845 .08109 m
.59524 .08033 L
s
0 0 0 r
2.5 Mabswid
.59524 .08033 Mdot
.039 .916 .04 r
.5 Mabswid
.56845 .08109 m
.59524 .08033 L
s
0 0 0 r
2.5 Mabswid
.59524 .08033 Mdot
.039 .916 .04 r
.5 Mabswid
.56885 .08503 m
.59524 .08394 L
s
0 0 0 r
2.5 Mabswid
.59524 .08394 Mdot
.039 .916 .04 r
.5 Mabswid
.56878 .08444 m
.59524 .08337 L
s
0 0 0 r
2.5 Mabswid
.59524 .08337 Mdot
.039 .916 .04 r
.5 Mabswid
.56889 .08533 m
.59524 .08423 L
s
0 0 0 r
2.5 Mabswid
.59524 .08423 Mdot
.039 .916 .04 r
.5 Mabswid
.56889 .08533 m
.59524 .08423 L
s
0 0 0 r
2.5 Mabswid
.59524 .08423 Mdot
.039 .916 .04 r
.5 Mabswid
.56871 .08385 m
.59524 .08281 L
s
0 0 0 r
2.5 Mabswid
.59524 .08281 Mdot
.039 .916 .04 r
.5 Mabswid
.56893 .08563 m
.59524 .08451 L
s
0 0 0 r
2.5 Mabswid
.59524 .08451 Mdot
.039 .916 .04 r
.5 Mabswid
.56893 .08563 m
.59524 .08451 L
s
0 0 0 r
2.5 Mabswid
.59524 .08451 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .05892 m
.97619 .0829 L
s
0 0 0 r
2.5 Mabswid
.97619 .0829 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .05835 m
.97619 .08298 L
s
0 0 0 r
2.5 Mabswid
.97619 .08298 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .0592 m
.97619 .08286 L
s
0 0 0 r
2.5 Mabswid
.97619 .08286 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .0592 m
.97619 .08286 L
s
0 0 0 r
2.5 Mabswid
.97619 .08286 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .05778 m
.97619 .08306 L
s
0 0 0 r
2.5 Mabswid
.97619 .08306 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .05948 m
.97619 .08283 L
s
0 0 0 r
2.5 Mabswid
.97619 .08283 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .05948 m
.97619 .08283 L
s
0 0 0 r
2.5 Mabswid
.97619 .08283 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .0631 m
.97619 .07903 L
s
0 0 0 r
2.5 Mabswid
.97619 .07903 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .06253 m
.97619 .0791 L
s
0 0 0 r
2.5 Mabswid
.97619 .0791 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .06338 m
.97619 .07899 L
s
0 0 0 r
2.5 Mabswid
.97619 .07899 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .06338 m
.97619 .07899 L
s
0 0 0 r
2.5 Mabswid
.97619 .07899 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .06196 m
.97619 .07917 L
s
0 0 0 r
2.5 Mabswid
.97619 .07917 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .06366 m
.97619 .07896 L
s
0 0 0 r
2.5 Mabswid
.97619 .07896 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .06366 m
.97619 .07896 L
s
0 0 0 r
2.5 Mabswid
.97619 .07896 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .06727 m
.97619 .07521 L
s
0 0 0 r
2.5 Mabswid
.97619 .07521 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .0667 m
.97619 .07528 L
s
0 0 0 r
2.5 Mabswid
.97619 .07528 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .06755 m
.97619 .07518 L
s
0 0 0 r
2.5 Mabswid
.97619 .07518 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .06755 m
.97619 .07518 L
s
0 0 0 r
2.5 Mabswid
.97619 .07518 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .06614 m
.97619 .07534 L
s
0 0 0 r
2.5 Mabswid
.97619 .07534 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .06783 m
.97619 .07515 L
s
0 0 0 r
2.5 Mabswid
.97619 .07515 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .06783 m
.97619 .07515 L
s
0 0 0 r
2.5 Mabswid
.97619 .07515 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07143 m
.97619 .07143 L
s
0 0 0 r
2.5 Mabswid
.97619 .07143 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07086 m
.97619 .07149 L
s
0 0 0 r
2.5 Mabswid
.97619 .07149 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07171 m
.97619 .0714 L
s
0 0 0 r
2.5 Mabswid
.97619 .0714 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07171 m
.97619 .0714 L
s
0 0 0 r
2.5 Mabswid
.97619 .0714 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .0703 m
.97619 .07155 L
s
0 0 0 r
2.5 Mabswid
.97619 .07155 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07199 m
.97619 .07137 L
s
0 0 0 r
2.5 Mabswid
.97619 .07137 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07199 m
.97619 .07137 L
s
0 0 0 r
2.5 Mabswid
.97619 .07137 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07559 m
.97619 .06764 L
s
0 0 0 r
2.5 Mabswid
.97619 .06764 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07503 m
.97619 .06771 L
s
0 0 0 r
2.5 Mabswid
.97619 .06771 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07587 m
.97619 .06761 L
s
0 0 0 r
2.5 Mabswid
.97619 .06761 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07587 m
.97619 .06761 L
s
0 0 0 r
2.5 Mabswid
.97619 .06761 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07446 m
.97619 .06777 L
s
0 0 0 r
2.5 Mabswid
.97619 .06777 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07616 m
.97619 .06758 L
s
0 0 0 r
2.5 Mabswid
.97619 .06758 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07616 m
.97619 .06758 L
s
0 0 0 r
2.5 Mabswid
.97619 .06758 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07976 m
.97619 .06383 L
s
0 0 0 r
2.5 Mabswid
.97619 .06383 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07919 m
.97619 .0639 L
s
0 0 0 r
2.5 Mabswid
.97619 .0639 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .08004 m
.97619 .06379 L
s
0 0 0 r
2.5 Mabswid
.97619 .06379 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .08004 m
.97619 .06379 L
s
0 0 0 r
2.5 Mabswid
.97619 .06379 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .07863 m
.97619 .06396 L
s
0 0 0 r
2.5 Mabswid
.97619 .06396 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .08033 m
.97619 .06376 L
s
0 0 0 r
2.5 Mabswid
.97619 .06376 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .08033 m
.97619 .06376 L
s
0 0 0 r
2.5 Mabswid
.97619 .06376 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .08394 m
.97619 .05995 L
s
0 0 0 r
2.5 Mabswid
.97619 .05995 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .08337 m
.97619 .06003 L
s
0 0 0 r
2.5 Mabswid
.97619 .06003 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .08423 m
.97619 .05991 L
s
0 0 0 r
2.5 Mabswid
.97619 .05991 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .08423 m
.97619 .05991 L
s
0 0 0 r
2.5 Mabswid
.97619 .05991 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .08281 m
.97619 .06011 L
s
0 0 0 r
2.5 Mabswid
.97619 .06011 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .08451 m
.97619 .05987 L
s
0 0 0 r
2.5 Mabswid
.97619 .05987 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .08451 m
.97619 .05987 L
s
0 0 0 r
2.5 Mabswid
.97619 .05987 Mdot
0 0 m
1 0 L
1 .14286 L
0 .14286 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{764, 109.062},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;l0000KB000`400?l00000o`00003oo`3ooooo
0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3oooo30?ooo`@00000
o`3ooolg0?ooo`00o`3oooo30?ooo`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo`P3o
ool500000?l0oooo=`3oool00?l0oooo`P3oool200000080Ogmo00<000000?ooo`3oool0o`3ooole
0?ooo`00o`3oooo10?ooo`030000001oOgl000000080Ogmo00<000000?ooo`3oool0o`3ooole0?oo
o`00o`3oooo00?ooo`040000001oOgl0Ogmo00000080Ogmo00<000000?ooo`3oool0o`3ooole0?oo
o`00o`3oooo00?ooo`040000001oOgl0Ogmo00000080Ogmo00<000000?ooo`3oool0o`3ooole0?oo
o`00o`3ooono0?ooo`040000001oOgl0Ogmo07moO`@00000o`3ooolg0?ooo`00o`3ooono0?ooo`05
0000001oOgl0Ogmo07moO`0000000P1oOgl00`000000oooo0?ooo`3o0?ooocD0oooo003o0?oookh0
oooo00<0000007moO`1oOgl00P1oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oookd0
oooo00<0000007moO`1oOgl00`1oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oookd0
oooo00<0000007moO`1oOgl00`1oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oook`0
oooo00<0000007moO`1oOgl0101oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oook`0
oooo00<0000007moO`1oOgl0101oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oook/0
oooo00<0000007moO`1oOgl01@1oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oookX0
oooo00<0000007moO`1oOgl01P1oOgl400000?l0oooo=`3oool00?l0oooo^P3oool00`000000Ogmo
07moO`0607moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo^@3oool00`000000Ogmo
07moO`0707moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo^@3oool00`000000Ogmo
07moO`0707moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo^03oool00`000000Ogmo
07moO`0807moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo^03oool00`000000Ogmo
07moO`0807moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo^03oool00`000000Ogmo
07moO`0807moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo]`3oool00`000000Ogmo
07moO`0907moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo]`3oool00`000000Ogmo
07moO`0907moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo]`3oool00`000000Ogmo
07moO`0907moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo]P3oool00`000000Ogmo
07moO`0:07moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo]P3oool00`000000Ogmo
07moO`0:07moO`@00000o`3ooolg0?ooo`00o`3ooonf0?ooo`030000001oOgl0Ogmo00X0Ogmo00@0
000007moO`1oOgl00000o`3ooolg0?ooo`00o`3ooone0?ooo`030000001oOgl0Ogmo00/0Ogmo00@0
000007moO`1oOgl00000o`3ooolg0?ooo`00o`3ooone0?ooo`030000001oOgl0Ogmo00/0Ogmo00@0
000007moO`1oOgl00000o`3ooolg0?ooo`00o`3ooone0?ooo`030000001oOgl0Ogmo00/0Ogmo00@0
000007moO`1oOgl00000o`3ooolg0?ooo`00o`3ooond0?ooo`030000001oOgl0Ogmo00`0Ogmo00@0
000007moO`1oOgl00000o`3ooolg0?ooo`00o`3ooond0?ooo`030000001oOgl0Ogmo00`0Ogmo00@0
000007moO`1oOgl00000o`3ooolg0?ooo`00o`3ooond0?ooo`030000001oOgl0Ogmo00`0Ogmo00@0
000007moO`1oOgl00000o`3ooolg0?ooo`00o`3ooonc0?ooo`030000001oOgl0Ogmo00d0Ogmo00@0
000007moO`1oOgl00000o`3ooolg0?ooo`00o`3ooonc0?ooo`030000001oOgl0Ogmo00d0Ogmo00@0
000007moO`1oOgl00000o`3ooolg0?ooo`00o`3ooonc0?ooo`030000001oOgl0Ogmo00d0Ogmo00@0
000007moO`1oOgl00000o`3ooolg0?ooo`00o`3ooonc0?ooo`030000001oOgl0Ogmo00d0Ogmo00@0
000007moO`1oOgl00000o`3ooolg0?ooo`00o`3ooonc0?ooo`030000001oOgl0Ogmo00d0Ogmo1000
003o0?ooocL0oooo003o0?oook80oooo00<0000007moO`1oOgl03P1oOgl010000000Ogmo07moO`00
003o0?ooocL0oooo003S0?ooold02NX:00<0000000WZ2P09jPX02@09jPX607moO`040000001oOgl0
Ogmo00000?l0oooo=`3oool001D0ooooo`09jPZL00WZ2P0300000009jPX02NX:01402NX:00<00000
00WZ2P09jPX01`09jP[o0?ooobl0oooo003T0?oool`02NX:00<0000000WZ2P09jPX04@09jPX00`00
00002NX:00WZ2P0F00WZ2_l0oooo203oool2000001H0oooo003o0?oook40oooo0P00000@07moO`04
0000001oOgl00000000000P0oooo7P09jP[a0?ooo`L02NX:0P00000F0?ooo`00h`3oooo=00WZ2P03
00000009jPX02NX:01402NX:00<0000000WZ2P09jPX02P09jPX=0?oooad02NX:d@3ooolA00WZ2PL0
oooo0P00000F0?ooo`005@3ooooo00WZ2Y`02NX:00<0000000WZ2P09jPX04@09jPX00`0000002NX:
00WZ2P0P00WZ2PL0oooo7009jPZa0?oooa802NX:5`3oool2000001H0oooo003o0?oook40oooo0P00
000:07moO`P02NX:00<0000000WZ2P09jPX0=P09jPX00`3oool02NX:00WZ2P0I00WZ2Y40oooo4`09
jPXK0?ooo``02NX:0P00000F0?ooo`00h`3oooo=00WZ2P0300000009jPX02NX:01402NX:00<00000
00WZ2P09jPX0HP09jPY`0?oooa@02NX:4@3ooolK00WZ2P/0oooo0P00000F0?ooo`005@3ooooo00WZ
2Y`02NX:00<0000000WZ2P09jPX04@09jPX00`0000002NX:00WZ2P1a00WZ2U00oooo5@09jPX70?oo
oad02NX:8`3oool2000001H0oooo003o0?oook40oooo0P00000:07moO`P02NX:00<0000000WZ2P09
jPX0P009jPX`0?oooc802NX:7`3ooolL00WZ2P8000005P3oool00?l0oooo/@3oool200000100Ogmo
00@0000007moO`00000000007@3ooomc00WZ2Q00ooooI`09jPX_0?ooo`005@3ooooo00WZ2[002NX:
00<0000000WZ2P09jPX0o`09jPXN00WZ2P8000005P3oool00>@0ooooh009jPX00`0000002NX:00WZ
2P3o00WZ2Qh02NX:0P00000F0?ooo`00o`3ooona0?ooo`800000401oOgl010000000Ogmo00000000
000L0?ooof/02NX:8@3ooomS00WZ2R/0oooo003S0?ooon402NX:00<0000000WZ2P09jPX0MP09jPY1
0?oooc402NX:6P3ooolK00WZ2P8000005P3oool001D0ooooo`09jPZL00WZ2P0300000009jPX02NX:
01402NX:00<0000000WZ2P09jPX05P09jPX?0?oood402NX:H@3ooolD00WZ2P<0oooo8009jPXO0?oo
o`8000005P3oool00?l0oooo/@3oool200000100Ogmo00@0000007moO`0000000000303ooom;00WZ
2X40oooo4`09jPX>0?oooa`02NX:8@3oool00><0ooooc@09jPX00`0000002NX:00WZ2P0A00WZ2P03
00000009jPX02NX:02802NX:1P3ooolN00WZ2Z40oooo4P09jPXI0?ooo`/02NX:0P00000F0?ooo`00
5@3ooooo00WZ2Y`02NX:00<0000000WZ2P09jPX04@09jPX00`0000002NX:00WZ2P0:00WZ2Pd0oooo
7`09jP[10?oooa402NX:5@3oool2000001H0oooo003T0?oool`02NX:00<0000000WZ2P09jPX02009
jPX707moO`040000001oOgl00000000000L0oooo8009jP[Q0?oooa002NX:7P3oool00?l0oooo/@3o
ool2000000T0Ogmo2@09jPX00`0000002NX:00WZ2P0F00WZ2_l0oooo0P3oool600WZ2P8000005P3o
ool00><0ooooc@09jPX00`0000002NX:00WZ2P0A00WZ2P0300000009jPX02NX:00H02NX:o`3ooolH
0?ooo`8000005P3oool001D0ooooo`09jPZL00WZ2P0300000009jPX02NX:00P02NX:1`1oOgl01000
0000Ogmo00000000003o0?ooocL0oooo003o0?oook40oooo0P00000@07moO`040000001oOgl0Ogmo
00000?l0oooo=`3oool00?l0oooo/P3oool00`000000Ogmo07moO`0>07moO`040000001oOgl0Ogmo
00000?l0oooo=`3oool00?l0oooo/`3oool00`000000Ogmo07moO`0=07moO`@00000o`3ooolg0?oo
o`00o`3ooonc0?ooo`030000001oOgl0Ogmo00d0Ogmo00@0000007moO`1oOgl00000o`3ooolg0?oo
o`00o`3ooonc0?ooo`030000001oOgl0Ogmo00d0Ogmo00@0000007moO`1oOgl00000o`3ooolg0?oo
o`00o`3ooonc0?ooo`030000001oOgl0Ogmo00d0Ogmo00@0000007moO`1oOgl00000o`3ooolg0?oo
o`00o`3ooonc0?ooo`030000001oOgl0Ogmo00d0Ogmo00@0000007moO`1oOgl00000o`3ooolg0?oo
o`00o`3ooonc0?ooo`030000001oOgl0Ogmo00d0Ogmo00@0000007moO`1oOgl00000o`3ooolg0?oo
o`00o`3ooond0?ooo`030000001oOgl0Ogmo00`0Ogmo00@0000007moO`1oOgl00000o`3ooolg0?oo
o`00o`3ooond0?ooo`030000001oOgl0Ogmo00`0Ogmo00@0000007moO`1oOgl00000o`3ooolg0?oo
o`00o`3ooond0?ooo`030000001oOgl0Ogmo00`0Ogmo00@0000007moO`1oOgl00000o`3ooolg0?oo
o`00o`3ooone0?ooo`030000001oOgl0Ogmo00/0Ogmo00@0000007moO`1oOgl00000o`3ooolg0?oo
o`00o`3ooone0?ooo`030000001oOgl0Ogmo00/0Ogmo00@0000007moO`1oOgl00000o`3ooolg0?oo
o`00o`3ooone0?ooo`030000001oOgl0Ogmo00/0Ogmo00@0000007moO`1oOgl00000o`3ooolg0?oo
o`00o`3ooonf0?ooo`030000001oOgl0Ogmo00X0Ogmo1000003o0?ooocL0oooo003o0?oookH0oooo
00<0000007moO`1oOgl02P1oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oookH0oooo
00<0000007moO`1oOgl02P1oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oookL0oooo
00<0000007moO`1oOgl02@1oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oookL0oooo
00<0000007moO`1oOgl02@1oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oookL0oooo
00<0000007moO`1oOgl02@1oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oookP0oooo
00<0000007moO`1oOgl0201oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oookP0oooo
00<0000007moO`1oOgl0201oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oookP0oooo
00<0000007moO`1oOgl0201oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oookT0oooo
00<0000007moO`1oOgl01`1oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oookT0oooo
00<0000007moO`1oOgl01`1oOgl010000000Ogmo07moO`00003o0?ooocL0oooo003o0?oookX0oooo
00<0000007moO`1oOgl01P1oOgl400000?l0oooo=`3oool00?l0oooo^P3oool00`000000Ogmo07mo
O`0607moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo^`3oool00`000000Ogmo07mo
O`0507moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo_03oool00`000000Ogmo07mo
O`0407moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo_03oool00`000000Ogmo07mo
O`0407moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo_@3oool00`000000Ogmo07mo
O`0307moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo_@3oool00`000000Ogmo07mo
O`0307moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo_P3oool00`000000Ogmo07mo
O`0207moO`040000001oOgl0Ogmo00000?l0oooo=`3oool00?l0oooo_`3oool010000000Ogmo07mo
O`1oOgl400000?l0oooo=`3oool00?l0oooo_`3oool01@000000Ogmo07moO`1oOgl000000080Ogmo
00<000000?ooo`3oool0o`3ooole0?ooo`00o`3oooo00?ooo`040000001oOgl0Ogmo00000080Ogmo
00<000000?ooo`3oool0o`3ooole0?ooo`00o`3oooo00?ooo`040000001oOgl0Ogmo00000080Ogmo
00<000000?ooo`3oool0o`3ooole0?ooo`00o`3oooo10?ooo`030000001oOgl000000080Ogmo00<0
00000?ooo`3oool0o`3ooole0?ooo`00o`3oooo20?ooo`D00000o`3ooolg0?ooo`00o`3oooo20?oo
o`8000000P1oOgl00`000000oooo0?ooo`3o0?ooocD0oooo003o0?oool<0oooo1000003o0?ooocL0
oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 763}, {108.062, 0}} -> {-10.3497, -26.2503, \
0.485844, 0.485844}}]
}, Open  ]],

Cell[TextData[{
  "Here, ",
  StyleBox["DistortionGrid", "Input"],
  " has generated an array of point sources that are nearly colinear."
}], "Text"],

Cell[TextData[{
  StyleBox["FindFocalSurface", "Input"],
  " traces the rays up to the focal surface of the imaging system and retains \
only the final ray segment to this surface. With the default, ",
  StyleBox["SingleRay -> True", "Input"],
  " setting, only the chief ray is retained for each focussed ray bundle that \
was originally generated by ",
  StyleBox["DistortionGrid", "Input"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Clear[imagefocus];
imagefocus = FindFocalSurface[{
\tDistortionGrid[PointOfRays[0.25], {10, 10}, {7, 7}],
\tMove[PlanoConvexLens[80, 50,10], 200],
\tBoundary[350, GraphicDesign -> Off]
}];
TurboPlot[imagefocus, RayPointSize -> 4];\
\>", "Input",
  GeneratedCell->False,
  CellTags->"FindImage"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70727 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0190131 1.01901 -0.133537 1.01901 [
[ 0 0 0 0 ]
[ 1 .70727 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .70727 L
0 .70727 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.23156 .44497 m
.21646 .41057 L
s
.23962 .44237 m
.23156 .44497 L
s
.24252 .48152 m
.23156 .44497 L
s
.24866 .51806 m
.24252 .48152 L
s
.24252 .48152 m
.25059 .47897 L
s
.22452 .40792 m
.23962 .44237 L
s
.23962 .44237 m
.25059 .47897 L
s
.25059 .47897 m
.25677 .51554 L
s
.21646 .41057 m
.22452 .40792 L
s
.21646 .41057 m
.19807 .3804 L
s
.20615 .37771 m
.22452 .40792 L
s
.24866 .51806 m
.25677 .51554 L
s
.19807 .3804 m
.20615 .37771 L
s
.19854 .53614 m .25774 .54988 L .24958 .55237 L .656 .751 .92 r
F
0 g
.24866 .51806 m
.24946 .54796 L
s
.24512 .58233 m
.24958 .55237 L
s
.19854 .53614 m .23135 .52595 L .25774 .54988 L .656 .751 .92 r
F
0 g
.25334 .57985 m
.25774 .54988 L
s
.25677 .51554 m
.25774 .54988 L
s
.24958 .55237 m
.25774 .54988 L
s
.17748 .35638 m .1827 .39379 L .14999 .40464 L .544 .324 .532 r
F
.17748 .35638 m .1856 .35364 L .1827 .39379 L F
0 g
.18479 .3649 m
.19807 .3804 L
s
.17748 .35638 m
.1856 .35364 L
s
.1856 .35364 m
.20615 .37771 L
s
.15591 .34013 m
.17748 .35638 L
s
.16409 .33734 m
.1856 .35364 L
s
.15793 .51611 m .23135 .52595 L .19854 .53614 L .656 .751 .92 r
F
0 g
.19854 .53614 m
.24958 .55237 L
s
.23542 .60592 m
.24512 .58233 L
s
.24512 .58233 m
.25334 .57985 L
s
.25334 .57985 m
.24372 .60345 L
s
.14999 .40464 m .17974 .43471 L .13339 .44982 L .544 .324 .532 r
F
.14999 .40464 m .1827 .39379 L .17974 .43471 L F
0 g
.14999 .40464 m
.17748 .35638 L
s
.1827 .39379 m
.1856 .35364 L
s
.15793 .51611 m .20435 .50147 L .23135 .52595 L .656 .751 .92 r
F
0 g
.23135 .52595 m
.25774 .54988 L
s
.15591 .34013 m
.16409 .33734 L
s
.15591 .34013 m
.13474 .33294 L
s
.14298 .33011 m
.16409 .33734 L
s
.12567 .49277 m .20435 .50147 L .15793 .51611 L .656 .751 .92 r
F
0 g
.15793 .51611 m
.19854 .53614 L
s
.22096 .62143 m
.23542 .60592 L
s
.23542 .60592 m
.24372 .60345 L
s
.13339 .44982 m .17673 .47642 L .12567 .49277 L .544 .324 .532 r
F
.13339 .44982 m .17974 .43471 L .17673 .47642 L F
0 g
.13339 .44982 m
.14999 .40464 L
s
.17974 .43471 m
.1827 .39379 L
s
.24372 .60345 m
.22934 .61894 L
s
.039 .916 .04 r
.19367 .46725 m
.85971 .2606 L
s
.12567 .49277 m .17673 .47642 L .20435 .50147 L .656 .751 .92 r
F
0 g
.20435 .50147 m
.23135 .52595 L
s
.039 .916 .04 r
.19312 .47492 m
.86758 .25235 L
s
.18859 .46262 m
.87087 .26192 L
s
0 g
.13474 .33294 m
.14298 .33011 L
s
.13474 .33294 m
.11537 .33559 L
s
.039 .916 .04 r
.57422 .34917 m
.87209 .24501 L
s
.19258 .48261 m
.57422 .34917 L
s
.18804 .4703 m
.87879 .25362 L
s
0 g
.12368 .33273 m
.14298 .33011 L
s
.12567 .49277 m .17365 .51896 L .12644 .53378 L .544 .324 .532 r
F
.12567 .49277 m .17673 .47642 L .17365 .51896 L F
.10133 .46611 m .17673 .47642 L .12567 .49277 L .656 .751 .92 r
F
0 g
.12976 .47 m
.13339 .44982 L
s
.039 .916 .04 r
.1835 .45797 m
.87876 .26435 L
s
.19205 .49032 m
.87324 .23874 L
s
.57529 .34882 m
.88333 .24622 L
s
.18749 .47799 m
.57529 .34882 L
s
.18295 .46566 m
.88674 .25607 L
s
.1784 .4533 m
.8833 .26782 L
s
0 g
.20255 .62752 m
.22096 .62143 L
s
.22096 .62143 m
.22934 .61894 L
s
.039 .916 .04 r
.19152 .49806 m
.57422 .34917 L
s
.57422 .34917 m
.87104 .23368 L
s
.18695 .48569 m
.88447 .23986 L
s
0 g
.22934 .61894 m
.21101 .62502 L
s
.039 .916 .04 r
.1824 .47335 m
.8913 .24865 L
s
.17784 .461 m
.89131 .25961 L
s
.17328 .4486 m
.57422 .34917 L
s
.57422 .34917 m
.88441 .27223 L
s
.191 .50585 m
.57357 .34937 L
s
.57357 .34937 m
.86553 .22996 L
s
.18641 .49343 m
.57529 .34882 L
s
.57529 .34882 m
.88223 .23468 L
s
.18185 .48106 m
.89243 .24225 L
s
.17729 .4687 m
.89589 .25222 L
s
.57529 .34882 m
.89244 .26414 L
s
.19049 .51369 m
.57249 .34972 L
s
.57249 .34972 m
.85677 .22769 L
s
.16813 .44386 m
.57357 .34937 L
s
.57357 .34937 m
.88206 .27748 L
s
.18588 .50122 m
.57465 .34903 L
s
.57465 .34903 m
.87664 .23081 L
s
.1813 .48881 m
.57593 .34862 L
s
.57593 .34862 m
.89016 .23699 L
s
.10133 .46611 m .14845 .45078 L .17673 .47642 L .656 .751 .92 r
F
.039 .916 .04 r
.17673 .47642 m
.89703 .24582 L
s
.17272 .45632 m
.57529 .34882 L
s
0 g
.17673 .47642 m
.17974 .43471 L
s
.17673 .47642 m
.20435 .50147 L
s
.039 .916 .04 r
.57593 .34862 m
.89704 .25683 L
s
.17215 .46403 m
.57593 .34862 L
s
.57465 .34903 m
.8901 .26955 L
s
.16756 .45159 m
.57465 .34903 L
s
.18535 .50905 m
.86777 .22836 L
s
.16294 .43907 m
.87621 .28345 L
s
.18075 .49659 m
.88452 .23301 L
s
.17617 .48417 m
.57614 .34855 L
s
.57614 .34855 m
.89474 .24052 L
s
.17159 .47176 m
.89818 .25047 L
s
.57529 .34882 m
.8947 .26237 L
s
.16699 .45933 m
.57529 .34882 L
s
.12644 .53378 m .17052 .56233 L .13659 .57277 L .544 .324 .532 r
F
.12644 .53378 m .17365 .51896 L .17052 .56233 L F
0 g
.12567 .49277 m
.12644 .53378 L
s
.17365 .51896 m
.17673 .47642 L
s
.039 .916 .04 r
.16237 .44683 m
.88425 .27574 L
s
0 g
.11537 .33559 m
.09921 .34823 L
s
.12368 .33273 m
.11537 .33559 L
s
.039 .916 .04 r
.1802 .50442 m
.87557 .23042 L
s
.1756 .49195 m
.5755 .34875 L
s
.5755 .34875 m
.88906 .23647 L
s
.17101 .47952 m
.57593 .34862 L
s
.57593 .34862 m
.89589 .24518 L
s
0 g
.1076 .34535 m
.12368 .33273 L
s
.039 .916 .04 r
.16641 .46707 m
.89585 .2561 L
s
.57422 .34917 m
.88886 .26874 L
s
.16179 .45459 m
.57422 .34917 L
s
.08569 .43571 m .14845 .45078 L .10133 .46611 L .656 .751 .92 r
F
0 g
.10133 .46611 m
.12567 .49277 L
s
.039 .916 .04 r
.17504 .49979 m
.57443 .3491 L
s
.57443 .3491 m
.88007 .23378 L
s
.17044 .48731 m
.57529 .34882 L
s
.57529 .34882 m
.8902 .2411 L
s
.16583 .47484 m
.57529 .34882 L
s
.57529 .34882 m
.89357 .25086 L
s
.16121 .46235 m
.89003 .2626 L
s
0 g
.18133 .62345 m
.20255 .62752 L
s
.20255 .62752 m
.21101 .62502 L
s
.039 .916 .04 r
.16985 .49515 m
.57422 .34917 L
s
.57422 .34917 m
.88119 .23834 L
s
0 g
.21101 .62502 m
.18986 .62091 L
s
.039 .916 .04 r
.16524 .48264 m
.57465 .34903 L
s
.57465 .34903 m
.8879 .24679 L
s
.16061 .47013 m
.57422 .34917 L
s
.57422 .34917 m
.88777 .25746 L
s
.16464 .49049 m
.57357 .34937 L
s
.57357 .34937 m
.87889 .24401 L
s
.16 .47795 m
.57357 .34937 L
s
.57357 .34937 m
.88213 .25344 L
s
.08569 .43571 m .1195 .42453 L .14845 .45078 L .656 .751 .92 r
F
0 g
.14845 .45078 m
.17673 .47642 L
s
.039 .916 .04 r
.15938 .48581 m
.87316 .25066 L
s
0 g
.09921 .34823 m
.1076 .34535 L
s
.09921 .34823 m
.08752 .37031 L
s
.13659 .57277 m .16732 .60657 L .15874 .60916 L .544 .324 .532 r
F
.13659 .57277 m .17052 .56233 L .16732 .60657 L F
0 g
.12644 .53378 m
.13659 .57277 L
s
.13659 .57277 m
.15874 .60916 L
s
.17052 .56233 m
.17365 .51896 L
s
.09599 .36743 m
.1076 .34535 L
s
.15874 .60916 m
.18133 .62345 L
s
.18133 .62345 m
.18986 .62091 L
s
.08131 .40052 m .1195 .42453 L .08569 .43571 L .656 .751 .92 r
F
0 g
.08569 .43571 m
.10133 .46611 L
s
.16732 .60657 m
.18986 .62091 L
s
.16732 .60657 m
.17052 .56233 L
s
.08131 .40052 m .08985 .39765 L .1195 .42453 L .656 .751 .92 r
F
0 g
.08985 .39765 m
.1195 .42453 L
s
.1195 .42453 m
.14845 .45078 L
s
.08131 .40052 m
.08569 .43571 L
s
.08752 .37031 m
.09599 .36743 L
s
.08131 .40052 m
.08752 .37031 L
s
.08985 .39765 m
.09599 .36743 L
s
.1364 .58539 m
.15874 .60916 L
s
.15874 .60916 m
.16732 .60657 L
s
.14503 .58275 m
.16732 .60657 L
s
.08131 .40052 m
.08985 .39765 L
s
.0812 .43678 m
.08131 .40052 L
s
.08979 .43394 m
.08985 .39765 L
s
.11603 .55372 m
.1364 .58539 L
s
.1364 .58539 m
.14503 .58275 L
s
.14503 .58275 m
.12468 .55103 L
s
.0812 .43678 m
.08979 .43394 L
s
.0812 .43678 m
.0873 .47644 L
s
.09593 .47364 m
.08979 .43394 L
s
.09921 .51646 m
.11603 .55372 L
s
.11603 .55372 m
.12468 .55103 L
s
.12468 .55103 m
.10787 .51371 L
s
.0873 .47644 m
.09593 .47364 L
s
.0873 .47644 m
.09921 .51646 L
s
.09921 .51646 m
.10787 .51371 L
s
.10787 .51371 m
.09593 .47364 L
s
0 0 0 r
4 Mabswid
.87316 .25066 Mdot
.88213 .25344 Mdot
.87889 .24401 Mdot
.88777 .25746 Mdot
.88119 .23834 Mdot
.8879 .24679 Mdot
.89003 .2626 Mdot
.88007 .23378 Mdot
.89357 .25086 Mdot
.88886 .26874 Mdot
.8902 .2411 Mdot
.88425 .27574 Mdot
.87621 .28345 Mdot
.87557 .23042 Mdot
.89585 .2561 Mdot
.86777 .22836 Mdot
.88906 .23647 Mdot
.89589 .24518 Mdot
.85677 .22769 Mdot
.8947 .26237 Mdot
.8901 .26955 Mdot
.88452 .23301 Mdot
.88206 .27748 Mdot
.89818 .25047 Mdot
.89474 .24052 Mdot
.87664 .23081 Mdot
.86553 .22996 Mdot
.89704 .25683 Mdot
.89016 .23699 Mdot
.89244 .26414 Mdot
.89703 .24582 Mdot
.88441 .27223 Mdot
.88223 .23468 Mdot
.89589 .25222 Mdot
.87104 .23368 Mdot
.89243 .24225 Mdot
.89131 .25961 Mdot
.8833 .26782 Mdot
.88447 .23986 Mdot
.8913 .24865 Mdot
.87324 .23874 Mdot
.88674 .25607 Mdot
.87876 .26435 Mdot
.88333 .24622 Mdot
.87209 .24501 Mdot
.87879 .25362 Mdot
.87087 .26192 Mdot
.86758 .25235 Mdot
.85971 .2606 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{505, 357.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0001IB000`400?l00000o`00003oo`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj
0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooooj0?ooo`00o`3ooon`0?ooo`8000000`3o
ool2000004<0oooo003o0?ooojl0oooo100000000`3oool0000000000002000000040?ooo`000000
0000000003h0oooo003o0?oooj`0oooo0`09jPX>000000030?ooo`000000000003X0oooo003o0?oo
ojX0oooo0P09jPX40?ooo`80000000<02NX:0000000000003000000i0?ooo`00o`3ooonX0?ooo`80
2NX:103oool300WZ2P<0oooo3P00000h0?ooo`00o`3ooonU0?ooo`<02NX:0`3oool400WZ2P80oooo
1@09jPX=000003L0oooo003o0?oooj<0oooo0P09jPX40?ooo`<02NX:0`3oool500WZ2P030?ooo`09
jPX02NX:00h00000=@3oool00?l0ooooX@3oool200WZ2P<0oooo1009jPX20?ooo`D02NX:0P3oool4
00WZ2Pl00000=03oool00?l0ooooWP3oool300WZ2P<0oooo1009jPX00`3oool02NX:00WZ2P0300WZ
2P80oooo1`09jPX30000000300WZ2P000000000000T00000=03oool00?l0ooooW03oool200WZ2P<0
oooo1009jPX20?ooo`D02NX:00<0oooo00WZ2P09jPX01`09jPX@000003@0oooo003o0?oooiX0oooo
0P09jPX30?ooo`@02NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`/02NX:4@00000c0?ooo`00o`3o
oonG0?ooo`<02NX:0`3oool300WZ2P80oooo1@09jPX00`3oool02NX:00WZ2P0=00WZ2P<0000000<0
2NX:0000000000002P00000c0?ooo`00o`3ooonE0?ooo`802NX:0`3oool400WZ2P030?ooo`09jPX0
2NX:00<02NX:00<0oooo00WZ2P09jPX03P09jPX60000000300WZ2P000000000000T00000<`3oool0
0?l0ooooT`3oool200WZ2P<0oooo0`09jPX20?ooo`D02NX:00<0oooo00WZ2P09jPX01P09jPX00`3o
ool02NX:00WZ2P0600WZ2P/000000P09jPX6000003<0oooo003o0?oooi00oooo0`09jPX20?ooo`@0
2NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0B00WZ2Pd0000000<02NX:00000000
00000P00000d0?ooo`00o`3ooon>0?ooo`802NX:0`3oool300WZ2P80oooo1009jPX00`3oool02NX:
00WZ2P0F00WZ2P8000000`09jPX=000003<0oooo003o0?oooh`0oooo0P09jPX20?ooo`@02NX:00<0
oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0D00WZ2P8000002009jPX2000000030?ooo`00
0000000000L00000<`3oool00?l0ooooR@3oool300WZ2P80oooo0`09jPX20?ooo`@02NX:00<0oooo
00WZ2P09jPX05P09jPX4000000<02NX:0P0000000`09jPX0oooo00WZ2P0200WZ2PP00000=03oool0
0?l0ooooQ`3oool200WZ2P<0oooo0`09jPX00`3oool02NX:00WZ2P0N00WZ2P@000000P09jPX40000
000300WZ2P000000000000802NX:1`00000d0?ooo`00o`3ooon50?ooo`802NX:0P3oool900WZ2P03
0?ooo`09jPX02NX:01`02NX:0P00000300WZ2PP0000000<02NX:0000000000001@00000d0?ooo`00
o`3ooon20?ooo`<02NX:0P3oool300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX0
9@09jPX2000000030?ooo`000000000000<0000000<02NX:0000000000000`00000e0?ooo`00o`3o
oon00?ooo`802NX:0P3oool900WZ2P030?ooo`09jPX02NX:02/02NX:2@00000f0?ooo`00o`3ooomn
0?ooo`802NX:0P3oool300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX09@09jPX0
0`3oool02NX:00WZ2P0600WZ2P030?ooo`000000000000D00000=`3oool00?l0ooooN`3oool300WZ
2P030?ooo`09jPX02NX:02d02NX:00<0oooo00WZ2P09jPX01P09jPX30?ooo`<02NX:1P00000g0?oo
o`00o`3ooomi0?ooo`802NX:0P3oool300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09
jPX0;009jPX20?ooo`H02NX:00<0oooo0000000000000`00000h0?ooo`00o`3ooomg0?ooo`802NX:
0P3oool/00WZ2P030?ooo`09jPX02NX:00H02NX:0P3oool600WZ2P@0oooo1000000j0?ooo`00o`3o
oomd0?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0`00WZ2P80oooo1P09jPX40?ooo`<02NX:
1@00000j0?ooo`00o`3ooomb0?ooo`802NX:0P3oool700WZ2P030?ooo`09jPX02NX:02P02NX:0P3o
ool600WZ2P<0oooo2009jPX4000003/0oooo003o0?ooog00oooo0P09jPX00`3oool02NX:00WZ2P0`
00WZ2P030?ooo`09jPX02NX:00@02NX:0`3oool800WZ2P80oooo0P0000000`3oool000000000000l
0?ooo`00o`3ooom]0?ooo`<02NX:00<0oooo00WZ2P09jPX0;P09jPX00`3oool02NX:00WZ2P0400WZ
2P<0oooo1`09jPX60?ooo`@00000?P3oool00?l0ooooJ`3oool200WZ2P80oooo;P09jPX00`3oool0
2NX:00WZ2P0400WZ2P<0oooo1`09jPX50?ooo`D02NX:1000000n0?ooo`00o`3ooomX0?ooo`<02NX:
00<0oooo00WZ2P09jPX0:`09jPX00`3oool02NX:00WZ2P0400WZ2P<0oooo1`09jPX40?ooo`D02NX:
1P3oool2000003l0oooo003o0?ooofH0oooo0P09jPX20?ooob/02NX:0P3oool500WZ2P80oooo1`09
jPX50?ooo`@02NX:C03oool00?l0ooooI03oool200WZ2P030?ooo`09jPX02NX:02T02NX:00<0oooo
00WZ2P09jPX00`09jPX20?ooo`L02NX:103oool500WZ2U00oooo003o0?ooof40oooo0`09jPX00`3o
ool02NX:00WZ2P0W00WZ2P030?ooo`09jPX02NX:00<02NX:0P3oool700WZ2P@0oooo1009jPYE0?oo
o`00o`3ooomO0?ooo`802NX:00<0oooo00WZ2P09jPX09P09jPX00`3oool02NX:00WZ2P0300WZ2P80
oooo1P09jPX40?ooo`D02NX:F@3oool00?l0ooooG@3oool200WZ2P030?ooo`09jPX02NX:02@02NX:
00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0500WZ2P<0oooo1@09jPYN0?ooo`00o`3o
oomJ0?ooo`<02NX:00<0oooo00WZ2P09jPX0:009jPX00`3oool02NX:00WZ2P0500WZ2P<0oooo1009
jPYS0?ooo`00o`3ooomH0?ooo`802NX:00<0oooo00WZ2P09jPX09`09jPX00`3oool02NX:00WZ2P04
00WZ2P<0oooo1@09jPYW0?ooo`00o`3ooomF0?ooo`802NX:00<0oooo00WZ2P09jPX09@09jPX00`3o
ool02NX:00WZ2P0400WZ2P<0oooo1009jPY/0?ooo`00o`3ooomC0?ooobT02NX:00<0oooo00WZ2P09
jPX01009jPX20?ooo`D02NX:L03oool00?l0ooooD@3oool200WZ2P030?ooo`09jPX02NX:02T02NX:
00<0oooo00WZ2P09jPX00`09jPYe0?ooo`00o`3ooom?0?ooob/02NX:0P3oool400WZ2WX0oooo003o
0?oood`0oooo:P09jPX00`3oool02NX:00WZ2P0300WZ2Wh0oooo003o0?ooodX0oooo0P09jPX00`3o
ool02NX:00WZ2P0S00WZ2P030?ooo`09jPX02NX:00802NX:P`3oool00?l0ooooB03ooolU00WZ2P03
0?ooo`09jPX02NX:00<02NX:Q`3oool00?l0ooooA@3ooolY00WZ2X`0oooo003o0?oood<0oooo9P09
jPZA0?ooo`00o`3ooom10?ooob@02NX:U@3oool00?l0oooo?P3ooolR00WZ2YX0oooo003o0?oooc`0
oooo8009jPZN0?ooo`00o`3ooolj0?oooad02NX:X`3oool00?l0oooo=`3ooolK00WZ2ZP0oooo0013
0?ooo`P00000j@3ooolI00WZ2Z`0oooo000l0?ooo`X000001@3oool300000>@0oooo5P09jPZa0?oo
o`00>@3oool6000000L0oooo0`0000050?ooo`<00000gP3ooolE00WZ2[D0oooo000h0?ooo`040000
003oool0oooo000000d0oooo0P0000060?ooo`<00000f@3ooolB00WZ2[X0oooo000g0?ooo`040000
003oool0000000000100oooo0`0000000`3oool00000000000030?ooo`030000003oool0oooo0=@0
oooo3`09jPZo0?ooo`00=P3oool00`000000oooo0000000E0?ooo`8000001@3oool00`000000oooo
0?ooo`3@0?ooo`h02NX:``3oool003D0oooo00<000000?ooo`000000603oool00`000000oooo0?oo
o`030?ooo`800000cP3oool;00WZ2/P0oooo000d0?ooo`<000006P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0<T0oooo2@09jP[<0?ooo`00<`3oool2000000030?ooo`000000oooo
01X0oooo0P0000050?ooo`800000aP3oool700WZ2]40oooo000b0?ooo`040000003oool0oooo0000
01h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`310?ooo`H02NX:e03oool00380
oooo00@000000?ooo`3oool000007`3oool2000000D0oooo00<000000?ooo`3oool0^`3oool700WZ
2]P0oooo000a0?ooo`040000003oool0oooo00000280oooo00<000000?ooo`3oool00P3oool20000
0;P0oooo2009jP[K0?ooo`00<@3oool010000000oooo0?ooo`00000S0?ooo`060000003oool00000
0000002;DXP00000/`3oool:00WZ2]h0oooo000`0?ooo`040000003oool0oooo000002D0oooo00@0
000008]BR02;DXP0Re:80P00002]0?ooo`d02NX:h03oool00300oooo00<000000?ooo`0000009P3o
ool01`000000Re:808]BR02;DXP000000?ooo`000000Z03oool>00WZ2^<0oooo000_0?ooo`040000
003oool0oooo000002D0oooo00<0000008]BR02;DXP00P2;DXP010000000oooo0?ooo`00002R0?oo
oa402NX:i@3oool002h0oooo00@000000?ooo`3oool000009P3oool00`000000Re:808]BR00208]B
R0050000003oool0oooo0?ooo`000000W@3ooolB00WZ2^P0oooo000^0?ooo`040000003oool0oooo
000002D0oooo00<0000008]BR02;DXP00`2;DXP00`000000oooo0?ooo`020?ooo`030000003oool0
oooo09D0oooo5@09jP[Z0?ooo`00;@3oool010000000oooo00000000000U0?ooo`030000002;DXP0
Re:800@0Re:800<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2?0?oooaP02NX:k03oool0
02d0oooo0P0000000`3oool000000?ooo`0T0?ooo`030000002;DXP0Re:800@0Re:80P0000040?oo
o`030000003oool0oooo08/0oooo6@09jP[_0?ooo`00;03oool01@000000oooo0?ooo`3oool00000
02@0oooo00<0000008]BR02;DXP01@2;DXP00`000000oooo000000040?ooo`030000003oool0oooo
08D0oooo7009jP[a0?ooo`00;03oool01@000000oooo0?ooo`3oool0000002@0oooo00<0000008]B
R02;DXP01@2;DXP010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0800oooo7@09jP[d
0?ooo`00;03oool010000000oooo0?ooo`00000T0?ooo`030000002;DXP0Re:800D0Re:800D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo07X0oooo8009jP[f0?ooo`00:`3oool0
1@000000oooo0?ooo`3oool0000002<0oooo00<0000008]BR02;DXP01P2;DXP00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0M03ooolS00WZ2_P0oooo000[
0?ooo`050000003oool0oooo0?ooo`0000008`3oool00`000000Re:808]BR00608]BR0030000003o
ool0oooo00<0oooo00@000000?ooo`3oool0oooo0`00001a0?ooo`@02NX:00<0oooo00WZ2P09jPX0
7@09jP[k0?ooo`00:`3oool01@000000oooo0?ooo`3oool000000280oooo00<0000008]BR02;DXP0
1`2;DXP00`000000oooo0?ooo`040?ooo`<000000P3oool00`000000oooo0?ooo`1Z0?ooo`D02NX:
00<0oooo00WZ2P09jPX07`09jP[m0?ooo`00:`3oool01@000000oooo0?ooo`3oool000000280oooo
00<0000008]BR02;DXP01`2;DXP00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0I@3oool400WZ2P030?ooo`09jPX02NX:02802NX:o`3oool002/0oooo00@0
00000?ooo`3oool000008P3oool00`000000Re:808]BR00808]BR0030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1O0?ooo`D02NX:00<0oooo00WZ2P09jPX0
9009jP[o0?ooo`80oooo000Z0?ooo`050000003oool0oooo0?ooo`0000008P3oool00`000000Re:8
08]BR00808]BR0030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1J0?ooo`D02NX:0P3ooolW00WZ2_l0oooo1@3oool002X0oooo00D000000?ooo`3oool0oooo
0000000Q0?ooo`030000002;DXP0Re:800T0Re:800<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo05D0oooo1009jPX20?ooobX02NX:o`3oool70?ooo`00:P3o
ool01@000000oooo0?ooo`3oool000000200oooo00<0000008]BR02;DXP02P2;DXP00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0D03oool500WZ2P80oooo
;009jP[o0?ooo`T0oooo000Z0?ooo`050000003oool0oooo0?ooo`000000803oool00`000000Re:8
08]BR00:08]BR0030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1;0?ooo`@02NX:0`3oool]00WZ2_l0oooo303oool002X0oooo00@000000?ooo`3oool00000
803oool00`000000Re:808]BR00;08]BR0030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`150?ooo`D02NX:0`3oool_00WZ2_l0oooo3P3oool002T0oooo00D0
00000?ooo`3oool0oooo0000000P0?ooo`030000002;DXP0Re:800/0Re:800<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo1@09jPX30?oooc802NX:
o`3oool@0?ooo`00:@3oool00`000000oooo00000003000001h0oooo00<0000008]BR02;DXP0302;
DXP00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>`3o
ool400WZ2P@0oooo1@09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:02<02NX:o`3o
oolC0?ooo`00:@3oool200000080Yl3[00<000000:O0j`000000703oool00`000000Re:808]BR00=
08]BR0030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0f
0?ooo`D02NX:103oool500WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX09@09jP[o
0?oooaD0oooo000Y0?ooo`050000002W`>/0Yl3[0:O0j`0000000P2W`>/00`000000oooo0?ooo`0I
0?ooo`030000002;DXP0Re:800d0Re:800<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0340oooo1009jPX50?ooo`D02NX:00<0oooo00WZ2P09jPX01@09jPX0
0`3oool02NX:00WZ2P0W00WZ2_l0oooo5`3oool002T0oooo00D000000:O0j`2W`>/0Yl3[00000003
0:O0j`030000003oool0oooo01L0oooo00<0000008]BR02;DXP03P2;DXP00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:`3oool500WZ2P@0oooo1P09jPX0
0`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:02P02NX:o`3ooolJ0?ooo`00:@3oool01@00
0000Yl3[0:O0j`2W`>/0000000@0Yl3[00<000000?ooo`3oool05P3oool00`000000Re:808]BR00=
08]BR0030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0V
0?ooo`D02NX:1@3oool600WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX09009jPX0
0`3oool02NX:00WZ2P0300WZ2_l0oooo703oool002T0oooo00D000000:O0j`2W`>/0Yl3[00000005
0:O0j`030000003oool0oooo01@0oooo00<0000008]BR02;DXP03P2;DXP00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00<000008`3oool400WZ2PH0oooo1@09jPX20?ooo`L02NX:0P3oool]
00WZ2_l0oooo7P3oool002T0oooo0P0000020:O0j`030000002W`>/0Yl3[00@0Yl3[0P00000D0?oo
o`030000002;DXP0Re:800h0Re:800<000000?ooo`3oool03`3oool200000080oooo00<000000?oo
o`3oool0703oool500WZ2PD0oooo1P09jPX20?ooo`L02NX:0P3ooolX00WZ2P030?ooo`09jPX02NX:
00<02NX:o`3ooolQ0?ooo`00:@3oool200000080Yl3[00<000000:O0j`2W`>/01P2W`>/00`000000
oooo0?ooo`0A0?ooo`030000002;DXP0Re:800h0Re:800<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo1009jPX60?ooo`H02NX:0P3oool700WZ2P80
oooo:P09jPX00`3oool02NX:00WZ2P0300WZ2_l0oooo8`3oool002T0oooo0P0000020:O0j`030000
002W`>/0Yl3[00L0Yl3[00<000000?ooo`3oool03`3oool00`000000Re:808]BR00?08]BR0030000
003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000D0?ooo`D02NX:1P3oool600WZ2P80
oooo1`09jPX20?ooob/02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2_l0oooo9@3oool002T0
oooo0P0000020:O0j`030000002W`>/0Yl3[00P0Yl3[00<000000?ooo`3oool03P3oool00`000000
Re:808]BR00?08]BR0030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000?0?oo
o`D02NX:1`3oool500WZ2P<0oooo2009jPX20?ooob`02NX:00<0oooo00WZ2P09jPX01009jP[o0?oo
obL0oooo000Y0?ooo`8000000P2W`>/00`000000Yl3[0:O0j`090:O0j`030000003oool0oooo00d0
oooo00<0000008]BR02;DXP03`2;DXP00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool400WZ2PL0oooo1P09jPX30?ooo`P02NX:0P3oool]00WZ2P03
0?ooo`09jPX02NX:00@02NX:o`3ooolZ0?ooo`00:@3oool200000080Yl3[00<000000:O0j`2W`>/0
2P2W`>/00`000000oooo0?ooo`0;0?ooo`030000002;DXP0Re:80100Re:800<000000?ooo`3oool0
4@3oool01@000000oooo0?ooo`3oool0000000D0oooo1@09jPX70?ooo`H02NX:0`3oool800WZ2P80
oooo;`09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:o`3oool/0?ooo`00:@3oool200000080
Yl3[00<000000:O0j`2W`>/02`2W`>/00`000000oooo0?ooo`0:0?ooo`030000002;DXP0Re:80100
Re:800<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`0300000009jPX02NX:0080
2NX:203oool600WZ2P80oooo2@09jPX20?oooc002NX:00<0oooo00WZ2P09jPX01@09jP[o0?ooobh0
oooo000Y0?ooo`8000000P2W`>/00`000000Yl3[0:O0j`0<0:O0j`8000002P3oool00`000000Re:8
08]BR00@08]BR0030000003oool0oooo0180oooo1@09jPX80?ooo`H02NX:0P3oool900WZ2P<0oooo
<@09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:o`3ooola0?ooo`00:@3oool200000080Yl3[
00<000000:O0j`2W`>/03P2W`>/00`000000oooo0?ooo`060?ooo`030000002;DXP0Re:80100Re:8
00<000000?ooo`3oool03P3oool500WZ2P030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P09jPX30?ooo`T02NX:0`3ooolb00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX0
o`3ooolc0?ooo`00:@3oool01@000000oooo0000002W`>/000000140Yl3[00<000000?ooo`3oool0
1@3oool00`000000Re:808]BR00@08]BR0030000003oool0oooo00X0oooo1009jPX60?ooo`030000
003oool0oooo00H02NX:0`3oool900WZ2P<0oooo<`09jPX20?ooo`L02NX:o`3ooole0?ooo`00:@3o
ool01@000000oooo0000002W`>/000000180Yl3[00<000000?ooo`3oool0103oool00`000000Re:8
08]BR00@08]BR0030000003oool0oooo00D0oooo1@09jPX90?ooo`H02NX:0`3oool900WZ2P<0oooo
=@09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX0o`3ooolh0?ooo`00:@3oool01@000000oooo0000
002W`>/0000001<0Yl3[00<000000?ooo`3oool00P3oool00`000000Re:808]BR00A08]BR0040000
003oool0oooo0?ooo`@02NX:2@3oool700WZ2P<0oooo2@09jPX40?oooc402NX:00@0oooo00WZ2P09
jPX02NX:0P3oool400WZ2P030?ooo`09jPX02NX:0?l0oooo>P3oool002T0oooo00<000000?ooo`00
00000P00000D0:O0j`050000003oool0oooo0?ooo`0000004P2;DXP500WZ2PT0oooo1P09jPX40?oo
o`@02NX:00<0oooo00WZ2P09jPX00P09jPX40?ooocL02NX:0P3oool300WZ2P040?ooo`09jPX02NX:
00WZ2_l0oooo?03oool002T0oooo0`0000000`2W`>/000000:O0j`0D0:O0j`040000003oool0oooo
000000d0Re:81@09jPX00`2;DXP000000?ooo`070?ooo`H02NX:103oool400WZ2P030?ooo`09jPX0
2NX:00802NX:00@0oooo0000003oool0oooo>009jPX20?ooo`@02NX:00<0oooo00WZ2P09jPX0o`3o
oolo0?ooo`00:@3oool01@000000oooo0000002W`>/0000001H0Yl3[0P00000<08]BR0802NX:1P2;
DXP00`000000oooo0?ooo`020?ooo`H02NX:103oool400WZ2P030?ooo`09jPX02NX:00802NX:00@0
oooo0000003oool0oooo3`09jPX00`3oool02NX:00WZ2P0S00WZ2P030?ooo`09jPX02NX:00802NX:
0P3oool300WZ2P80oooo0P09jP[o0?oood40oooo000Y0?ooo`030000003oool0oooo008000005`2W
`>/00`000000Re:808]BR00B08]BR00300000009jPX02NX:00@02NX:103oool400WZ2P030?ooo`09
jPX02NX:00802NX:103ooolk00WZ2P80oooo1009jPX0103oool02NX:00WZ2P09jP[o0?oood<0oooo
000Y0?ooo`060000003oool0oooo0000002W`>/000005`2W`>/00`000000Re:808]BR00=08]BR0L0
2NX:103oool400WZ2P030?ooo`09jPX02NX:00<02NX:103oool?00WZ2P030?ooo`09jPX02NX:02D0
2NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`@02NX:00<0oooo00WZ2P09jPX0o`3ooom60?ooo`00
:P3oool00`000000oooo0?ooo`02000001P0Yl3[00<0000008]BR02;DXP02P2;DXP400WZ2P80Re:8
00<000000?ooo`3oool01009jPX00`3oool02NX:00WZ2P0300WZ2P@0oooo>009jPX00`3oool02NX:
00WZ2P0200WZ2P<0oooo0`09jPX20?ooo`802NX:o`3ooom80?ooo`00:P3oool00`000000oooo0?oo
o`02000001T0Yl3[00<0000008]BR02;DXP01`2;DXP200WZ2PD0Re:800D02NX:00000009jPX02NX:
0?ooo`0500WZ2P@0oooo4009jPX00`3oool02NX:00WZ2P0W00WZ2P030?ooo`09jPX02NX:00802NX:
0P3oool400WZ2P040?ooo`09jPX02NX:00WZ2_l0ooooBP3oool002X0oooo00D000000?ooo`3oool0
oooo0000000J0:O0j`030000002;DXP0Re:800/0Re:80P09jPX00`2;DXP02NX:00WZ2P0300WZ2P@0
oooo4@09jPX00`0000002NX:00WZ2P0W00WZ2P030?ooo`09jPX02NX:00802NX:0`3oool300WZ2P80
oooo0P09jP[o0?ooodd0oooo000Z0?ooo`050000003oool0oooo0?ooo`0000006`2W`>/2000000X0
Re:81@09jPX50?oooa002NX:00<0oooo00WZ2P09jPX0:009jPX00`3oool02NX:00WZ2P0200WZ2P<0
oooo1009jPX20?ooo`802NX:o`3ooom?0?ooo`00:P3oool010000000oooo0?ooo`3oool2000001`0
Yl3[00<0000008]BR02;DXP0102;DXP400WZ2P<0Re:800<000000?ooo`09jPX00`09jPX00`3oool0
2NX:00WZ2P0:00WZ2P030?ooo`09jPX02NX:00`02NX:00<0oooo00WZ2P09jPX06P09jPX00`3oool0
2NX:00WZ2P0200WZ2P<0oooo0`09jPX30?ooo`802NX:o`3ooomA0?ooo`00:P3oool01`000000oooo
0?ooo`3oool000000?ooo`000000702W`>/010000000Re:808]BR02;DXP200WZ2PH0Re:800<02NX:
00000009jPX02@09jPX01@3oool02NX:00WZ2P09jPX0oooo00l02NX:00<0oooo00WZ2P09jPX06P09
jPX00`3oool02NX:00WZ2P0200WZ2P<0oooo1009jPX20?ooo`<02NX:o`3ooomC0?ooo`00:P3oool0
0`000000oooo0?ooo`020?ooo`8000007@2W`>/00`000000Re:808]BR00608]BR0l02NX:00<0oooo
00WZ2P09jPX03@09jPX00`0000002NX:00WZ2P0K00WZ2P030?ooo`09jPX02NX:00802NX:0`3oool4
00WZ2P80oooo0P09jP[o0?oooeH0oooo000[0?ooo`070000003oool0oooo0?ooo`000000oooo0000
000M0:O0j`030000002;DXP0Re:800@0Re:81009jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:
00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0900WZ2P030?ooo`09jPX02NX:01/02NX:
00<0oooo00WZ2P09jPX00P09jPX30?ooo`@02NX:0`3oool200WZ2_l0ooooF03oool002/0oooo00L0
00000?ooo`3oool0oooo0000003oool0000001h0Yl3[00<0000008]BR02;DXP01009jPX208]BR003
00000009jPX02NX:00<02NX:00<0oooo00WZ2P09jPX0;009jPX20?ooo`@02NX:0`3oool400WZ2P80
oooo0`09jP[o0?oooeX0oooo000[0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
Yl3[0:O0j`0L0:O0j`8000001@2;DXP300WZ2P80oooo3`09jPX00`3oool02NX:00WZ2P0M00WZ2P03
0?ooo`09jPX02NX:00802NX:103oool300WZ2P<0oooo0P09jP[o0?oooed0oooo000[0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000Yl3[0:O0j`0N0:O0j`030000002;DXP0Re:80080
2NX:00<0Re:800WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0900WZ2P030?ooo`09jPX02NX:01d0
2NX:00<0oooo00WZ2P09jPX00`09jPX30?ooo`@02NX:0`3oool200WZ2_l0ooooG`3oool002/0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000002W`>/0Yl3[01h0Yl3[00<0000008]BR009
jPX00`09jPX00`3oool02NX:00WZ2P0900WZ2P030?ooo`09jPX02NX:01d02NX:0P3oool400WZ2P@0
oooo1009jPX20?ooo`<02NX:o`3ooomQ0?ooo`00:`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000:O0j`2W`>/07@2W`>/200WZ2P050000002;DXP0Re:808]BR00000002@09jPX00`3o
ool02NX:00WZ2P0N00WZ2P030?ooo`09jPX02NX:00<02NX:0`3oool400WZ2P<0oooo0P09jP[o0?oo
of@0oooo000[0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000L0:O0
j`802NX:0`2W`>/00`000000Re:800WZ2P0700WZ2P030?ooo`09jPX02NX:00/02NX:00<0oooo00WZ
2P09jPX04009jPX20?ooo`@02NX:103oool400WZ2P<0oooo0P09jP[o0?ooofH0oooo000/0?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000Yl3[0:O0j`0M0:O0j`802NX:00@0000000WZ
2P09jPX02NX:0`3oool=00WZ2P030?ooo`09jPX02NX:01002NX:0P3oool400WZ2P@0oooo1009jPX3
0?ooo`<02NX:o`3ooomX0?ooo`00;03oool00`000000oooo00000002000000D0oooo00<000000:O0
j`2W`>/06P2W`>/500WZ2P80000000<0oooo00WZ2P09jPX02`09jPX00`3oool02NX:00WZ2P0A00WZ
2P030?ooo`0000002NX:00<02NX:103oool400WZ2P<0oooo0P09jP[o0?ooof/0oooo000/0?ooo`80
00000P3oool00`000000oooo0?ooo`040?ooo`030000002W`>/0Yl3[01P0Yl3[0`09jPX40:O0j`80
00002P09jPX00`3oool02NX:00WZ2P0A00WZ2P030000003oool02NX:00<02NX:103oool400WZ2P@0
oooo0P09jP[o0?ooofd0oooo000/0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000
Yl3[0:O0j`0E0:O0j`802NX:1@2W`>/00`2;DXP02NX:00WZ2P0800WZ2P030?ooo`09jPX02NX:0140
2NX:0P3oool500WZ2P040?ooo`000000oooo0?ooo`@02NX:0`3oool300WZ2_l0ooooK`3oool002`0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000002W`>/0Yl3[01P0
Yl3[00<0Re:800WZ2P09jPX01009jPX01@2W`>/02NX:00WZ2P09jPX0oooo01@02NX:0P3oool400WZ
2P030000003oool00000008000001009jPX30?ooo`802NX:o`3ooomb0?ooo`00;@3oool01@000000
oooo0?ooo`3oool0000000P0oooo00<000000:O0j`2W`>/0502W`>/208]BR0D02NX:00D0Re:80000
0009jPX02NX:0:O0j`0300WZ2P030?ooo`09jPX02NX:00h02NX:0P3oool500WZ2P80oooo0P000004
00WZ2P@0oooo0P09jP[o0?ooog@0oooo000]0?ooo`050000003oool0oooo0?ooo`0000002@3oool0
0`000000Yl3[0:O0j`0@0:O0j`@0Re:80`09jPX308]BR00300WZ2P0000002NX:00802NX:00<0Yl3[
00000009jPX03P09jPX30?ooo`@02NX:1@3oool400WZ2P040000003oool0oooo0?ooo`802NX:o`3o
oomf0?ooo`00;@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<00000
0:O0j`2W`>/02`2W`>/608]BR0802NX:1@2;DXP300WZ2P80Yl3[4009jPX20?ooo`D02NX:103oool4
00WZ2P<0oooo00@0000000WZ2P09jPX02NX:o`3ooomh0?ooo`00;P3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00<000000:O0j`2W`>/01`2W`>/=08]BR0<02NX:00@0Re:80000002W`>/0Yl3[
3P09jPX30?ooo`@02NX:1@3oool400WZ2P040?ooo`000000oooo0?ooo`802NX:00<000000?ooo`3o
ool0o`3ooomh0?ooo`00;P3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000:O0j`2W
`>/00`2W`>/?08]BR00300WZ2P2;DXP0Re:80080Re:800<0000000WZ2P09jPX01009jPX00`2W`>/0
2NX:0000000500WZ2P80oooo1@09jPX40?ooo`@02NX:1@3oool200WZ2P80oooo00<000000?ooo`3o
ool0o`3ooomh0?ooo`00;P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00<000000:O0j`2;DXP05P2;DXP400WZ2P<0Yl3[1@09jPX20?ooo`D02NX:1@3oool400WZ2P@0oooo
0`09jPX01@000000oooo0?ooo`3oool000000?l0ooooNP3oool002l0oooo00D000000?ooo`3oool0
oooo0000000;0?ooo`030000002;DXP0Re:801@0Re:80`09jPX30:O0j`D02NX:0P2W`>/00`000000
2NX:00WZ2P0200WZ2PD0oooo1@09jPX40?ooo`802NX:0`3oool01@000000oooo0?ooo`3oool00000
0?l0ooooNP3oool002l0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000002;DXP0Re:8
01<0Re:800@02NX:08]BR02;DXP000000P2W`>/400WZ2P80Yl3[1@09jPX50?ooo`@02NX:1@3oool2
00WZ2PD0oooo00D000000?ooo`3oool0oooo0000003o0?ooogX0oooo000_0?ooo`050000003oool0
oooo0?ooo`0000002`3oool00`000000Re:808]BR00F08]BR00400000009jPX02NX:00WZ2P@0Yl3[
0`09jPX20:O0j`040000003oool0oooo0?ooo`@02NX:103oool300WZ2PL0oooo00D000000?ooo`3o
ool0oooo0000003o0?ooogX0oooo000_0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000Re:808]BR00F08]BR00300WZ2P2W`>/0Yl3[00<0Yl3[0`09jPX50:O0j`04
00000009jPX02NX:00WZ2PD0oooo0P09jPX:0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0o`3ooomg0?ooo`00<03oool01@000000oooo0?ooo`3oool0000000X0oooo00<0000008]B
R02;DXP05P2;DXP00`000000Yl3[0:O0j`0300WZ2PH0Yl3[1009jPX00`000000oooo0?ooo`020?oo
o`802NX:3@3oool01@000000oooo0?ooo`3oool000000?l0ooooN@3oool00300oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`030000002;DXP0Re:801H0Re:800<000000:O0j`09jPX01P2W`>/4
00WZ2P@0Yl3[00@0000000WZ2P09jPX02NX:3`3oool01@000000oooo0?ooo`3oool000000?l0oooo
N@3oool00300oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000002;
DXP0Re:801H0Re:800<000000:O0j`2W`>/01@2W`>/300WZ2PD0Yl3[0P09jPX00`000000oooo0?oo
o`0?0?ooo`050000003oool0oooo0?ooo`000000o`3ooomi0?ooo`00<@3oool01@000000oooo0?oo
o`3oool0000000T0oooo00<0000008]BR02;DXP05P2;DXP00`000000Yl3[0:O0j`030:O0j`<02NX:
1@2W`>/200WZ2P<0Yl3[00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool000000?l0
ooooN@3oool00340oooo00D000000?ooo`3oool0oooo000000090?ooo`030000002;DXP0Re:801D0
Re:800<000000:O0j`2W`>/00`2W`>/00`09jPX0Yl3[0:O0j`030:O0j`<02NX:1P2W`>/00`000000
oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000o`3ooomi0?ooo`00<@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0000008]BR02;DXP05@2;DXP00`000000
Yl3[0:O0j`070:O0j`802NX:2P2W`>/00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0o`3ooomf0?ooo`00<P3oool00`000000oooo00000002000000P0oooo
00<0000008]BR02;DXP05@2;DXP00`000000Yl3[0:O0j`060:O0j`0300WZ2P2W`>/0Yl3[00/0Yl3[
00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000?l0ooooN03oool00380oooo
0P0000020?ooo`030000003oool0oooo00H0oooo00<0000008]BR02;DXP05@2;DXP00`000000Yl3[
0:O0j`0E0:O0j`030000003oool0oooo00/0oooo00<000000?ooo`0000000P00003o0?ooogP0oooo
000b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000Re:808]B
R00E08]BR0030000002W`>/0Yl3[01H0Yl3[00<000000?ooo`3oool02P3oool200000080oooo00<0
00000?ooo`3oool0o`3ooomf0?ooo`00<`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<0
000008]BR02;DXP05@2;DXP00`000000Yl3[0:O0j`0G0:O0j`030000003oool0oooo00T0oooo00D0
00000?ooo`3oool0oooo0000003o0?ooogP0oooo000c0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000Re:808]BR00E08]BR0030000002W`>/0Yl3[01P0Yl3[00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000?l0ooooN03oool003<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000002;DXP0Re:801D0Re:80P00
000J0:O0j`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000003o0?ooogP0oooo
000d0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000Re:808]B
R00E08]BR0030000003oool0000000800000602W`>/2000000L0oooo00D000000?ooo`3oool0oooo
0000003o0?ooogP0oooo000d0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000Re:808]BR00E08]BR0030000003oool0oooo0080oooo0P00000H0:O0j`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo0000003o0?ooogP0oooo000e0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000Re:808]BR00E08]BR0030000003o
ool0oooo00@0oooo0P00000G0:O0j`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
0000003o0?ooogP0oooo000e0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000Re:808]BR00E08]BR0030000003oool0oooo00H0oooo0P00000F0:O0j`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo0000003o0?ooogP0oooo000f0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo0000000G08]BR0030000003oool0oooo00P0oooo
0P00000E0:O0j`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`3o0?ooogD0
oooo000f0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000G08]BR003
0000003oool0oooo00X0oooo0P00000D0:O0j`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0o`3ooome0?ooo`00=P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000005`2;DXP00`000000oooo0?ooo`0<0?ooo`<000004P2W`>/3000000@0oooo00<000000?oo
o`3oool0o`3ooome0?ooo`00=`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000005P2;DXP00`000000oooo0?ooo`0?0?ooo`<000004@2W`>/00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0?l0ooooM@3oool003L0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000001H0Re:800<000000?ooo`3oool04P3oool3000000l0Yl3[00D000000?oo
o`3oool0oooo0000003o0?ooogL0oooo000h0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000005@2;DXP00`000000oooo0?ooo`0F0?ooo`<000003@2W`>/010000000oooo0?ooo`00
003o0?ooogL0oooo000h0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
000D08]BR0030000003oool0oooo01T0oooo0P00000<0:O0j`030000003oool000000?l0ooooM`3o
ool003T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000D08]BR0030000003o
ool0oooo01/0oooo0`00000:0:O0j`800000o`3ooomg0?ooo`00>@3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000001@0Re:800<000000?ooo`3oool07P3oool3000000L0Yl3[0P00
003o0?ooogL0oooo000i0?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000Re:808]B
R00A08]BR0030000003oool0oooo0240oooo0`0000001P2W`>/00000000000000000oooo00000?l0
ooooM`3oool003X0oooo0`0000020?ooo`040000003oool0oooo000001<0Re:800<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooM@3oool003X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0000000C08]BR0030000003oool0oooo02@0oooo
00D000000?ooo`3oool0oooo0000003o0?ooogP0oooo000k0?ooo`030000003oool0oooo00<0oooo
0P00000C08]BR0030000003oool0oooo02@0oooo00D000000?ooo`3oool0oooo0000003o0?ooogP0
oooo000l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000004P2;DXP00`000000oooo
0?ooo`0T0?ooo`050000003oool0oooo0?ooo`000000o`3ooomh0?ooo`00?03oool00`000000oooo
0?ooo`030?ooo`8000004P2;DXP00`000000oooo0?ooo`0T0?ooo`050000003oool0oooo0?ooo`00
0000o`3ooomh0?ooo`00?@3oool00`000000oooo0?ooo`020?ooo`8000004P2;DXP00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooomf0?ooo`00?@3o
ool00`000000oooo0?ooo`030?ooo`8000004@2;DXP00`000000oooo0?ooo`0S0?ooo`050000003o
ool0oooo0?ooo`000000o`3ooomi0?ooo`00?P3oool00`000000oooo0?ooo`030?ooo`030000002;
DXP0Re:800l0Re:800<000000?ooo`3oool08`3oool01@000000oooo0?ooo`3oool000000?l0oooo
N@3oool003l0oooo00<000000?ooo`3oool00P3oool00`000000Re:808]BR00?08]BR0030000003o
ool0oooo02<0oooo00D000000?ooo`3oool0oooo0000003o0?ooogT0oooo000o0?ooo`030000003o
ool0oooo00<0oooo00<0000008]BR02;DXP03P2;DXP00`000000oooo0?ooo`0S0?ooo`050000003o
ool0oooo0?ooo`000000o`3ooomi0?ooo`00@03oool00`000000oooo0?ooo`020?ooo`8000003`2;
DXP00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`000000o`3ooomi0?ooo`00@@3o
ool010000000oooo0?ooo`3oool2000000h0Re:800<000000?ooo`3oool0903oool010000000oooo
0?ooo`00003o0?ooogX0oooo00110?ooo`030000003oool0oooo0080oooo0P00000=08]BR0030000
003oool0oooo02<0oooo00D000000?ooo`3oool0oooo0000003o0?ooogX0oooo00120?ooo`030000
003oool0oooo0080oooo00<0000008]BR02;DXP02`2;DXP00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00800000o`3ooomj0?ooo`00@P3oool00`000000oooo0?ooo`020?ooo`800000302;
DXP00`000000oooo0?ooo`0S0?ooo`<0000000<0oooo0000003oool0o`3ooomi0?ooo`00@`3oool0
10000000oooo0?ooo`3oool3000000/0Re:800<000000?ooo`3oool08`3oool010000000oooo0?oo
o`00003o0?ooog/0oooo00140?ooo`<0000000<0oooo0000000000002`2;DXP00`000000oooo0?oo
o`0S0?ooo`040000003oool0oooo00000?l0ooooN`3oool004D0oooo00@000000?ooo`3oool0oooo
0P00000:08]BR0030000003oool0oooo0280oooo00D000000?ooo`3oool0oooo0000003o0?ooog/0
oooo00160?ooo`040000003oool0oooo0?ooo`8000002@2;DXP00`000000oooo0?ooo`0R0?ooo`04
0000003oool0oooo00000?l0ooooO03oool004L0oooo00H000000?ooo`3oool0000008]BR0000008
08]BR0030000003oool0oooo0240oooo00D000000?ooo`3oool0oooo0000003o0?ooog`0oooo0018
0?ooo`060000003oool0oooo0000002;DXP000001`2;DXP00`000000oooo0?ooo`0Q0?ooo`040000
003oool0oooo00000?l0ooooO@3oool004T0oooo00<000000?ooo`0000000P2;DXP00`000000Re:8
08]BR00408]BR0030000003oool0oooo0200oooo00D000000?ooo`3oool0oooo0000003o0?ooogd0
oooo001:0?ooo`030000003oool000000080Re:800<0000008]BR02;DXP00P2;DXP00`000000oooo
0?ooo`0Q0?ooo`040000003oool0oooo00000?l0ooooOP3oool004/0oooo00<000000?ooo`000000
0P2;DXP01@000000Re:808]BR02;DXP0000002<0oooo00@000000?ooo`3oool00000o`3ooomn0?oo
o`00C03oool2000000<0Re:800@0000008]BR02;DXP000008P3oool01@000000oooo0?ooo`3oool0
00000?l0ooooOP3oool004d0oooo0P00000308]BR0030000002;DXP000000280oooo1000003o0?oo
ogl0oooo001>0?ooo`030000002;DXP0Re:80080Re:80P00000Q0?ooo`8000000P3oool00`000000
oooo0?ooo`3o0?ooogd0oooo001?0?ooo`030000002;DXP0Re:800@00000803oool010000000oooo
0?ooo`00003o0?oooh00oooo001@0?ooo`800000103oool00`000000oooo0?ooo`0L0?ooo`040000
003oool0oooo00000?l0ooooP@3oool00580oooo00<000000?ooo`3oool00P3oool2000001/0oooo
00@000000?ooo`3oool00000o`3ooon20?ooo`00D`3oool2000000@0oooo0P00000H0?ooo`040000
003oool0oooo00000?l0ooooP`3oool005D0oooo0P0000040?ooo`030000003oool0oooo01@0oooo
00@000000?ooo`3oool00000o`3ooon40?ooo`00E`3oool00`000000oooo0?ooo`020?ooo`800000
4`3oool010000000oooo0?ooo`00003o0?ooohD0oooo001H0?ooo`800000103oool00`000000oooo
0?ooo`0?0?ooo`@00000o`3ooon60?ooo`00FP3oool00`000000oooo0?ooo`06000000/0oooo1000
003o0?ooohP0oooo001K0?ooo`@00000103oool5000000<0oooo1000003o0?oooh/0oooo001O0?oo
o`D00000103oool400000?l0ooooSP3oool006@0oooo1000003o0?oooi80oooo003o0?ooooX0oooo
003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo
003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo
003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo
003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo
003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo
003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo
003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo
003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo003o0?ooooX0oooo0000\
\>"],
  ImageRangeCache->{{{0, 504}, {356.125, 0}} -> {0.0181863, 0.131042, \
0.00194899, 0.00194899}}]
}, Open  ]],

Cell[TextData[{
  "You can use ",
  StyleBox["RayLineRGB -> False", "Input"],
  " to remove the ray line segments from the plot and retain only the \
intercept points."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[imagefocus, RayLineRGB -> False, RayPointSize -> \
4];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70727 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0190131 1.01901 -0.133537 1.01901 [
[ 0 0 0 0 ]
[ 1 .70727 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .70727 L
0 .70727 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.23156 .44497 m
.21646 .41057 L
s
.23962 .44237 m
.23156 .44497 L
s
.24252 .48152 m
.23156 .44497 L
s
.24866 .51806 m
.24252 .48152 L
s
.24252 .48152 m
.25059 .47897 L
s
.22452 .40792 m
.23962 .44237 L
s
.23962 .44237 m
.25059 .47897 L
s
.25059 .47897 m
.25677 .51554 L
s
.21646 .41057 m
.22452 .40792 L
s
.21646 .41057 m
.19807 .3804 L
s
.20615 .37771 m
.22452 .40792 L
s
.24866 .51806 m
.25677 .51554 L
s
.19807 .3804 m
.20615 .37771 L
s
.19854 .53614 m .25774 .54988 L .24958 .55237 L .656 .751 .92 r
F
0 g
.24866 .51806 m
.24946 .54796 L
s
.24512 .58233 m
.24958 .55237 L
s
.19854 .53614 m .23135 .52595 L .25774 .54988 L .656 .751 .92 r
F
0 g
.25334 .57985 m
.25774 .54988 L
s
.25677 .51554 m
.25774 .54988 L
s
.24958 .55237 m
.25774 .54988 L
s
.17748 .35638 m .1827 .39379 L .14999 .40464 L .544 .324 .532 r
F
.17748 .35638 m .1856 .35364 L .1827 .39379 L F
0 g
.18479 .3649 m
.19807 .3804 L
s
.17748 .35638 m
.1856 .35364 L
s
.1856 .35364 m
.20615 .37771 L
s
.15591 .34013 m
.17748 .35638 L
s
.16409 .33734 m
.1856 .35364 L
s
.15793 .51611 m .23135 .52595 L .19854 .53614 L .656 .751 .92 r
F
0 g
.19854 .53614 m
.24958 .55237 L
s
.23542 .60592 m
.24512 .58233 L
s
.24512 .58233 m
.25334 .57985 L
s
.25334 .57985 m
.24372 .60345 L
s
.14999 .40464 m .17974 .43471 L .13339 .44982 L .544 .324 .532 r
F
.14999 .40464 m .1827 .39379 L .17974 .43471 L F
0 g
.14999 .40464 m
.17748 .35638 L
s
.1827 .39379 m
.1856 .35364 L
s
.15793 .51611 m .20435 .50147 L .23135 .52595 L .656 .751 .92 r
F
0 g
.23135 .52595 m
.25774 .54988 L
s
.15591 .34013 m
.16409 .33734 L
s
.15591 .34013 m
.13474 .33294 L
s
.14298 .33011 m
.16409 .33734 L
s
.12567 .49277 m .20435 .50147 L .15793 .51611 L .656 .751 .92 r
F
0 g
.15793 .51611 m
.19854 .53614 L
s
.22096 .62143 m
.23542 .60592 L
s
.23542 .60592 m
.24372 .60345 L
s
.13339 .44982 m .17673 .47642 L .12567 .49277 L .544 .324 .532 r
F
.13339 .44982 m .17974 .43471 L .17673 .47642 L F
0 g
.13339 .44982 m
.14999 .40464 L
s
.17974 .43471 m
.1827 .39379 L
s
.24372 .60345 m
.22934 .61894 L
s
.12567 .49277 m .17673 .47642 L .20435 .50147 L .656 .751 .92 r
F
0 g
.20435 .50147 m
.23135 .52595 L
s
.13474 .33294 m
.14298 .33011 L
s
.13474 .33294 m
.11537 .33559 L
s
.12368 .33273 m
.14298 .33011 L
s
.12567 .49277 m .17365 .51896 L .12644 .53378 L .544 .324 .532 r
F
.12567 .49277 m .17673 .47642 L .17365 .51896 L F
.10133 .46611 m .17673 .47642 L .12567 .49277 L .656 .751 .92 r
F
0 g
.12976 .47 m
.13339 .44982 L
s
.20255 .62752 m
.22096 .62143 L
s
.22096 .62143 m
.22934 .61894 L
s
.22934 .61894 m
.21101 .62502 L
s
.10133 .46611 m .14845 .45078 L .17673 .47642 L .656 .751 .92 r
F
0 g
.17673 .47642 m
.17974 .43471 L
s
.17673 .47642 m
.20435 .50147 L
s
.12644 .53378 m .17052 .56233 L .13659 .57277 L .544 .324 .532 r
F
.12644 .53378 m .17365 .51896 L .17052 .56233 L F
0 g
.12567 .49277 m
.12644 .53378 L
s
.17365 .51896 m
.17673 .47642 L
s
.11537 .33559 m
.09921 .34823 L
s
.12368 .33273 m
.11537 .33559 L
s
.1076 .34535 m
.12368 .33273 L
s
.08569 .43571 m .14845 .45078 L .10133 .46611 L .656 .751 .92 r
F
0 g
.10133 .46611 m
.12567 .49277 L
s
.18133 .62345 m
.20255 .62752 L
s
.20255 .62752 m
.21101 .62502 L
s
.21101 .62502 m
.18986 .62091 L
s
.08569 .43571 m .1195 .42453 L .14845 .45078 L .656 .751 .92 r
F
0 g
.14845 .45078 m
.17673 .47642 L
s
.09921 .34823 m
.1076 .34535 L
s
.09921 .34823 m
.08752 .37031 L
s
.13659 .57277 m .16732 .60657 L .15874 .60916 L .544 .324 .532 r
F
.13659 .57277 m .17052 .56233 L .16732 .60657 L F
0 g
.12644 .53378 m
.13659 .57277 L
s
.13659 .57277 m
.15874 .60916 L
s
.17052 .56233 m
.17365 .51896 L
s
.09599 .36743 m
.1076 .34535 L
s
.15874 .60916 m
.18133 .62345 L
s
.18133 .62345 m
.18986 .62091 L
s
.08131 .40052 m .1195 .42453 L .08569 .43571 L .656 .751 .92 r
F
0 g
.08569 .43571 m
.10133 .46611 L
s
.16732 .60657 m
.18986 .62091 L
s
.16732 .60657 m
.17052 .56233 L
s
.08131 .40052 m .08985 .39765 L .1195 .42453 L .656 .751 .92 r
F
0 g
.08985 .39765 m
.1195 .42453 L
s
.1195 .42453 m
.14845 .45078 L
s
.08131 .40052 m
.08569 .43571 L
s
.08752 .37031 m
.09599 .36743 L
s
.08131 .40052 m
.08752 .37031 L
s
.08985 .39765 m
.09599 .36743 L
s
.1364 .58539 m
.15874 .60916 L
s
.15874 .60916 m
.16732 .60657 L
s
.14503 .58275 m
.16732 .60657 L
s
.08131 .40052 m
.08985 .39765 L
s
.0812 .43678 m
.08131 .40052 L
s
.08979 .43394 m
.08985 .39765 L
s
.11603 .55372 m
.1364 .58539 L
s
.1364 .58539 m
.14503 .58275 L
s
.14503 .58275 m
.12468 .55103 L
s
.0812 .43678 m
.08979 .43394 L
s
.0812 .43678 m
.0873 .47644 L
s
.09593 .47364 m
.08979 .43394 L
s
.09921 .51646 m
.11603 .55372 L
s
.11603 .55372 m
.12468 .55103 L
s
.12468 .55103 m
.10787 .51371 L
s
.0873 .47644 m
.09593 .47364 L
s
.0873 .47644 m
.09921 .51646 L
s
.09921 .51646 m
.10787 .51371 L
s
.10787 .51371 m
.09593 .47364 L
s
0 0 0 r
4 Mabswid
.87316 .25066 Mdot
.88213 .25344 Mdot
.87889 .24401 Mdot
.88777 .25746 Mdot
.88119 .23834 Mdot
.8879 .24679 Mdot
.89003 .2626 Mdot
.88007 .23378 Mdot
.89357 .25086 Mdot
.88886 .26874 Mdot
.8902 .2411 Mdot
.88425 .27574 Mdot
.87621 .28345 Mdot
.87557 .23042 Mdot
.89585 .2561 Mdot
.86777 .22836 Mdot
.88906 .23647 Mdot
.89589 .24518 Mdot
.85677 .22769 Mdot
.8947 .26237 Mdot
.8901 .26955 Mdot
.88452 .23301 Mdot
.88206 .27748 Mdot
.89818 .25047 Mdot
.89474 .24052 Mdot
.87664 .23081 Mdot
.86553 .22996 Mdot
.89704 .25683 Mdot
.89016 .23699 Mdot
.89244 .26414 Mdot
.89703 .24582 Mdot
.88441 .27223 Mdot
.88223 .23468 Mdot
.89589 .25222 Mdot
.87104 .23368 Mdot
.89243 .24225 Mdot
.89131 .25961 Mdot
.8833 .26782 Mdot
.88447 .23986 Mdot
.8913 .24865 Mdot
.87324 .23874 Mdot
.88674 .25607 Mdot
.87876 .26435 Mdot
.88333 .24622 Mdot
.87209 .24501 Mdot
.87879 .25362 Mdot
.87087 .26192 Mdot
.86758 .25235 Mdot
.85971 .2606 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{559, 395.312},
  ImageMargins->{{15, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008_0001Rb000`400?l00000o`00003oo`3ooooo
0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo
003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0
oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool0
0?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3o
oola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00
o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oo
oc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o
0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo
<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0
ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola
0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3o
oooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40
oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?oo
ool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3o
ool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0oooo
o`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?oo
o`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo
0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo
003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0
oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool0
0?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3o
oola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00
o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oo
oc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o
0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo
<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0
ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola
0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3o
oooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40
oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?oo
ool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3o
ool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0oooo
o`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?oo
o`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo
0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo
003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooN0?ooo`800000103oool20000
04X0oooo003o0?ooomd0oooo100000020?ooo`@0000000@0oooo0000000000000000A@3oool00?l0
oooog@3oool4000000030?ooo`000000000000P00000A03oool00?l0oooogP3oool200000080oooo
3@0000110?ooo`00o`3ooooS0?ooo`d00000@03oool00?l0ooooi@3oool4000000030?ooo`000000
000000L00000?@3oool00?l0ooooiP3oool300000080oooo2@00000l0?ooo`00o`3ooooV0?ooo`@0
000000<0oooo0000000000002000000k0?ooo`00o`3ooooV0?ooo`@0000000<0oooo000000000000
2@00000j0?ooo`00o`3ooooV0?ooo`<0000000<0oooo0000000000000`0000000`3oool000000000
0004000003X0oooo003o0?ooonD0oooo4P00000i0?ooo`00o`3ooooU0?oooa800000>@3oool00?l0
ooooiP3oool3000000030?ooo`000000000000/00000>@3oool00?l0ooooi03oool6000000<0oooo
2`00000h0?ooo`00o`3ooooS0?ooo`/000000`3oool7000003P0oooo003o0?ooon<0oooo5000000i
0?ooo`00o`3ooooT0?ooo`8000000`3oool>000003T0oooo003o0?ooonX0oooo3@00000i0?ooo`00
o`3ooooP0?ooo`800000303oool9000003T0oooo003o0?oooml0oooo100000030?ooo`8000001`3o
ool7000003X0oooo003o0?oooml0oooo100000020?ooo`@0000000<0oooo0000000000000`3oool7
000003X0oooo003o0?ooon00oooo0P0000030?ooo`P000000P3oool7000003X0oooo003o0?ooonH0
oooo0P0000000`3oool0000000000004000000030?ooo`000000000000<00000>`3oool00?l0oooo
jP3oool:000003`0oooo003o0?ooon`0oooo1`00000m0?ooo`00o`3oooo/0?ooo`L00000?@3oool0
0?l0ooook03oool6000003h0oooo003o0?ooon`0oooo100000100?ooo`00o`3oooo[0?ooo`D00000
@03oool00?l0ooooj`3oool400000440oooo003o0?ooon`0oooo0P0000120?ooo`00o`3ooooY0?oo
o`800000A@3oool00?l0ooooj03oool4000004@0oooo003o0?ooonP0oooo100000140?ooo`00o`3o
oooY0?ooo`800000A@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0
oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool0
0?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3o
oola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00
o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oo
oc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o
0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo001=0?ooo`D00000
o`3ooooN0?ooo`00B03oool6000000@0oooo0`00003o0?ooom/0oooo00130?ooo`/000001`3oool3
00000?l0oooof03oool003l0oooo1`0000080?ooo`<000001`3oool300000?l0ooooe@3oool003h0
oooo00D000000?ooo`3oool0oooo0000000>0?ooo`<000001P3oool300000?l0ooood`3oool003d0
oooo00<000000?ooo`3oool00P00000B0?ooo`<0000000<0oooo0000000000000`3oool00`000000
oooo0?ooo`3o0?ooom00oooo000k0?ooo`8000000P3oool00`000000oooo0?ooo`0E0?ooo`800000
1@3oool00`000000oooo0?ooo`3o0?oooll0oooo000j0?ooo`050000003oool0oooo0?ooo`000000
6P3oool00`000000oooo0?ooo`030?ooo`800000o`3oooo?0?ooo`00>@3oool01@000000oooo0?oo
o`3oool0000001`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oool`0oooo
000h0?ooo`030000003oool00000008000007P3oool2000000D0oooo00<000000?ooo`3oool0o`3o
ooo;0?ooo`00=`3oool300000080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`03
0?ooo`800000o`3oooo;0?ooo`00=`3oool01@000000oooo0?ooo`3oool000000280oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooolP0oooo000f0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool08@3oool2000000D0oooo00<000000?ooo`3oool0o`3oooo70?oo
o`00=P3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool00P3oool20000
0?l0oooob03oool003D0oooo00D000000?ooo`3oool0oooo0000000X0?ooo`060000003oool00000
0000002;DXP00000o`3oooo80?ooo`00=@3oool01@000000oooo0?ooo`3oool0000002T0oooo00@0
000008]BR02;DXP0Re:80P00003o0?ooolL0oooo000d0?ooo`050000003oool0oooo0?ooo`000000
:P3oool01`000000Re:808]BR02;DXP000000?ooo`000000o`3oooo60?ooo`00=03oool01@000000
oooo0?ooo`3oool0000002T0oooo00<0000008]BR02;DXP00P2;DXP010000000oooo0?ooo`00003o
0?ooolD0oooo000d0?ooo`040000003oool0oooo000002X0oooo00<0000008]BR02;DXP00P2;DXP0
1@000000oooo0?ooo`3oool000000?l0ooooa03oool003<0oooo00@000000?ooo`3oool00000:P3o
ool00`000000Re:808]BR00308]BR0030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3o
ooo10?ooo`00<`3oool010000000oooo0?ooo`00000Y0?ooo`030000002;DXP0Re:800@0Re:800<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oool00oooo000b0?ooo`040000003oool0
0000000002X0oooo00<0000008]BR02;DXP0102;DXP00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0?l0oooo`03oool00380oooo0P0000000`3oool000000?ooo`0X0?ooo`030000002;DXP0
Re:800D0Re:80P0000050?ooo`030000003oool0oooo0?l0oooo_`3oool00340oooo00D000000?oo
o`3oool0oooo0000000Y0?ooo`030000002;DXP0Re:800D0Re:800<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`3o0?oookh0oooo000a0?ooo`050000003oool0oooo0?ooo`000000:03oool0
0`000000Re:808]BR00608]BR0040000003oool0oooo000000D0oooo00<000000?ooo`3oool0o`3o
oonm0?ooo`00<@3oool010000000oooo0?ooo`00000X0?ooo`030000002;DXP0Re:800H0Re:800<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo_03o
ool00300oooo00D000000?ooo`3oool0oooo0000000X0?ooo`030000002;DXP0Re:800H0Re:800<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo^`3o
ool00300oooo00D000000?ooo`3oool0oooo0000000W0?ooo`030000002;DXP0Re:800L0Re:800<0
00000?ooo`3oool0103oool010000000oooo0?ooo`3oool300000?l0oooo_03oool00300oooo00D0
00000?ooo`3oool0oooo0000000W0?ooo`030000002;DXP0Re:800L0Re:800<000000?ooo`3oool0
1@3oool300000080oooo00<000000?ooo`3oool0o`3ooonj0?ooo`00<03oool01@000000oooo0?oo
o`3oool0000002H0oooo00<0000008]BR02;DXP0202;DXP00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oooni0?ooo`00;`3oool01@000000oooo0?oo
o`3oool0000002H0oooo00<0000008]BR02;DXP02@2;DXP00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0o`3oooni0?ooo`00;`3oool01@000000oooo0?oo
o`3oool0000002H0oooo00<0000008]BR02;DXP02@2;DXP00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooonh0?ooo`00;`3oool01@000000oooo0?oo
o`3oool0000002D0oooo00<0000008]BR02;DXP02P2;DXP00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooong0?ooo`00;`3oool01@000000oooo0?oo
o`3oool0000002D0oooo00<0000008]BR02;DXP02P2;DXP00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooong0?ooo`00;P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0280oooo00<0000008]BR02;DXP02`2;DXP00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooonf0?ooo`00;P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<0000008]BR02;DXP0302;DXP0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonf
0?ooo`00;P3oool01@000000oooo0?ooo`3oool0000002@0oooo00<0000008]BR02;DXP0302;DXP0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooone
0?ooo`00;P3oool01@000000oooo0?ooo`3oool0000002<0oooo00<0000008]BR02;DXP03@2;DXP0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooond
0?ooo`00;@3oool00`000000oooo0?ooo`0400000280oooo00<0000008]BR02;DXP03@2;DXP00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooond0?oo
o`00;@3oool300000080Yl3[00<000000:O0j`000000803oool00`000000Re:808]BR00>08]BR003
0000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oook<0
oooo000]0?ooo`030000002W`>/0Yl3[0080Yl3[00@000000:O0j`2W`>/000007P3oool00`000000
Re:808]BR00?08]BR0030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`3o0?oook<0oooo000]0?ooo`030000002W`>/0Yl3[0080Yl3[00D000000:O0j`2W`>/0
Yl3[0000000M0?ooo`030000002;DXP0Re:800l0Re:800<000000?ooo`3oool0303oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo/P3oool002d0oooo00<000000:O0j`2W`>/0
0P2W`>/00`000000Yl3[0:O0j`020:O0j`030000003oool0oooo01T0oooo00<0000008]BR02;DXP0
402;DXP00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
o`3ooona0?ooo`00;@3oool2000000<0Yl3[00<000000:O0j`2W`>/00`2W`>/00`000000oooo0?oo
o`0H0?ooo`030000002;DXP0Re:800l0Re:800<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0?l0oooo/@3oool002d0oooo0P0000030:O0j`030000002W`>/0
Yl3[00@0Yl3[00<000000?ooo`3oool05P3oool00`000000Re:808]BR00@08]BR0030000003oool0
oooo00l0oooo00@000000?ooo`3oool0oooo0`00003o0?oook80oooo000]0?ooo`8000000`2W`>/0
0`000000Yl3[0:O0j`050:O0j`030000003oool0oooo01D0oooo00<0000008]BR02;DXP0402;DXP0
0`000000oooo0?ooo`0@0?ooo`<000000P3oool00`000000oooo0?ooo`3o0?oook00oooo000]0?oo
o`8000000`2W`>/00`000000Yl3[0:O0j`060:O0j`030000003oool0oooo01@0oooo00<0000008]B
R02;DXP0402;DXP00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0o`3ooon_0?ooo`00;@3oool2000000<0Yl3[00<000000:O0j`2W`>/01`2W`>/00`000000
oooo0?ooo`0B0?ooo`030000002;DXP0Re:80140Re:800<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo[`3oool002d0oooo0P0000030:O0j`030000
002W`>/0Yl3[00P0Yl3[00<000000?ooo`3oool04@3oool00`000000Re:808]BR00A08]BR0030000
003oool0oooo0140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooojl0oooo
000]0?ooo`8000000`2W`>/00`000000Yl3[0:O0j`090:O0j`030000003oool0oooo0100oooo00<0
000008]BR02;DXP04@2;DXP00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3ooon^0?ooo`00;@3oool00`000000oooo000000020:O0j`030000002W`>/0
Yl3[00X0Yl3[00<000000?ooo`3oool03P3oool00`000000Re:808]BR00B08]BR0030000003oool0
oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooojh0oooo000]0?oo
o`030000003oool000000080Yl3[00<000000:O0j`2W`>/02`2W`>/00`000000oooo0?ooo`0=0?oo
o`030000002;DXP0Re:80180Re:800<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0?l0oooo[@3oool002d0oooo00<000000?ooo`0000000P2W`>/00`000000
Yl3[0:O0j`0<0:O0j`030000003oool0oooo00`0oooo00<0000008]BR02;DXP04P2;DXP00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooon]0?ooo`00
;@3oool00`000000oooo000000020:O0j`030000002W`>/0Yl3[00d0Yl3[0P00000;0?ooo`030000
002;DXP0Re:801<0Re:800<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0?l0oooo[03oool002d0oooo00<000000?ooo`0000000P2W`>/00`000000Yl3[0:O0
j`0?0:O0j`030000003oool0oooo00P0oooo00<0000008]BR02;DXP04P2;DXP00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooon/0?ooo`00;@3oool0
0`000000oooo000000020:O0j`030000002W`>/0Yl3[0100Yl3[00<000000?ooo`3oool01P3oool0
0`000000Re:808]BR00C08]BR0030000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo0000
003o0?ooojh0oooo000]0?ooo`030000003oool000000080Yl3[00<000000:O0j`2W`>/04@2W`>/0
0`000000oooo0?ooo`050?ooo`030000002;DXP0Re:801<0Re:800<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooZ`3oool002d0oooo00H000000?oo
o`3oool000000:O0j`00000D0:O0j`030000003oool0oooo00@0oooo00<0000008]BR02;DXP04`2;
DXP00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3o
oon[0?ooo`00;@3oool00`000000oooo0?ooo`03000001D0Yl3[00<000000?ooo`3oool00P3oool0
0`000000Re:808]BR00D08]BR0030000003oool0oooo01L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3o0?ooojX0oooo000]0?ooo`@0000000<0Yl3[0000002W`>/05@2W`>/01@00
0000oooo0?ooo`3oool0000001H0Re:800<000000?ooo`3oool05`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0?l0ooooZP3oool002d0oooo00H000000?ooo`3oool000000:O0j`00
000G0:O0j`80000000<0oooo0000002;DXP05@2;DXP00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0o`3ooonY0?ooo`00;@3oool010000000oooo0?ooo`3o
ool2000001T0Yl3[00<0000008]BR02;DXP05@2;DXP00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0o`3ooonY0?ooo`00;@3oool010000000oooo0?ooo`3o
ool2000001X0Yl3[00<0000008]BR02;DXP0502;DXP00`000000oooo0?ooo`0I0?ooo`050000003o
ool0oooo0?ooo`000000o`3ooon[0?ooo`00;@3oool00`000000oooo0?ooo`020?ooo`8000006P2W
`>/00`000000Re:808]BR00C08]BR0030000003oool0oooo01T0oooo00<000000?ooo`3oool00`00
003o0?ooojX0oooo000]0?ooo`030000003oool0oooo0080oooo0P00000K0:O0j`030000002;DXP0
Re:80180Re:800<000000?ooo`3oool06P3oool200000080oooo00<000000?ooo`3oool0o`3ooonX
0?ooo`00;P3oool00`000000oooo0?ooo`020?ooo`030000002W`>/0Yl3[01X0Yl3[00<0000008]B
R02;DXP04@2;DXP00`000000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`000000o`3ooonZ
0?ooo`00;P3oool00`000000oooo0?ooo`020?ooo`030000002W`>/0Yl3[01/0Yl3[00<0000008]B
R02;DXP03`2;DXP00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0o`3ooonW0?ooo`00;P3oool00`000000oooo0?ooo`020?ooo`8000007@2W`>/00`000000
Re:808]BR00>08]BR0030000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo0000003o0?oo
ojT0oooo000^0?ooo`030000003oool0oooo0080oooo0P00000N0:O0j`8000003P2;DXP00`000000
oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`000000o`3ooonY0?ooo`00;P3oool00`000000
oooo0?ooo`020?ooo`800000802W`>/00`000000Re:808]BR00;08]BR0030000003oool0oooo01`0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooojH0oooo000^0?ooo`030000
003oool0oooo00<0oooo0P00000P0:O0j`030000002;DXP0Re:800X0Re:800<000000?ooo`3oool0
7@3oool01@000000oooo0?ooo`3oool000000?l0ooooZ03oool002h0oooo00<000000?ooo`3oool0
0`3oool200000240Yl3[00<0000008]BR02;DXP02@2;DXP00`000000oooo0?ooo`0M0?ooo`050000
003oool0oooo0?ooo`000000o`3ooonX0?ooo`00;`3oool00`000000oooo0?ooo`020?ooo`030000
003oool000000240Yl3[00<0000008]BR02;DXP0202;DXP00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonU0?ooo`00;`3oool00`000000oooo0?oo
o`020?ooo`030000003oool000000280Yl3[00<0000008]BR02;DXP01`2;DXP00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonU0?ooo`00;`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000280Yl3[00<0000008]BR02;DXP01P2;
DXP00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`000000o`3ooonW0?ooo`00;`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000002<0Yl3[00<0000008]BR02;DXP0
1@2;DXP00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`000000o`3ooonW0?ooo`00
;`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000008`2W`>/00`000000
Re:808]BR00408]BR0030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`3o0?oooj@0oooo000_0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
0000902W`>/00`000000Re:808]BR00208]BR0030000003oool0oooo0200oooo00D000000?ooo`3o
ool0oooo0000003o0?ooojH0oooo000_0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo0000000T0:O0j`050000002;DXP0Re:808]BR00000008P3oool01@000000oooo0?ooo`3o
ool000000?l0ooooYP3oool00300oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000002W`>/0Yl3[0280Yl3[00@0000008]BR02;DXP000008P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0?l0ooooX`3oool00300oooo00@000000?ooo`3oool0oooo0P00
00050?ooo`030000002W`>/0Yl3[0280Yl3[00<0000008]BR00000008P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0?l0ooooX`3oool00300oooo100000000`3oool000000?ooo`05
0?ooo`030000002W`>/0Yl3[0280Yl3[0P00000S0?ooo`050000003oool0oooo0?ooo`000000o`3o
oonU0?ooo`00<03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<00000
0:O0j`2W`>/08P2W`>/200000280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o
0?oooj80oooo000`0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000Yl3[0:O0j`0O0:O0j`80Re:800<000000:O0j`0000008@3oool010000000oooo0?ooo`3oool2
00000?l0ooooY03oool00300oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`030000002W`>/0Yl3[01/0Yl3[1@2;DXP010000000Yl3[0:O0j`00000Q0?ooo`<0000000<0oooo
0000003oool0o`3ooonS0?ooo`00<@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo00<000000:O0j`2W`>/05`2W`>/808]BR0050000002W`>/0Yl3[0:O0j`000000803oool0
1@000000oooo0?ooo`3oool000000?l0ooooY03oool00340oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`030000002W`>/0Yl3[01<0Yl3[2`2;DXP00`000000Yl3[0:O0j`02
0:O0j`030000003oool0oooo01d0oooo00D000000?ooo`3oool0oooo0000003o0?oooj@0oooo000a
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000Yl3[0:O0j`0?
0:O0j`h0Re:800<000000:O0j`2W`>/00`2W`>/00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`00<P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00T0oooo00<000000:O0j`2W`>/02`2W`>/A08]BR0030000002W`>/0Yl3[
00@0Yl3[00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0?l0ooooX@3oool00380oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`03
0000002W`>/0Yl3[00L0Yl3[502;DXP00`000000Yl3[0:O0j`050:O0j`800000703oool01@000000
oooo0?ooo`3oool000000?l0ooooX`3oool00380oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0:0?ooo`030000002W`>/0Yl3[00<0Yl3[5`2;DXP00`000000Yl3[0:O0j`070:O0j`03
0000003oool0oooo01T0oooo00D000000?ooo`3oool0oooo0000003o0?oooj<0oooo000c0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000Yl3[08]BR00I08]BR003
0000002W`>/0Yl3[00P0Yl3[00<000000?ooo`3oool0603oool01@000000oooo0?ooo`3oool00000
0?l0ooooX`3oool003<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`03
0000002;DXP0Re:801T0Re:800<000000:O0j`2W`>/02@2W`>/00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonP0?ooo`00<`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00X0oooo00<0000008]BR02;DXP06@2;DXP00`000000Yl3[
0:O0j`0:0:O0j`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`3o0?oooj00oooo000d0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3o
ool00`000000Re:808]BR00I08]BR0030000002W`>/0Yl3[00/0Yl3[00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooX03oool003@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000002;DXP0Re:801P0Re:800<00000
0:O0j`2W`>/03@2W`>/00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0o`3ooonP0?ooo`00=03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00<0000008]BR02;DXP0602;DXP00`000000Yl3[0:O0j`0>0:O0j`8000005@3oool01@00
0000oooo0?ooo`3oool000000?l0ooooXP3oool003D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`030000002;DXP0Re:801P0Re:800<000000:O0j`2W`>/0402W`>/00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonO0?oo
o`00=@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<0000008]BR02;
DXP0602;DXP00`000000Yl3[0:O0j`0A0:O0j`030000003oool0oooo0140oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`3o0?oooil0oooo000e0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool00`000000Re:808]BR00H08]BR0030000002W`>/0Yl3[0180Yl3[
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo
W`3oool003H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000002;
DXP0Re:801P0Re:800<000000:O0j`2W`>/04`2W`>/00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0o`3ooonO0?ooo`00=P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<0000008]BR02;DXP0602;DXP00`000000Yl3[0:O0j`0D
0:O0j`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o
0?oooil0oooo000f0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`00
0000Re:808]BR00H08]BR0030000002W`>/0Yl3[01D0Yl3[0P00000>0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0o`3ooonN0?ooo`00=`3oool00`000000oooo0?ooo`03000000T0
oooo00<0000008]BR02;DXP0602;DXP00`000000Yl3[0:O0j`0G0:O0j`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oooih0oooo000g0?ooo`<00000
0P3oool00`000000oooo0?ooo`070?ooo`030000002;DXP0Re:801P0Re:800<000000:O0j`2W`>/0
602W`>/00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<00000o`3ooonP0?ooo`00=`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0000008]BR02;DXP0602;
DXP00`000000Yl3[0:O0j`0I0:O0j`030000003oool0oooo00X0oooo0`0000020?ooo`030000003o
ool0oooo0?l0ooooWP3oool003P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000002;DXP0Re:801P0Re:800<000000:O0j`2W`>/06P2W`>/00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonN0?ooo`00>03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<0000008]BR02;DXP0602;DXP00`00
0000Yl3[0:O0j`0K0:O0j`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`3o0?oooih0oooo000i0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01@3oool00`000000Re:808]BR00H08]BR0030000002W`>/0Yl3[01`0Yl3[00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooWP3oool003T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000002;DXP0Re:801P0Re:8
0`00000M0:O0j`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`3o0?oooih0oooo000i0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000Re:808]BR00H08]BR0030000003oool0oooo00800000702W`>/00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonN0?ooo`00>P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0000008]BR02;DXP0602;DXP0
0`000000oooo0?ooo`020?ooo`8000006`2W`>/00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0o`3ooonN0?ooo`00>P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<0000008]BR02;DXP0602;DXP00`000000oooo0?ooo`040?oo
o`8000006P2W`>/00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0o`3ooonN0?ooo`00>`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<0000008]BR02;DXP05`2;DXP00`000000oooo0?ooo`070?ooo`8000006@2W`>/00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonN0?ooo`00
>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0000008]BR02;DXP0
5`2;DXP00`000000oooo0?ooo`090?ooo`800000602W`>/00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000o`3ooonP0?ooo`00?03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<0000008]BR02;DXP05`2;DXP00`000000oooo0?ooo`0;0?ooo`<00000
5P2W`>/01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0o`3ooonN0?ooo`00
?03oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000006@2;DXP00`000000
oooo0?ooo`0>0?ooo`<00000502W`>/010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
0?l0ooooWP3oool003`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000002;DXP0Re:801H0Re:800<000000?ooo`3oool04@3oool300000180Yl3[00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`3o0?oooih0oooo000m0?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo0000000H08]BR0030000003oool0oooo01@0oooo0`00000@0:O0j`80
00000`3oool00`000000oooo0?ooo`3o0?oooih0oooo000m0?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo0000000H08]BR0030000003oool0oooo01L0oooo1000000=0:O0j`05
0000003oool0oooo0?ooo`000000o`3ooonP0?ooo`00?P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<0000008]BR02;DXP05@2;DXP00`000000oooo0?ooo`0K0?ooo`<0
00002`2W`>/010000000oooo0?ooo`00003o0?oooj00oooo000n0?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo0000000G08]BR0030000003oool0oooo01h0oooo0`0000090:O0
j`030000003oool000000?l0ooooX03oool003l0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000001L0Re:800<000000?ooo`3oool08@3oool3000000L0Yl3[0P00003o0?oo
oj00oooo000o0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000002;DXP0Re:801D0
Re:800<000000?ooo`3oool0903oool3000000<0Yl3[0`00003o0?oooj00oooo000o0?ooo`030000
003oool000000080000000<0oooo0000003oool00P3oool00`000000Re:808]BR00D08]BR0030000
003oool0oooo02L0oooo0`0000020?ooo`030000003oool0oooo0?l0ooooWP3oool00400oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`00000E08]BR0030000003oool0oooo02T0oooo
00D000000?ooo`3oool0oooo0000003o0?oooj00oooo00100?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`0000005@2;DXP00`000000oooo0?ooo`0Y0?ooo`050000003oool0oooo0?ooo`00
0000o`3ooonP0?ooo`00@@3oool00`000000oooo0?ooo`030?ooo`030000003oool0000001D0Re:8
00<000000?ooo`3oool0:@3oool01@000000oooo0?ooo`3oool000000?l0ooooX03oool00480oooo
00<000000?ooo`3oool00`3oool00`000000oooo0000000D08]BR0030000003oool0oooo02P0oooo
00D000000?ooo`3oool0oooo0000003o0?oooj40oooo00120?ooo`030000003oool0oooo00@0oooo
0P00000D08]BR0030000003oool0oooo02P0oooo00D000000?ooo`3oool0oooo0000003o0?oooj40
oooo00130?ooo`030000003oool0oooo00<0oooo0P00000D08]BR0030000003oool0oooo02P0oooo
00D000000?ooo`3oool0oooo0000003o0?oooj40oooo00140?ooo`030000003oool0oooo00<0oooo
0P00000C08]BR0030000003oool0oooo02P0oooo00D000000?ooo`3oool0oooo0000003o0?oooj40
oooo00140?ooo`030000003oool0oooo00@0oooo00<0000008]BR02;DXP04@2;DXP00`000000oooo
0?ooo`0X0?ooo`050000003oool0oooo0?ooo`000000o`3ooonQ0?ooo`00A@3oool00`000000oooo
0?ooo`030?ooo`030000002;DXP0Re:80140Re:800<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?l0ooooW`3oool004H0oooo00<000000?ooo`3oool00P3o
ool200000180Re:800<000000?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0?l0ooooW`3oool004H0oooo00<000000?ooo`3oool00`3oool200000140Re:800<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooW`3oool0
04L0oooo00<000000?ooo`3oool00P3oool200000140Re:800<000000?ooo`3oool09`3oool01@00
0000oooo0?ooo`3oool000000?l0ooooXP3oool004P0oooo00L000000?ooo`3oool0oooo0000002;
DXP0000000l0Re:800<000000?ooo`3oool0:03oool01@000000oooo0?ooo`3oool000000?l0oooo
XP3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000Re:80000000>08]BR0030000003o
ool0oooo02P0oooo00D000000?ooo`3oool0oooo0000003o0?oooj80oooo00190?ooo`030000003o
ool0oooo0080oooo0P00000>08]BR0030000003oool0oooo02L0oooo00@000000?ooo`3oool0oooo
0P00003o0?oooj80oooo001:0?ooo`070000003oool0oooo0?ooo`000000Re:80000000=08]BR003
0000003oool0oooo02L0oooo100000000`3oool000000?ooo`3o0?oooj40oooo001:0?ooo`030000
003oool0oooo0080oooo0`00000<08]BR0030000003oool0oooo02L0oooo00D000000?ooo`3oool0
oooo0000003o0?oooj<0oooo001;0?ooo`030000003oool000000080000000<0Re:80000002;DXP0
2`2;DXP00`000000oooo0?ooo`0W0?ooo`050000003oool0oooo0?ooo`000000o`3ooonS0?ooo`00
C03oool01`000000oooo0?ooo`3oool0000008]BR00000002`2;DXP00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`00C03oool00`000000
oooo0?ooo`020?ooo`030000002;DXP0000000X0Re:800<000000?ooo`3oool09P3oool01@000000
oooo0?ooo`3oool000000?l0ooooY03oool004d0oooo00D000000?ooo`3oool0oooo0000000208]B
R0030000002;DXP0Re:800L0Re:800<000000?ooo`3oool09P3oool01@000000oooo0?ooo`3oool0
00000?l0ooooY03oool004h0oooo00D000000?ooo`3oool0oooo0000000208]BR0030000002;DXP0
Re:800H0Re:800<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0?l0ooooXP3oool004l0oooo00@000000?ooo`3oool000000`2;DXP00`000000Re:808]BR005
08]BR0030000003oool0oooo02D0oooo00D000000?ooo`3oool0oooo0000003o0?ooojD0oooo001@
0?ooo`040000003oool0oooo000000<0Re:800<0000008]BR02;DXP0102;DXP00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonS0?ooo`00D@3oool0
10000000oooo0?ooo`00000308]BR0030000002;DXP0Re:80080Re:800<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooX`3oool00580oooo00<00000
0?ooo`000000102;DXP01@000000Re:808]BR02;DXP0000002L0oooo00D000000?ooo`3oool0oooo
0000003o0?ooojH0oooo001C0?ooo`030000003oool0000000@0Re:800@0000008]BR02;DXP00000
9P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooY03oool005@0oooo0P00
000508]BR0030000002;DXP0000002H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3o0?oooj@0oooo001E0?ooo`8000001@2;DXP2000002H0oooo00<000000?ooo`0000000P00003o
0?ooojL0oooo001F0?ooo`800000102;DXP3000002@0oooo0`0000000`3oool000000?ooo`3o0?oo
ojL0oooo001G0?ooo`030000002;DXP00000008000000`3oool00`000000oooo0?ooo`0Q0?ooo`04
0000003oool0oooo00000?l0ooooZ@3oool005P0oooo0P0000060?ooo`800000803oool010000000
oooo0?ooo`00003o0?ooojX0oooo001J0?ooo`030000003oool0oooo00D0oooo0P00000M0?ooo`04
0000003oool0oooo00000?l0ooooZ`3oool005/0oooo0P0000070?ooo`030000003oool0oooo01T0
oooo00@000000?ooo`3oool00000o`3ooon/0?ooo`00G@3oool2000000H0oooo0P00000H0?ooo`04
0000003oool0oooo00000?l0oooo[@3oool005l0oooo00<000000?ooo`3oool01@3oool2000001D0
oooo00@000000?ooo`3oool00000o`3ooon^0?ooo`00H03oool2000000L0oooo00<000000?ooo`3o
ool04@3oool010000000oooo00000000003o0?ooojl0oooo001R0?ooo`8000001@3oool4000000l0
oooo0`00003o0?oook40oooo001T0?ooo`030000003oool0000000800000103oool4000000P0oooo
0`00003o0?oook@0oooo001U0?ooo`@00000203oool300000080oooo0`00003o0?oookL0oooo001Y
0?ooo`H00000103oool300000?l0oooo^P3oool006l0oooo1000003o0?oookd0oooo003o0?ooool0
oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool0
0?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3o
oola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00
o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oo
oc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o
0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo
<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0
ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola
0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3o
oooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40
oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?oo
ool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3o
ool00?l0ooooo`3ooola0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 558}, {394.312, 0}} -> {0.0182252, 0.131042, \
0.00176023, 0.00176023}}]
}, Open  ]],

Cell["\<\
Here is a projection of the focal surface points onto a plane. Note \
the pin-cushion effect.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[imagefocus, PlotType->FrontView, RayLineRGB -> False, \
RayPointSize -> 4, ShowComponents -> False];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.50003 0.14794 0.5 0.14794 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
4 Mabswid
.95996 .95993 Mdot
.96898 .81263 Mdot
.97439 .65812 Mdot
.97619 .5 Mdot
.97439 .34188 Mdot
.96898 .18737 Mdot
.95996 .04007 Mdot
.81269 .96899 Mdot
.81871 .81868 Mdot
.82232 .66115 Mdot
.82352 .5 Mdot
.82232 .33885 Mdot
.81871 .18132 Mdot
.81269 .03101 Mdot
.65817 .97441 Mdot
.66118 .8223 Mdot
.66299 .66296 Mdot
.66359 .5 Mdot
.66299 .33704 Mdot
.66118 .1777 Mdot
.65817 .02559 Mdot
.50003 .97619 Mdot
.50003 .8235 Mdot
.50003 .66356 Mdot
.50003 .5 Mdot
.50003 .33644 Mdot
.50003 .1765 Mdot
.50003 .02381 Mdot
.34191 .97435 Mdot
.33889 .82228 Mdot
.33707 .66296 Mdot
.33647 .5 Mdot
.33707 .33704 Mdot
.33889 .17772 Mdot
.34191 .02565 Mdot
.18744 .96889 Mdot
.18137 .81866 Mdot
.17774 .66115 Mdot
.17652 .5 Mdot
.17774 .33885 Mdot
.18137 .18134 Mdot
.18744 .03111 Mdot
.04022 .95981 Mdot
.0311 .81262 Mdot
.02563 .65813 Mdot
.02381 .5 Mdot
.02563 .34187 Mdot
.0311 .18738 Mdot
.04022 .04019 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00H@3oool2000002`0oooo0P00000[0?ooo`800000HP3oool00600oooo1000000Z0?ooo`@0
0000:@3oool400000640oooo000e0?ooo`800000:@3oool4000002X0oooo1000000Y0?ooo`@00000
:@3oool2000003H0oooo000d0?ooo`@00000:@3oool2000002`0oooo0P00000[0?ooo`800000:@3o
ool4000003D0oooo000d0?ooo`@00000[`3oool4000002P0oooo0P00000;0?ooo`002`3oool20000
02P0oooo0P00002a0?ooo`800000:03oool4000000X0oooo000:0?ooo`@00000o`3oool50?ooo`@0
00002P3oool000X0oooo1000003o0?ooo`H0oooo0P00000;0?ooo`002`3oool200000?l0oooo503o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00600oooo0P00000]0?ooo`800000;03oool200000640oooo000c0?ooo`800000:P3oool40000
02/0oooo1000000Z0?ooo`@00000:P3oool2000003@0oooo000b0?ooo`@00000:@3oool4000002/0
oooo1000000Z0?ooo`@00000:@3oool4000003<0oooo00080?ooo`800000:03oool4000002X0oooo
0P00000]0?ooo`800000;03oool2000002X0oooo1000000X0?ooo`8000002@3oool000L0oooo1000
000X0?ooo`800000]@3oool2000002P0oooo100000080?ooo`001`3oool400000?l0oooo2P3oool4
000000P0oooo00080?ooo`800000o`3oool<0?ooo`8000002@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00380oooo0P00000/0?ooo`800000;@3oool20000
02`0oooo0P00000/0?ooo`800000<`3oool000H0oooo0P00000Y0?ooo`@00000:P3oool4000002/0
oooo1000000Z0?ooo`@00000:P3oool4000002T0oooo0P0000070?ooo`001@3oool4000002P0oooo
1000000Z0?ooo`@00000:`3oool4000002X0oooo1000000Z0?ooo`@00000:03oool4000000H0oooo
00050?ooo`@00000:@3oool2000002`0oooo0P00000]0?ooo`800000;03oool2000002`0oooo0P00
000Y0?ooo`@000001P3oool000H0oooo0P00003o0?oooa00oooo0P0000070?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`001P3oool2000002X0oooo0P00000/0?ooo`800000;@3oool2000002`0oooo0P00000/0?ooo`80
0000:P3oool2000000L0oooo00050?ooo`@00000:03oool4000002X0oooo1000000[0?ooo`@00000
:P3oool4000002X0oooo1000000X0?ooo`@000001P3oool000D0oooo1000000X0?ooo`@00000:P3o
ool4000002/0oooo1000000Z0?ooo`@00000:P3oool4000002P0oooo100000060?ooo`001P3oool2
000002X0oooo0P00000/0?ooo`800000;@3oool2000002`0oooo0P00000/0?ooo`800000:P3oool2
000000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo00060?ooo`800000o`3oool@0?ooo`800000
1`3oool000D0oooo1000000Y0?ooo`800000;03oool2000002d0oooo0P00000/0?ooo`800000;03o
ool2000002T0oooo100000060?ooo`001@3oool4000002P0oooo1000000Z0?ooo`@00000:`3oool4
000002X0oooo1000000Z0?ooo`@00000:03oool4000000H0oooo00060?ooo`800000:@3oool40000
02X0oooo1000000[0?ooo`@00000:P3oool4000002X0oooo1000000Y0?ooo`8000001`3oool00380
oooo0P00000/0?ooo`800000;@3oool2000002`0oooo0P00000/0?ooo`800000<`3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool000P0oooo0P00003o0?ooo``0
oooo0P0000090?ooo`001`3oool400000?l0oooo2P3oool4000000P0oooo00070?ooo`@00000:03o
ool200000;D0oooo0P00000X0?ooo`@00000203oool000P0oooo0P00000X0?ooo`@00000:P3oool2
000002d0oooo0P00000/0?ooo`800000:P3oool4000002P0oooo0P0000090?ooo`00<P3oool40000
02T0oooo1000000[0?ooo`@00000:P3oool4000002T0oooo1000000c0?ooo`00<`3oool2000002X0
oooo1000000[0?ooo`@00000:P3oool4000002X0oooo0P00000d0?ooo`00H03oool2000002d0oooo
0P00000/0?ooo`800000H@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool000/0oooo0P00003o0?ooo`L0oooo0P00000;0?ooo`002P3oool4
00000?l0oooo1@3oool4000000X0oooo000:0?ooo`@00000o`3oool50?ooo`@000002P3oool000/0
oooo0P00000X0?ooo`800000/@3oool2000002T0oooo0P00000;0?ooo`00=03oool400000:l0oooo
1000000e0?ooo`00=03oool4000002T0oooo0P00000/0?ooo`800000:`3oool2000002T0oooo1000
000e0?ooo`00=@3oool2000002T0oooo1000000Z0?ooo`@00000:@3oool4000002T0oooo0P00000f
0?ooo`00H03oool4000002X0oooo1000000Y0?ooo`@00000H@3oool00640oooo0P00000/0?ooo`80
0000:`3oool200000680oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-3.37999, -3.37978, 0.0235525, \
0.0235525}}]
}, Open  ]],

Cell["\<\
Here is the image surface intercepts plotted as a stereo pair. To \
see this in three-dimensions you need to use crossed eyes such that the two \
images become superimposed.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[imagefocus, RayLineRGB -> False, RayPointSize -> 4, \
ShowComponents -> False, CreateStereoView->Crossed];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .57143 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0136054 0.47619 [
[ 0 0 0 0 ]
[ 1 .57143 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .57143 L
0 .57143 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0136054 0.568027 0.557823 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 0 r
4 Mabswid
.47494 .4825 Mdot
.56192 .5164 Mdot
.5234 .40955 Mdot
.61815 .56689 Mdot
.53726 .34244 Mdot
.6164 .44213 Mdot
.63866 .63313 Mdot
.51265 .28465 Mdot
.61965 .7132 Mdot
.67746 .49311 Mdot
.63445 .37298 Mdot
.55915 .80403 Mdot
.45768 .90153 Mdot
.44721 .23986 Mdot
.70091 .56183 Mdot
.34084 .21153 Mdot
.19622 .20249 Mdot
.61146 .31258 Mdot
.69879 .42362 Mdot
.68234 .64643 Mdot
.61944 .74367 Mdot
.54451 .26485 Mdot
.51272 .84903 Mdot
.72402 .49399 Mdot
.67691 .36216 Mdot
.43315 .23356 Mdot
.28018 .22178 Mdot
.70522 .58226 Mdot
.60835 .31277 Mdot
.63979 .68504 Mdot
.70227 .43326 Mdot
.52831 .79742 Mdot
.49243 .2794 Mdot
.3321 .26532 Mdot
.68229 .52416 Mdot
.63183 .38371 Mdot
.61423 .63133 Mdot
.49885 .74951 Mdot
.51189 .34933 Mdot
.34562 .33348 Mdot
.60957 .47605 Mdot
.53891 .58616 Mdot
.42091 .70847 Mdot
.48632 .44182 Mdot
.31605 .42476 Mdot
.29453 .67755 Mdot
.41338 .55315 Mdot
.12407 .65952 Mdot
.24155 .53541 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.431973 0.0136054 0.97619 0.557823 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 0 r
4 Mabswid
.4433 .48291 Mdot
.53606 .51679 Mdot
.49833 .41 Mdot
.59719 .56699 Mdot
.51828 .34302 Mdot
.59737 .44278 Mdot
.62201 .63278 Mdot
.49914 .28509 Mdot
.66364 .49352 Mdot
.6067 .71257 Mdot
.62202 .37403 Mdot
.54886 .80376 Mdot
.44819 .90281 Mdot
.43803 .2396 Mdot
.69182 .56167 Mdot
.60533 .3138 Mdot
.69206 .4246 Mdot
.33382 .20989 Mdot
.67748 .64567 Mdot
.18786 .19893 Mdot
.61788 .74282 Mdot
.54379 .26564 Mdot
.72249 .49437 Mdot
.51256 .84927 Mdot
.67716 .36352 Mdot
.43587 .23315 Mdot
.70838 .58186 Mdot
.2828 .21952 Mdot
.6149 .31398 Mdot
.70827 .43415 Mdot
.64665 .68426 Mdot
.53682 .7974 Mdot
.50339 .27969 Mdot
.69333 .52427 Mdot
.64469 .38469 Mdot
.34382 .26401 Mdot
.62905 .63097 Mdot
.51507 .7498 Mdot
.52966 .34976 Mdot
.62765 .47647 Mdot
.36445 .33276 Mdot
.56048 .58629 Mdot
.44304 .70944 Mdot
.50924 .44211 Mdot
.33958 .42452 Mdot
.43902 .55364 Mdot
.31926 .67939 Mdot
.26656 .53612 Mdot
.14615 .66242 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{687.812, 393},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:_0001RB000`400?l00000o`00003oo`3ooooo
0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo
003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0
oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool0
0?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3o
oona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00
o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oo
ok40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o
0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo
/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0
ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona
0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3o
oooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40
oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?oo
ool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3o
ool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0oooo
o`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?oo
o`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo
0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo
003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0
oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool0
0?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3o
oona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00
o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oo
ok40oooo003o0?ooool0oooo/@3oool00?l0ooooK`3oool200000?l0oooo@03oool005T0oooo0P00
003o0?oooa<0oooo1000003o0?ooocl0oooo001H0?ooo`@00000o`3ooolB0?ooo`@00000o`3ooolo
0?ooo`00F03oool400000?l0oooo4`3oool200000?l0oooo@03oool005T0oooo0P00000d0?ooo`80
0000o`3ooolD0?ooo`800000o`3oool:0?ooo`00SP3oool400000?l0oooo4P3oool400000?l0oooo
2@3oool008h0oooo1000003o0?oooa80oooo1000003o0?ooo`T0oooo002?0?ooo`800000o`3oool1
0?ooo`8000004@3oool200000?l0oooo2P3oool007P0oooo0P00003o0?oooaL0oooo1000003o0?oo
oa`0oooo001g0?ooo`@00000o`3ooolF0?ooo`@00000o`3ooolL0?ooo`00M`3oool400000?l0oooo
5`3oool200000?l0oooo7@3oool007P0oooo0P00003o0?ooool0oooo=`3oool00?l0oooob`3oool2
00000><0oooo002a0?ooo`800000o`3ooolG0?ooo`@00000hP3oool00;00oooo1000003o0?oooaH0
oooo1000003R0?ooo`00/03oool4000000<0oooo0P00003o0?oooa80oooo0`00003R0?ooo`00/@3o
ool2000000<0oooo1000003o0?oooa40oooo1000003Q0?ooo`00]P3oool400000?l0oooo4@3oool4
00000>40oooo002g0?ooo`800000o`3ooolC0?ooo`800000hP3oool00?l0ooooo`3ooona0?ooo`00
o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oo
ok40oooo002<0?ooo`800000C@3oool200000</0oooo0P00003o0?ooo`H0oooo002;0?ooo`@00000
B`3oool400000<T0oooo100000180?ooo`800000^P3oool008/0oooo1000001;0?ooo`@00000b@3o
ool4000004L0oooo1000002i0?ooo`00S03oool2000004d0oooo0P00003;0?ooo`800000B03oool4
00000;T0oooo003o0?oooo@0oooo0P00002j0?ooo`00o`3ooooo0?oook40oooo00380?ooo`800000
o`3ooolK0?ooo`800000b@3oool00<L0oooo1000003o0?oooaT0oooo100000380?ooo`00a`3oool4
000000@0oooo0P00003o0?oooa80oooo1@0000380?ooo`00b03oool2000000@0oooo1000003o0?oo
oa00oooo1@0000390?ooo`00cP3oool400000?l0oooo403oool400000<X0oooo003?0?ooo`800000
o`3ooolB0?ooo`800000b`3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?oo
ool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3o
ool00?<0oooo0`00003o0?oookX0oooo003b0?ooo`D00000o`3ooolD0?ooo`80000000<0oooo0000
00000000X03oool00?80oooo1@00003o0?oooa<0oooo1`00002O0?ooo`00l`3oool300000?l0oooo
503oool7000009l0oooo003o0?ooool0oooo303oool2000000030?ooo`00000000000:00oooo003o
0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo002A0?ooo`800000
o`3ooolN0?ooo`800000o@3oool00900oooo1000003o0?oooa`0oooo1000003l0?ooo`00T03oool4
00000?l0oooo703oool400000?`0oooo002A0?ooo`800000A@3oool200000=H0oooo0P00000g0?oo
o`800000a03oool00=L0oooo1000003o0?ooo`h0oooo100000330?ooo`00e`3oool400000?l0oooo
3P3oool400000<<0oooo003?0?ooo`8000001`3oool200000?l0oooo403oool200000080oooo0P00
00300?ooo`00cP3oool400000?l0oooo6`3oool400000;l0oooo003>0?ooo`@00000o`3ooolK0?oo
o`@00000_`3oool00<l0oooo0P00003o0?oooad0oooo0P0000300?ooo`00o`3ooooo0?oook40oooo
003o0?ooo`d0oooo0P00003o0?oooaP0oooo0P0000280?ooo`00o`3oool<0?ooo`@00000o`3ooolF
0?ooo`@00000Q`3oool00?l0oooo303oool400000?l0oooo5P3oool4000008L0oooo003o0?ooo`d0
oooo0P00003o0?oooaP0oooo0P0000280?ooo`00o@3oool200000?l0oooo4P3oool2000009d0oooo
003l0?ooo`@00000o`3oool@0?ooo`@00000W03oool00?`0oooo1000003o0?oooa00oooo1000002L
0?ooo`00o@3oool200000?l0oooo4P3oool2000009d0oooo003l0?ooo`800000o`3ooolK0?ooo`80
0000U@3oool00?/0oooo1000003o0?oooaT0oooo1000002D0?ooo`00n`3oool400000?l0oooo6@3o
ool4000009@0oooo003l0?ooo`800000o`3ooolK0?ooo`800000U@3oool00?l0ooooo`3ooona0?oo
o`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo
0?oook40oooo003C0?ooo`800000o`3oool>0?ooo`800000b`3oool00=80oooo1000003o0?ooo``0
oooo1000003:0?ooo`00dP3oool400000?l0oooo303oool400000<X0oooo003C0?ooo`800000o`3o
ool>0?ooo`800000b`3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo00260?ooo`80
0000S@3oool2000008l0oooo0P0000220?ooo`800000P`3oool008D0oooo1000002;0?ooo`@00000
S@3oool400000800oooo100000220?ooo`00Q@3oool4000008/0oooo1000002=0?ooo`@00000P03o
ool400000880oooo00260?ooo`800000S@3oool3000008h0oooo0P0000220?ooo`800000103oool2
000007d0oooo003o0?oooaH0oooo1000003o0?oooaL0oooo1000001l0?ooo`00o`3ooolF0?ooo`@0
0000o`3ooolG0?ooo`@00000O03oool00<D0oooo0P00000_0?ooo`8000007P3oool200000<h0oooo
0P0000180?ooo`800000O@3oool00<@0oooo1000000]0?ooo`@00000k03oool4000001h0oooo0P00
002V0?ooo`00a03oool4000002d0oooo1000003/0?ooo`@000007@3oool400000:D0oooo00350?oo
o`800000;`3oool200000>h0oooo0P00000N0?ooo`@00000Y@3oool00?l0ooooo`3oool90?ooo`80
0000YP3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool0
0?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3o
oona0?ooo`00o`3ooooo0?oook40oooo003c0?ooo`800000o`3ooolN0?ooo`800000V`3oool00?80
oooo1000003o0?oooa`0oooo1000002J0?ooo`00`@3oool2000002l0oooo1000003o0?oooa`0oooo
1000002J0?ooo`00`03oool4000002l0oooo0P00003H0?ooo`800000@`3oool2000009/0oooo0030
0?ooo`@00000o`3oool90?ooo`@00000g`3oool00<40oooo0P00003o0?ooo`X0oooo1000003O0?oo
o`00o`3oool>0?ooo`800000_P3oool200000>00oooo003o0?ooo`d0oooo1000000>0?ooo`800000
o`3oool2000001@0oooo0P00001h0?ooo`00o`3oool=0?ooo`@000003@3oool400000?d0oooo1000
000B0?ooo`@00000M`3oool00?l0oooo3P3oool2000000h0oooo1000003m0?ooo`@000004P3oool4
000007L0oooo003o0?oooal0oooo0P00003o0?ooo`800000503oool2000007P0oooo003o0?ooool0
oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool0
0>40oooo0P00003o0?ooo`h0oooo0P00002m0?ooo`00h03oool400000?l0oooo303oool400000;`0
oooo003P0?ooo`@00000o`3oool<0?ooo`@00000_03oool00>40oooo0P00000[0?ooo`800000h03o
ool2000003T0oooo0P0000220?ooo`00o`3oool>0?ooo`@00000o`3ooolJ0?ooo`@00000P@3oool0
0?l0oooo3P3oool400000?l0oooo6P3oool400000840oooo003o0?ooo`l0oooo0P00003o0?oooa`0
oooo0P0000220?ooo`00JP3oool200000?l0ooooo`3ooom50?ooo`00J@3oool400000?l0oooo7`3o
ool200000?l0oooo8`3oool006T0oooo1000003o0?oooah0oooo1000003o0?ooob80oooo001Z0?oo
o`800000o`3ooolO0?ooo`@00000o`3ooolR0?ooo`00o`3ooon<0?ooo`800000o`3ooolS0?ooo`00
o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00:X0oooo0P00003o0?ooob40oooo0P00003Q
0?ooo`00Z@3oool400000?l0oooo7`3oool400000>00oooo002Y0?ooo`@00000o`3ooolO0?ooo`@0
0000h03oool00:X0oooo0P00001Y0?ooo`800000]@3oool2000005`0oooo0P0000230?ooo`00o`3o
oolE0?ooo`@00000o`3ooolB0?ooo`@00000PP3oool00?H0oooo0P00000L0?ooo`@00000k`3oool2
00000200oooo100000220?ooo`00m@3oool4000001`0oooo0P00003_0?ooo`@00000803oool20000
08<0oooo003e0?ooo`@00000o`3oool>0?ooo`@00000Y@3oool00?H0oooo0P00003o0?oooa00oooo
0P00002V0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0oooo603oool20000
0?l0oooo603oool2000007d0oooo003I0?ooo`800000>`3oool400000=l0oooo0P00000d0?ooo`@0
0000O03oool00=P0oooo1000000j0?ooo`@00000gP3oool4000003<0oooo1000001l0?ooo`00f03o
ool4000003/0oooo0P00003O0?ooo`@00000=03oool2000007d0oooo003I0?ooo`800000o`3ooolO
0?ooo`800000]03oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo
/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0
ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona
0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00m@3o
ool200000?l0oooo7@3oool2000009X0oooo003d0?ooo`@000001P3oool200000?l0oooo4@3oool6
000009T0oooo003d0?ooo`@000001@3oool400000?l0oooo3`3oool7000009T0oooo003e0?ooo`80
00001P3oool400000?l0oooo3`3oool6000009X0oooo003n0?ooo`800000o`3ooolA0?ooo`800000
W@3oool00?l0ooooo`3ooolW0?ooo`800000R03oool00?l0oooo3`3oool200000?l0oooo5@3oool4
000008L0oooo003o0?ooo`h0oooo1000003o0?oooa@0oooo100000270?ooo`00o`3oool>0?ooo`@0
0000o`3ooolE0?ooo`800000R03oool00?l0oooo3`3oool200000?l0ooooX03oool00?l0ooooo`3o
oona0?ooo`00?P3oool200000?l0ooooo`3oooma0?ooo`00?@3oool400000?l0oooo7P3oool20000
0?l0ooooD03oool003d0oooo1000003o0?oooad0oooo1000003o0?ooodl0oooo000n0?ooo`800000
o`3ooolN0?ooo`@00000o`3ooom?0?ooo`00o`3ooomO0?ooo`800000o`3ooom@0?ooo`00o`3ooooo
0?oook40oooo001n0?ooo`800000o`3ooooo0?oooc40oooo001m0?ooo`@00000o`3ooolO0?ooo`80
0000o`3oool?0?ooo`00O@3oool400000?l0oooo7P3oool400000?l0oooo3P3oool007h0oooo0P00
001o0?ooo`800000W@3oool4000007L0oooo0P00002D0?ooo`00oP3oool4000009d0oooo0P00001g
0?ooo`@00000T`3oool00?h0oooo1000003o0?oooaL0oooo1000002C0?ooo`00o`3oool200000?l0
oooo6@3oool2000009@0oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo
0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00[@3oool200000?l0oooo
7`3oool200000>00oooo002/0?ooo`@00000o`3ooolM0?ooo`@00000>P3oool200000:<0oooo002/
0?ooo`@00000A`3oool200000=<0oooo1000000i0?ooo`@00000XP3oool00:d0oooo0P0000170?oo
o`@00000d`3oool2000003X0oooo1000002R0?ooo`00mP3oool400000?l0oooo4@3oool200000:<0
oooo003g0?ooo`800000o`3ooong0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool0
0?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3o
oona0?ooo`00o`3ooooo0?oook40oooo003g0?ooo`800000o`3ooolF0?ooo`800000W`3oool00?H0
oooo1000003o0?oooa@0oooo1000002N0?ooo`00bP3oool2000002X0oooo1000003^0?ooo`800000
8`3oool4000009h0oooo00390?ooo`@00000:P3oool200000>h0oooo1000000S0?ooo`800000W`3o
ool00<T0oooo1000003o0?oooa/0oooo100000340?ooo`00bP3oool200000?l0oooo7@3oool20000
0<D0oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o
0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo
/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0
ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona
0?ooo`00e@3oool200000?l0oooo6P3oool200000;d0oooo003D0?ooo`@00000o`3ooolH0?ooo`@0
0000_03oool00=@0oooo1000003o0?oooaP0oooo100000020?ooo`800000^03oool00=D0oooo0P00
00090?ooo`800000o`3oool?0?ooo`8000000P3oool400000;L0oooo003O0?ooo`@00000o`3ooolB
0?ooo`@00000]`3oool00=l0oooo1000003o0?oooa<0oooo0P00002h0?ooo`00h03oool200000?l0
oooocP3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool0
0?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3o
oona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00
o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00<l0oooo0P00003o0?oooaL0oooo0P000036
0?ooo`00cP3oool400000?l0oooo5@3oool400000<D0oooo003>0?ooo`@00000o`3ooolE0?ooo`@0
0000a@3oool00<l0oooo0P00003o0?oooaL0oooo0P0000360?ooo`00o`3ooooo0?oook40oooo003o
0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo
/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0
ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona
0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3o
oooo0?oook40oooo002k0?ooo`800000o`3ooolC0?ooo`800000gP3oool00;X0oooo1000003o0?oo
oa40oooo1000003M0?ooo`00^P3oool400000?l0oooo4@3oool400000=d0oooo002k0?ooo`800000
o`3ooolC0?ooo`800000gP3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?oo
ool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3o
ool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0oooo
o`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?oo
o`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo
0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo
003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0
oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool0
0?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3o
oona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00
o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oo
ok40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o
0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 686.812}, {392, 0}} -> {-0.0512568, -0.0285774, \
0.00306127, 0.00306127}, {{16.6875, 390.062}, {382.625, 9.3125}} -> \
{-0.0447903, -0.0251183, 0.00267875, 0.00267875}, {{296.688, 670.062}, \
{382.625, 9.3125}} -> {-0.79484, -0.0251183, 0.00267875, 0.00267875}}]
}, Open  ]],

Cell[TextData[{
  "You can use ",
  StyleBox["ReadTurboRays", "Input"],
  " with ",
  StyleBox["RayEnd", "Input"],
  " to recover the three-dimensional intercept points at the focal surface. \
Note that there is only a single intercept coordinate for each ray bundle."
}], "Text"],

Cell[CellGroupData[{

Cell["ReadTurboRays[imagefocus, RayEnd]", "Input"],

Cell[BoxData[
    \({{331.7281038806663`, 3.1089069823070403`, 
        3.1089069823070403`}, {333.0692654820115`, 3.1698673460444953`, 
        2.113244897362997`}, {333.8764578832688`, 3.206428846767743`, 
        1.068809615589248`}, {334.14593007566543`, 3.2186131512821605`, 
        0.`}, {333.8764578832689`, 
        3.206428846767748`, \(-1.06880961558925`\)}, {333.06926548201153`, 
        3.1698673460444984`, \(-2.1132448973629994`\)}, {331.7281038806662`, 
        3.1089069823070323`, \(-3.1089069823070323`\)}, {333.07366509727586`, 
        2.1134301474107087`, 3.170145221116062`}, {334.4218502564432`, 
        2.154125942312604`, 2.1541259423126053`}, {335.2331950987417`, 
        2.1785313129709287`, 1.0892656564854644`}, {335.50404082050494`, 
        2.18666413501068`, 0.`}, {335.2331950987416`, 
        2.178531312970924`, \(-1.089265656485462`\)}, {334.42185025644324`, 
        2.1541259423126067`, \(-2.154125942312608`\)}, {333.0736650972758`, 
        2.113430147410706`, \(-3.170145221116058`\)}, {333.8817225503739`, 
        1.0689201994684012`, 3.2067605984052054`}, {335.2347667947752`, 
        1.0892985450855586`, 2.178597090171117`}, {336.04899557268425`, 
        1.1015188790621129`, 1.1015188790621129`}, {336.3207971521784`, 
        1.105591066304096`, 0.`}, {336.0489955726842`, 
        1.1015188790621118`, \(-1.1015188790621118`\)}, {335.23476679477517`, 
        1.0892985450855583`, \(-2.1785970901711167`\)}, {333.8817225503739`, 
        1.0689201994684012`, \(-3.2067605984052054`\)}, {334.14916818844546`, 
        0.`, 3.21881704520108`}, {335.50501050360555`, 0.`, 
        2.186704686741381`}, {336.3209192174688`, 0.`, 
        1.1055936129177484`}, {336.5932808922226`, 0.`, 
        0.`}, {336.32091921746877`, 
        0.`, \(-1.105593612917748`\)}, {335.50501050360555`, 
        0.`, \(-2.1867046867413804`\)}, {334.14916818844546`, 
        0.`, \(-3.21881704520108`\)}, {333.8755030707422`, \
\(-1.0687895598343524`\), 
        3.2063686795030586`}, {335.232108257509`, \(-1.0892429137375619`\), 
        2.1784858274751238`}, {336.0485091705307`, \(-1.1015087237778622`\), 
        1.1015087237778622`}, {336.321040742742`, \(-1.105596148265174`\), 
        0.`}, {336.04850917053074`, \(-1.1015087237778634`\), \
\(-1.1015087237778634`\)}, {335.2321082575092`, \(-1.089242913737566`\), \
\(-2.178485827475132`\)}, {333.87550307074207`, \(-1.0687895598343498`\), \
\(-3.2063686795030506`\)}, {333.0627293681496`, \(-2.112969687979449`\), 
        3.1694545319691727`}, {334.41800699133034`, \(-2.15396473228488`\), 
        2.153964732284882`}, {335.23367831424525`, \(-2.1785515360689276`\), 
        1.0892757680344638`}, {335.505978069585`, \(-2.186745149934986`\), 
        0.`}, {335.23367831424525`, \(-2.178551536068928`\), \
\(-1.089275768034464`\)}, {334.4180069913304`, \(-2.1539647322848836`\), \
\(-2.1539647322848854`\)}, {333.0627293681495`, \(-2.1129696879794473`\), \
\(-3.16945453196917`\)}, {331.7153988173875`, \(-3.108101461271461`\), 
        3.108101461271461`}, {333.06712569892744`, \(-3.169732199596025`\), 
        2.1131547997306837`}, {333.8807634147622`, \(-3.2067001587224335`\), 
        1.0689000529074781`}, {334.15240180113665`, \(-3.219020655763358`\), 
        0.`}, {333.8807634147622`, \(-3.2067001587224304`\), \
\(-1.0689000529074772`\)}, {333.0671256989274`, \(-3.1697321995960204`\), \
\(-2.1131547997306805`\)}, {331.71539881738755`, \(-3.108101461271466`\), \
\(-3.108101461271466`\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Conversely, the ",
  StyleBox["SingleRay -> False", "Input"],
  " setting keeps all of the traced rays that were originally generated by ",
  StyleBox["DistortionGrid", "Input"],
  "."
}], "Text"],

Cell["\<\
Clear[imagefocus2];
imagefocus2 = FindFocalSurface[{
\tDistortionGrid[PointOfRays[0.25], {10, 10}, {7, 7}],
\tMove[PlanoConvexLens[80, 50,10], 200],
\tBoundary[350, GraphicDesign -> Off]
},
\tSingleRay -> False
];\
\>", "Input",
  GeneratedCell->False,
  CellTags->"FindImage"],

Cell["\<\
This plot shows multiple rays at each focal spot. These rays can \
offer information about spot sizes in addition to giving the focal positions.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[imagefocus2, PlotType->FrontView, RayLineRGB -> False, \
ShowComponents -> False];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499844 0.147765 0.500086 0.147765 [
[ 0 0 0 0 ]
[ 1 1.00017 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
2.5 Mabswid
.95923 .95947 Mdot
.95926 .96007 Mdot
.95975 .9592 Mdot
.95877 .95925 Mdot
.95938 .96069 Mdot
.96028 .95897 Mdot
.95838 .95911 Mdot
.96824 .81235 Mdot
.96844 .81275 Mdot
.96851 .81202 Mdot
.96786 .81234 Mdot
.96872 .81316 Mdot
.96881 .81172 Mdot
.96754 .8124 Mdot
.97364 .65802 Mdot
.97394 .65822 Mdot
.9737 .65769 Mdot
.97338 .65818 Mdot
.97432 .65843 Mdot
.97379 .65737 Mdot
.97316 .65838 Mdot
.97544 .50009 Mdot
.97577 .50009 Mdot
.97532 .49982 Mdot
.97532 .50035 Mdot
.97619 .50009 Mdot
.97524 .49953 Mdot
.97524 .50064 Mdot
.97364 .34215 Mdot
.97394 .34195 Mdot
.97338 .342 Mdot
.9737 .34248 Mdot
.97432 .34175 Mdot
.97316 .34179 Mdot
.97379 .3428 Mdot
.96824 .18782 Mdot
.96844 .18743 Mdot
.96786 .18783 Mdot
.96851 .18815 Mdot
.96872 .18701 Mdot
.96754 .18777 Mdot
.96881 .18845 Mdot
.95923 .0407 Mdot
.95926 .0401 Mdot
.95877 .04093 Mdot
.95975 .04097 Mdot
.95938 .03948 Mdot
.95838 .04106 Mdot
.96028 .0412 Mdot
.81214 .96852 Mdot
.812 .96892 Mdot
.81256 .96849 Mdot
.81191 .96824 Mdot
.81192 .96935 Mdot
.81298 .96852 Mdot
.81174 .96805 Mdot
.81815 .81839 Mdot
.81817 .81866 Mdot
.81838 .81827 Mdot
.81795 .8183 Mdot
.81826 .81895 Mdot
.81862 .81819 Mdot
.8178 .81827 Mdot
.82176 .66104 Mdot
.82188 .66118 Mdot
.82183 .66089 Mdot
.82161 .66108 Mdot
.82206 .66132 Mdot
.82192 .66076 Mdot
.82151 .66116 Mdot
.82296 .50009 Mdot
.82311 .50009 Mdot
.82291 .49996 Mdot
.82291 .50021 Mdot
.82333 .50009 Mdot
.82289 .49983 Mdot
.82289 .50034 Mdot
.82176 .33913 Mdot
.82188 .339 Mdot
.82161 .33909 Mdot
.82183 .33928 Mdot
.82206 .33885 Mdot
.82151 .33901 Mdot
.82192 .33941 Mdot
.81815 .18178 Mdot
.81817 .18151 Mdot
.81795 .18187 Mdot
.81838 .1819 Mdot
.81826 .18123 Mdot
.8178 .18191 Mdot
.81862 .18198 Mdot
.81214 .03165 Mdot
.812 .03125 Mdot
.81191 .03193 Mdot
.81256 .03168 Mdot
.81192 .03082 Mdot
.81174 .03213 Mdot
.81298 .03165 Mdot
.65779 .97393 Mdot
.65754 .97414 Mdot
.65809 .97409 Mdot
.65778 .97366 Mdot
.65733 .97438 Mdot
.65837 .97431 Mdot
.6578 .97346 Mdot
.6608 .82201 Mdot
.66072 .82215 Mdot
.66096 .82204 Mdot
.66076 .82189 Mdot
.66067 .8223 Mdot
.66112 .82212 Mdot
.66074 .82182 Mdot
.66261 .66285 Mdot
.66262 .66292 Mdot
.66267 .66283 Mdot
.66257 .66284 Mdot
.66267 .663 Mdot
.66273 .66282 Mdot
.66254 .66285 Mdot
.66321 .50009 Mdot
.66326 .50009 Mdot
.6632 .50005 Mdot
.6632 .50012 Mdot
.66333 .50009 Mdot
.66321 .50001 Mdot
.66321 .50016 Mdot
.66261 .33732 Mdot
.66262 .33725 Mdot
.66257 .33733 Mdot
.66267 .33735 Mdot
.66267 .33717 Mdot
.66254 .33732 Mdot
.66273 .33735 Mdot
.6608 .17816 Mdot
.66072 .17803 Mdot
.66076 .17828 Mdot
.66096 .17813 Mdot
.66067 .17787 Mdot
.66074 .17835 Mdot
.66112 .17805 Mdot
.65779 .02624 Mdot
.65754 .02603 Mdot
.65778 .02651 Mdot
.65809 .02608 Mdot
.65733 .02579 Mdot
.6578 .02671 Mdot
.65837 .02586 Mdot
.49984 .97572 Mdot
.49955 .97573 Mdot
.49998 .976 Mdot
.5 .9755 Mdot
.49926 .97577 Mdot
.50009 .97636 Mdot
.50019 .97536 Mdot
.49984 .8232 Mdot
.49971 .82321 Mdot
.4999 .82334 Mdot
.49992 .82312 Mdot
.49958 .82324 Mdot
.49994 .82352 Mdot
.50001 .82308 Mdot
.49984 .66345 Mdot
.49981 .66346 Mdot
.49986 .66349 Mdot
.49987 .66344 Mdot
.49978 .66347 Mdot
.49986 .66356 Mdot
.49989 .66345 Mdot
.49984 .50009 Mdot
.49984 .50009 Mdot
.49984 .50008 Mdot
.49984 .50009 Mdot
.49984 .50009 Mdot
.49984 .50009 Mdot
.49984 .50009 Mdot
.49984 .33672 Mdot
.49981 .33671 Mdot
.49987 .33673 Mdot
.49986 .33668 Mdot
.49978 .3367 Mdot
.49989 .33673 Mdot
.49986 .33661 Mdot
.49984 .17697 Mdot
.49971 .17696 Mdot
.49992 .17705 Mdot
.4999 .17683 Mdot
.49958 .17693 Mdot
.50001 .17709 Mdot
.49994 .17665 Mdot
.49984 .02446 Mdot
.49955 .02444 Mdot
.5 .02467 Mdot
.49998 .02417 Mdot
.49926 .0244 Mdot
.50019 .02481 Mdot
.50009 .02381 Mdot
.34191 .97388 Mdot
.34163 .9737 Mdot
.34186 .97423 Mdot
.34222 .97379 Mdot
.34133 .97355 Mdot
.34176 .97467 Mdot
.34253 .97376 Mdot
.33889 .82199 Mdot
.33878 .82187 Mdot
.33881 .82216 Mdot
.33905 .82199 Mdot
.33864 .82177 Mdot
.3387 .8224 Mdot
.33922 .82203 Mdot
.33708 .66285 Mdot
.33706 .66279 Mdot
.33701 .6629 Mdot
.33713 .66289 Mdot
.33702 .66274 Mdot
.33692 .66298 Mdot
.33718 .66295 Mdot
.33648 .50009 Mdot
.33649 .50009 Mdot
.33645 .50006 Mdot
.33645 .50011 Mdot
.33648 .50009 Mdot
.33641 .50005 Mdot
.33641 .50012 Mdot
.33708 .33732 Mdot
.33706 .33738 Mdot
.33713 .33728 Mdot
.33701 .33727 Mdot
.33702 .33743 Mdot
.33718 .33723 Mdot
.33692 .33719 Mdot
.33889 .17818 Mdot
.33878 .1783 Mdot
.33905 .17818 Mdot
.33881 .17801 Mdot
.33864 .1784 Mdot
.33922 .17814 Mdot
.3387 .17777 Mdot
.34191 .0263 Mdot
.34163 .02647 Mdot
.34222 .02638 Mdot
.34186 .02594 Mdot
.34133 .02662 Mdot
.34253 .02641 Mdot
.34176 .0255 Mdot
.18762 .96842 Mdot
.18742 .96805 Mdot
.18734 .96879 Mdot
.18804 .96851 Mdot
.18717 .96771 Mdot
.18701 .96925 Mdot
.18845 .96865 Mdot
.18156 .81837 Mdot
.18153 .81812 Mdot
.18132 .81852 Mdot
.18178 .81852 Mdot
.18144 .81789 Mdot
.18103 .81875 Mdot
.18199 .81869 Mdot
.17793 .66104 Mdot
.17799 .66092 Mdot
.17775 .66104 Mdot
.17798 .6612 Mdot
.17801 .6608 Mdot
.17753 .66108 Mdot
.17802 .66136 Mdot
.17672 .50009 Mdot
.17682 .50009 Mdot
.17664 .49998 Mdot
.17664 .50019 Mdot
.17686 .50009 Mdot
.17653 .4999 Mdot
.17653 .50028 Mdot
.17793 .33913 Mdot
.17799 .33925 Mdot
.17798 .33897 Mdot
.17775 .33913 Mdot
.17801 .33937 Mdot
.17802 .33882 Mdot
.17753 .33909 Mdot
.18156 .1818 Mdot
.18153 .18205 Mdot
.18178 .18166 Mdot
.18132 .18165 Mdot
.18144 .18228 Mdot
.18199 .18148 Mdot
.18103 .18142 Mdot
.18762 .03175 Mdot
.18742 .03212 Mdot
.18804 .03166 Mdot
.18734 .03138 Mdot
.18717 .03246 Mdot
.18845 .03152 Mdot
.18701 .03092 Mdot
.04057 .95936 Mdot
.04051 .95879 Mdot
.04005 .95968 Mdot
.04107 .95968 Mdot
.04037 .95826 Mdot
.03945 .9601 Mdot
.04155 .96005 Mdot
.03147 .81234 Mdot
.03158 .81196 Mdot
.03103 .81242 Mdot
.03171 .81269 Mdot
.0316 .8116 Mdot
.03052 .81258 Mdot
.03193 .81306 Mdot
.026 .65803 Mdot
.02621 .65784 Mdot
.02569 .65793 Mdot
.02603 .65836 Mdot
.02634 .65767 Mdot
.02531 .65787 Mdot
.02602 .65868 Mdot
.02418 .50009 Mdot
.02443 .50009 Mdot
.02402 .49984 Mdot
.02402 .50033 Mdot
.02459 .50009 Mdot
.02381 .49963 Mdot
.02381 .50054 Mdot
.026 .34214 Mdot
.02621 .34233 Mdot
.02603 .34182 Mdot
.02569 .34225 Mdot
.02634 .34251 Mdot
.02602 .3415 Mdot
.02531 .3423 Mdot
.03147 .18783 Mdot
.03158 .18821 Mdot
.03171 .18748 Mdot
.03103 .18775 Mdot
.0316 .18857 Mdot
.03193 .18711 Mdot
.03052 .18759 Mdot
.04057 .04082 Mdot
.04051 .04138 Mdot
.04107 .04049 Mdot
.04005 .04049 Mdot
.04037 .04191 Mdot
.04155 .04012 Mdot
.03945 .04007 Mdot
0 0 m
1 0 L
1 1.00017 L
0 1.00017 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421, 421.062},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006U0001YB000`400?l00000o`00003oo`3ooonV
0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV
0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00d03oool3
00000=80oooo002>0?ooo`<00000?`3oool300000400oooo0P00002@0?ooo`00SP3oool300000400
oooo0P0000100?ooo`800000T03oool004d0oooo0`00003o0?ooo`D0oooo0P00001?0?ooo`00C@3o
ool300000?l0oooo1@3oool2000004l0oooo001=0?ooo`<00000o`3oool50?ooo`800000C`3oool0
0?l0ooooYP3oool000l0oooo0`00003o0?oooh00oooo0`00000A0?ooo`003`3oool300000?l0oooo
P03oool300000140oooo000@0?ooo`800000o`3ooonD0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?oo
o`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?oo
o`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?oo
o`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?oo
o`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?oo
o`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?oo
o`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?oo
o`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?oo
o`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?oo
o`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?oo
o`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?oo
o`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00d@3oool200000=80oooo002=0?ooo`800000@P3oool2
00000440oooo0P00002?0?ooo`00B`3oool200000400oooo0P0000120?ooo`800000@@3oool20000
0400oooo0P00001=0?ooo`00B`3oool200000?l0oooo2P3oool3000004`0oooo001;0?ooo`800000
o`3oool:0?ooo`<00000C03oool000`0oooo0P00003o0?ooohP0oooo0`00000=0?ooo`00303oool2
00000?l0ooooR03oool3000000d0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo001:0?ooo`800000@03oool2000004<0
oooo0P0000120?ooo`800000SP3oool004T0oooo0`0000100?ooo`800000@`3oool200000480oooo
0P0000110?ooo`800000B`3oool000T0oooo0`00000m0?ooo`<00000o`3oool=0?ooo`800000?@3o
ool3000000/0oooo00090?ooo`<00000o`3ooon<0?ooo`<000002`3oool00?l0ooooYP3oool00?l0
ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0
ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0
ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0
ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0
ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0
ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0
ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0
ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0
ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0
ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0
ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0
ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool00?l0
ooooYP3oool00?l0ooooYP3oool00?l0ooooYP3oool000T0oooo0P00000n0?ooo`800000@@3oool2
000004<0oooo0P0000120?ooo`800000@@3oool3000003d0oooo0`00000:0?ooo`002@3oool20000
03h0oooo0P0000110?ooo`800000@`3oool200000480oooo0P0000110?ooo`<00000?@3oool30000
00X0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?oo
ojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?oo
ojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?oo
ojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?oo
ojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?oo
ojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?oo
ojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?oo
ojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?oo
ojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?oo
ojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?oo
ojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?oo
ojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?oo
ojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo00090?oo
o`<00000o`3ooon=0?ooo`8000002`3oool000T0oooo0`00003o0?oooh`0oooo0`00000;0?ooo`00
2P3oool2000003d0oooo0`00003o0?ooo`d0oooo0P00000m0?ooo`<000002`3oool004T0oooo0`00
00100?ooo`800000@`3oool200000480oooo0P0000110?ooo`800000B`3oool008`0oooo0P000013
0?ooo`800000@P3oool2000008h0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo
003o0?ooojH0oooo003o0?ooojH0oooo000<0?ooo`800000o`3ooon80?ooo`<000003@3oool000`0
oooo0P00003o0?ooohP0oooo0`00000=0?ooo`00303oool200000?l0ooooR03oool3000000d0oooo
001;0?ooo`800000o`3oool:0?ooo`<00000C03oool004/0oooo0P0000100?ooo`800000Q@3oool2
00000400oooo0`00001<0?ooo`00S@3oool200000480oooo0P0000110?ooo`800000S`3oool008d0
oooo0P0000120?ooo`800000@@3oool2000008l0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o
0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o
0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o
0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o
0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o
0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o
0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o
0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o
0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o
0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o
0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o
0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo000?0?ooo`<00000o`3ooon00?ooo`<00000
4@3oool000l0oooo0`00003o0?oooh00oooo0`00000A0?ooo`00o`3ooonC0?ooo`8000004@3oool0
0?l0ooooYP3oool004d0oooo0`00003o0?ooo`D0oooo0P00001?0?ooo`00C@3oool300000?l0oooo
1@3oool2000004l0oooo002>0?ooo`<00000PP3oool200000900oooo002>0?ooo`<00000?`3oool3
00000400oooo0P00002@0?ooo`00SP3oool200000400oooo0`00003B0?ooo`00o`3ooonV0?ooo`00
o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00
o`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 420}, {420.062, 0}} -> {-3.3828, -3.38437, \
0.0161136, 0.0161136}}]
}, Open  ]],

Cell["\<\
The amount of reported information is now much greater but perhaps \
less useful in most instances.\
\>", "Text"],

Cell[CellGroupData[{

Cell["ReadTurboRays[imagefocus, RayEnd]", "Input"],

Cell[BoxData[
    \({{331.7281038806663`, 3.1089069823070403`, 
        3.1089069823070403`}, {331.7278366932637`, 3.10910792599961`, 
        3.112919976975831`}, {331.72800126614493`, 3.112403894344556`, 
        3.107028452108694`}, {331.72839876749816`, 3.105800020411662`, 
        3.1073631451869046`}, {331.72751745267635`, 3.109928592215512`, 
        3.1171342043953842`}, {331.72786997919184`, 3.1160096278105454`, 
        3.105493306902207`}, {331.7286245858897`, 3.1031465512594796`, 
        3.10645512621085`}, {333.0692654820115`, 3.1698673460444953`, 
        2.113244897362997`}, {333.0690688947027`, 3.1711925750632077`, 
        2.1159256301332663`}, {333.06924301175775`, 3.1717052650787476`, 
        2.1110216446765335`}, {333.0694307486917`, 3.1672938857123594`, 
        2.1131803172725405`}, {333.0688274025782`, 3.1731390604161165`, 
        2.1187408827165157`}, {333.0692025415843`, 3.1737073798440796`, 
        2.1089795623970637`}, {333.06955132586506`, 3.165114901818278`, 
        2.113585313675125`}, {333.8764578832688`, 3.206428846767743`, 
        1.068809615589248`}, {333.876303952476`, 3.2084241429236577`, 
        1.0701515914159385`}, {333.87647897221296`, 3.2068298386573635`, 
        1.0666027021548063`}, {333.87654948769347`, 3.2046215281124444`, 
        1.0698707496173152`}, {333.8761093983635`, 3.211041606402649`, 
        1.0715609354671662`}, {333.8764857516193`, 3.207451438839272`, 
        1.0644151683498009`}, {333.8766135094022`, 3.2031501065048147`, 
        1.0712372657091498`}, {334.14593007566543`, 3.2186131512821605`, 
        0.`}, {334.14579041314596`, 3.220831043580353`, 
        0.`}, {334.145981370492`, 
        3.217798570525001`, \(-0.0018201712618658612`\)}, {334.145981370492`, 
        3.217798570525002`, 0.0018201712618657294`}, {334.14561155321104`, 
        3.223671405287515`, 0.`}, {334.14601516616415`, 
        3.2172618827924704`, \(-0.003782944168468791`\)}, \
{334.14601516616415`, 3.217261882792472`, 
        0.0037829441684683676`}, {333.8764578832689`, 
        3.206428846767748`, \(-1.06880961558925`\)}, {333.8763039524761`, 
        3.2084241429236635`, \(-1.0701515914159403`\)}, {333.8765494876936`, 
        3.20462152811245`, \(-1.0698707496173174`\)}, {333.876478972213`, 
        3.2068298386573693`, \(-1.066602702154808`\)}, {333.87610939836355`, 
        3.211041606402655`, \(-1.0715609354671682`\)}, {333.87661350940226`, 
        3.2031501065048196`, \(-1.0712372657091516`\)}, {333.87648575161944`, 
        3.2074514388392785`, \(-1.0644151683498022`\)}, {333.06926548201153`, 
        3.1698673460444984`, \(-2.1132448973629994`\)}, {333.06906889470275`, 
        3.171192575063211`, \(-2.115925630133268`\)}, {333.06943074869173`, 
        3.167293885712364`, \(-2.1131803172725414`\)}, {333.0692430117578`, 
        3.171705265078751`, \(-2.1110216446765353`\)}, {333.0688274025783`, 
        3.1731390604161196`, \(-2.1187408827165175`\)}, {333.0695513258651`, 
        3.165114901818281`, \(-2.113585313675128`\)}, {333.06920254158433`, 
        3.1737073798440836`, \(-2.1089795623970673`\)}, {331.7281038806662`, 
        3.1089069823070323`, \(-3.1089069823070323`\)}, {331.7278366932636`, 
        3.109107925999602`, \(-3.1129199769758236`\)}, {331.728398767498`, 
        3.105800020411654`, \(-3.1073631451868975`\)}, {331.72800126614476`, 
        3.1124038943445487`, \(-3.1070284521086866`\)}, {331.72751745267624`, 
        3.109928592215504`, \(-3.117134204395377`\)}, {331.7286245858896`, 
        3.1031465512594725`, \(-3.1064551262108426`\)}, {331.7278699791917`, 
        3.1160096278105343`, \(-3.105493306902199`\)}, {333.07366509727586`, 
        2.1134301474107087`, 3.170145221116062`}, {333.0735335711632`, 
        2.112485030038481`, 3.1728576300986306`}, {333.07355912362874`, 
        2.1162775836177063`, 3.1699247126277488`}, {333.073848815659`, 
        2.1119208463305963`, 3.1682427793566785`}, {333.07337182567846`, 
        2.1119610364550914`, 3.175767725132486`}, {333.07342724916174`, 
        2.1191374504609524`, 3.170105980665482`}, {333.0739811260011`, 
        2.1107639001073526`, 3.166919330113031`}, {334.4218502564432`, 
        2.154125942312604`, 2.1541259423126053`}, {334.4217671900116`, 
        2.1542941951995327`, 2.1559378792081794`}, {334.421817687157`, 
        2.155693069960999`, 2.153335221759056`}, {334.4219329882096`, 
        2.1527828129476596`, 2.153496859861213`}, {334.42166086915637`, 
        2.1548846334844702`, 2.1578819842659156`}, {334.4217722804787`, 
        2.15732787563053`, 2.1527828490027394`}, {334.4219860094334`, 
        2.1517344915407923`, 2.153281228031454`}, {335.2331950987417`, 
        2.1785313129709287`, 1.0892656564854644`}, {335.23314130668666`, 
        2.1793630239879285`, 1.0901727159436772`}, {335.2331946830705`, 
        2.1790397774329326`, 1.0882685906099485`}, {335.2332288106018`, 
        2.1775829317939537`, 1.0895514799846664`}, {335.23306843296245`, 
        2.1806175506907595`, 1.0911459715691472`}, {335.2331875053898`, 
        2.17967194197748`, 1.0873472507287019`}, {335.23324736308837`, 
        2.176871968173333`, 1.0900868669667685`}, {335.50404082050494`, 
        2.18666413501068`, 0.`}, {335.5039968196776`, 2.1877162289455123`, 
        0.`}, {335.50405463125384`, 
        2.186333909285161`, \(-0.0008295817506178277`\)}, \
{335.50405463125384`, 2.186333909285161`, 
        0.0008295817506177722`}, {335.50393512705045`, 2.189191347543143`, 
        0.`}, {335.5040609001444`, 
        2.186184015245982`, \(-0.001745871569987234`\)}, {335.5040609001444`, 
        2.186184015245982`, 0.0017458715699873728`}, {335.2331950987416`, 
        2.178531312970924`, \(-1.089265656485462`\)}, {335.23314130668655`, 
        2.1793630239879236`, \(-1.090172715943675`\)}, {335.2332288106017`, 
        2.177582931793949`, \(-1.0895514799846642`\)}, {335.2331946830704`, 
        2.179039777432928`, \(-1.088268590609946`\)}, {335.23306843296234`, 
        2.1806175506907546`, \(-1.0911459715691447`\)}, {335.23324736308825`, 
        2.1768719681733275`, \(-1.090086866966765`\)}, {335.2331875053897`, 
        2.179671941977477`, \(-1.0873472507286999`\)}, {334.42185025644324`, 
        2.1541259423126067`, \(-2.154125942312608`\)}, {334.4217671900117`, 
        2.1542941951995354`, \(-2.155937879208182`\)}, {334.4219329882097`, 
        2.1527828129476605`, \(-2.1534968598612156`\)}, {334.42181768715704`, 
        2.1556930699610017`, \(-2.1533352217590584`\)}, {334.4216608691564`, 
        2.154884633484473`, \(-2.1578819842659183`\)}, {334.42198600943345`, 
        2.151734491540796`, \(-2.1532812280314575`\)}, {334.42177228047876`, 
        2.157327875630532`, \(-2.152782849002743`\)}, {333.0736650972758`, 
        2.113430147410706`, \(-3.170145221116058`\)}, {333.0735335711631`, 
        2.1124850300384783`, \(-3.172857630098627`\)}, {333.07384881565895`, 
        2.111920846330593`, \(-3.168242779356675`\)}, {333.0735591236287`, 
        2.116277583617704`, \(-3.1699247126277452`\)}, {333.0733718256784`, 
        2.1119610364550887`, \(-3.1757677251324825`\)}, {333.07398112600106`, 
        2.1107639001073517`, \(-3.1669193301130276`\)}, {333.0734272491617`, 
        2.1191374504609497`, \(-3.17010598066548`\)}, {333.8817225503739`, 
        1.0689201994684012`, 3.2067605984052054`}, {333.8816692973165`, 
        1.0672371350523067`, 3.2081666558235353`}, {333.8816150894608`, 
        1.0709084962940982`, 3.2078030558837374`}, {333.8818420386634`, 
        1.0688111438515702`, 3.204900873116862`}, {333.8815990064757`, 
        1.0657788546071754`, 3.2097681460767786`}, {333.88148040665675`, 
        1.0728116562383219`, 3.209305857710361`}, {333.8819233497205`, 
        1.0689544150409445`, 3.2035628470388966`}, {335.2347667947752`, 
        1.0892985450855586`, 2.178597090171117`}, {335.2347395190613`, 
        1.0887233178636464`, 2.179536395894819`}, {335.2347335854937`, 
        1.0903845716709089`, 2.1788475383493005`}, {335.23480678759404`, 
        1.0889835804397545`, 2.1777990336027906`}, {335.2347020579991`, 
        1.0883734532939917`, 2.180606376395448`}, {335.2346886179374`, 
        1.0914409590164726`, 2.179393743802464`}, {335.2348277443463`, 
        1.0888644729144217`, 2.1773578726788925`}, {336.04899557268425`, 
        1.1015188790621129`, 1.1015188790621129`}, {336.0489839822337`, 
        1.1016037580456428`, 1.1019891075938815`}, {336.0489907855649`, 
        1.101924913163345`, 1.101342116986911`}, {336.04900378146124`, 
        1.101223596705277`, 1.101421014156921`}, {336.0489663125024`, 
        1.1019143431550296`, 1.1025247881852303`}, {336.04898268428735`, 
        1.1023573156673145`, 1.1012977132207795`}, {336.0490050450235`, 
        1.1010675854395087`, 1.1015165089715848`}, {336.3207971521784`, 
        1.105591066304096`, 0.`}, {336.32079080662214`, 1.105895205423184`, 
        0.`}, {336.3207982848447`, 
        1.1055367782112626`, \(-0.00022861800050332295`\)}, \
{336.3207982848447`, 1.1055367782112626`, 
        0.00022861800050331602`}, {336.3207797495595`, 1.1064251645262138`, 
        0.`}, {336.3207976915637`, 
        1.1055652138542096`, \(-0.0004877132987623489`\)}, \
{336.3207976915637`, 1.1055652138542102`, 
        0.00048771329876227953`}, {336.0489955726842`, 
        1.1015188790621118`, \(-1.1015188790621118`\)}, {336.04898398223366`, 
        1.1016037580456415`, \(-1.1019891075938801`\)}, {336.0490037814612`, 
        1.101223596705276`, \(-1.1014210141569194`\)}, {336.0489907855648`, 
        1.1019249131633433`, \(-1.1013421169869102`\)}, {336.04896631250233`, 
        1.1019143431550282`, \(-1.102524788185229`\)}, {336.0490050450234`, 
        1.1010675854395076`, \(-1.1015165089715835`\)}, {336.0489826842873`, 
        1.102357315667313`, \(-1.101297713220778`\)}, {335.23476679477517`, 
        1.0892985450855583`, \(-2.1785970901711167`\)}, {335.23473951906124`, 
        1.0887233178636462`, \(-2.179536395894818`\)}, {335.23480678759404`, 
        1.088983580439754`, \(-2.17779903360279`\)}, {335.2347335854937`, 
        1.0903845716709089`, \(-2.1788475383493005`\)}, {335.2347020579991`, 
        1.0883734532939915`, \(-2.1806063763954477`\)}, {335.2348277443463`, 
        1.0888644729144217`, \(-2.1773578726788925`\)}, {335.2346886179374`, 
        1.0914409590164726`, \(-2.179393743802464`\)}, {333.8817225503739`, 
        1.0689201994684012`, \(-3.2067605984052054`\)}, {333.8816692973165`, 
        1.0672371350523067`, \(-3.2081666558235353`\)}, {333.8818420386634`, 
        1.0688111438515708`, \(-3.204900873116862`\)}, {333.8816150894608`, 
        1.0709084962940982`, \(-3.2078030558837374`\)}, {333.8815990064757`, 
        1.0657788546071754`, \(-3.2097681460767786`\)}, {333.8819233497205`, 
        1.0689544150409442`, \(-3.2035628470388966`\)}, {333.88148040665675`, 
        1.0728116562383216`, \(-3.209305857710361`\)}, {334.14916818844546`, 
        0.`, 3.21881704520108`}, {334.1491620672636`, \
\(-0.0019990980563442708`\), 3.2189142517513414`}, {334.1490475671025`, 
        0.0009151931454007504`, 3.220732556645859`}, {334.1492578653752`, 
        0.0010837747537064835`, 
        3.2173929425254637`}, {334.149143701893`, \(-0.003968410256284312`\), 
        3.219205900535056`}, {334.14889426721874`, 0.0016464724710956828`, 
        3.223167015363911`}, {334.14931831751153`, 0.00232089619839658`, 
        3.216432940352595`}, {335.50501050360555`, 0.`, 
        2.186704686741381`}, {335.5050077851603`, \
\(-0.0008913036318855955`\), 2.186769686843963`}, {335.5049726118244`, 
        0.000389298786828236`, 2.187610708645218`}, {335.50503473679163`, 
        0.0005019472915573382`, 
        2.1861252524769883`}, {335.5049996290186`, \
\(-0.0017527346429607807`\), 2.186964706489318`}, {335.50491994640316`, 
        0.0006508080104785166`, 2.1888699797450486`}, {335.5050464201632`, 
        0.0011014660317154416`, 2.1858458940193213`}, {336.3209192174688`, 
        0.`, 1.1055936129177484`}, {336.320918538175`, \
\(-0.00023122647549837783`\), 1.1056261710928372`}, {336.3209137854613`, 
        0.00008740524295490319`, 1.1058539661302844`}, {336.32092124884343`, 
        0.0001438068924764866`, 
        1.1054962502277026`}, {336.32091650009363`, \
\(-0.00043252890559905555`\), 1.1057238552306525`}, {336.3209044076474`, 
        0.00010338787438799596`, 1.1063034397239557`}, {336.32092042321824`, 
        0.00032902621902353504`, 1.1055358220110532`}, {336.5932808922226`, 
        0.`, 0.`}, {336.59328089220196`, \(-0.000011976682504535874`\), 
        0.`}, {336.59328089223294`, 
        5.9883187894967105`*^-6, \(-0.000010372066224319243`\)}, \
{336.59328089223294`, 5.988318789519262`*^-6, 
        0.000010372066224312304`}, {336.5932808921813`, 
        5.9877697340740554`*^-6, 
        0.`}, {336.59328089224323`, \(-2.9939154197709816`*^-6\), 
        5.185601279843188`*^-6}, {336.59328089224323`, \
\(-2.993915419750165`*^-6\), \(-5.185601279912577`*^-6\)}, \
{336.32091921746877`, 
        0.`, \(-1.105593612917748`\)}, {336.320918538175`, \
\(-0.00023122647549839864`\), \(-1.105626171092837`\)}, {336.32092124884343`, 
        0.00014380689247642416`, \(-1.1054962502277026`\)}, \
{336.32091378546124`, 
        0.00008740524295490146`, \(-1.105853966130284`\)}, \
{336.32091650009363`, \(-0.0004325289055990972`\), \(-1.1057238552306523`\)}, \
{336.32092042321824`, 
        0.00032902621902341014`, \(-1.105535822011053`\)}, \
{336.32090440764733`, 
        0.00010338787438806535`, \(-1.1063034397239557`\)}, \
{335.50501050360555`, 
        0.`, \(-2.1867046867413804`\)}, {335.5050077851603`, \
\(-0.0008913036318856128`\), \(-2.1867696868439626`\)}, {335.50503473679163`, 
        0.0005019472915573243`, \(-2.1861252524769883`\)}, \
{335.5049726118244`, 
        0.00038929878682824465`, \(-2.187610708645218`\)}, \
{335.5049996290185`, \(-0.0017527346429608154`\), \(-2.1869647064893174`\)}, \
{335.5050464201632`, 
        0.0011014660317154833`, \(-2.1858458940193217`\)}, \
{335.50491994640316`, 
        0.0006508080104781627`, \(-2.1888699797450486`\)}, \
{334.14916818844546`, 
        0.`, \(-3.21881704520108`\)}, {334.1491620672636`, \
\(-0.0019990980563442777`\), \(-3.2189142517513414`\)}, {334.1492578653752`, 
        0.0010837747537065113`, \(-3.2173929425254633`\)}, \
{334.1490475671025`, 
        0.000915193145400707`, \(-3.220732556645859`\)}, {334.149143701893`, \
\(-0.003968410256284333`\), \(-3.219205900535056`\)}, {334.14931831751153`, 
        0.002320896198396611`, \(-3.2164329403525946`\)}, \
{334.14889426721874`, 
        0.0016464724710955267`, \(-3.2231670153639107`\)}, \
{333.8755030707422`, \(-1.0687895598343524`\), 
        3.2063686795030586`}, {333.87553972071146`, \(-1.0706777024656948`\), 
        3.205157725532464`}, {333.87534401299695`, \(-1.0691614520000154`\), 
        3.208768692885015`}, {333.87558423888123`, \(-1.0667259238907856`\), 
        3.2057685571030756`}, {333.8755606398985`, \(-1.072730607505648`\), 
        3.204141471666513`}, {333.87514260052836`, \(-1.0698172965313144`\), 
        3.211746153306624`}, {333.8756409622827`, \(-1.0646069256080675`\), 
        3.205574785466365`}, {335.232108257509`, \(-1.0892429137375619`\), 
        2.1784858274751238`}, {335.2321258967593`, \(-1.0900177580265604`\), 
        2.1776769549229575`}, {335.2320479910791`, \(-1.0897669522621678`\), 
        2.1796637395911542`}, {335.23213038623624`, \(-1.0881399480198906`\), 
        2.178508593977095`}, {335.23213463033346`, \(-1.090957778227244`\), 
        2.1769982755990993`}, {335.23196578962876`, \(-1.0905178119794272`\), 
        2.181252329302391`}, {335.23214233629443`, \(-1.0870370794905901`\), 
        2.1787745083890293`}, {336.0485091705307`, \(-1.1015087237778622`\), 
        1.1015087237778622`}, {336.04851529797065`, \(-1.1016201629815408`\), 
        1.1011038198884255`}, {336.04849317529386`, \(-1.101958064216879`\), 
        1.1018254515501127`}, {336.04851086834924`, \(-1.101143574118241`\), 
        1.1017925589386506`}, {336.04851660983473`, \(-1.1018970237133314`\), 
        1.1007641293573105`}, {336.04846850290164`, \(-1.102577123600116`\), 
        1.1023880399068606`}, {336.04850971298464`, \(-1.1008346287353281`\), 
        1.1021568388110208`}, {336.321040742742`, \(-1.105596148265174`\), 
        0.`}, {336.3210430153368`, \(-1.1054872240186993`\), 
        0.`}, {336.32103756662843`, \(-1.105748377679406`\), \
\(-0.00017187031117127383`\)}, {336.32103756662843`, \
\(-1.1057483776794053`\), 
        0.00017187031117131893`}, {336.32104183487803`, \
\(-1.1055438027742597`\), 
        0.`}, {336.32103203713166`, \(-1.1060134034860098`\), \
\(-0.00026138285422280805`\)}, {336.32103203713166`, \
\(-1.1060134034860096`\), 
        0.00026138285422278723`}, {336.04850917053074`, \
\(-1.1015087237778634`\), \(-1.1015087237778634`\)}, {336.0485152979707`, \
\(-1.1016201629815416`\), \(-1.1011038198884264`\)}, {336.0485108683493`, \
\(-1.1011435741182418`\), \(-1.101792558938652`\)}, {336.0484931752939`, \
\(-1.1019580642168796`\), \(-1.1018254515501131`\)}, {336.0485166098348`, \
\(-1.1018970237133323`\), \(-1.1007641293573116`\)}, {336.04850971298464`, \
\(-1.10083462873533`\), \(-1.1021568388110219`\)}, {336.0484685029017`, \
\(-1.1025771236001165`\), \(-1.1023880399068617`\)}, {335.2321082575092`, \
\(-1.089242913737566`\), \(-2.178485827475132`\)}, {335.2321258967595`, \
\(-1.0900177580265642`\), \(-2.1776769549229655`\)}, {335.23213038623646`, \
\(-1.088139948019895`\), \(-2.178508593977104`\)}, {335.23204799107936`, \
\(-1.0897669522621722`\), \(-2.179663739591163`\)}, {335.2321346303337`, \
\(-1.0909577782272475`\), \(-2.1769982755991077`\)}, {335.23214233629466`, \
\(-1.087037079490595`\), \(-2.178774508389039`\)}, {335.231965789629`, \
\(-1.0905178119794319`\), \(-2.1812523293023984`\)}, {333.87550307074207`, \
\(-1.0687895598343498`\), \(-3.2063686795030506`\)}, {333.87553972071134`, \
\(-1.0706777024656924`\), \(-3.205157725532456`\)}, {333.8755842388811`, \
\(-1.0667259238907818`\), \(-3.2057685571030685`\)}, {333.87534401299683`, \
\(-1.0691614520000137`\), \(-3.208768692885007`\)}, {333.87556063989837`, \
\(-1.0727306075056458`\), \(-3.2041414716665053`\)}, {333.8756409622826`, \
\(-1.0646069256080655`\), \(-3.205574785466358`\)}, {333.87514260052825`, \
\(-1.0698172965313122`\), \(-3.211746153306617`\)}, {333.0627293681496`, \
\(-2.112969687979449`\), 
        3.1694545319691727`}, {333.06283123031284`, \(-2.114323540610081`\), 
        3.166939274649187`}, {333.0624931902962`, \(-2.1148383352675393`\), 
        3.1719479513804236`}, {333.0628098786726`, \(-2.1101403171099054`\), 
        3.170066131007774`}, {333.06290555098616`, \(-2.116037138914222`\), 
        3.164620225671567`}, {333.06220063399843`, \(-2.117092307024506`\), 
        3.1750770752821653`}, {333.0628666159677`, \(-2.1073526153259796`\), 
        3.171026330063751`}, {334.41800699133034`, \(-2.15396473228488`\), 
        2.153964732284882`}, {334.41806784723303`, \(-2.154194231270317`\), 
        2.152284512147638`}, {334.4178931147609`, \(-2.15561533399998`\), 
        2.155028791624777`}, {334.4180270992029`, \(-2.1524768709721323`\), 
        2.1549732495169778`}, {334.4181080700464`, \(-2.154784397662118`\), 
        2.150735489122316`}, {334.4177459018305`, \(-2.157592732654833`\), 
        2.1565607470949186`}, {334.4180353163913`, \(-2.151086202126753`\), 
        2.156168031864592`}, {335.23367831424525`, \(-2.1785515360689276`\), 
        1.0892757680344638`}, {335.233714356643`, \(-2.178110942472343`\), 
        1.0884346504615492`}, {335.2336282101236`, \(-2.179753263909455`\), 
        1.0892665639492802`}, {335.23367188119954`, \(-2.178182111146352`\), 
        1.0903220243065912`}, {335.2337339056599`, \(-2.178031563851321`\), 
        1.087659247746187`}, {335.2335605362397`, \(-2.181223567953284`\), 
        1.0895597877061203`}, {335.23365851518963`, \(-2.177966311434012`\), 
        1.091392325467576`}, {335.505978069585`, \(-2.186745149934986`\), 
        0.`}, {335.5060058058404`, \(-2.1860819545518746`\), 
        0.`}, {335.5059560140773`, \(-2.187272514234702`\), \
\(-0.0007141697803122599`\)}, {335.5059560140773`, \(-2.187272514234702`\), 
        0.0007141697803122286`}, {335.5060184277149`, \
\(-2.1857801557407317`\), 
        0.`}, {335.5059251422983`, \(-2.1880106824218166`\), \
\(-0.0012896864758972712`\)}, {335.5059251422983`, \(-2.188010682421816`\), 
        0.0012896864758971532`}, {335.23367831424525`, \
\(-2.178551536068928`\), \(-1.089275768034464`\)}, {335.233714356643`, \
\(-2.178110942472343`\), \(-1.0884346504615494`\)}, {335.23367188119954`, \
\(-2.178182111146353`\), \(-1.0903220243065916`\)}, {335.2336282101236`, \
\(-2.1797532639094555`\), \(-1.0892665639492802`\)}, {335.2337339056599`, \
\(-2.1780315638513215`\), \(-1.087659247746187`\)}, {335.2336585151897`, \
\(-2.177966311434013`\), \(-1.091392325467576`\)}, {335.2335605362397`, \
\(-2.181223567953284`\), \(-1.0895597877061205`\)}, {334.4180069913304`, \
\(-2.1539647322848836`\), \(-2.1539647322848854`\)}, {334.4180678472331`, \
\(-2.1541942312703206`\), \(-2.1522845121476415`\)}, {334.41802709920296`, \
\(-2.152476870972136`\), \(-2.1549732495169813`\)}, {334.41789311476094`, \
\(-2.1556153339999837`\), \(-2.155028791624779`\)}, {334.41810807004646`, \
\(-2.1547843976621213`\), \(-2.1507354891223196`\)}, {334.4180353163914`, \
\(-2.1510862021267565`\), \(-2.1561680318645964`\)}, {334.4177459018306`, \
\(-2.1575927326548374`\), \(-2.156560747094923`\)}, {333.0627293681495`, \
\(-2.1129696879794473`\), \(-3.16945453196917`\)}, {333.0628312303128`, \
\(-2.1143235406100795`\), \(-3.1669392746491845`\)}, {333.0628098786726`, \
\(-2.110140317109904`\), \(-3.1700661310077716`\)}, {333.06249319029615`, \
\(-2.1148383352675375`\), \(-3.171947951380421`\)}, {333.0629055509861`, \
\(-2.1160371389142205`\), \(-3.164620225671565`\)}, {333.06286661596766`, \
\(-2.1073526153259783`\), \(-3.1710263300637482`\)}, {333.06220063399843`, \
\(-2.117092307024506`\), \(-3.175077075282163`\)}, {331.7153988173875`, \
\(-3.108101461271461`\), 
        3.108101461271461`}, {331.7156146470904`, \(-3.108510014498655`\), 
        3.104288956483937`}, {331.71503387135704`, \(-3.111667880086957`\), 
        3.11029077774829`}, {331.71547299244537`, \(-3.104717323153496`\), 
        3.110315749624074`}, {331.71578260271707`, \(-3.1094746272286216`\), 
        3.100675436743107`}, {331.7145939989246`, \(-3.115722421993194`\), 
        3.1131736706114834`}, {331.7155199805172`, \(-3.101470965899349`\), 
        3.1128210358371513`}, {333.06712569892744`, \(-3.169732199596025`\), 
        2.1131547997306837`}, {333.0672792045681`, \(-3.168999839095367`\), 
        2.1106078724374933`}, {333.06691378979815`, \(-3.172714841483189`\), 
        2.113713277240664`}, {333.0671303067424`, \(-3.168071450701357`\), 
        2.1155364960944887`}, {333.06739189483505`, \(-3.168824975095948`\), 
        2.1081939881873257`}, {333.06665276321206`, \(-3.1761252780883695`\), 
        2.1147965091991856`}, {333.06711722005326`, \(-3.166604455003`\), 
        2.1180477736092365`}, {333.8807634147622`, \(-3.2067001587224335`\), 
        1.0689000529074781`}, {333.88087921043797`, \(-3.2052876873380027`\), 
        1.0676250223255195`}, {333.8806422981184`, \(-3.208863064071373`\), 
        1.068177085999616`}, {333.880727507818`, \(-3.2065384823151164`\), 
        1.0710944295142164`}, {333.88095841982073`, \(-3.2044335664581634`\), 
        1.0664166280661531`}, {333.88049045257907`, \(-3.2113940291669296`\), 
        1.0678127866904683`}, {333.8806764642072`, \(-3.206627702222997`\), 
        1.0732566970937325`}, {334.15240180113665`, \(-3.219020655763358`\), 
        0.`}, {334.1525049742138`, \(-3.2173822292358536`\), 
        0.`}, {334.1523316854259`, \(-3.2201341191160804`\), \
\(-0.0016422934842050471`\)}, {334.1523316854259`, \(-3.2201341191160804`\), 
        0.0016422934842051165`}, {334.15257296965825`, \(-3.2163024364934256`\
\), 0.`}, {334.15224210871753`, \(-3.2215566302914116`\), \
\(-0.003089927629853273`\)}, {334.15224210871753`, \(-3.2215566302914116`\), 
        0.003089927629853405`}, {333.8807634147622`, \
\(-3.2067001587224304`\), \(-1.0689000529074772`\)}, {333.8808792104379`, \
\(-3.2052876873379996`\), \(-1.0676250223255184`\)}, {333.88072750781794`, \
\(-3.2065384823151146`\), \(-1.071094429514215`\)}, {333.88064229811835`, \
\(-3.2088630640713696`\), \(-1.0681770859996134`\)}, {333.8809584198207`, \
\(-3.2044335664581602`\), \(-1.0664166280661518`\)}, {333.88067646420717`, \
\(-3.2066277022229936`\), \(-1.0732566970937314`\)}, {333.880490452579`, \
\(-3.2113940291669274`\), \(-1.067812786690467`\)}, {333.0671256989274`, \
\(-3.1697321995960204`\), \(-2.1131547997306805`\)}, {333.067279204568`, \
\(-3.168999839095362`\), \(-2.11060787243749`\)}, {333.06713030674234`, \
\(-3.168071450701352`\), \(-2.1155364960944856`\)}, {333.0669137897981`, \
\(-3.1727148414831845`\), \(-2.1137132772406604`\)}, {333.067391894835`, \
\(-3.1688249750959434`\), \(-2.1081939881873226`\)}, {333.0671172200532`, \
\(-3.1666044550029957`\), \(-2.118047773609232`\)}, {333.066652763212`, \
\(-3.1761252780883638`\), \(-2.114796509199182`\)}, {331.71539881738755`, \
\(-3.108101461271466`\), \(-3.108101461271466`\)}, {331.7156146470905`, \
\(-3.10851001449866`\), \(-3.1042889564839418`\)}, {331.7154729924454`, \
\(-3.1047173231535012`\), \(-3.1103157496240783`\)}, {331.7150338713571`, \
\(-3.111667880086962`\), \(-3.1102907777482955`\)}, {331.7157826027171`, \
\(-3.109474627228626`\), \(-3.100675436743112`\)}, {331.7155199805173`, \
\(-3.1014709658993533`\), \(-3.1128210358371575`\)}, {331.71459399892467`, \
\(-3.1157224219931994`\), \(-3.1131736706114888`\)}}\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{878, 590},
WindowMargins->{{25, Automatic}, {Automatic, 61}},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3257567525-4308219"->{
    Cell[2120, 66, 1099, 15, 232, "Print",
      CellTags->"Info3257567525-4308219"]},
  "Info3257567535-1728977"->{
    Cell[72497, 1482, 624, 9, 127, "Print",
      CellTags->"Info3257567535-1728977"]},
  "FindImage"->{
    Cell[101662, 3108, 304, 10, 117, "Input",
      CellTags->"FindImage"],
    Cell[212609, 5711, 287, 11, 132, "Input",
      CellTags->"FindImage"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3257567525-4308219", 255717, 6633},
  {"Info3257567535-1728977", 255834, 6636},
  {"FindImage", 255939, 6639}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 306, 9, 48, "Text"],

Cell[CellGroupData[{
Cell[2085, 64, 32, 0, 27, "Input"],
Cell[2120, 66, 1099, 15, 232, "Print",
  CellTags->"Info3257567525-4308219"]
}, Open  ]],
Cell[3234, 84, 113, 4, 31, "Text"],

Cell[CellGroupData[{
Cell[3372, 92, 112, 4, 57, "Input"],
Cell[3487, 98, 27320, 489, 296, 2100, 173, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30844, 592, 121, 4, 57, "Input"],
Cell[30968, 598, 41356, 871, 296, 5242, 421, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[72339, 1472, 96, 4, 31, "Text"],

Cell[CellGroupData[{
Cell[72460, 1480, 34, 0, 27, "Input"],
Cell[72497, 1482, 624, 9, 127, "Print",
  CellTags->"Info3257567535-1728977"]
}, Open  ]],
Cell[73136, 1494, 54, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[73215, 1498, 195, 6, 87, "Input"],
Cell[73413, 1506, 27646, 1580, 118, 18687, 1465, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[101074, 3089, 149, 4, 31, "Text"],
Cell[101226, 3095, 411, 9, 48, "Text"],

Cell[CellGroupData[{
Cell[101662, 3108, 304, 10, 117, "Input",
  CellTags->"FindImage"],
Cell[101969, 3120, 41914, 1092, 366, 9120, 683, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[143898, 4215, 180, 5, 31, "Text"],

Cell[CellGroupData[{
Cell[144103, 4224, 89, 3, 27, "Input"],
Cell[144195, 4229, 37783, 827, 404, 6325, 434, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[181993, 5059, 117, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[182135, 5066, 135, 3, 42, "Input"],
Cell[182273, 5071, 8873, 183, 296, 1483, 87, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[191161, 5257, 197, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[191383, 5265, 141, 3, 42, "Input"],
Cell[191527, 5270, 16964, 363, 401, 3257, 190, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[208506, 5636, 280, 7, 47, "Text"],

Cell[CellGroupData[{
Cell[208811, 5647, 50, 0, 27, "Input"],
Cell[208864, 5649, 3512, 51, 221, "Output"]
}, Open  ]],
Cell[212391, 5703, 215, 6, 31, "Text"],
Cell[212609, 5711, 287, 11, 132, "Input",
  CellTags->"FindImage"],
Cell[212899, 5724, 170, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[213094, 5732, 117, 3, 27, "Input"],
Cell[213214, 5737, 15620, 491, 430, 7069, 381, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[228849, 6231, 123, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[228997, 6238, 50, 0, 27, "Input"],
Cell[229050, 6240, 25853, 371, 1620, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

