(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5550,        184]*)
(*NotebookOutlinePosition[      6260,        209]*)
(*  CellTagsIndexPosition[      6216,        205]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Create \".mx\" Files for Optica", "Section"],

Cell[TextData[{
  StyleBox["Reason for creating a new \".mx\" file:",
    FontVariations->{"Underline"->True}],
  "\nAll changes in Optica are masked by the \".mx\" file. To access the \
changes, the user must either create a new \".mx\" file or rename or remove a \
directory or file in the path Optica2.mx/$SystemID/Optica2.mx inside the \
Optica main directory $OpticaHome. \n",
  StyleBox["Backup:",
    FontVariations->{"Underline"->True}],
  "\nPlease move the \".mx\" file in a backup location before you start to \
create a new one. Then you can restore the original, if necessary.\n",
  StyleBox["System Dependency:",
    FontVariations->{"Underline"->True}],
  "\nPlease note that all \".mx\" files are operating system dependent and \
must be created independently for each system being used. The \".mx\" files \
created with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version 3 may also be used with version 4, but not vice versa.\n",
  StyleBox["Context:",
    FontVariations->{"Underline"->True}],
  "\nPlease execute the commands with the \"Global`\" context as actual one."
}], "Commentary"],

Cell["\<\
The time shown in the commands below was obtained on a Pentium II / \
233MHz under Linux.\
\>", "Text"],

Cell["First, load Optica as first input", "Text"],

Cell[CellGroupData[{

Cell["Needs[\"Optica2`Optica2`\"]", "Input",
  CellLabel->"In[1]:="],

Cell["+++++++++++++++++++++++++", "Print",
  CellLabel->"From In[1]:="],

Cell[BoxData[
    \("Optica version 2.1 was loaded in 88 s and needs 5099 kilobytes of \
memory on top of 2341 kilobytes already used"\)], "Print"]
}, Open  ]],

Cell["\<\
Some special caches may be created with RestoreOpticaCache that may \
take some time:\
\>", "Text"],

Cell[CellGroupData[{

Cell["Timing[RestoreOpticaCache[]]", "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \({64.4600000000000061`\ Second, Null}\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell["\<\
These caches do not affect any results, only the calculation time \
can be shorter. Part of these caches are the objects being used in the \
\"Elements\" palette of Optica.\
\>", "Text"],

Cell["\<\
Set directory to correct location (should exist and be emptied \
before)\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
PackageHomeDirectory[$OpticaContext]
Fold[ToFileName, %, {ExtractFileName[%]<>\".mx\", $SystemID}]
SetDirectory[%]\
\>", "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \("/usr/local/mathematica/AddOns/Applications/Optica2"\)], "Output",
  CellLabel->"Out[3]="],

Cell[BoxData[
    \("/usr/local/mathematica/AddOns/Applications/Optica2/Optica2.mx/Linux"\)]\
, "Output",
  CellLabel->"Out[4]="],

Cell[BoxData[
    \("/usr/local/mathematica/AddOns/Applications/Optica2/Optica2.mx/Linux"\)]\
, "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
  "Now an \".mx\" file is created. We include definitions made for symbols in \
the \"System`\" context. The selection is necessary, because some symbols are \
\"System`\" symbols in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version 4, but not in version 3 (in version 3, they are in the Optica \
developer context)."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Timing[With[{savelist=
\tFlatten[{Map[
\t\tIf[Length[Names[#]]>0 && 
\t\t\tContext[#]===\"System`\", #, {}]&, 
\t\t$SystemSymbolsInPackage
\t], \"Optica2`\", \"Graphics`Graphics3D`\"}]
},
\tDumpSave[\"Optica2.mx\", savelist]
];]\
\>", "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \({96.2400000000000055`\ Second, Null}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell["\<\
From now on, the new \".mx\" file is available in the operating \
system, where it was created. Loading time is less than 1.5 seconds.\
\>", 
  "Text"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1600}, {0, 1200}},
ScreenStyleEnvironment->"AllBrackets",
WindowSize->{520, 600},
WindowMargins->{{109, Automatic}, {Automatic, 235}},
StyleDefinitions -> "Manual.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 50, 0, 72, "Section"],
Cell[1784, 53, 1123, 22, 304, "Commentary"],
Cell[2910, 77, 113, 3, 32, "Text"],
Cell[3026, 82, 49, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[3100, 86, 68, 1, 27, "Input"],
Cell[3171, 89, 71, 1, 23, "Print"],
Cell[3245, 92, 147, 2, 55, "Print"]
}, Open  ]],
Cell[3407, 97, 109, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[3541, 104, 69, 1, 27, "Input"],
Cell[3613, 107, 94, 2, 27, "Output"]
}, Open  ]],
Cell[3722, 112, 196, 4, 50, "Text"],
Cell[3921, 118, 96, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[4042, 125, 163, 5, 57, "Input"],
Cell[4208, 132, 110, 2, 27, "Output"],
Cell[4321, 136, 129, 3, 43, "Output"],
Cell[4453, 141, 129, 3, 43, "Output"]
}, Open  ]],
Cell[4597, 147, 362, 8, 86, "Text"],

Cell[CellGroupData[{
Cell[4984, 159, 277, 11, 147, "Input"],
Cell[5264, 172, 94, 2, 27, "Output"]
}, Open  ]],
Cell[5373, 177, 161, 4, 50, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

